@@ -22,8 +22,11 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-from stoqlib.database.orm import IntCol, UnicodeCol, ForeignKey
-from stoqlib.database.orm import LeftJoin, Join, Viewable
+from storm.expr import LeftJoin, Join
+from storm.references import Reference
+
+from stoqlib.database.properties import IntCol, UnicodeCol
+from stoqlib.database.viewable import Viewable
 from stoqlib.domain.base import Domain
 from stoqlib.domain.person import Person
 from stoqlib.domain.product import Product
@@ -40,7 +43,10 @@ class BookPublisher(Domain):
     statuses = {STATUS_ACTIVE: _(u'Active'),
                 STATUS_INACTIVE: _(u'Inactive')}
 
-    person = ForeignKey('Person')
+    __storm_table__ = 'book_publisher'
+
+    person_id = IntCol()
+    person = Reference(person_id, 'Person.id')
     status = IntCol(default=STATUS_ACTIVE)
 
     #
@@ -69,58 +75,55 @@ class BookPublisher(Domain):
 
 
 class PublisherView(Viewable):
-    columns = dict(
-        id=Person.q.id,
-        publisher_id=BookPublisher.q.id,
-        name=Person.q.name,
-        status=BookPublisher.q.status,
-    )
+    publiser = BookPublisher
 
-    joins = [
-        Join(BookPublisher,
-                    Person.q.id == BookPublisher.q.person_id),
+    id=Person.id,
+    name=Person.name,
+    publisher_id=BookPublisher.id,
+    status=BookPublisher.status,
+
+    tables = [
+        Person,
+        Join(BookPublisher, Person.id == BookPublisher.person_id),
     ]
 
-    @property
-    def publisher(self):
-        return BookPublisher.get(self.publisher_id,
-                                 connection=self.get_connection())
-
 
 class Book(Domain):
     """ A book class for products, holding specific data about books  """
-    product = ForeignKey('Product')
-    publisher = ForeignKey('BookPublisher', default=None)
-    author = UnicodeCol(default='')
-    series = UnicodeCol(default='')
-    edition = UnicodeCol(default='')
-    subject = UnicodeCol(default='')
-    isbn = UnicodeCol(default='')
-    language = UnicodeCol(default='')
-    decorative_finish = UnicodeCol(default='')
+
+    __storm_table__ = 'book'
+
+    product_id = IntCol()
+    product = Reference(product_id, 'Product.id')
+    publisher_id = IntCol(default=None)
+    publisher = Reference(publisher_id, 'BookPublisher.id')
+    author = UnicodeCol(default=u'')
+    series = UnicodeCol(default=u'')
+    edition = UnicodeCol(default=u'')
+    subject = UnicodeCol(default=u'')
+    isbn = UnicodeCol(default=u'')
+    language = UnicodeCol(default=u'')
+    decorative_finish = UnicodeCol(default=u'')
     country = UnicodeCol(default=u'Brazil')
     pages = IntCol(default=0)
     year = IntCol(default=0)
-    synopsis = UnicodeCol(default='')
+    synopsis = UnicodeCol(default=u'')
 
 
 class ProductBookFullStockView(ProductFullStockView):
-    columns = ProductFullStockView.columns.copy()
-    columns.update(dict(
-        publisher=Person.q.name,
-        author=Book.q.author,
-        series=Book.q.series,
-        edition=Book.q.edition,
-        subject=Book.q.subject,
-        isbn=Book.q.isbn,
-        language=Book.q.language,
-        pages=Book.q.pages,
-    ))
-    joins = ProductFullStockView.joins[:]
-    joins.extend([
-        Join(Book,
-                    Book.q.product_id == Product.q.id),
-        LeftJoin(Person,
-                   Person.q.id == Book.q.publisher_id),
+    publisher = Person.name
+    author = Book.author
+    series = Book.series
+    edition = Book.edition
+    subject = Book.subject
+    isbn = Book.isbn
+    language = Book.language
+    pages = Book.pages
+
+    tables = ProductFullStockView.tables[:]
+    tables.extend([
+        Join(Book, Book.product_id == Product.id),
+        LeftJoin(Person, Person.id == Book.publisher_id),
     ])
+
     clause = ProductFullStockView.clause
