@@ -26,7 +26,7 @@ import gtk
 
 from kiwi.log import Logger
 
-from stoqlib.database.runtime import get_connection
+from stoqlib.database.runtime import get_default_store
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.editors.producteditor import ProductEditor
 from stoqlib.gui.events import (StartApplicationEvent, StopApplicationEvent,
@@ -45,7 +45,7 @@ log = Logger("stoq-books-plugin")
 class BooksUI(object):
     def __init__(self):
         self._ui = None
-        self.conn = get_connection()
+        self.default_store = get_default_store()
         StartApplicationEvent.connect(self._on_StartApplicationEvent)
         StopApplicationEvent.connect(self._on_StopApplicationEvent)
         EditorSlaveCreateEvent.connect(self._on_EditorSlaveCreateEvent)
@@ -127,9 +127,9 @@ class BooksUI(object):
         uimanager.remove_ui(self._ui)
         self._ui = None
 
-    def _add_product_slave(self, editor, model, conn):
+    def _add_product_slave(self, editor, model, store):
         editor.add_extra_tab(ProductBookSlave.title,
-                             ProductBookSlave(conn, model))
+                             ProductBookSlave(store, model))
 
     #
     # Events
@@ -146,24 +146,24 @@ class BooksUI(object):
     def _on_StopApplicationEvent(self, appname, app):
         self._remove_app_ui(app.main_window.uimanager)
 
-    def _on_EditorSlaveCreateEvent(self, editor, model, conn, *args):
+    def _on_EditorSlaveCreateEvent(self, editor, model, store, *args):
         # Use type() instead of isinstance so tab does
         # not appear on production product editor
         if not type(editor) is ProductEditor:
             return
 
-        self._add_product_slave(editor, model, conn)
+        self._add_product_slave(editor, model, store)
 
     #
     # Callbacks
     #
 
     def _on_BookSearch__activate(self, action):
-        run_dialog(ProductBookSearch, None, self.conn, hide_price_column=True)
+        run_dialog(ProductBookSearch, None, self.default_store, hide_price_column=True)
 
     def _on_BookSearchView__activate(self, action):
-        run_dialog(ProductBookSearch, None, self.conn, hide_cost_column=True,
+        run_dialog(ProductBookSearch, None, self.default_store, hide_cost_column=True,
                    hide_toolbar=True)
 
     def _on_Publishers__activate(self, action):
-        run_dialog(PublisherSearch, None, self.conn, hide_footer=True)
+        run_dialog(PublisherSearch, None, self.default_store, hide_footer=True)
