@@ -42,13 +42,12 @@ class PublisherEditor(BasePersonRoleEditor):
     model_type = BookPublisher
     gladefile = 'BaseTemplate'
 
-    def create_model(self, conn):
-        person = BasePersonRoleEditor.create_model(self, conn)
-        publisher = BookPublisher.selectOneBy(person=person,
-                                              connection=conn)
+    def create_model(self, store):
+        person = BasePersonRoleEditor.create_model(self, store)
+        publisher = store.find(BookPublisher, person=person).one()
         if publisher is None:
             publisher = BookPublisher(person=person,
-                                      connection=conn)
+                                      store=store)
         return publisher
 
 
