@@ -31,9 +31,10 @@ from zope.interface import implements
 from stoqdrivers.enum import TaxType, UnitType
 from stoqdrivers.exceptions import (DriverError, CouponNotOpenError,
                                     CancelItemError)
+from storm.expr import Desc
 
-from stoqlib.database.runtime import new_transaction
-from stoqlib.database.orm import const
+from stoqlib.database.expr import TransactionTimestamp
+from stoqlib.database.runtime import new_store
 from stoqlib.domain.devices import FiscalDayHistory, FiscalDayTax
 from stoqlib.domain.interfaces import IContainer
 from stoqlib.exceptions import DeviceError
@@ -189,16 +190,16 @@ class CouponPrinter(object):
         if type == ECFDocumentHistory.TYPE_Z_REDUCTION:
             crz = self._driver.get_crz() + 1
 
-        trans = new_transaction()
-        printer = trans.get(self._printer)
-        doc = ECFDocumentHistory(connection=trans,
+        store = new_store()
+        printer = store.fetch(self._printer)
+        doc = ECFDocumentHistory(store=store,
                                  printer=printer,
                                  type=type,
                                  coo=coo,
                                  gnf=gnf,
                                  crz=crz)
 
-        trans.commit(close=True)
+        store.commit(close=True)
         return doc
 
     def _update_sintegra_data(self):
@@ -206,7 +207,7 @@ class CouponPrinter(object):
         if data is None:
             return
 
-        trans = new_transaction()
+        store = new_store()
         # coupon_start and coupon_end are actually, start coo, and current coo.
         coupon_start = data.coupon_start
         coupon_end = data.coupon_end
@@ -214,9 +215,9 @@ class CouponPrinter(object):
         # the current coo from the the database and add 1
         # TODO: try to avoid this hack
         if coupon_start == 0:
-            results = FiscalDayHistory.selectBy(
-                station=self._printer.station,
-                connection=trans).orderBy('-emission_date')
+            results = store.find(FiscalDayHistory,
+                                 station=self._printer.station).order_by(
+                                 Desc(FiscalDayHistory.emission_date))
             if results.count():
                 coupon_start = results[0].coupon_end + 1
             else:
@@ -224,29 +225,29 @@ class CouponPrinter(object):
 
         # Something went wrong or no coupons opened during the day
         if coupon_end <= coupon_start:
-            trans.commit(close=True)
+            store.commit(close=True)
             return
 
-        station = trans.get(self._printer.station)
-        day = FiscalDayHistory(connection=trans,
+        station = store.fetch(self._printer.station)
+        day = FiscalDayHistory(store=store,
                                emission_date=data.opening_date,
                                station=station,
-                               serial=data.serial,
+                               serial=unicode(data.serial),
                                # 1 -> 001, FIXME: should fix stoqdrivers
                                serial_id=int(data.serial_id),
                                coupon_start=coupon_start,
                                coupon_end=coupon_end,
                                crz=data.crz,
                                cro=data.cro,
-                               reduction_date=const.NOW(),
+                               reduction_date=TransactionTimestamp(),
                                period_total=data.period_total,
                                total=data.total)
 
         for code, value, type in data.taxes:
             FiscalDayTax(fiscal_day_history=day,
-                         code=code, value=value,
-                         type=type, connection=trans)
-        trans.commit(close=True)
+                         code=unicode(code), value=value,
+                         type=unicode(type), store=store)
+        store.commit(close=True)
 
     def get_printer(self):
         return self._printer
@@ -412,13 +413,13 @@ class Coupon(object):
         return coupon_id
 
     def _create_fiscal_sale_data(self, sale):
-        trans = sale.get_connection()
+        store = sale.store
         FiscalSaleHistory(sale=sale,
                           document_type=self._customer_document_type,
                           document=self._customer_document,
                           coo=self.get_coo(),
                           document_counter=self.get_ccf(),
-                          connection=trans)
+                          store=store)
 
     def get_ccf(self):
         return self._driver.get_ccf()
