@@ -32,8 +32,9 @@ from serial import SerialException
 from kiwi.log import Logger
 from kiwi.python import Settable
 from stoqdrivers.exceptions import CouponOpenError, DriverError
-from stoqlib.database.runtime import (get_current_station, get_connection,
-                                      new_transaction)
+from stoqlib.database.runtime import (get_current_station,
+                                      get_default_store,
+                                      new_store)
 from stoqlib.domain.events import (SaleStatusChangedEvent, TillAddCashEvent,
                                    TillRemoveCashEvent, TillOpenEvent,
                                    TillCloseEvent, TillAddTillEntryEvent,
@@ -69,7 +70,7 @@ log = Logger("stoq-ecf-plugin")
 class ECFUI(object):
     def __init__(self):
         self._ui = None
-        self.conn = get_connection()
+        self.default_store = get_default_store()
         self._printer_verified = False
         # Delay printer creation until we are accessing pos or till app. Other
         # applications should still be accessible without a printer
@@ -109,9 +110,9 @@ class ECFUI(object):
         if self._printer:
             return self._printer
 
-        station = get_current_station(self.conn)
-        printer = ECFPrinter.selectOneBy(station=station, is_active=True,
-                                         connection=self.conn)
+        station = get_current_station(self.default_store)
+        printer = self.default_store.find(ECFPrinter, station=station,
+                                          is_active=True).one()
         if not printer:
             return None
 
@@ -178,7 +179,7 @@ class ECFUI(object):
         self._ui = uimanager.add_ui_from_string(ui_string)
 
     def _add_pos_menus(self, uimanager):
-        if sysparam(self.conn).POS_SEPARATE_CASHIER:
+        if sysparam(self.default_store).POS_SEPARATE_CASHIER:
             return
 
         ui_string = """<ui>
@@ -297,7 +298,7 @@ class ECFUI(object):
 
         printer = self._printer.get_printer()
 
-        if (sysparam(self.conn).ENABLE_PAULISTA_INVOICE and not
+        if (sysparam(self.default_store).ENABLE_PAULISTA_INVOICE and not
             (printer.user_number and printer.register_date and
              printer.register_cro)):
             response = warning(
@@ -336,12 +337,12 @@ class ECFUI(object):
                 # XXX: Make sure this is tested
                 day = till.opening_date
 
-            dir = sysparam(self.conn).CAT52_DEST_DIR.path
+            dir = sysparam(self.default_store).CAT52_DEST_DIR.path
             dir = os.path.expanduser(dir)
             if not os.path.exists(dir):
                 os.mkdir(dir)
 
-            generator = StoqlibCATGenerator(self.conn, day, printer)
+            generator = StoqlibCATGenerator(self.default_store, day, printer)
             generator.write(dir)
 
         self._reset_last_doc()
@@ -350,7 +351,7 @@ class ECFUI(object):
 
     def _needs_cat52(self, printer):
         # If the param is not enabled, we dont need.
-        if not sysparam(self.conn).ENABLE_PAULISTA_INVOICE:
+        if not sysparam(self.default_store).ENABLE_PAULISTA_INVOICE:
             return False
 
         # Even if the parameter is enabled, we can only generate cat52 for
@@ -364,23 +365,23 @@ class ECFUI(object):
 
         return True
 
-    def _set_last_sale(self, sale, trans):
-        printer = trans.get(self._printer._printer)
+    def _set_last_sale(self, sale, store):
+        printer = store.fetch(self._printer._printer)
         printer.last_sale = sale
         printer.last_till_entry = None
 
-    def _set_last_till_entry(self, till_entry, trans):
-        printer = trans.get(self._printer._printer)
+    def _set_last_till_entry(self, till_entry, store):
+        printer = store.fetch(self._printer._printer)
         printer.last_till_entry = till_entry
         printer.last_sale = None
 
     def _reset_last_doc(self):
         # Last ecf document is not a sale or a till_entry anymore.
-        trans = new_transaction()
-        printer = trans.get(self._printer._printer)
+        store = new_store()
+        printer = store.fetch(self._printer._printer)
         printer.last_till_entry = None
         printer.last_sale = None
-        trans.commit()
+        store.commit()
 
     def _add_cash(self, till, value):
         log.info('ECFCouponPrinter.add_cash(%r, %r)' % (till, value, ))
@@ -431,10 +432,10 @@ class ECFUI(object):
             fiscalcoupon.connect_object(signal, callback, coupon)
         return coupon
 
-    def _get_last_document(self, trans):
+    def _get_last_document(self, store):
         printer = self._printer.get_printer()
         return ECFPrinter.get_last_document(station=printer.station,
-                                            conn=trans)
+                                            store=store)
 
     def _confirm_last_document_cancel(self, last_doc):
         if last_doc.last_sale is None and last_doc.last_till_entry is None:
@@ -458,8 +459,8 @@ class ECFUI(object):
         return yesno(msg, gtk.RESPONSE_NO, _("Cancel Last Document"),
                      _("Not now"))
 
-    def _cancel_last_till_entry(self, last_doc, trans):
-        till_entry = trans.get(last_doc.last_till_entry)
+    def _cancel_last_till_entry(self, last_doc, store):
+        till_entry = store.fetch(last_doc.last_till_entry)
         try:
             self._printer.cancel_last_coupon()
             if till_entry.value > 0:
@@ -473,12 +474,12 @@ class ECFUI(object):
             info(_("Cancelling failed, nothing to cancel"))
             return
 
-    def _cancel_last_sale(self, last_doc, trans):
+    def _cancel_last_sale(self, last_doc, store):
         if last_doc.last_sale.status == Sale.STATUS_RETURNED:
             return
-        sale = trans.get(last_doc.last_sale)
+        sale = store.fetch(last_doc.last_sale)
         returned_sale = sale.create_sale_return_adapter()
-        returned_sale.reason = _("Cancelling last document on ECF")
+        returned_sale.reason = _(u"Cancelling last document on ECF")
         returned_sale.return_()
         last_doc.last_sale = None
         info(_("Document was cancelled"))
@@ -490,29 +491,29 @@ class ECFUI(object):
             warning(str(e))
             return
 
-        trans = new_transaction()
-        last_doc = self._get_last_document(trans)
+        store = new_store()
+        last_doc = self._get_last_document(store)
         if not self._confirm_last_document_cancel(last_doc):
-            trans.close()
+            store.close()
             return
 
         if last_doc.last_till_entry:
-            self._cancel_last_till_entry(last_doc, trans)
+            self._cancel_last_till_entry(last_doc, store)
         elif last_doc.last_sale:
             # Verify till balance before cancel the last sale.
-            till = Till.get_current(trans)
+            till = Till.get_current(store)
             if last_doc.last_sale.total_amount > till.get_balance():
                 warning(_("You do not have this value on till."))
-                trans.close()
+                store.close()
                 return
             cancelled = self._printer.cancel()
             if not cancelled:
                 info(_("Cancelling sale failed, nothing to cancel"))
-                trans.close()
+                store.close()
                 return
             else:
-                self._cancel_last_sale(last_doc, trans)
-        trans.commit()
+                self._cancel_last_sale(last_doc, store)
+        store.commit()
 
     def _till_summarize(self):
         try:
@@ -530,7 +531,7 @@ class ECFUI(object):
         except DeviceError, e:
             warning(str(e))
             return
-        retval = run_dialog(FiscalMemoryDialog, None, self.conn, self._printer)
+        retval = run_dialog(FiscalMemoryDialog, None, self.default_store, self._printer)
         if retval:
             self._reset_last_doc()
 
@@ -554,7 +555,7 @@ class ECFUI(object):
                             document=document)
 
     def _identify_customer(self, coupon, sale=None):
-        if not sysparam(self.conn).ENABLE_PAULISTA_INVOICE:
+        if not sysparam(self.default_store).ENABLE_PAULISTA_INVOICE:
             return
 
         model = None
@@ -566,7 +567,7 @@ class ECFUI(object):
         if model:
             initial_client_document = model.document
 
-        model = run_dialog(PaulistaInvoiceDialog, self, self.conn, model)
+        model = run_dialog(PaulistaInvoiceDialog, self, self.default_store, model)
 
         # User cancelled the dialog or the document didn't change.
         if not model or model.document == initial_client_document:
@@ -587,10 +588,10 @@ class ECFUI(object):
     def _on_SaleStatusChanged(self, sale, old_status):
         if sale.status == Sale.STATUS_CONFIRMED:
             self._confirm_sale(sale)
-            self._set_last_sale(sale, sale.get_connection())
+            self._set_last_sale(sale, sale.store)
 
     def _on_ECFIsLastSale(self, sale):
-        last_doc = self._get_last_document(sale.get_connection())
+        last_doc = self._get_last_document(sale.store)
         return last_doc.last_sale == sale
 
     def _on_TillOpen(self, till):
@@ -608,8 +609,8 @@ class ECFUI(object):
     def _on_CouponCreatedEvent(self, coupon):
         self._coupon_create(coupon)
 
-    def _on_AddTillEntry(self, till_entry, trans):
-        self._set_last_till_entry(till_entry, trans)
+    def _on_AddTillEntry(self, till_entry, store):
+        self._set_last_till_entry(till_entry, store)
 
     def _on_HasPendingReduceZ(self):
         return self._has_pending_reduce()
