@@ -25,11 +25,12 @@
 import datetime
 
 from kiwi.log import Logger
+from storm.references import Reference
 from twisted.internet.defer import inlineCallbacks, returnValue, maybeDeferred
 from twisted.web.xmlrpc import Fault
 
-from stoqlib.database.orm import BoolCol, IntCol, ForeignKey, AND
-from stoqlib.database.runtime import new_transaction, finish_transaction
+from stoqlib.database.properties import BoolCol, IntCol
+from stoqlib.database.runtime import new_store
 from stoqlib.domain.base import Domain
 from stoqlib.lib.translation import stoqlib_gettext
 
@@ -62,7 +63,22 @@ class MagentoBase(Domain):
     keep_need_sync = False
     magento_id = IntCol(default=None)
     need_sync = BoolCol(default=True)
-    config = ForeignKey('MagentoConfig')
+    config_id = IntCol()
+    config = Reference(config_id, 'MagentoConfig.id')
+
+    #
+    #  Domain hooks
+    #
+
+    def __init__(self, **kwargs):
+        if not self.__class__.API_NAME:
+            raise ValueError("The class %s must implement API_NAME "
+                             "attribute." % self.__class__.__name__)
+        if not self.__class__.API_ID_NAME:
+            raise ValueError("The class %s must implement API_ID_NAME "
+                             "attribute." % self.__class__.__name__)
+
+        super(MagentoBase, self).__init__(**kwargs)
 
     #
     #  Properties
@@ -92,20 +108,18 @@ class MagentoBase(Domain):
         @returns: C{True} if all sync went well, C{False} otherwise
         """
         retval_list = list()
-        trans = new_transaction()
+        store = new_store()
 
         table_config = config.get_table_config(cls)
         if table_config.need_ensure_config:
-            retval = yield cls.ensure_config(trans.get(config))
+            retval = yield cls.ensure_config(store.fetch(config))
             if not retval:
                 returnValue(False)
 
             table_config.need_ensure_config = not retval
-            finish_transaction(trans, retval)
+            store.confirm(retval)
 
-        for obj in cls.select(connection=trans,
-                              clause=AND(cls.q.config_id == config.id,
-                                         cls.q.need_sync == True)):
+        for obj in store.find(cls, config=config, need_sync=True):
             retval = yield maybeDeferred(obj.process)
             retval_list.append(retval)
 
@@ -115,7 +129,7 @@ class MagentoBase(Domain):
             # if they need to.
             obj.keep_need_sync = False
 
-            finish_transaction(trans, retval)
+            store.confirm(retval)
 
         if retval_list:
             objs_ok = len([retval for retval in retval_list if retval])
@@ -127,7 +141,7 @@ class MagentoBase(Domain):
                 print (_("    %s: %d records synchronized.") %
                        (cls.__name__, objs_ok))
 
-        trans.close()
+        store.close()
         returnValue(not retval_list or all(retval_list))
 
     @classmethod
@@ -214,20 +228,6 @@ class MagentoBase(Domain):
         # Returning instead of raising to allow super logic.
         return NotImplementedError
 
-    #
-    #  Domain hooks
-    #
-
-    def _init(self, *args, **kwargs):
-        if not self.__class__.API_NAME:
-            raise ValueError("The class %s must implement API_NAME "
-                             "attribute." % self.__class__.__name__)
-        if not self.__class__.API_ID_NAME:
-            raise ValueError("The class %s must implement API_ID_NAME "
-                             "attribute." % self.__class__.__name__)
-
-        super(MagentoBase, self)._init(*args, **kwargs)
-
 
 class MagentoBaseSyncUp(MagentoBase):
     """A :class:`MagentoBase` that syncs from Stoq => Magento"""
@@ -347,8 +347,8 @@ class MagentoBaseSyncDown(MagentoBase):
 
         @returns: C{True} if all sync went well, C{False} otherwise
         """
-        trans = new_transaction()
-        table_config = trans.get(config.get_table_config(cls))
+        store = new_store()
+        table_config = store.fetch(config.get_table_config(cls))
 
         last_sync_date = table_config.last_sync_date
         filters = {
@@ -360,11 +360,10 @@ class MagentoBaseSyncDown(MagentoBase):
         if mag_records:
             for mag_record in mag_records:
                 magento_id = mag_record[cls.API_ID_NAME]
-                obj = cls.selectOneBy(connection=trans,
-                                      config=config,
-                                      magento_id=magento_id)
+                obj = store.find(cls, config=config,
+                                 magento_id=magento_id).one()
                 if not obj:
-                    obj = cls(connection=trans,
+                    obj = cls(store=store,
                               config=config,
                               magento_id=magento_id)
 
@@ -377,9 +376,9 @@ class MagentoBaseSyncDown(MagentoBase):
                                                     datetime.datetime.min))
 
             table_config.last_sync_date = last_sync_date
-            finish_transaction(trans, True)
+            store.confirm(True)
 
-        trans.close()
+        store.close()
         retval = yield super(MagentoBaseSyncDown, cls).synchronize(config)
         returnValue(retval)
 
