@@ -25,9 +25,11 @@
 import datetime
 import decimal
 
-from stoqlib.database.orm import (DecimalCol, IntCol, UnicodeCol, DateTimeCol,
-                                  BoolCol, ForeignKey)
-from stoqlib.database.runtime import get_current_branch, new_transaction
+from storm.references import Reference
+
+from stoqlib.database.properties import (DecimalCol, IntCol, UnicodeCol, DateTimeCol,
+                                  BoolCol)
+from stoqlib.database.runtime import get_current_branch, new_store
 from stoqlib.domain.base import Domain
 from stoqlib.domain.person import Employee, Individual, Person, SalesPerson
 from stoqlib.domain.sellable import Sellable, SellableCategory
@@ -51,77 +53,75 @@ class MagentoConfig(Domain):
     @ivar root_category: the id of the root category on magento
     """
 
+    __storm_table__ = 'magento_config'
+
     url = UnicodeCol()
     api_user = UnicodeCol(default='')
     api_key = UnicodeCol(default='')
 
     tz_hours = DecimalCol(default=decimal.Decimal(0))
     qty_days_as_new = IntCol(default=45)
-    branch = ForeignKey('Branch')
-    salesperson = ForeignKey('SalesPerson')
+    branch_id = IntCol()
+    branch = Reference(branch_id, 'Branch.id')
+    salesperson_id = IntCol()
+    salesperson = Reference(salesperson_id, 'SalesPerson.id')
 
     default_product_set = IntCol(default=None)
     root_category = IntCol(default=None)
 
+    def __init__(self, store=None, **kwargs):
+        if not 'salesperson' in kwargs:
+            kwargs['salesperson'] = self._create_salesperson()
+        if not 'branch' in kwargs:
+            kwargs['branch'] = get_current_branch(store)
+
+        super(MagentoConfig, self).__init__(store=store, **kwargs)
+
     #
     #  Public API
     #
 
     def get_table_config(self, klass):
-        conn = self.get_connection()
+        store = self.store
         name = klass.__name__
-        table_config = MagentoTableConfig.selectOneBy(connection=conn,
-                                                      config=self,
-                                                      magento_table=name)
+        table_config = store.find(MagentoTableConfig, config=self,
+                                  magento_table=name).one()
         if not table_config:
-            trans = new_transaction()
-            MagentoTableConfig(connection=trans,
-                               config=trans.get(self),
+            store = new_store()
+            MagentoTableConfig(store=store,
+                               config=store.fetch(self),
                                magento_table=name)
-            trans.commit(close=True)
-            # We created the obj. Now the selectOneBy above will work
+            store.commit(close=True)
+            # We created the obj. Now the find().one() above will work
             return self.get_table_config(klass)
 
         return table_config
 
-    #
-    #  ORMObject hooks
-    #
-
-    def _create(self, *args, **kwargs):
-        conn = self.get_connection()
-        if not 'salesperson' in kwargs:
-            kwargs['salesperson'] = self._create_salesperson()
-        if not 'branch' in kwargs:
-            kwargs['branch'] = get_current_branch(conn)
-
-        super(MagentoConfig, self)._create(*args, **kwargs)
-
     #
     #  AbstractDomain hooks
     #
 
     def on_create(self):
         from magentoproduct import MagentoProduct, MagentoCategory
-        conn = self.get_connection()
-        sysparam_ = sysparam(conn)
+        store = self.store
+        sysparam_ = sysparam(store)
 
         # When commiting, ensure we known all products to synchronize using the
         # server registered on self. Events should take care of creating others
-        for sellable in Sellable.select(connection=conn):
+        for sellable in store.find(Sellable):
             if sellable.service == sysparam_.DELIVERY_SERVICE:
                 # Do not sync delivery service
                 continue
 
             # Just need to create. All other information will be synchronized
             # on MagentoProduct.synchronize
-            mag_product = MagentoProduct(connection=conn,
+            mag_product = MagentoProduct(store=store,
                                          sellable=sellable,
                                          config=self)
             assert mag_product
         # Like products above, ensure we know all categories to synchronize.
-        for category in SellableCategory.select(connection=conn):
-            mag_category = MagentoCategory(connection=conn,
+        for category in store.find(SellableCategory):
+            mag_category = MagentoCategory(store=store,
                                            category=category,
                                            config=self)
             assert mag_category
@@ -131,28 +131,28 @@ class MagentoConfig(Domain):
     #
 
     def _create_salesperson(self):
-        conn = self.get_connection()
-        old_magento_configs = MagentoConfig.select(connection=conn)
+        store = self.store
+        old_magento_configs = store.find(MagentoConfig)
         if len(list(old_magento_configs)):
             # Try to reuse the salesperson of the already existing
             # MagentoConfig. Probably it's the one we create bellow
             return old_magento_configs[0].salesperson
 
-        sysparam_ = sysparam(conn)
+        sysparam_ = sysparam(store)
         name = _("Magento e-commerce")
         occupation = _("E-commerce software")
         role = sysparam_.DEFAULT_SALESPERSON_ROLE
 
-        person = Person(connection=conn,
+        person = Person(store=store,
                         name=name)
         Individual(person=person,
                    occupation=occupation,
-                   connection=conn)
+                   store=store)
         Employee(person=person,
                  role=role,
-                 connection=conn)
+                 store=store)
 
-        return SalesPerson(person=person, connection=conn)
+        return SalesPerson(person=person, store=store)
 
 
 class MagentoTableConfig(Domain):
@@ -162,7 +162,10 @@ class MagentoTableConfig(Domain):
     @ivar magento_table: the name of the table associated with this config
     """
 
-    config = ForeignKey('MagentoConfig')
+    __storm_table__ = 'magento_table_config'
+
+    config_id = IntCol()
+    config = Reference(config_id, 'MagentoConfig.id')
     magento_table = UnicodeCol()
     last_sync_date = DateTimeCol(default=datetime.datetime.min)
     need_ensure_config = BoolCol(default=True)
