@@ -27,12 +27,13 @@ import urllib
 
 from dateutil.relativedelta import relativedelta
 from kiwi.log import Logger
+from storm.expr import In
+from storm.references import Reference, ReferenceSet
 from twisted.internet.defer import inlineCallbacks, returnValue
 from twisted.web.xmlrpc import Fault
 
-from stoqlib.database.orm import (IntCol, UnicodeCol, DateTimeCol, BoolCol,
-                                  ForeignKey, SingleJoin, MultipleJoin, IN)
-from stoqlib.database.runtime import get_connection
+from stoqlib.database.properties import IntCol, UnicodeCol, DateTimeCol, BoolCol
+from stoqlib.database.runtime import get_default_store
 from stoqlib.domain.image import Image
 
 from domain.magentobase import MagentoBaseSyncUp
@@ -45,6 +46,8 @@ log = Logger('plugins.magento.domain.magentoproduct')
 class MagentoProduct(MagentoBaseSyncUp):
     """Class for products synchronization between Stoq and Magento"""
 
+    __storm_table__ = 'magento_product'
+
     API_NAME = 'product'
     API_ID_NAME = 'product_id'
 
@@ -83,13 +86,14 @@ class MagentoProduct(MagentoBaseSyncUp):
     url_key = UnicodeCol(default=None)
     news_from_date = DateTimeCol(default=None)
     news_to_date = DateTimeCol(default=None)
-    magento_category = ForeignKey('MagentoCategory', default=None)
-    sellable =  ForeignKey('Sellable')
+    magento_category_id = IntCol(default=None)
+    magento_category = Reference(magento_category_id, 'MagentoCategory.id')
+    sellable_id = IntCol()
+    sellable = Reference(sellable_id, 'Sellable.id')
 
-    magento_stock = SingleJoin('MagentoStock',
-                               joinColumn='magento_product_id')
-    magento_images = MultipleJoin('MagentoImage',
-                                  joinColumn='magento_product_id')
+    magento_stock = Reference('id', 'MagentoStock.magento_product_id',
+                              on_remote=True)
+    magento_images = ReferenceSet('id', 'MagentoImage.magento_product_id')
 
     #
     #  Properties
@@ -167,7 +171,7 @@ class MagentoProduct(MagentoBaseSyncUp):
             self.magento_id = retval
 
         if retval:
-            MagentoStock(connection=self.get_connection(),
+            MagentoStock(store=self.store,
                          magento_id=self.magento_id,
                          config=self.config,
                          magento_product=self)
@@ -212,13 +216,13 @@ class MagentoProduct(MagentoBaseSyncUp):
                             "product on magento: %s" % err.faultString)
                 returnValue(False)
 
-        conn = self.get_connection()
+        store = self.store
         mag_stock = self.magento_stock
         if mag_stock:
-            mag_stock.delete(mag_stock.id, conn)
+            mag_stock.delete(mag_stock.id, store)
         for mag_image in self.magento_images:
-            mag_image.delete(mag_image.id, conn)
-        self.delete(self.id, conn)
+            mag_image.delete(mag_image.id, store)
+        self.delete(self.id, store)
 
         returnValue(retval)
 
@@ -227,7 +231,7 @@ class MagentoProduct(MagentoBaseSyncUp):
     #
 
     def _update_category(self, category):
-        conn = self.get_connection()
+        store = self.store
         mag_category = self.magento_category
 
         if mag_category and mag_category.category == category:
@@ -237,9 +241,8 @@ class MagentoProduct(MagentoBaseSyncUp):
             # Make sure we will remove the product from the category
             mag_category.need_sync = True
 
-        mag_category = MagentoCategory.selectOneBy(connection=conn,
-                                                   config=self.config,
-                                                   category=category)
+        mag_category = store.find(MagentoCategory, config=self.config,
+                                  category=category).one()
         self.magento_category = mag_category
         self.magento_category.need_sync = True
 
@@ -314,13 +317,16 @@ class MagentoProduct(MagentoBaseSyncUp):
 class MagentoStock(MagentoBaseSyncUp):
     """Class for product stock synchronization between Stoq and Magento"""
 
+    __storm_table__ = 'magento_stock'
+
     API_NAME = 'product_stock'
     API_ID_NAME = MagentoProduct.API_ID_NAME
 
     (ERROR_STOCK_PRODUCT_NOT_EXISTS,
      ERROR_STOCK_NOT_UPDATED) = range(101, 103)
 
-    magento_product = ForeignKey('MagentoProduct')
+    magento_product_id = IntCol()
+    magento_product = Reference(magento_product_id, 'MagentoProduct.id')
 
     #
     #  MagentoBase hooks
@@ -331,10 +337,10 @@ class MagentoStock(MagentoBaseSyncUp):
     def list_remote(cls, config, *args, **kwargs):
         args = list(args)
         if not args:
+            store = get_default_store()
             # If this is not an info call, mimic the list api behavior
             args.append([mag_stock.magento_id for mag_stock in
-                         cls.selectBy(connection=get_connection(),
-                                      config=config)])
+                         store.find(cls, config=config)])
 
         retval = yield super(MagentoStock, cls).list_remote(config, *args,
                                                             **kwargs)
@@ -401,6 +407,8 @@ class MagentoStock(MagentoBaseSyncUp):
 class MagentoImage(MagentoBaseSyncUp):
     """Class for product image synchronization between Stoq and Magento"""
 
+    __storm_table__ = 'magento_image'
+
     API_NAME = 'product_media'
     API_ID_NAME = MagentoProduct.API_ID_NAME
 
@@ -417,11 +425,13 @@ class MagentoImage(MagentoBaseSyncUp):
     TYPE_SMALL_IMAGE = 'small_image'
     TYPE_THUMBNAIL = 'thumbnail'
 
-    image = ForeignKey('Image')
+    image_id = IntCol()
+    image = Reference(image_id, 'Image.id')
     filename = UnicodeCol(default='')
     is_main = BoolCol(default=False)
     visible = BoolCol(default=True)
-    magento_product = ForeignKey('MagentoProduct')
+    magento_product_id = IntCol()
+    magento_product = Reference(magento_product_id, 'MagentoProduct.id')
 
     #
     #  MagentoBaseSyncUp hooks
@@ -499,7 +509,7 @@ class MagentoImage(MagentoBaseSyncUp):
                             "product's image on magento: %s" % err.faultString)
                 returnValue(False)
 
-        self.delete(self.id, self.get_connection())
+        self.delete(self.id, self.store)
 
         returnValue(retval)
 
@@ -523,6 +533,8 @@ class MagentoImage(MagentoBaseSyncUp):
 class MagentoCategory(MagentoBaseSyncUp):
     """Class for product category synchronization between Stoq and Magento"""
 
+    __storm_table__ = 'magento_category'
+
     API_NAME = 'category'
     API_ID_NAME = 'category_id'
 
@@ -535,12 +547,21 @@ class MagentoCategory(MagentoBaseSyncUp):
      ERROR_CATEGORY_PRODUCT_NOT_ASSIGNED) = range(100, 107)
 
     is_active = BoolCol(default=None)
-    category = ForeignKey('SellableCategory')
+    category_id = IntCol()
+    category = Reference(category_id, 'SellableCategory.id')
     description = UnicodeCol(default=None)
     meta_keywords = UnicodeCol(default=None)
 
-    magento_products = MultipleJoin('MagentoProduct',
-                                    joinColumn='magento_category_id')
+    magento_products = ReferenceSet('id', 'MagentoProduct.magento_category_id')
+
+    def __init__(self, store=None, **kw):
+        if not 'is_active' in kw:
+            category = kw['category']
+            # By default, if the category has a parent, that parent
+            # will dictate it's activeness. Otherwise, it's True.
+            kw['is_active'] = None if category.category else True
+
+        super(MagentoCategory, self).__init__(store=store, **kw)
 
     #
     #  Properties
@@ -548,8 +569,8 @@ class MagentoCategory(MagentoBaseSyncUp):
 
     @property
     def parent(self):
-        return MagentoCategory.selectOneBy(connection=self.get_connection(),
-                                           category=self.category.category)
+        return self.store.find(MagentoCategory,
+                                     category=self.category.category).one()
 
     #
     #  Classmethods
@@ -700,7 +721,7 @@ class MagentoCategory(MagentoBaseSyncUp):
 
     @inlineCallbacks
     def update_remote(self):
-        conn = self.get_connection()
+        store = self.store
         data = [self.magento_id, self._get_data()]
 
         try:
@@ -731,10 +752,8 @@ class MagentoCategory(MagentoBaseSyncUp):
 
             # Deassign products not listed on self anymore
             if assigned_ids:
-                for mag_product in MagentoProduct.select(
-                    connection=conn,
-                    clause=IN(MagentoProduct.q.magento_id, assigned_ids),
-                    ):
+                for mag_product in store.find(MagentoProduct,
+                    clause=In(MagentoProduct.magento_id, assigned_ids)):
                     mag_product.need_sync = True
                     retval_ = yield self.remove_product_remote(mag_product)
                     retval_list.append(retval_)
@@ -757,19 +776,6 @@ class MagentoCategory(MagentoBaseSyncUp):
 
         returnValue(retval)
 
-    #
-    #  Domain hooks
-    #
-
-    def _create(self, id, **kw):
-        if not 'is_active' in kw:
-            category = kw['category']
-            # By default, if the category has a parent, that parent
-            # will dictate it's activeness. Otherwise, it's True.
-            kw['is_active'] = None if category.category else True
-
-        super(MagentoCategory, self)._create(id, **kw)
-
     #
     #  Private
     #
