@@ -23,12 +23,12 @@
 ##
 
 from kiwi.log import Logger
+from storm.references import Reference
 from twisted.internet.defer import (inlineCallbacks, returnValue,
                                     maybeDeferred)
 from twisted.web.xmlrpc import Fault
 
-from stoqlib.database.orm import (IntCol, UnicodeCol, BoolCol, ForeignKey,
-                                  SingleJoin)
+from stoqlib.database.properties import UnicodeCol, BoolCol, IntCol
 from stoqlib.domain.payment.group import PaymentGroup
 from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.sale import Sale, Delivery
@@ -46,6 +46,8 @@ log = Logger('plugins.magento.domain.magentosale')
 class MagentoSale(MagentoBaseSyncBoth):
     """Class for sale synchronization between Stoq and Magento"""
 
+    __storm_table__ = 'magento_sale'
+
     API_NAME = 'order'
     API_ID_NAME = 'increment_id'
 
@@ -64,15 +66,18 @@ class MagentoSale(MagentoBaseSyncBoth):
     STATUS_PENDING_PAYMENT = 'pending_payment'
 
     status = UnicodeCol(default=STATUS_NEW)
-    sale = ForeignKey('Sale', default=None)
+    sale_id = IntCol(default=None)
+    sale = Reference(sale_id, 'Sale.id')
     can_deliver = BoolCol(default=False)
-    magento_client = ForeignKey('MagentoClient', default=None)
-    magento_address = ForeignKey('MagentoAddress', default=None)
+    magento_client_id = IntCol(default=None)
+    magento_client = Reference(magento_client_id, 'MagentoClient.id')
+    magento_address_id = IntCol(default=None)
+    magento_address = Reference(magento_address_id, 'MagentoAddress.id')
 
-    magento_invoice = SingleJoin('MagentoInvoice',
-                                 joinColumn='magento_sale_id')
-    magento_delivery = SingleJoin('MagentoShipment',
-                                  joinColumn='magento_sale_id')
+    magento_invoice = Reference('id', 'MagentoInvoice.magento_sale_id',
+                                on_remote=True)
+    magento_delivery = Reference('id', 'MagentoShipment.magento_sale_id',
+                                 on_remote=True)
 
     #
     #  Public API
@@ -140,14 +145,13 @@ class MagentoSale(MagentoBaseSyncBoth):
     def create_local(self, info):
         assert self.need_create_local()
 
-        conn = self.get_connection()
-        sysparam_ = sysparam(conn)
+        store = self.store
+        sysparam_ = sysparam(store)
 
         if not self.magento_client:
             mag_client_id = info[MagentoClient.API_ID_NAME]
-            mag_client = MagentoClient.selectOneBy(connection=conn,
-                                                   config=self.config,
-                                                   magento_id=mag_client_id)
+            mag_client = store.find(MagentoClient, config=self.config,
+                                    magento_id=mag_client_id).one()
             if not mag_client:
                 log.error("Unexpected error: Could not find the magento "
                           "client by id %s. It should be synchronized "
@@ -163,12 +167,12 @@ class MagentoSale(MagentoBaseSyncBoth):
         branch = self.config.branch
         salesperson = self.config.salesperson
         operation_nature = sysparam_.DEFAULT_OPERATION_NATURE
-        group = PaymentGroup(connection=conn)
+        group = PaymentGroup(store=store)
         open_date = info['created_at']
         total_amount = info['grand_total']
         notes = _("Magento sale #%s\n") % self.magento_id
 
-        self.sale = Sale(connection=conn,
+        self.sale = Sale(store=store,
                          client=client,
                          branch=branch,
                          salesperson=salesperson,
@@ -180,9 +184,8 @@ class MagentoSale(MagentoBaseSyncBoth):
                          coupon_id=None)
 
         for item in info['items']:
-            mag_product = MagentoProduct.selectOneBy(connection=conn,
-                                                     config=self.config,
-                                                     sku=item['sku'])
+            mag_product = store.find(MagentoProduct, config=self.config,
+                                     sku=item['sku']).one()
             if not mag_product:
                 log.error("Unexpected error: Could not find the magento "
                           "product by sku %s. It should be synchronized "
@@ -207,7 +210,7 @@ class MagentoSale(MagentoBaseSyncBoth):
             self.sale.add_sellable(delivery_service.sellable,
                                    price=delivery_price)
 
-        method = PaymentMethod.get_by_name(conn, 'online')
+        method = PaymentMethod.get_by_name(store, 'online')
         # Till needs to be None, or else, it will try to get the current one,
         # which doesn't exists on daemon
         method.create_inpayment(group, info['grand_total'], till=None)
@@ -217,15 +220,12 @@ class MagentoSale(MagentoBaseSyncBoth):
         return self.update_local(info)
 
     def update_local(self, info):
-        conn = self.get_connection()
+        store = self.store
         if self.can_deliver and not self.magento_address:
             mag_address_id = (info['shipping_address']['customer_address_id'] or
                               info['billing_address']['customer_address_id'])
-            mag_address = MagentoAddress.selectOneBy(
-                connection=conn,
-                config=self.config,
-                magento_id=mag_address_id,
-                )
+            mag_address = store.find(MagentoAddress, config=self.config,
+                                     magento_id=mag_address_id).one()
             if not mag_address:
                 log.error("Unexpected error: Could not find the magento "
                           "address by id %s. It should be synchronized "
@@ -249,12 +249,12 @@ class MagentoSale(MagentoBaseSyncBoth):
     @inlineCallbacks
     def update_remote(self):
         assert not self.need_create_local()
-        conn = self.get_connection()
+        store = self.store
 
         if self.sale.status == Sale.STATUS_PAID:
             if not self.magento_invoice:
                 # Just creating. It'll be syncronized soon
-                MagentoInvoice(connection=conn,
+                MagentoInvoice(store=store,
                                config=self.config,
                                magento_sale=self)
             if self.can_deliver:
@@ -280,8 +280,8 @@ class MagentoSale(MagentoBaseSyncBoth):
         if self.magento_delivery:
             return True
 
-        conn = self.get_connection()
-        sysparam_ = sysparam(conn)
+        store = self.store
+        sysparam_ = sysparam(store)
         sale_items = set(self.sale.get_items())
 
         service_item = None
@@ -296,14 +296,14 @@ class MagentoSale(MagentoBaseSyncBoth):
                 sale_items.remove(item)
                 continue
 
-        delivery = Delivery(connection=conn,
+        delivery = Delivery(store=store,
                             address=self.magento_address.address,
                             service_item=service_item,
                             transporter=self.sale.transporter)
         for item in sale_items:
             delivery.add_item(item)
 
-        mag_delivery = MagentoShipment(connection=conn,
+        mag_delivery = MagentoShipment(store=store,
                                        config=self.config,
                                        magento_sale=self,
                                        delivery=delivery)
@@ -314,6 +314,8 @@ class MagentoSale(MagentoBaseSyncBoth):
 class MagentoInvoice(MagentoBaseSyncBoth):
     """Class for sale invoice synchronization between Stoq and Magento"""
 
+    __storm_table__ = 'magento_invoice'
+
     API_NAME = 'order_invoice'
     API_ID_NAME = 'increment_id'
 
@@ -329,7 +331,8 @@ class MagentoInvoice(MagentoBaseSyncBoth):
 
     status = IntCol(default=STATUS_OPEN)
     can_void = BoolCol(default=False)
-    magento_sale = ForeignKey('MagentoSale', default=None)
+    magento_sale_id = IntCol(default=None)
+    magento_sale = Reference(magento_sale_id, 'MagentoSale.id')
 
     #
     #  Public API
@@ -403,11 +406,10 @@ class MagentoInvoice(MagentoBaseSyncBoth):
         return not self.magento_sale
 
     def create_local(self, info):
-        conn = self.get_connection()
+        store = self.store
         mag_sale_id = info['order_increment_id']
-        mag_sale = MagentoSale.selectOneBy(connection=conn,
-                                           config=self.config,
-                                           magento_id=mag_sale_id)
+        mag_sale = store.find(MagentoSale, config=self.config,
+                              magento_id=mag_sale_id).one()
         if not mag_sale:
             log.error("Unexpected error: Could not find the magento sale by "
                       "id %s. It should be synchronized at this point" %
@@ -494,6 +496,8 @@ class MagentoInvoice(MagentoBaseSyncBoth):
 class MagentoShipment(MagentoBaseSyncUp):
     """Class for sale shipment synchronization between Stoq and Magento"""
 
+    __storm_table__ = 'magento_shipment'
+
     API_NAME = 'order_shipment'
     API_ID_NAME = 'increment_id'
 
@@ -505,8 +509,10 @@ class MagentoShipment(MagentoBaseSyncUp):
      ERROR_SHIPMENT_TRACKING_NOT_DELETED) = range(100, 106)
 
     was_track_added = BoolCol(default=False)
-    delivery = ForeignKey('Delivery')
-    magento_sale = ForeignKey('MagentoSale', default=None)
+    delivery_id = IntCol()
+    delivery = Reference(delivery_id, 'Delivery.id')
+    magento_sale_id = IntCol(default=None)
+    magento_sale = Reference(magento_sale_id, 'MagentoSale.id')
 
     #
     #  Public API
