@@ -38,7 +38,7 @@ from twisted.internet.task import LoopingCall
 from zope.interface import implements
 
 from stoqlib.database.migration import PluginSchemaMigration
-from stoqlib.database.runtime import get_connection
+from stoqlib.database.runtime import get_default_store
 from stoqlib.domain.events import (ProductCreateEvent, ProductRemoveEvent,
                                    ProductEditEvent, ProductStockUpdateEvent,
                                    CategoryCreateEvent, CategoryEditEvent,
@@ -70,7 +70,7 @@ class MagentoPlugin(object):
 
     implements(IPlugin)
 
-    name = 'magento'
+    name = u'magento'
 
     def __init__(self):
         self._lock = DeferredLock()
@@ -98,7 +98,7 @@ class MagentoPlugin(object):
                 # synchronized at the same time. Can save a lot of time!
                 retval = yield gatherResults(
                     [self._synchronize_magento_table(table, config) for config
-                     in MagentoConfig.select(connection=get_connection())]
+                     in get_default_store().find(MagentoConfig)]
                     )
                 retval_list.append(all(retval))
             returnValue(all(retval_list))
@@ -186,9 +186,8 @@ class MagentoPlugin(object):
         returnValue(retval)
 
     def _get_magento_products_by_sellable(self, sellable):
-        conn = sellable.get_connection()
-        mag_products = MagentoProduct.selectBy(connection=conn,
-                                               sellable=sellable)
+        store = sellable.store
+        mag_products = store.find(MagentoProduct, sellable=sellable)
         return mag_products
 
     def _get_magento_products_by_product(self, product):
@@ -198,9 +197,8 @@ class MagentoPlugin(object):
         return self._get_magento_products_by_sellable(service.sellable)
 
     def _get_magento_categories_by_category(self, category):
-        conn = category.get_connection()
-        mag_categories = MagentoCategory.selectBy(connection=conn,
-                                                  category=category)
+        store = category.store
+        mag_categories = store.find(MagentoCategory, category=category)
         return mag_categories
 
     #
@@ -208,13 +206,12 @@ class MagentoPlugin(object):
     #
 
     def _on_product_create(self, product, **kwargs):
-        conn = product.get_connection()
-        for config in MagentoConfig.select(connection=conn):
-            if not MagentoProduct.selectOneBy(connection=conn,
-                                              sellable=product.sellable,
-                                              config=config):
+        store = product.store
+        for config in store.find(MagentoConfig):
+            if not store.find(MagentoProduct, sellable=product.sellable,
+                              config=config).one():
                 # Just create the registry and it will be synchronized later.
-                MagentoProduct(connection=conn,
+                MagentoProduct(store=store,
                                sellable=product.sellable,
                                config=config)
 
@@ -232,20 +229,19 @@ class MagentoPlugin(object):
 
     def _on_product_stock_update(self, product, branch, old_quantity,
                                  new_quantity, **kwargs):
-        conn = product.get_connection()
+        store = product.store
         for mag_product in self._get_magento_products_by_product(product):
-            for mag_stock in MagentoStock.selectBy(connection=conn,
-                                                   magento_product=mag_product):
+            for mag_stock in store.find(MagentoStock,
+                                        magento_product=mag_product):
                 mag_stock.need_sync = True
 
     def _on_service_create(self, service, **kwargs):
-        conn = service.get_connection()
-        for config in MagentoConfig.select(connection=conn):
-            if not MagentoProduct.selectOneBy(connection=conn,
-                                              sellable=service.sellable,
-                                              config=config):
+        store = service.store
+        for config in store.find(MagentoConfig):
+            if not store.find(MagentoProduct, sellable=service.sellable,
+                              config=config).one():
                 # Just create the registry and it will be synchronized later.
-                MagentoProduct(connection=conn,
+                MagentoProduct(store=store,
                                sellable=service.sellable,
                                config=config)
 
@@ -266,9 +262,8 @@ class MagentoPlugin(object):
             mag_product.need_sync = True
 
     def _on_image_create(self, image, **kwargs):
-        conn = image.get_connection()
-        sellable = Sellable.selectOneBy(connection=conn,
-                                        image=image)
+        store = image.store
+        sellable = store.find(Sellable, image=image).one()
         if sellable:
             for mag_product in self._get_magento_products_by_sellable(sellable):
                 for mag_image in mag_product.magento_images:
@@ -277,22 +272,22 @@ class MagentoPlugin(object):
                         mag_image.image = image
                         mag_image.need_sync = True
                 else:
-                    MagentoImage(connection=conn,
+                    MagentoImage(store=store,
                                  config=mag_product.config,
                                  image=image,
                                  magento_product=mag_product,
                                  is_main=True)
 
     def _on_image_update(self, image, **kwargs):
-        conn = image.get_connection()
-        for mag_image in MagentoImage.selectBy(connection=conn,
-                                               image=image):
+        store = image.store
+        for mag_image in store.find(MagentoImage,
+                                    image=image):
             mag_image.need_sync = True
 
     def _on_image_delete(self, image, **kwargs):
-        conn = image.get_connection()
-        for mag_image in MagentoImage.selectBy(connection=conn,
-                                               image=image):
+        store = image.store
+        for mag_image in store.find(MagentoImage,
+                                    image=image):
             # Remove the foreign key reference, so the image can be
             # deleted on stoq without problems. This deletion will happen
             # later when synchronizing images.
@@ -300,13 +295,12 @@ class MagentoPlugin(object):
             mag_image.need_sync = True
 
     def _on_category_create(self, category, **kwargs):
-        conn = category.get_connection()
-        for config in MagentoConfig.select(connection=conn):
-            if not MagentoCategory.selectOneBy(connection=conn,
-                                               category=category,
-                                               config=config):
+        store = category.store
+        for config in store.find(MagentoConfig):
+            if not store.find(MagentoCategory, category=category,
+                              config=config).one():
                 # Just create the registry and it will be synchronized later.
-                MagentoCategory(connection=conn,
+                MagentoCategory(store=store,
                                 category=category,
                                 config=config)
 
@@ -319,16 +313,13 @@ class MagentoPlugin(object):
                 mag_category.need_sync = True
 
     def _on_sale_status_change(self, sale, old_status, **kwargs):
-        mag_sale = MagentoSale.selectOneBy(connection=sale.get_connection(),
-                                           sale=sale)
+        mag_sale = self.store.find(MagentoSale, sale=sale).one()
         if mag_sale:
             mag_sale.need_sync = True
 
     def _on_delivery_status_change(self, delivery, old_status, **kwargs):
-        mag_delivery = MagentoShipment.selectOneBy(
-            connection=delivery.get_connection(),
-            delivery=delivery,
-            )
+        mag_delivery = self.store.find(MagentoShipment,
+                                             delivery=delivery).one()
         if mag_delivery:
             mag_delivery.need_sync = True
 
