@@ -169,7 +169,7 @@ class StoqCommandHandler:
             self._register_station()
 
         if options.plugins:
-            self._enable_plugins(options.plugins.split(','))
+            self._enable_plugins(unicode(options.plugins).split(','))
 
         if options.demo:
             self._enable_demo()
@@ -216,11 +216,11 @@ class StoqCommandHandler:
         self._register_station()
 
     def _enable_demo(self):
-        from stoqlib.database.runtime import new_transaction
-        trans = new_transaction()
-        trans.query("UPDATE parameter_data SET field_value = '1' WHERE field_name = 'DEMO_MODE';")
-        trans.commit()
-        trans.close()
+        from stoqlib.database.runtime import new_store
+        store = new_store()
+        store.execute("UPDATE parameter_data SET field_value = '1' WHERE field_name = 'DEMO_MODE';")
+        store.commit()
+        store.close()
 
     def _enable_plugins(self, plugin_names):
         from stoqlib.lib.pluginmanager import (PluginError,
@@ -243,29 +243,29 @@ class StoqCommandHandler:
 
     def _register_station(self):
         # Register the current computer as a branch station
-        import socket
-        from stoqlib.database.runtime import new_transaction
+        from stoqlib.database.runtime import new_store
         from stoqlib.domain.person import Branch
         from stoqlib.domain.station import BranchStation
         from stoqlib.exceptions import StoqlibError
-        trans = new_transaction()
+        from stoqlib.net.socketutils import get_hostname
+        store = new_store()
 
-        branches = Branch.select(connection=trans)
+        branches = store.find(Branch)
         if branches:
             branch = branches[0]
         else:
             branch = None
 
         try:
-            BranchStation(connection=trans,
+            BranchStation(store=store,
                           is_active=True,
                           branch=branch,
-                          name=socket.gethostname())
+                          name=get_hostname())
         except StoqlibError, e:
             raise SystemExit("ERROR: %s" % e)
 
-        trans.commit()
-        trans.close()
+        store.commit()
+        store.close()
 
     def _create_dbuser(self, username):
         import os
@@ -311,48 +311,11 @@ class StoqCommandHandler:
         if not migration.update(backup=options.disable_backup):
             return 1
 
-    def cmd_serve(self, options):
-        """Start a synchronization server"""
-        from stoqlib.database.synchronization import SynchronizationService
-        self._read_config(options, check_schema=False, register_station=False)
-        service = SynchronizationService("", 9000)
-        service.serve()
-
-    def cmd_clone(self, options, hostname, station):
-        from stoqlib.database.synchronization import SynchronizationClient
-        self._read_config(options)
-
-        client = SynchronizationClient(hostname, 9000)
-        if options.dry:
-            client.disable_commit()
-        client_station = client.get_station_name()
-        if client_station != station:
-            raise SystemExit(
-                "The station name for the server is %s, expected %s" %
-                (client_station, station))
-        client.clean()
-        client.clone(station)
-
     def opt_clone(self, parser, group):
         group.add_option('', '--dry',
                          action='store_true',
                          dest='dry')
 
-    def cmd_update(self, options, hostname, station):
-        """Update the database from a synchronization server"""
-        from stoqlib.database.synchronization import SynchronizationClient
-        self._read_config(options)
-
-        client = SynchronizationClient(hostname, 9000)
-        if options.dry:
-            client.disable_commit()
-        client_station = client.get_station_name()
-        if client_station != station:
-            raise SystemExit(
-                "The station name for the server is %s, expected %s" %
-                (client_station, station))
-        client.update(station)
-
     def opt_update(self, parser, group):
         group.add_option('', '--dry',
                          action='store_true',
@@ -389,7 +352,7 @@ class StoqCommandHandler:
                           check_schema=False,
                           load_plugins=False)
 
-        self._enable_plugins([plugin_name])
+        self._enable_plugins([unicode(plugin_name)])
 
     def cmd_generate_sintegra(self, options, filename, month):
         """Generate a sintegra file"""
@@ -449,7 +412,7 @@ class StoqCommandHandler:
             console.interact()
 
         if options.commit:
-            console.trans.commit()
+            console.store.commit()
 
     def opt_console(self, parser, group):
         group.add_option('-b', '--bare',
