@@ -23,7 +23,6 @@
 ##
 """ Main gui definition for admin application.  """
 
-import gettext
 import operator
 
 import glib
@@ -44,6 +43,7 @@ from stoqlib.gui.dialogs.sellabledialog import SellableTaxConstantsDialog
 from stoqlib.gui.dialogs.sintegradialog import SintegraDialog
 from stoqlib.gui.editors.personeditor import UserEditor
 from stoqlib.gui.keybindings import get_accels
+from stoqlib.gui.search.costcentersearch import CostCenterSearch
 from stoqlib.gui.search.eventsearch import EventSearch
 from stoqlib.gui.search.fiscalsearch import CfopSearch, FiscalBookEntrySearch
 from stoqlib.gui.search.parametersearch import ParameterSearch
@@ -66,11 +66,11 @@ from stoqlib.gui.wizards.personwizard import run_person_role_dialog
 from stoqlib.lib.decorators import public
 from stoqlib.lib.message import info
 from stoqlib.lib.permissions import PermissionManager
-from stoqlib.lib.translation import locale_sorted
+from stoqlib.lib.translation import locale_sorted, stoqlib_gettext
 
 from stoq.gui.application import AppWindow
 
-_ = gettext.gettext
+_ = stoqlib_gettext
 
 logger = Logger('stoq.gui.admin')
 
@@ -158,114 +158,114 @@ class Tasks(object):
         func()
 
     def _open_branches(self):
-        self.app.run_dialog(BranchSearch, self.app.conn,
+        self.app.run_dialog(BranchSearch, self.app.store,
                             hide_footer=True)
 
     def _open_clients(self):
-        self.app.run_dialog(ClientSearch, self.app.conn)
+        self.app.run_dialog(ClientSearch, self.app.store)
 
     def _open_client_categories(self):
-        trans = api.new_transaction()
-        model = self.app.run_dialog(ClientCategoryDialog, trans)
-        api.finish_transaction(trans, model)
-        trans.close()
+        store = api.new_store()
+        model = self.app.run_dialog(ClientCategoryDialog, store)
+        store.confirm(model)
+        store.close()
 
     def _open_devices(self):
-        self.app.run_dialog(DeviceSettingsDialog, self.app.conn)
+        self.app.run_dialog(DeviceSettingsDialog, self.app.store)
 
     def _open_employees(self):
-        self.app.run_dialog(EmployeeSearch, self.app.conn)
+        self.app.run_dialog(EmployeeSearch, self.app.store)
 
     def _open_employee_roles(self):
-        self.app.run_dialog(EmployeeRoleSearch, self.app.conn)
+        self.app.run_dialog(EmployeeRoleSearch, self.app.store)
 
     def _open_events(self):
-        self.app.run_dialog(EventSearch, self.app.conn)
+        self.app.run_dialog(EventSearch, self.app.store)
 
     def _open_forms(self):
-        trans = api.new_transaction()
-        model = self.app.run_dialog(FormFieldEditor, trans)
-        api.finish_transaction(trans, model)
-        trans.close()
+        store = api.new_store()
+        model = self.app.run_dialog(FormFieldEditor, store)
+        store.confirm(model)
+        store.close()
 
     def _open_fiscal_books(self):
-        self.app.run_dialog(FiscalBookEntrySearch, self.app.conn,
+        self.app.run_dialog(FiscalBookEntrySearch, self.app.store,
                             hide_footer=True)
 
     def _open_invoice_layouts(self):
-        trans = api.new_transaction()
-        model = self.app.run_dialog(InvoiceLayoutDialog, trans)
-        api.finish_transaction(trans, model)
-        trans.close()
+        store = api.new_store()
+        model = self.app.run_dialog(InvoiceLayoutDialog, store)
+        store.confirm(model)
+        store.close()
 
     def _open_invoice_printers(self):
-        if not InvoiceLayout.select(connection=self.app.conn):
+        if self.app.store.find(InvoiceLayout).is_empty():
             info(_("You must create at least one invoice layout "
                    "before adding an invoice printer"))
             return
 
-        trans = api.new_transaction()
-        model = self.app.run_dialog(InvoicePrinterDialog, trans)
-        api.finish_transaction(trans, model)
-        trans.close()
+        store = api.new_store()
+        model = self.app.run_dialog(InvoicePrinterDialog, store)
+        store.confirm(model)
+        store.close()
 
     def _open_payment_categories(self):
-        trans = api.new_transaction()
-        model = self.app.run_dialog(PaymentCategoryDialog, trans)
-        api.finish_transaction(trans, model)
-        trans.close()
+        store = api.new_store()
+        model = self.app.run_dialog(PaymentCategoryDialog, store)
+        store.confirm(model)
+        store.close()
 
     def _open_payment_methods(self):
-        trans = api.new_transaction()
-        model = self.app.run_dialog(PaymentMethodsDialog, trans)
-        api.finish_transaction(trans, model)
-        trans.close()
+        store = api.new_store()
+        model = self.app.run_dialog(PaymentMethodsDialog, store)
+        store.confirm(model)
+        store.close()
 
     def _open_parameters(self):
-        trans = api.new_transaction()
-        model = self.app.run_dialog(ParameterSearch, trans)
-        api.finish_transaction(trans, model)
-        trans.close()
+        store = api.new_store()
+        model = self.app.run_dialog(ParameterSearch, store)
+        store.confirm(model)
+        store.close()
 
     def _open_plugins(self):
-        trans = api.new_transaction()
-        model = self.app.run_dialog(PluginManagerDialog, trans)
-        api.finish_transaction(trans, model)
-        trans.close()
+        store = api.new_store()
+        model = self.app.run_dialog(PluginManagerDialog, store)
+        store.confirm(model)
+        store.close()
 
     def _open_cfop(self):
-        self.app.run_dialog(CfopSearch, self.app.conn, hide_footer=True)
+        self.app.run_dialog(CfopSearch, self.app.store, hide_footer=True)
 
     def _open_sintegra(self):
-        branch = api.get_current_branch(self.app.conn)
+        branch = api.get_current_branch(self.app.store)
         if branch.manager is None:
             info(_(
                 "You must define a manager to this branch before you can create"
                 " a sintegra archive"))
             return
 
-        self.app.run_dialog(SintegraDialog, self.app.conn)
+        self.app.run_dialog(SintegraDialog, self.app.store)
 
     def _open_stations(self):
-        self.app.run_dialog(StationSearch, self.app.conn, hide_footer=True)
+        self.app.run_dialog(StationSearch, self.app.store, hide_footer=True)
 
     def _open_suppliers(self):
-        self.app.run_dialog(SupplierSearch, self.app.conn)
+        self.app.run_dialog(SupplierSearch, self.app.store)
 
     def _open_taxes(self):
-        self.app.run_dialog(SellableTaxConstantsDialog, self.app.conn)
+        self.app.run_dialog(SellableTaxConstantsDialog, self.app.store)
 
     def _open_tax_templates(self):
-        self.app.run_dialog(TaxTemplatesSearch, self.app.conn)
+        self.app.run_dialog(TaxTemplatesSearch, self.app.store)
 
     def _open_transporters(self):
-        self.app.run_dialog(TransporterSearch, self.app.conn)
+        self.app.run_dialog(TransporterSearch, self.app.store)
 
     def _open_users(self):
-        self.app.run_dialog(UserSearch, self.app.conn)
+        self.app.run_dialog(UserSearch, self.app.store)
 
     def _open_user_profiles(self):
-        self.app.run_dialog(UserProfileSearch, self.app.conn)
+        self.app.run_dialog(UserProfileSearch, self.app.store)
 
 
 class AdminApp(AppWindow):
@@ -316,6 +316,8 @@ class AdminApp(AppWindow):
              group.get('search_employees')),
             ("SearchEvents", None, _("Events..."),
              group.get('search_events')),
+            ("SearchCostCenters", None, _("Cost Centers..."),
+             group.get('search_cost_centers')),
             ("SearchCfop", None, _("C.F.O.P..."),
              group.get('search_cfop')),
             ("SearchFiscalBook", None, _("Fiscal books..."),
@@ -402,10 +404,10 @@ class AdminApp(AppWindow):
     # Private
 
     def _new_user(self):
-        trans = api.new_transaction()
-        model = run_person_role_dialog(UserEditor, self, trans)
-        api.finish_transaction(trans, model)
-        trans.close()
+        store = api.new_store()
+        model = run_person_role_dialog(UserEditor, self, store)
+        store.confirm(model)
+        store.close()
     #
     # Callbacks
     #
@@ -416,3 +418,8 @@ class AdminApp(AppWindow):
     # New
     def on_NewUser__activate(self, action):
         self._new_user()
+
+    # TODO: Create an task for this. I still need to find a proper metaphor
+    # for the icon
+    def on_SearchCostCenters__activate(self, action):
+        self.run_dialog(CostCenterSearch, self.store)
