@@ -24,13 +24,11 @@
 """ Base classes for application's GUI """
 
 import datetime
-import gettext
 import locale
 import os
 import platform
 import sys
 
-import gobject
 import gtk
 from kiwi.component import get_utility
 from kiwi.enums import SearchFilterPosition
@@ -38,7 +36,7 @@ from kiwi.environ import environ
 from kiwi.log import Logger
 from kiwi.ui.delegates import GladeDelegate
 from stoqlib.api import api
-from stoqlib.database.orm import ORMObjectQueryExecuter
+from stoqlib.database.queryexecuter import StoqlibQueryExecuter
 from stoqlib.exceptions import StoqlibError
 from stoqlib.lib.crashreport import has_tracebacks
 from stoqlib.lib.decorators import cached_function
@@ -51,7 +49,6 @@ from stoqlib.gui.base.dialogs import (get_dialog, run_dialog,
                                       get_current_toplevel)
 from stoqlib.gui.base.search import StoqlibSearchSlaveDelegate
 from stoqlib.gui.dialogs.crashreportdialog import show_dialog
-from stoqlib.gui.dialogs.feedbackdialog import FeedbackDialog
 from stoqlib.gui.dialogs.spreadsheetexporterdialog import SpreadSheetExporter
 from stoqlib.gui.editors.preferenceseditor import PreferencesEditor
 from stoqlib.gui.events import StopApplicationEvent
@@ -63,100 +60,21 @@ from stoqlib.gui.openbrowser import open_browser
 from stoqlib.gui.printing import print_report
 from stoqlib.gui.toolmenuaction import ToolMenuAction
 from stoqlib.domain.inventory import Inventory
+from stoqlib.lib.translation import stoqlib_gettext as _
 from twisted.internet import reactor
 from twisted.internet.defer import succeed
 
 import stoq
+from stoq.gui.shell.statusbar import ShellStatusbar
 
 log = Logger('stoq.application')
-_ = gettext.gettext
-
-
-class Statusbar(gtk.Statusbar):
-    def __init__(self, app):
-        gtk.Statusbar.__init__(self)
-        self._disable_border()
-        self.message_area = self._create_message_area()
-        self._create_default_widgets()
-        self.app = app
-
-    def _disable_border(self):
-        # Disable border on statusbar
-        children = self.get_children()
-        if children and isinstance(children[0], gtk.Frame):
-            frame = children[0]
-            frame.set_shadow_type(gtk.SHADOW_NONE)
-
-    def _create_message_area(self):
-        for child in self.get_children():
-            child.hide()
-        area = gtk.HBox(False, 4)
-        self.add(area)
-        area.show()
-        return area
-
-    def _create_default_widgets(self):
-        alignment = gtk.Alignment(0.0, 0.0, 1.0, 1.0)
-        # FIXME: These looks good on Mac, might need to tweak
-        # on Linux to look good
-        alignment.set_padding(2, 3, 5, 5)
-        self.message_area.pack_start(alignment, True, True)
-        alignment.show()
-
-        widget_area = gtk.HBox(False, 0)
-        alignment.add(widget_area)
-        widget_area.show()
-
-        self._text_label = gtk.Label()
-        self._text_label.set_alignment(0.0, 0.5)
-        widget_area.pack_start(self._text_label, True, True)
-        self._text_label.show()
-
-        vsep = gtk.VSeparator()
-        widget_area.pack_start(vsep, False, False, 0)
-        vsep.show()
-        from stoqlib.gui.stockicons import STOQ_FEEDBACK
-        self._feedback_button = gtk.Button(_('Feedback'))
-        image = gtk.Image()
-        image.set_from_stock(STOQ_FEEDBACK, gtk.ICON_SIZE_MENU)
-        self._feedback_button.set_image(image)
-        image.show()
-        self._feedback_button.set_can_focus(False)
-        self._feedback_button.connect('clicked',
-          self._on_feedback__clicked)
-        self._feedback_button.set_relief(gtk.RELIEF_NONE)
-        widget_area.pack_start(self._feedback_button, False, False, 0)
-        self._feedback_button.show()
-
-        vsep = gtk.VSeparator()
-        widget_area.pack_start(vsep, False, False, 0)
-        vsep.show()
-
-    def do_text_popped(self, ctx, text):
-        self._text_label.set_label(text)
-
-    def do_text_pushed(self, ctx, text):
-        self._text_label.set_label(text)
-
-    #
-    # Callbacks
-    #
-
-    def _on_feedback__clicked(self, button):
-        if self.app.current_app:
-            screen = self.app.current_app.app.name + ' application'
-        else:
-            screen = 'launcher'
-        run_dialog(FeedbackDialog, self.get_toplevel(), screen)
-
-gobject.type_register(Statusbar)
 
 
 class App(object):
     """Class for application control. """
 
     def __init__(self, window_class, config, options, shell, embedded,
-                 launcher, name, conn=None):
+                 launcher, name, store=None):
         """
         Create a new object App.
 
@@ -174,7 +92,7 @@ class App(object):
 
         # The self should be passed to main_window to let it access
         # shutdown and do_sync methods.
-        self.main_window = window_class(self, conn=conn)
+        self.main_window = window_class(self, store=store)
 
     def show(self, params=None):
         if self.embedded:
@@ -225,15 +143,15 @@ class AppWindow(GladeDelegate):
         'HelpHelp': ('app.common.help', PermissionManager.PERM_ACCESS),
     }
 
-    def __init__(self, app, keyactions=None, conn=None):
-        if conn is None:
-            conn = api.get_connection()
+    def __init__(self, app, keyactions=None, store=None):
+        if store is None:
+            store = api.get_default_store()
         self._action_groups = {}
         self._osx_app = None
         self._sensitive_group = dict()
         self._tool_items = []
         self.app = app
-        self.conn = conn
+        self.store = store
         self.current_app = None
         self.current_app_widget = None
         self.uimanager = None
@@ -532,7 +450,7 @@ class AppWindow(GladeDelegate):
                                                 action_widget=button)
 
     def _check_demo_mode(self):
-        if not api.sysparam(self.conn).DEMO_MODE:
+        if not api.sysparam(self.store).DEMO_MODE:
             return
 
         if api.user_settings.get('hide-demo-warning'):
@@ -550,9 +468,9 @@ class AppWindow(GladeDelegate):
         self.add_info_bar(gtk.MESSAGE_WARNING, msg, action_widget=button)
 
     def _check_version(self):
-        if not api.sysparam(self.conn).ONLINE_SERVICES:
+        if not api.sysparam(self.store).ONLINE_SERVICES:
             return
-        self._version_checker = VersionChecker(self.conn, self)
+        self._version_checker = VersionChecker(self.store, self)
         self._version_checker.check_new_version()
 
     def _read_resource(self, domain, name):
@@ -637,12 +555,12 @@ class AppWindow(GladeDelegate):
         d['y'] = str(self._y)
 
     def _create_statusbar(self):
-        statusbar = Statusbar(self)
+        statusbar = ShellStatusbar(self)
 
         # Set the initial text, the currently logged in user and the actual
         # branch and station.
-        user = api.get_current_user(self.conn)
-        station = api.get_current_station(self.conn)
+        user = api.get_current_user(self.store)
+        station = api.get_current_station(self.store)
         status_str = '   |   '.join([
             _("User: %s") % (user.get_description(),),
             _("Computer: %s") % (station.name,)
@@ -694,7 +612,7 @@ class AppWindow(GladeDelegate):
 
         log.debug('Logging out the current user')
         try:
-            user = api.get_current_user(api.get_connection())
+            user = api.get_current_user(api.get_default_store())
             if user:
                 user.logout()
         except StoqlibError:
@@ -776,7 +694,7 @@ class AppWindow(GladeDelegate):
 
     def get_title(self):
         # This method must be redefined in child when it's needed
-        branch = api.get_current_branch(self.conn)
+        branch = api.get_current_branch(self.store)
         return _('[%s] - %s') % (branch.get_description(), self.app_name)
 
     def can_change_application(self):
@@ -972,8 +890,8 @@ class AppWindow(GladeDelegate):
 
     @cached_function()
     def has_open_inventory(self):
-        return Inventory.has_open(self.conn,
-                                  api.get_current_branch(self.conn))
+        return Inventory.has_open(self.store,
+                                  api.get_current_branch(self.store))
 
     def check_open_inventory(self):
         """Checks if there is an open inventory.
@@ -1275,11 +1193,11 @@ class AppWindow(GladeDelegate):
 
     def _on_ChangePassword__activate(self, action):
         from stoqlib.gui.slaves.userslave import PasswordEditor
-        trans = api.new_transaction()
-        user = api.get_current_user(trans)
-        retval = self.run_dialog(PasswordEditor, trans, user)
-        api.finish_transaction(trans, retval)
-        trans.close()
+        store = api.new_store()
+        user = api.get_current_user(store)
+        retval = self.run_dialog(PasswordEditor, store, user)
+        store.confirm(retval)
+        store.close()
 
     def _on_SignOut__activate(self, action):
         from stoqlib.lib.interfaces import ICookieFile
@@ -1298,8 +1216,8 @@ class AppWindow(GladeDelegate):
     # View
 
     def _on_Preferences__activate(self, action):
-        with api.trans() as trans:
-            self.run_dialog(PreferencesEditor, trans)
+        with api.trans() as store:
+            self.run_dialog(PreferencesEditor, store)
         self._update_toolbar_style()
 
     # Edit
@@ -1356,7 +1274,7 @@ class AppWindow(GladeDelegate):
     def _on_RemoveSettingsCache_activate(self, action):
         keys = ['app-ui', 'launcher-geometry']
         keys.append('search-columns-%s' % (
-            api.get_current_user(api.get_connection()).username, ))
+            api.get_current_user(api.get_default_store()).username, ))
 
         for key in keys:
             try:
@@ -1399,20 +1317,20 @@ class SearchableAppWindow(AppWindow):
     #: the report class for printing the object list embedded on app.
     report_table = None
 
-    def __init__(self, app, conn=None):
+    def __init__(self, app, store=None):
         if self.search_table is None:
             raise TypeError("%r must define a search_table attribute" % self)
 
         self._loading_filters = False
 
-        if conn is None:
-            conn = api.get_connection()
-        self.executer = ORMObjectQueryExecuter(conn)
+        if store is None:
+            store = api.get_default_store()
+        self.executer = StoqlibQueryExecuter(store)
         # FIXME: Remove this limit, but we need to migrate all existing
         #        searches to use lazy lists first. That in turn require
         #        us to rewrite the queries in such a way that count(*)
         #        will work properly.
-        self.executer.set_limit(sysparam(conn).MAX_SEARCH_RESULTS)
+        self.executer.set_limit(sysparam(store).MAX_SEARCH_RESULTS)
         self.executer.set_table(self.search_table)
 
         self.search = StoqlibSearchSlaveDelegate(self.get_columns(),
@@ -1424,7 +1342,7 @@ class SearchableAppWindow(AppWindow):
         self.results = self.search.search.results
         self.set_text_field_label(self.search_label)
 
-        AppWindow.__init__(self, app, conn=conn)
+        AppWindow.__init__(self, app, store=store)
         self.attach_slave('search_holder', self.search)
 
         self.create_filters()
@@ -1569,8 +1487,8 @@ class VersionChecker(object):
     #   Private API
     #
 
-    def __init__(self, conn, app):
-        self.conn = conn
+    def __init__(self, store, app):
+        self.store = store
         self.app = app
 
     def _display_new_version_message(self, latest_version):
@@ -1595,7 +1513,7 @@ class VersionChecker(object):
     def _download_details(self):
         log.debug('Downloading new version information')
         api = WebService()
-        response = api.version(self.conn, stoq.version)
+        response = api.version(self.store, stoq.version)
         response.addCallback(self._on_response_done)
 
     def _on_response_done(self, details):
