@@ -46,18 +46,15 @@ Current flow of the database steps:
   * :obj:`FinishInstallationStep`
 """
 
-import gettext
 import os
 import platform
-import socket
 
+import glib
 import gtk
-import gobject
 from kiwi.component import provide_utility
 from kiwi.datatypes import ValidationError
 from kiwi.log import Logger
 from kiwi.python import Settable
-from kiwi.ui.dialogs import info
 from kiwi.ui.delegates import GladeSlaveDelegate
 
 from stoqlib.api import api
@@ -66,7 +63,8 @@ from stoqlib.database.admin import (USER_ADMIN_DEFAULT_NAME, ensure_admin_user,
                                     create_default_profile_settings)
 from stoqlib.database.interfaces import (ICurrentBranchStation,
                                          ICurrentBranch)
-from stoqlib.database.settings import DatabaseSettings, test_local_database
+from stoqlib.database.settings import (DatabaseSettings, test_local_database,
+                                       validate_database_name)
 from stoqlib.domain.person import LoginUser
 from stoqlib.domain.station import BranchStation
 from stoqlib.domain.system import SystemTable
@@ -83,14 +81,14 @@ from stoqlib.lib.message import error, warning, yesno
 from stoqlib.lib.osutils import get_product_key, read_registry_key
 from stoqlib.lib.validators import validate_email
 from stoqlib.lib.webservice import WebService
+from stoqlib.lib.translation import stoqlib_gettext as _
+from stoqlib.net.socketutils import get_hostname
 from twisted.internet import reactor
 
-from stoq.gui.shell import PRIVACY_STRING
+from stoq.gui.shell.shell import PRIVACY_STRING
 from stoq.lib.options import get_option_parser
 from stoq.lib.startup import setup
 
-_ = gettext.gettext
-
 logger = Logger('stoq.gui.config')
 
 
@@ -201,8 +199,7 @@ class DatabaseSettingsStep(WizardEditorStep):
     def validate_step(self):
         if not self.model.check_database_address():
             msg = _("The database address '%s' is invalid. "
-                    "Please fix it and try again"
-                    % self.model.address)
+                    "Please fix it and try again") % self.model.address
             warning(_(u'Invalid database address'), msg)
             # '' is not strictly invalid, since it's an alias for
             # unix socket, so don't tell that to the user, make him
@@ -266,6 +263,10 @@ class DatabaseSettingsStep(WizardEditorStep):
     def on_authentication_type__content_changed(self, *args):
         self._update_widgets()
 
+    def on_dbname__validate(self, widget, value):
+        if not validate_database_name(value):
+            return ValidationError(_('%s is not a valid database name') % value)
+
 
 class InstallationModeStep(BaseWizardStep):
     gladefile = "InstallationModeStep"
@@ -329,8 +330,6 @@ class TefStep(WizardEditorStep):
     def _setup_widgets(self):
         self.send_progress.hide()
         self.send_error_label.hide()
-        # Setting mask in glade file is not working properly.
-        self.phone.set_mask('(00) 0000-0000')
 
     def _pulse(self):
         # FIXME: This is a hack, remove it when we can avoid
@@ -385,10 +384,10 @@ class TefStep(WizardEditorStep):
         self.send_progress.set_pulse_step(0.05)
         self.details_table.set_sensitive(False)
         self.wizard.next_button.set_sensitive(False)
-        gobject.timeout_add(50, self._pulse)
+        glib.timeout_add(50, self._pulse)
 
         # Cancel the request after 30 seconds without a reply
-        gobject.timeout_add(30000, self._cancel_request)
+        glib.timeout_add(30000, self._cancel_request)
 
         # Stay on the same step while sending the details
         return self
@@ -635,17 +634,17 @@ class CreateDatabaseStep(BaseWizardStep):
         settings = self.wizard.settings
         self.wizard.config.load_settings(settings)
 
-        conn = settings.get_default_connection()
-        version = conn.dbVersion()
-        if version < (8, 1):
-            info(_("Stoq requires PostgresSQL 8.1 or later, but %s found") %
-                 ".".join(map(str, version)))
-            conn.close()
-            return False
+        # store = settings.get_super_store()
+        # version = store.dbVersion()
+        # if version < (8, 1):
+        #     info(_("Stoq requires PostgresSQL 8.1 or later, but %s found") %
+        #          ".".join(map(str, version)))
+        #     store.close()
+        #     return False
 
         # Secondly, ask the user if he really wants to create the database,
         dbname = settings.dbname
-        if not yesno(_("The specifed database '%s' does not exist.\n"
+        if not yesno(_("The specified database '%s' does not exist.\n"
                        "Do you want to create it?") % dbname,
                      gtk.RESPONSE_NO, _("Don't create"), _("Create database")):
             self.process_view.feed("** Creating database\r\n")
@@ -847,7 +846,7 @@ class FirstTimeConfigWizard(BaseWizard):
         self.get_toplevel().set_deletable(False)
         self.next_button.grab_focus()
 
-    def _create_station(self, trans):
+    def _create_station(self, store):
         # FIXME: This is fishy, we can probably simplify this significantly by
         #        allowing users to connect to the initial database without
         #        having a branch station nor branch registered.
@@ -855,38 +854,36 @@ class FirstTimeConfigWizard(BaseWizard):
         #        be done at the same place.
         logger.info('_create_station')
         if self.enable_production:
-            branch = api.sysparam(trans).MAIN_COMPANY
+            branch = api.sysparam(store).MAIN_COMPANY
             assert branch
             provide_utility(ICurrentBranch, branch)
         else:
             branch = None
 
         # FIXME: what about LTSP
-        station_name = socket.gethostname()
-        if BranchStation.selectOneBy(name=station_name,
-                                     branch=branch,
-                                     connection=trans):
+        station_name = get_hostname()
+        if store.find(BranchStation, branch=branch, name=station_name).one():
             return
-        station = BranchStation(connection=trans,
+        station = BranchStation(store=store,
                                 is_active=True,
                                 branch=branch,
                                 name=station_name)
         provide_utility(ICurrentBranchStation, station)
 
-    def _set_admin_password(self, trans):
+    def _set_admin_password(self, store):
         logger.info('_set_admin_password')
-        adminuser = LoginUser.selectOneBy(username=USER_ADMIN_DEFAULT_NAME,
-                                          connection=trans)
+        adminuser = store.find(LoginUser,
+                               username=USER_ADMIN_DEFAULT_NAME).one()
         if adminuser is None:
             raise DatabaseInconsistency(
                 ("You should have a user with username: %s"
                  % USER_ADMIN_DEFAULT_NAME))
         adminuser.set_password(self.login_password)
 
-    def _set_online_services(self, trans):
+    def _set_online_services(self, store):
         logger.info('_set_online_services (%s)' %
                             self.enable_online_services)
-        api.sysparam(trans).ONLINE_SERVICES = int(self.enable_online_services)
+        api.sysparam(store).ONLINE_SERVICES = int(self.enable_online_services)
 
     # Public API
 
@@ -908,9 +905,9 @@ class FirstTimeConfigWizard(BaseWizard):
         self.config.load_settings(settings)
         try:
             if settings.has_database():
-                conn = settings.get_connection()
-                self.has_installed_db = SystemTable.is_available(conn)
-                conn.close()
+                store = settings.create_store()
+                self.has_installed_db = SystemTable.is_available(store)
+                store.close()
         except DatabaseError, e:
             if warn:
                 warning(e.short, str(e.msg))
@@ -948,8 +945,11 @@ class FirstTimeConfigWizard(BaseWizard):
         # If we have the SystemTable we are pretty much there,
         # could verify a few more tables in the future, including
         # row content of the tables.
-        if SystemTable.is_available(self.settings.get_connection()):
+        store = self.settings.create_store()
+        if SystemTable.is_available(store):
+            store.close()
             return False
+        store.close()
 
         # okay, we have a database which exists and doesn't have
         # the "SystemTable" SQL table present, means that we cannot use
@@ -1028,7 +1028,7 @@ class FirstTimeConfigWizard(BaseWizard):
         else:
             lines = []
 
-        # _get_connection_internal connects to the 'postgres' database,
+        # _get_store_internal connects to the 'postgres' database,
         # we need to allow connections without asking the password,
         # otherwise stoqdbadmin will be stuck in the wizard when creating
         # a new database.
@@ -1062,11 +1062,11 @@ class FirstTimeConfigWizard(BaseWizard):
             self.load_config_and_call_setup()
         else:
             # Commit data created during the wizard, such as stations
-            trans = api.new_transaction()
-            self._set_admin_password(trans)
-            self._create_station(trans)
-            self._set_online_services(trans)
-            trans.commit()
+            store = api.new_store()
+            self._set_admin_password(store)
+            self._create_station(store)
+            self._set_online_services(store)
+            store.commit()
 
         # Write configuration to disk
         if self.remove_demo:
