@@ -29,7 +29,6 @@ stoq/gui/financial/financial.py:
 
 import datetime
 import decimal
-import gettext
 
 from dateutil.relativedelta import relativedelta
 import gobject
@@ -37,15 +36,15 @@ import gtk
 from kiwi.currency import currency
 from kiwi.db.query import DateQueryState, DateIntervalQueryState
 from kiwi.python import Settable
-from kiwi.ui.dialogs import open as open_dialog
+from kiwi.ui.dialogs import selectfile
 from kiwi.ui.objectlist import ColoredColumn, Column, SearchColumn, ObjectList
 from kiwi.ui.search import Any, DateSearchFilter, DateSearchOption, SearchContainer
 from stoqlib.api import api
-from stoqlib.database.orm import const, OR, AND
+from stoqlib.database.expr import Date
 from stoqlib.domain.account import Account, AccountTransaction, AccountTransactionView
 from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.payment.views import InPaymentView, OutPaymentView
-from stoqlib.database.orm import ORMObjectQueryExecuter
+from stoqlib.database.queryexecuter import StoqlibQueryExecuter
 from stoqlib.gui.accounttree import AccountTree
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.editors.accounteditor import AccountEditor
@@ -56,12 +55,12 @@ from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.printing import print_report
 from stoqlib.lib.dateutils import get_month_names
 from stoqlib.lib.message import yesno
+from stoqlib.lib.translation import stoqlib_gettext as _
 from stoqlib.reporting.payment import AccountTransactionReport
+from storm.expr import Or, And
 
 from stoq.gui.application import AppWindow
 
-_ = gettext.gettext
-
 
 class NotebookCloseButton(gtk.Button):
     pass
@@ -124,7 +123,7 @@ class TransactionPage(object):
     def _create_search(self):
         self.search = TransactionSearchContainer(
             self, columns=self._get_columns(self.model.kind))
-        self.query = ORMObjectQueryExecuter(self.app.conn)
+        self.query = StoqlibQueryExecuter(self.app.store)
         self.search.set_query_executer(self.query)
         self.search.results.connect('row-activated', self._on_row__activated)
         self.results = self.search.results
@@ -142,7 +141,7 @@ class TransactionPage(object):
         for i, month in enumerate(month_names):
             name = month_names[i]
             option = type(name + 'Option', (MonthOption, ),
-                          {'name': gettext.gettext(name),
+                          {'name': _(name),
                            'month': i + 1,
                            'year': year})
             self.date_filter.add_option(option, i + 1)
@@ -154,31 +153,25 @@ class TransactionPage(object):
         date = self.date_filter.get_state()
         queries = []
         if isinstance(date, DateQueryState) and date.date is not None:
-            queries.append(const.DATE(field) == date.date)
+            queries.append(Date(field) == date.date)
         elif isinstance(date, DateIntervalQueryState):
-            queries.append(const.DATE(field) >= date.start)
-            queries.append(const.DATE(field) <= date.end)
+            queries.append(Date(field) >= date.start)
+            queries.append(Date(field) <= date.end)
         return queries
 
-    def _payment_query(self, query, having, conn):
-        queries = self._append_date_query(self.query.table.q.due_date)
-        if query:
-            queries.append(query)
+    def _payment_query(self, store):
+        queries = self._append_date_query(self.query.table.due_date)
+        if queries:
+            return store.find(self.query.table, And(*queries))
 
-        query = AND(*queries)
-        if not queries:
-            query = None
-        return self.query.table.select(query, connection=conn)
+        return store.find(self.query.table)
 
-    def _transaction_query(self, query, having, conn):
-        queries = [OR(self.model.id == AccountTransaction.q.account_id,
-                      self.model.id == AccountTransaction.q.source_account_id)]
+    def _transaction_query(self, store):
+        queries = [Or(self.model.id == AccountTransaction.account_id,
+                      self.model.id == AccountTransaction.source_account_id)]
 
-        queries.extend(self._append_date_query(AccountTransaction.q.date))
-
-        if query:
-            queries.append(query)
-        return AccountTransactionView.select(AND(*queries), connection=conn)
+        queries.extend(self._append_date_query(AccountTransaction.date))
+        return store.find(AccountTransactionView, And(*queries))
 
     def show(self):
         self.search.show()
@@ -202,7 +195,7 @@ class TransactionPage(object):
     def refresh(self):
         self.search.results.clear()
         if self.model.kind == 'account':
-            transactions = AccountTransactionView.get_for_account(self.model, self.app.conn)
+            transactions = AccountTransactionView.get_for_account(self.model, self.app.store)
             self.append_transactions(transactions)
         elif self.model.kind == 'payable':
             self._populate_payable_payments(OutPaymentView)
@@ -262,7 +255,7 @@ class TransactionPage(object):
         self.update_totals()
 
     def _populate_payable_payments(self, view_class):
-        for view in view_class.select():
+        for view in self.app.store.find(view_class):
             self.search.results.append(view)
 
     def _add_transaction(self, transaction, description, value):
@@ -285,40 +278,40 @@ class TransactionPage(object):
             item.total = total
 
     def _edit_transaction_dialog(self, item):
-        trans = api.new_transaction()
+        store = api.new_store()
         if isinstance(item.transaction, AccountTransactionView):
-            account_transaction = trans.get(item.transaction.transaction)
+            account_transaction = store.fetch(item.transaction.transaction)
         else:
-            account_transaction = trans.get(item.transaction)
+            account_transaction = store.fetch(item.transaction)
         model = getattr(self.model, 'account', self.model)
 
         transaction = run_dialog(AccountTransactionEditor, self.app,
-                                 trans, account_transaction, model)
+                                 store, account_transaction, model)
 
         if transaction:
-            transaction.syncUpdate()
+            store.flush()
             self._update_transaction(item, transaction,
                                      transaction.edited_account.description,
                                      transaction.value)
             self.update_totals()
             self.search.results.update(item)
-            self.app.accounts.refresh_accounts(self.app.conn)
-        api.finish_transaction(trans, transaction)
-        trans.close()
+            self.app.accounts.refresh_accounts(self.app.store)
+        store.confirm(transaction)
+        store.close()
 
     def on_dialog__opened(self, dialog):
         dialog.connect('account-added', self.on_dialog__account_added)
 
     def on_dialog__account_added(self, dialog):
-        self.app.accounts.refresh_accounts(self.app.conn)
+        self.app.accounts.refresh_accounts(self.app.store)
 
     def add_transaction_dialog(self):
-        trans = api.new_transaction()
+        store = api.new_store()
         model = getattr(self.model, 'account', self.model)
-        model = trans.get(model)
+        model = store.fetch(model)
 
         transaction = run_dialog(AccountTransactionEditor, self.app,
-                                 trans, None, model)
+                                 store, None, model)
         if transaction:
             transaction.sync()
             value = transaction.value
@@ -328,9 +321,9 @@ class TransactionPage(object):
             item = self._add_transaction(transaction, other.description, value)
             self.update_totals()
             self.search.results.update(item)
-            self.app.accounts.refresh_accounts(self.app.conn)
-        api.finish_transaction(trans, transaction)
-        trans.close()
+            self.app.accounts.refresh_accounts(self.app.store)
+        store.confirm(transaction)
+        store.close()
 
     def _on_row__activated(self, objectlist, item):
         if self.model.kind == 'account':
@@ -343,13 +336,13 @@ class FinancialApp(AppWindow):
     gladefile = 'financial'
     embedded = True
 
-    def __init__(self, app, conn=None):
+    def __init__(self, app, store=None):
         self._pages = {}
         self.accounts = AccountTree()
-        AppWindow.__init__(self, app, conn=conn)
-        self._tills_account = api.sysparam(self.conn).TILLS_ACCOUNT
-        self._imbalance_account = api.sysparam(self.conn).IMBALANCE_ACCOUNT
-        self._banks_account = api.sysparam(self.conn).BANKS_ACCOUNT
+        AppWindow.__init__(self, app, store=store)
+        self._tills_account = api.sysparam(self.store).TILLS_ACCOUNT
+        self._imbalance_account = api.sysparam(self.store).IMBALANCE_ACCOUNT
+        self._banks_account = api.sysparam(self.store).BANKS_ACCOUNT
 
     #
     # AppWindow overrides
@@ -376,7 +369,7 @@ class FinancialApp(AppWindow):
              group.get('new_account'),
              _("Add a new account")),
             ("NewTransaction", gtk.STOCK_NEW, _("Transaction..."),
-             group.get('new_transaction'),
+             group.get('new_store'),
              _("Add a new transaction")),
             ("Edit", gtk.STOCK_EDIT, _("Edit..."),
              group.get('edit')),
@@ -388,8 +381,8 @@ class FinancialApp(AppWindow):
         self.DeleteAccount.set_short_label(_('Delete'))
         self.DeleteTransaction.set_short_label(_('Delete'))
 
-        user = api.get_current_user(self.conn)
-        if not user.profile.check_app_permission('admin'):
+        user = api.get_current_user(self.store)
+        if not user.profile.check_app_permission(u'admin'):
             self.ConfigurePaymentMethods.set_sensitive(False)
 
     def create_ui(self):
@@ -467,11 +460,11 @@ class FinancialApp(AppWindow):
                 parent_view = page.account_view
         retval = self._run_account_editor(None, parent_view)
         if retval:
-            self.accounts.refresh_accounts(self.conn)
+            self.accounts.refresh_accounts(self.store)
 
     def _refresh_accounts(self):
         self.accounts.clear()
-        self.accounts.insert_initial(self.conn)
+        self.accounts.insert_initial(self.store)
 
     def _edit_existing_account(self, account_view):
         assert account_view.kind == 'account'
@@ -479,22 +472,22 @@ class FinancialApp(AppWindow):
                                           self.accounts.get_parent(account_view))
         if not retval:
             return
-        self.accounts.refresh_accounts(self.conn)
+        self.accounts.refresh_accounts(self.store)
 
     def _run_account_editor(self, model, parent_account):
-        trans = api.new_transaction()
+        store = api.new_store()
         if model:
-            model = trans.get(model.account)
+            model = store.fetch(model.account)
         if parent_account:
             if parent_account.kind in ['payable', 'receivable']:
                 parent_account = None
-            if parent_account == api.sysparam(self.conn).IMBALANCE_ACCOUNT:
+            if parent_account == api.sysparam(self.store).IMBALANCE_ACCOUNT:
                 parent_account = None
-        retval = self.run_dialog(AccountEditor, trans, model=model,
+        retval = self.run_dialog(AccountEditor, store, model=model,
                                  parent_account=parent_account)
-        if api.finish_transaction(trans, retval):
-            self.accounts.refresh_accounts(self.conn)
-        trans.close()
+        if store.confirm(retval):
+            self.accounts.refresh_accounts(self.store)
+        store.close()
 
         return retval
 
@@ -599,30 +592,29 @@ class FinancialApp(AppWindow):
         gnucash_filter.add_mime_type('application/x-gzip')
         ffilters.append(gnucash_filter)
 
-        filename, file_chooser = open_dialog("Import", parent=self.get_toplevel(),
-                                             filter=ffilters, with_file_chooser=True)
-        if filename is None:
-            file_chooser.destroy()
-            return
+        with selectfile("Import", parent=self.get_toplevel(),
+                        filters=ffilters) as file_chooser:
+            file_chooser.run()
 
-        ffilter = file_chooser.get_filter()
-        if ffilter == gnucash_filter:
-            format = 'gnucash.xml'
-        elif ffilter == ofx_filter:
-            format = 'account.ofx'
-        elif ffilter == all_filter:
-            # Guess
-            if filename.endswith('.ofx'):
+            filename = file_chooser.get_filename()
+            if not filename:
+                return
+
+            ffilter = file_chooser.get_filter()
+            if ffilter == gnucash_filter:
+                format = 'gnucash.xml'
+            elif ffilter == ofx_filter:
                 format = 'account.ofx'
             else:
-                format = 'gnucash.xml'
-
-        file_chooser.destroy()
-
+                # Guess
+                if filename.endswith('.ofx'):
+                    format = 'account.ofx'
+                else:
+                    format = 'gnucash.xml'
         run_dialog(ImporterDialog, self, format, filename)
 
         # Refresh everthing after an import
-        self.accounts.refresh_accounts(self.conn)
+        self.accounts.refresh_accounts(self.store)
         for page in self._pages.values():
             page.refresh()
 
@@ -708,25 +700,23 @@ class FinancialApp(AppWindow):
         self._refresh_accounts()
 
     def _delete_account(self, account_view):
-        trans = api.new_transaction()
-        account = trans.get(account_view.account)
-        methods = PaymentMethod.selectBy(
-            destination_account=account,
-            connection=trans)
+        store = api.new_store()
+        account = store.fetch(account_view.account)
+        methods = PaymentMethod.get_by_account(store, account)
         if methods.count() > 0:
             if yesno(
                 _('This account is used in at least one payment method.\n'
                   'To be able to delete it the payment methods needs to be'
                   're-configured first'), gtk.RESPONSE_YES,
                 _("Keep account"), _("Configure payment methods")):
-                trans.close()
+                store.close()
                 return
 
         elif yesno(
-            _('Are you sure you want to remove account "%s" ?' %
+            _('Are you sure you want to remove account "%s" ?') % (
               (account_view.description, )), gtk.RESPONSE_YES,
             _("Keep account"), _("Remove account")):
-            trans.close()
+            store.close()
             return
 
         if account_view.id in self._pages:
@@ -736,15 +726,15 @@ class FinancialApp(AppWindow):
         self.accounts.remove(account_view)
         self.accounts.flush()
 
-        imbalance = api.sysparam(trans).IMBALANCE_ACCOUNT
+        imbalance = api.sysparam(store).IMBALANCE_ACCOUNT
         for method in methods:
             method.destination_account = imbalance
 
-        account.remove(trans)
-        trans.commit(close=True)
+        account.remove(store)
+        store.commit(close=True)
 
     def _delete_transaction(self, item):
-        msg = _('Are you sure you want to remove transaction "%s" ?' %
+        msg = _('Are you sure you want to remove transaction "%s" ?') % (
                 (item.description))
         if yesno(msg, gtk.RESPONSE_YES,
                  _("Keep transaction"), _("Remove transaction")):
@@ -753,13 +743,13 @@ class FinancialApp(AppWindow):
         account_transactions = self._get_current_page_widget()
         account_transactions.results.remove(item)
 
-        trans = api.new_transaction()
+        store = api.new_store()
         if isinstance(item.transaction, AccountTransactionView):
-            account_transaction = trans.get(item.transaction.transaction)
+            account_transaction = store.fetch(item.transaction.transaction)
         else:
-            account_transaction = trans.get(item.transaction)
-        account_transaction.delete(account_transaction.id, connection=trans)
-        trans.commit(close=True)
+            account_transaction = store.fetch(item.transaction)
+        account_transaction.delete(account_transaction.id, store=store)
+        store.commit(close=True)
         account_transactions.update_totals()
 
     def _print_transaction_report(self):
@@ -844,7 +834,7 @@ class FinancialApp(AppWindow):
     # Edit
     def on_ConfigurePaymentMethods__activate(self, action):
         from stoqlib.gui.dialogs.paymentmethod import PaymentMethodsDialog
-        trans = api.new_transaction()
-        model = self.run_dialog(PaymentMethodsDialog, trans)
-        api.finish_transaction(trans, model)
-        trans.close()
+        store = api.new_store()
+        model = self.run_dialog(PaymentMethodsDialog, store)
+        store.confirm(model)
+        store.close()
