@@ -28,7 +28,6 @@ stoq/gui/payable/payable.py:
 """
 
 import datetime
-import gettext
 
 import pango
 import gtk
@@ -48,15 +47,14 @@ from stoqlib.gui.editors.paymentseditor import PurchasePaymentsEditor
 from stoqlib.gui.keybindings import get_accels
 from stoqlib.gui.printing import print_report
 from stoqlib.gui.search.paymentsearch import OutPaymentBillCheckSearch
-from stoqlib.gui.slaves.installmentslave import PurchaseInstallmentConfirmationSlave
+from stoqlib.gui.slaves.paymentconfirmslave import PurchasePaymentConfirmSlave
 from stoqlib.lib.message import warning
+from stoqlib.lib.translation import stoqlib_gettext as _
 from stoqlib.reporting.payment import PayablePaymentReport
-from stoqlib.reporting.payments_receipt import OutPaymentReceipt
+from stoqlib.reporting.paymentsreceipt import OutPaymentReceipt
 
 from stoq.gui.accounts import BaseAccountWindow, FilterItem
 
-_ = gettext.gettext
-
 
 class PayableApp(BaseAccountWindow):
 
@@ -160,7 +158,7 @@ class PayableApp(BaseAccountWindow):
         self.add_payment()
 
     def search_activate(self):
-        run_dialog(OutPaymentBillCheckSearch, self, self.conn)
+        run_dialog(OutPaymentBillCheckSearch, self, self.store)
 
     #
     # SearchableAppWindow
@@ -273,11 +271,11 @@ class PayableApp(BaseAccountWindow):
         return payable_views[0].can_change_due_date()
 
     def _edit(self, payable_views):
-        with api.trans() as trans:
-            order = trans.get(payable_views[0].purchase)
-            run_dialog(PurchasePaymentsEditor, self, trans, order)
+        with api.trans() as store:
+            order = store.fetch(payable_views[0].purchase)
+            run_dialog(PurchasePaymentsEditor, self, store, order)
 
-        if trans.committed:
+        if store.committed:
             self.refresh()
 
     def _pay(self, payable_views):
@@ -293,19 +291,19 @@ class PayableApp(BaseAccountWindow):
         purchase_order = payable_views[0].purchase
 
         if (purchase_order and
-            api.sysparam(self.conn).BLOCK_INCOMPLETE_PURCHASE_PAYMENTS and
+            api.sysparam(self.store).BLOCK_INCOMPLETE_PURCHASE_PAYMENTS and
             not purchase_order.status == PurchaseOrder.ORDER_CLOSED):
 
             return warning(_("Can't confirm the payment if the purchase "
                              "is not completely received yet."))
 
-        with api.trans() as trans:
-            payments = [trans.get(view.payment) for view in payable_views]
+        with api.trans() as store:
+            payments = [store.fetch(view.payment) for view in payable_views]
 
-            run_dialog(PurchaseInstallmentConfirmationSlave, self, trans,
+            run_dialog(PurchasePaymentConfirmSlave, self, store,
                        payments=payments)
 
-        if trans.committed:
+        if store.committed:
             # We need to refresh the whole list as the payment(s) can possibly
             # disappear for the selected view
             self.refresh()
@@ -392,7 +390,7 @@ class PayableApp(BaseAccountWindow):
         return items
 
     def _run_bill_check_search(self):
-        run_dialog(OutPaymentBillCheckSearch, self, self.conn)
+        run_dialog(OutPaymentBillCheckSearch, self, self.store)
 
     def _update_filter_items(self):
         options = [
