@@ -23,7 +23,6 @@
 ##
 """ Main interface definition for pos application.  """
 
-import gettext
 from decimal import Decimal
 
 import pango
@@ -43,12 +42,13 @@ from stoqlib.domain.sale import Sale, Delivery
 from stoqlib.domain.sellable import Sellable
 from stoqlib.drivers.scale import read_scale_info
 from stoqlib.exceptions import StoqlibError, TaxError
-from stoqlib.gui.events import POSConfirmSaleEvent
+from stoqlib.gui.events import POSConfirmSaleEvent, CloseLoanWizardFinishEvent
 from stoqlib.lib.barcode import parse_barcode, BarcodeInfo
 from stoqlib.lib.decorators import cached_property, public
 from stoqlib.lib.defaults import quantize
 from stoqlib.lib.message import warning, info, yesno, marker
 from stoqlib.lib.pluginmanager import get_plugin_manager
+from stoqlib.lib.translation import stoqlib_gettext as _
 from stoqlib.gui.base.dialogs import push_fullscreen, pop_fullscreen
 from stoqlib.gui.base.gtkadds import button_set_image_with_label
 from stoqlib.gui.editors.deliveryeditor import CreateDeliveryEditor
@@ -63,23 +63,26 @@ from stoqlib.gui.search.salesearch import (SaleWithToolbarSearch,
                                            SoldItemsByBranchSearch)
 from stoqlib.gui.search.sellablesearch import SellableSearch
 from stoqlib.gui.search.servicesearch import ServiceSearch
+from stoqlib.gui.search.paymentreceivingsearch import PaymentReceivingSearch
+from stoqlib.gui.wizards.loanwizard import CloseLoanWizard
 from stoqlib.gui.wizards.salereturnwizard import SaleTradeWizard
 
 from stoq.gui.application import AppWindow
 
-_ = gettext.gettext
 log = Logger('stoq.pos')
 
 
 @public(since="1.5.0")
 class TemporarySaleItem(object):
-    def __init__(self, sellable, quantity, price=None, notes=None):
+    def __init__(self, sellable, quantity, price=None,
+                 notes=None, can_remove=True):
         # Use only 3 decimal places for the quantity
         self.quantity = Decimal('%.3f' % quantity)
         self.sellable = sellable
         self.description = sellable.get_description()
         self.unit = sellable.get_unit_description()
         self.code = sellable.code
+        self.can_remove = can_remove
 
         if not price:
             price = sellable.price
@@ -117,19 +120,21 @@ class PosApp(AppWindow):
     gladefile = "pos"
     embedded = True
 
-    def __init__(self, app, conn=None):
+    def __init__(self, app, store=None):
+        self._current_store = None
         self._trade = None
         self._trade_infobar = None
+        self._trade_total_paid = 0
 
-        AppWindow.__init__(self, app, conn=conn)
+        AppWindow.__init__(self, app, store=store)
 
         self._delivery = None
-        self.param = api.sysparam(self.conn)
+        self.param = api.sysparam(self.store)
         self._coupon = None
         # Cant use self._coupon to verify if there is a sale, since
         # CONFIRM_SALES_ON_TILL doesnt create a coupon
         self._sale_started = False
-        self._scale_settings = DeviceSettings.get_scale_settings(self.conn)
+        self._scale_settings = DeviceSettings.get_scale_settings(self.store)
 
     #
     # Application
@@ -141,10 +146,15 @@ class PosApp(AppWindow):
             # File
             ('NewTrade', None, _('Trade...'),
              group.get('new_trade')),
+            ('PaymentReceive', None, _('Payment Receival...'),
+             group.get('payment_receive')),
             ("TillOpen", None, _("Open Till..."),
              group.get('till_open')),
             ("TillClose", None, _("Close Till..."),
              group.get('till_close')),
+            ("TillVerify", None, _("Verify Till..."),
+             group.get('till_verify')),
+            ("LoanClose", None, _("Close loan...")),
 
             # Order
             ("OrderMenu", None, _("Order")),
@@ -217,6 +227,8 @@ class PosApp(AppWindow):
         # be enabled.
         self._printer.run_initial_checks()
 
+        CloseLoanWizardFinishEvent.connect(self._on_CloseLoanWizardFinishEvent)
+
     def deactivate(self):
         self.uimanager.remove_ui(self.pos_ui)
 
@@ -224,6 +236,11 @@ class PosApp(AppWindow):
         self.uimanager.get_widget('/toolbar').show()
         self.uimanager.get_widget('/menubar/ViewMenu/ToggleToolbar').show()
 
+        # one PosApp is created everytime the pos is opened. If we dont
+        # disconnect, the callback from this instance would still be called, but
+        # its no longer valid.
+        CloseLoanWizardFinishEvent.disconnect(self._on_CloseLoanWizardFinishEvent)
+
     def setup_focus(self):
         self.barcode.grab_focus()
 
@@ -283,7 +300,7 @@ class PosApp(AppWindow):
     #
 
     def _setup_printer(self):
-        self._printer = FiscalPrinterHelper(self.conn,
+        self._printer = FiscalPrinterHelper(self.store,
                                             parent=self)
         self._printer.connect('till-status-changed',
                               self._on_PrinterHelper__till_status_changed)
@@ -315,7 +332,7 @@ class PosApp(AppWindow):
             pop_fullscreen(window)
             window.unfullscreen()
 
-        for widget in (self.TillOpen, self.TillClose):
+        for widget in [self.TillOpen, self.TillClose, self.TillVerify]:
             widget.set_visible(not self.param.POS_SEPARATE_CASHIER)
 
         if self.param.CONFIRM_SALES_ON_TILL:
@@ -328,7 +345,8 @@ class PosApp(AppWindow):
     def _setup_widgets(self):
         self._inventory_widgets = [self.Sales, self.barcode, self.quantity,
                                    self.sale_items, self.advanced_search,
-                                   self.checkout_button]
+                                   self.checkout_button, self.NewTrade,
+                                   self.LoanClose]
         self.register_sensitive_group(self._inventory_widgets,
                                       lambda: not self.has_open_inventory())
 
@@ -398,8 +416,8 @@ class PosApp(AppWindow):
         sale_item = TemporarySaleItem(sellable=sellable,
                                       quantity=quantity)
         if is_service:
-            with api.trans() as trans:
-                rv = self.run_dialog(ServiceItemEditor, trans, sale_item)
+            with api.trans() as store:
+                rv = self.run_dialog(ServiceItemEditor, store, sale_item)
             if not rv:
                 return
         self._update_added_item(sale_item)
@@ -411,8 +429,9 @@ class PosApp(AppWindow):
         barcode = self.barcode.get_text()
         if not barcode:
             raise StoqlibError("_get_sellable needs a barcode")
+        barcode = unicode(barcode)
 
-        fmt = api.sysparam(self.conn).SCALE_BARCODE_FORMAT
+        fmt = api.sysparam(self.store).SCALE_BARCODE_FORMAT
 
         # Check if this barcode is from a scale
         info = parse_barcode(barcode, fmt)
@@ -420,15 +439,13 @@ class PosApp(AppWindow):
             barcode = info.code
             weight = info.weight
 
-        sellable = Sellable.selectOneBy(barcode=barcode,
-                                        status=Sellable.STATUS_AVAILABLE,
-                                        connection=self.conn)
+        sellable = self.store.find(Sellable, barcode=barcode,
+                                   status=Sellable.STATUS_AVAILABLE).one()
 
         # If the barcode didnt match, maybe the user typed the product code
         if not sellable:
-            sellable = Sellable.selectOneBy(code=barcode,
-                                            status=Sellable.STATUS_AVAILABLE,
-                                            connection=self.conn)
+            sellable = self.store.find(Sellable, code=barcode,
+                                       status=Sellable.STATUS_AVAILABLE).one()
 
         # If the barcode has the price information, we need to calculate the
         # corresponding weight.
@@ -450,7 +467,7 @@ class PosApp(AppWindow):
         # Enable/disable the part of the ui that is used for sales,
         # usually manipulated when printer information changes.
         widgets = [self.barcode, self.quantity, self.sale_items,
-                   self.advanced_search]
+                   self.advanced_search, self.PaymentReceive]
         self.set_sensitive(widgets, value)
 
         if value:
@@ -461,7 +478,7 @@ class PosApp(AppWindow):
 
         # It's possible to do a Sangria from the Sale search,
         # disable it for now
-        widgets = [self.TillOpen, self.TillClose, self.Sales]
+        widgets = [self.TillOpen, self.TillClose, self.TillVerify, self.Sales]
         self.set_sensitive(widgets, False)
 
         text = _(u"POS operations requires a connected fiscal printer.")
@@ -486,7 +503,9 @@ class PosApp(AppWindow):
         self.till_status_label.set_markup(text)
 
         self.set_sensitive([self.TillOpen], closed)
-        self.set_sensitive([self.TillClose, self.NewTrade],
+        self.set_sensitive([self.TillVerify],
+                           not closed and not blocked)
+        self.set_sensitive([self.TillClose, self.NewTrade, self.LoanClose],
                            not closed or blocked)
 
         self._set_sale_sensitive(not closed and not blocked)
@@ -515,6 +534,8 @@ class PosApp(AppWindow):
             sale_item.service and
             sale_item.service != self.param.DELIVERY_SERVICE)
         self.set_sensitive([self.edit_item_button], can_edit)
+        self.set_sensitive([self.remove_item_button],
+                           sale_item is not None and sale_item.can_remove)
 
         self.set_sensitive((self.checkout_button,
                             self.ConfirmOrder), has_products or has_services)
@@ -542,13 +563,13 @@ class PosApp(AppWindow):
         return quantity
 
     def _read_scale(self, sellable):
-        data = read_scale_info(self.conn)
+        data = read_scale_info(self.store)
         self.quantity.set_value(data.weight)
 
     def _run_advanced_search(self, search_str=None, message=None):
         sellable_view_item = self.run_dialog(
             SellableSearch,
-            self.conn,
+            self.store,
             selection_mode=gtk.SELECTION_BROWSE,
             search_str=search_str,
             sale_items=self.sale_items,
@@ -559,7 +580,7 @@ class PosApp(AppWindow):
             self.barcode.grab_focus()
             return
 
-        sellable = Sellable.get(sellable_view_item.id, connection=self.conn)
+        sellable = sellable_view_item.sellable
         self._update_list(sellable)
         self.barcode.grab_focus()
 
@@ -624,7 +645,7 @@ class PosApp(AppWindow):
         self.barcode.grab_focus()
 
     def _check_available_stock(self, storable, sellable):
-        branch = api.get_current_branch(self.conn)
+        branch = api.get_current_branch(self.store)
         available = storable.get_balance_for_branch(branch)
         added = sum([sale_item.quantity
                      for sale_item in self.sale_items
@@ -637,7 +658,8 @@ class PosApp(AppWindow):
         self._sale_started = False
         self.sale_items.clear()
 
-        widgets = [self.search_box, self.list_vbox, self.CancelOrder]
+        widgets = [self.search_box, self.list_vbox, self.CancelOrder,
+                   self.PaymentReceive]
         self.set_sensitive(widgets, True)
 
         self._delivery = None
@@ -646,20 +668,17 @@ class PosApp(AppWindow):
         self.barcode.set_text('')
         self._update_widgets()
 
-    def _clear_trade(self):
-        if not self._trade:
-            return
-
-        trans = self._trade.get_connection()
-        try:
-            trans.rollback()
-            trans.close()
-        except Exception:
-            # trans may have been closed on checkout
-            pass
+        # store may already been closed on checkout
+        if self._current_store and not self._current_store.obsolete:
+            self._current_store.rollback(close=True)
+        self._current_store = None
 
+    def _clear_trade(self, remove=False):
+        if self._trade and remove:
+            self._trade.remove()
         self._trade = None
-        self._update_trade_infobar()
+        self._trade_total_paid = 0
+        self._remove_trade_infobar()
 
     def _edit_sale_item(self, sale_item):
         if sale_item.service:
@@ -667,8 +686,8 @@ class PosApp(AppWindow):
             if sale_item.service == delivery_service:
                 self._edit_delivery()
                 return
-            with api.trans() as trans:
-                model = self.run_dialog(ServiceItemEditor, trans, sale_item)
+            with api.trans() as store:
+                model = self.run_dialog(ServiceItemEditor, store, sale_item)
             if model:
                 self.sale_items.update(sale_item)
         else:
@@ -711,7 +730,7 @@ class PosApp(AppWindow):
         @returns: The delivery
         """
         #FIXME: Canceling the editor still saves the changes.
-        return self.run_dialog(CreateDeliveryEditor, self.conn,
+        return self.run_dialog(CreateDeliveryEditor, self.store,
                                self._delivery,
                                sale_items=self._get_deliverable_items())
 
@@ -735,33 +754,33 @@ class PosApp(AppWindow):
         self._update_added_item(self._delivery_item,
                                 new_item=new_item)
 
-    def _create_sale(self, trans):
-        user = api.get_current_user(trans)
-        branch = api.get_current_branch(trans)
+    def _create_sale(self, store):
+        user = api.get_current_user(store)
+        branch = api.get_current_branch(store)
         salesperson = user.person.salesperson
-        cfop = api.sysparam(trans).DEFAULT_SALES_CFOP
-        group = PaymentGroup(connection=trans)
-        sale = Sale(connection=trans,
+        cfop = api.sysparam(store).DEFAULT_SALES_CFOP
+        group = PaymentGroup(store=store)
+        sale = Sale(store=store,
                     branch=branch,
                     salesperson=salesperson,
                     group=group,
                     cfop=cfop,
                     coupon_id=None,
-                    operation_nature=api.sysparam(trans).DEFAULT_OPERATION_NATURE)
+                    operation_nature=api.sysparam(store).DEFAULT_OPERATION_NATURE)
 
         if self._delivery:
-            sale.client = trans.get(self._delivery.client)
-            sale.transporter = trans.get(self._delivery.transporter)
+            sale.client = store.fetch(self._delivery.client)
+            sale.storeporter = store.fetch(self._delivery.transporter)
             delivery = Delivery(
-                connection=trans,
-                address=trans.get(self._delivery.address),
-                transporter=trans.get(self._delivery.transporter),
+                store=store,
+                address=store.fetch(self._delivery.address),
+                transporter=store.fetch(self._delivery.transporter),
                 )
         else:
             delivery = None
 
         for fake_sale_item in self.sale_items:
-            sale_item = sale.add_sellable(trans.get(fake_sale_item.sellable),
+            sale_item = sale.add_sellable(store.fetch(fake_sale_item.sellable),
                                           price=fake_sale_item.price,
                                           quantity=fake_sale_item.quantity)
             sale_item.notes = fake_sale_item.notes
@@ -783,6 +802,14 @@ class PosApp(AppWindow):
         """
         assert len(self.sale_items) >= 1
 
+        if self._current_store:
+            store = self._current_store
+            savepoint = 'before_run_fiscalprinter_confirm'
+            store.savepoint(savepoint)
+        else:
+            store = api.new_store()
+            savepoint = None
+
         if self._trade:
             if self._get_subtotal() < self._trade.returned_total:
                 info(_("Traded value is greater than the new sale's value. "
@@ -790,34 +817,36 @@ class PosApp(AppWindow):
                        "then make a new sale"))
                 return
 
-            trans = self._trade.get_connection()
-            sale = self._create_sale(trans)
+            sale = self._create_sale(store)
             self._trade.new_sale = sale
             self._trade.trade()
         else:
-            trans = api.new_transaction()
-            sale = self._create_sale(trans)
+            sale = self._create_sale(store)
 
         if self.param.CONFIRM_SALES_ON_TILL:
             sale.order()
-            trans.commit(close=True)
+            store.commit(close=True)
         else:
             assert self._coupon
 
-            ordered = self._coupon.confirm(sale, trans)
-            # Dont call finish_transaction here, since confirm() above did it
-            # already
+            ordered = self._coupon.confirm(sale, store, savepoint,
+                                           subtotal=self._get_subtotal(),
+                                           total_paid=self._trade_total_paid)
+            # Dont call store.confirm() here, since coupon.confirm()
+            # above already did it
             if not ordered:
                 # FIXME: Move to TEF plugin
                 manager = get_plugin_manager()
                 if manager.is_active('tef') or cancel_clear:
                     self._cancel_order(show_confirmation=False)
-                trans.close()
-                self._clear_trade()
+                elif not self._current_store:
+                    # Just do that if a store was created above and
+                    # if _cancel_order wasn't called (it closes the connection)
+                    store.rollback(close=True)
                 return
 
             log.info("Checking out")
-            trans.close()
+            store.close()
 
         self._coupon = None
         POSConfirmSaleEvent.emit(sale, self.sale_items[:])
@@ -825,6 +854,7 @@ class PosApp(AppWindow):
 
     def _remove_selected_item(self):
         sale_item = self.sale_items.get_selected()
+        assert sale_item.can_remove
         self._coupon_remove_item(sale_item)
         self.sale_items.remove(sale_item)
         self._check_delivery_removed(sale_item)
@@ -840,20 +870,26 @@ class PosApp(AppWindow):
         else:
             self._add_sale_item(search_str)
 
-    def _update_trade_infobar(self):
-        if self._trade and self._trade_infobar:
-            self._trade_infobar.show()
-        elif not self._trade and self._trade_infobar:
-            self._trade_infobar.hide()
-        elif self._trade:
-            button = gtk.Button(_("Cancel trade"))
-            button.connect('clicked', self._on_remove_trade_button__clicked)
-            value = converter.as_string(currency, self._trade.returned_total)
-            msg = _("There is a trade with value %s in progress...\n"
-                    "When checking out, it will be used as part of "
-                    "the payment.") % (value, )
-            self._trade_infobar = self.add_info_bar(gtk.MESSAGE_INFO, msg,
-                                                    action_widget=button)
+    def _remove_trade_infobar(self):
+        if not self._trade_infobar:
+            return
+        self._trade_infobar.destroy()
+        self._trade_infobar = None
+
+    def _show_trade_infobar(self, trade):
+        self._remove_trade_infobar()
+        if not trade:
+            return
+
+        button = gtk.Button(_("Cancel trade"))
+        button.connect('clicked', self._on_remove_trade_button__clicked)
+        value = converter.as_string(currency, self._trade.returned_total)
+        msg = _("There is a trade with value %s in progress...\n"
+                "When checking out, it will be used as part of "
+                "the payment.") % (value, )
+        self._trade_infobar = self.add_info_bar(gtk.MESSAGE_INFO, msg,
+                                                action_widget=button)
+        self._trade_total_paid += self._trade.returned_total
 
     #
     # Coupon related
@@ -870,6 +906,7 @@ class PosApp(AppWindow):
                     gtk.RESPONSE_YES, _("Try again"), _("Cancel sale")):
                     return None
 
+        self.set_sensitive([self.PaymentReceive], False)
         return coupon
 
     def _coupon_add_item(self, sale_item):
@@ -916,25 +953,25 @@ class PosApp(AppWindow):
         self._cancel_order()
 
     def on_Clients__activate(self, action):
-        self.run_dialog(ClientSearch, self.conn, hide_footer=True)
+        self.run_dialog(ClientSearch, self.store, hide_footer=True)
 
     def on_Sales__activate(self, action):
-        with api.trans() as trans:
-            self.run_dialog(SaleWithToolbarSearch, trans)
+        with api.trans() as store:
+            self.run_dialog(SaleWithToolbarSearch, store)
 
     def on_SoldItemsByBranchSearch__activate(self, action):
-        self.run_dialog(SoldItemsByBranchSearch, self.conn)
+        self.run_dialog(SoldItemsByBranchSearch, self.store)
 
     def on_ProductSearch__activate(self, action):
-        self.run_dialog(ProductSearch, self.conn, hide_footer=True,
+        self.run_dialog(ProductSearch, self.store, hide_footer=True,
                         hide_toolbar=True, hide_cost_column=True)
 
     def on_ServiceSearch__activate(self, action):
-        self.run_dialog(ServiceSearch, self.conn, hide_toolbar=True,
+        self.run_dialog(ServiceSearch, self.store, hide_toolbar=True,
                         hide_cost_column=True)
 
     def on_DeliverySearch__activate(self, action):
-        self.run_dialog(DeliverySearch, self.conn)
+        self.run_dialog(DeliverySearch, self.store)
 
     def on_ConfirmOrder__activate(self, action):
         self.checkout()
@@ -942,30 +979,62 @@ class PosApp(AppWindow):
     def on_NewDelivery__activate(self, action):
         self._create_delivery()
 
+    def on_PaymentReceive__activate(self, action):
+        self.run_dialog(PaymentReceivingSearch, self.store)
+
     def on_TillClose__activate(self, action):
         self._close_till()
 
     def on_TillOpen__activate(self, action):
         self._printer.open_till()
 
+    def on_TillVerify__activate(self, action):
+        self._printer.verify_till()
+
+    def on_LoanClose__activate(self, action):
+        if self.check_open_inventory():
+            return
+
+        if self._current_store:
+            store = self._current_store
+            store.savepoint('before_run_wizard_closeloan')
+        else:
+            store = api.new_store()
+
+        rv = self.run_dialog(CloseLoanWizard, store, create_sale=False,
+                             require_sale_items=True)
+        if rv:
+            self._current_store = store
+        elif self._current_store:
+            store.rollback_to_savepoint('before_run_wizard_closeloan')
+        else:
+            store.rollback(close=True)
+
     def on_NewTrade__activate(self, action):
         if self._trade:
             if yesno(_("There is already a trade in progress... Do you "
                        "want to cancel it and start a new one?"),
-                     gtk.RESPONSE_NO, _("Cancel trade"), _("Don't cancel")):
-                self._clear_trade()
+                     gtk.RESPONSE_NO, _("Cancel trade"), _("Finish trade")):
+                self._clear_trade(remove=True)
             else:
                 return
 
-        trans = api.new_transaction()
-        rv = self.run_dialog(SaleTradeWizard, trans)
-        if rv:
-            self._trade = rv
+        if self._current_store:
+            store = self._current_store
+            store.savepoint('before_run_wizard_saletrade')
         else:
-            trans.rollback()
-            trans.close()
+            store = api.new_store()
 
-        self._update_trade_infobar()
+        trade = self.run_dialog(SaleTradeWizard, store)
+        if trade:
+            self._trade = trade
+            self._current_store = store
+        elif self._current_store:
+            store.rollback_to_savepoint('before_run_wizard_saletrade')
+        else:
+            store.rollback(close=True)
+
+        self._show_trade_infobar(trade)
 
     #
     # Other callbacks
@@ -979,7 +1048,7 @@ class PosApp(AppWindow):
 
     def _on_context_remove__can_disable(self, menu_item):
         selected = self.sale_items.get_selected()
-        if selected:
+        if selected and selected.can_remove:
             return False
 
         return True
@@ -987,7 +1056,7 @@ class PosApp(AppWindow):
     def _on_remove_trade_button__clicked(self, button):
         if yesno(_("Do you really want to cancel the trade in progress?"),
                  gtk.RESPONSE_NO, _("Cancel trade"), _("Don't cancel")):
-            self._clear_trade()
+            self._clear_trade(remove=True)
 
     def on_till_status_label__activate_link(self, button, link):
         if link == 'open-till':
@@ -1047,3 +1116,9 @@ class PosApp(AppWindow):
 
         # We dont have an ecf. Disable till related operations
         self._disable_printer_ui()
+
+    def _on_CloseLoanWizardFinishEvent(self, loan, sale, wizard):
+        for item in wizard.get_sold_items():
+            self.add_sale_item(
+                TemporarySaleItem(sellable=item[0], quantity=item[1],
+                                  price=item[2], can_remove=False))
