@@ -23,7 +23,6 @@
 ##
 """ Implementation of sales application.  """
 
-import gettext
 import decimal
 from datetime import date
 from dateutil.relativedelta import relativedelta
@@ -34,9 +33,9 @@ from kiwi.currency import currency
 from kiwi.enums import SearchFilterPosition
 from kiwi.ui.search import ComboSearchFilter
 from kiwi.ui.objectlist import SearchColumn
-
+from storm.expr import And, Or
 from stoqlib.api import api
-from stoqlib.database.orm import func, AND, OR
+from stoqlib.database.expr import Date
 from stoqlib.domain.invoice import InvoicePrinter
 from stoqlib.domain.sale import Sale, SaleView
 from stoqlib.gui.dialogs.invoicedialog import SaleInvoicePrinterDialog
@@ -61,14 +60,12 @@ from stoqlib.lib.formatters import format_quantity
 from stoqlib.lib.invoice import SaleInvoice, print_sale_invoice
 from stoqlib.lib.message import info, yesno
 from stoqlib.lib.permissions import PermissionManager
+from stoqlib.lib.translation import stoqlib_gettext as _
 from stoqlib.reporting.sale import SalesReport
 
 from stoq.gui.application import SearchableAppWindow
 
 
-_ = gettext.gettext
-
-
 class FilterItem(object):
     def __init__(self, name, value=None):
         self.name = name
@@ -77,19 +74,19 @@ class FilterItem(object):
 
 
 SALES_FILTERS = {
-    'sold-today': AND(func.DATE(Sale.q.open_date) == date.today(),
-                      OR(Sale.q.status == Sale.STATUS_CONFIRMED,
-                         Sale.q.status == Sale.STATUS_PAID)),
-    'sold-7days': AND(func.DATE(Sale.q.open_date) <= date.today(),
-                      func.DATE(Sale.q.open_date) >= date.today() - relativedelta(days=7),
-                      OR(Sale.q.status == Sale.STATUS_CONFIRMED,
-                          Sale.q.status == Sale.STATUS_PAID)),
-    'sold-28days': AND(func.DATE(Sale.q.open_date) <= date.today(),
-                       func.DATE(Sale.q.open_date) >= date.today() - relativedelta(days=28),
-                       OR(Sale.q.status == Sale.STATUS_CONFIRMED,
-                          Sale.q.status == Sale.STATUS_PAID)),
-    'expired-quotes': AND(func.DATE(Sale.q.expire_date) < date.today(),
-                          Sale.q.status == Sale.STATUS_QUOTE),
+    'sold-today': And(Date(Sale.open_date) == date.today(),
+                      Or(Sale.status == Sale.STATUS_CONFIRMED,
+                         Sale.status == Sale.STATUS_PAID)),
+    'sold-7days': And(Date(Sale.open_date) <= date.today(),
+                      Date(Sale.open_date) >= date.today() - relativedelta(days=7),
+                      Or(Sale.status == Sale.STATUS_CONFIRMED,
+                          Sale.status == Sale.STATUS_PAID)),
+    'sold-28days': And(Date(Sale.open_date) <= date.today(),
+                       Date(Sale.open_date) >= date.today() - relativedelta(days=28),
+                       Or(Sale.status == Sale.STATUS_CONFIRMED,
+                          Sale.status == Sale.STATUS_PAID)),
+    'expired-quotes': And(Date(Sale.expire_date) < date.today(),
+                          Sale.status == Sale.STATUS_QUOTE),
 }
 
 
@@ -114,10 +111,10 @@ class SalesApp(SearchableAppWindow):
         "SalesPrintInvoice": ('app.sales.print_invoice', PermissionManager.PERM_SEARCH),
     }
 
-    def __init__(self, app, conn=None):
+    def __init__(self, app, store=None):
         self.summary_label = None
         self._visible_date_col = None
-        SearchableAppWindow.__init__(self, app, conn=conn)
+        SearchableAppWindow.__init__(self, app, store=store)
 
     #
     # Application
@@ -200,7 +197,7 @@ class SalesApp(SearchableAppWindow):
         self.set_help_section(_("Sales help"), 'app-sales')
 
     def create_ui(self):
-        if api.sysparam(self.conn).SMART_LIST_LOADING:
+        if api.sysparam(self.store).SMART_LIST_LOADING:
             self.search.search.enable_lazy_search()
 
         self.popup = self.uimanager.get_widget('/SaleSelection')
@@ -313,7 +310,7 @@ class SalesApp(SearchableAppWindow):
 
     def _setup_slaves(self):
         # This is only here to reuse the logic in it.
-        self.sale_toolbar = SaleListToolbar(self.conn, self.results,
+        self.sale_toolbar = SaleListToolbar(self.store, self.results,
                                             parent=self)
 
     def _can_cancel(self, view):
@@ -345,9 +342,9 @@ class SalesApp(SearchableAppWindow):
     def _print_invoice(self):
         sale_view = self.results.get_selected()
         assert sale_view
-        sale = Sale.get(sale_view.id, connection=self.conn)
-        station = api.get_current_station(self.conn)
-        printer = InvoicePrinter.get_by_station(station, self.conn)
+        sale = sale_view.sale
+        station = api.get_current_station(self.store)
+        printer = InvoicePrinter.get_by_station(station, self.store)
         if printer is None:
             info(_("There are no invoice printer configured for this station"))
             return
@@ -357,11 +354,11 @@ class SalesApp(SearchableAppWindow):
         if not invoice.has_invoice_number() or sale.invoice_number:
             print_sale_invoice(invoice, printer)
         else:
-            trans = api.new_transaction()
-            retval = self.run_dialog(SaleInvoicePrinterDialog, trans,
-                                     trans.get(sale), printer)
-            api.finish_transaction(trans, retval)
-            trans.close()
+            store = api.new_store()
+            retval = self.run_dialog(SaleInvoicePrinterDialog, store,
+                                     store.fetch(sale), printer)
+            store.confirm(retval)
+            store.close()
 
     def _setup_columns(self, sale_status=Sale.STATUS_CONFIRMED):
         self._status_col.visible = False
@@ -412,7 +409,7 @@ class SalesApp(SearchableAppWindow):
 
     def _get_status_query(self, state):
         if state.value is None:
-            return SaleView.q.status != Sale.STATUS_ORDERED
+            return SaleView.status != Sale.STATUS_ORDERED
 
         if state.value.name == 'custom':
             self._setup_columns(None)
@@ -420,24 +417,23 @@ class SalesApp(SearchableAppWindow):
 
         elif state.value.name == 'status':
             self._setup_columns(state.value.value)
-            return SaleView.q.status == state.value.value
+            return SaleView.status == state.value.value
 
         raise AssertionError(state.value.name, state.value.value)
 
-    def _query(self, query, having, conn):
-        branch = api.get_current_branch(self.conn)
-        return self.search_table.select_by_branch(query, branch, having=having,
-                                                  connection=conn)
+    def _query(self, store):
+        branch = api.get_current_branch(self.store)
+        return self.search_table.find_by_branch(store, branch)
 
     def _new_sale_quote(self):
-        trans = api.new_transaction()
-        model = self.run_dialog(SaleQuoteWizard, trans)
-        api.finish_transaction(trans, model)
-        trans.close()
+        store = api.new_store()
+        model = self.run_dialog(SaleQuoteWizard, store)
+        store.confirm(model)
+        store.close()
 
     def _search_product(self):
-        hide_cost_column = not api.sysparam(self.conn).SHOW_COST_COLUMN_IN_SALES
-        self.run_dialog(ProductSearch, self.conn, hide_footer=True,
+        hide_cost_column = not api.sysparam(self.store).SHOW_COST_COLUMN_IN_SALES
+        self.run_dialog(ProductSearch, self.store, hide_footer=True,
                         hide_toolbar=True, hide_cost_column=hide_cost_column)
 
     #
@@ -468,12 +464,12 @@ class SalesApp(SearchableAppWindow):
         if yesno(_('This will cancel the selected quote. Are you sure?'),
                  gtk.RESPONSE_NO, _("Don't cancel"), _("Cancel quote")):
             return
-        trans = api.new_transaction()
+        store = api.new_store()
         sale_view = self.results.get_selected()
-        sale = trans.get(sale_view.sale)
+        sale = store.fetch(sale_view.sale)
         sale.cancel()
-        api.finish_transaction(trans, True)
-        trans.close()
+        store.confirm(True)
+        store.close()
         self.search.refresh()
 
     def on_SalesPrintInvoice__activate(self, action):
@@ -484,56 +480,56 @@ class SalesApp(SearchableAppWindow):
     def on_LoanNew__activate(self, action):
         if self.check_open_inventory():
             return
-        trans = api.new_transaction()
-        model = self.run_dialog(NewLoanWizard, trans)
-        api.finish_transaction(trans, model)
-        trans.close()
+        store = api.new_store()
+        model = self.run_dialog(NewLoanWizard, store)
+        store.confirm(model)
+        store.close()
 
     def on_LoanClose__activate(self, action):
         if self.check_open_inventory():
             return
-        trans = api.new_transaction()
-        model = self.run_dialog(CloseLoanWizard, trans)
-        api.finish_transaction(trans, model)
-        trans.close()
+        store = api.new_store()
+        model = self.run_dialog(CloseLoanWizard, store)
+        store.confirm(model)
+        store.close()
 
     def on_LoanSearch__activate(self, action):
-        self.run_dialog(LoanSearch, self.conn)
+        self.run_dialog(LoanSearch, self.store)
 
     def on_LoanSearchItems__activate(self, action):
-        self.run_dialog(LoanItemSearch, self.conn)
+        self.run_dialog(LoanItemSearch, self.store)
 
     # Search
 
     def on_SearchClient__activate(self, button):
-        self.run_dialog(ClientSearch, self.conn, hide_footer=True)
+        self.run_dialog(ClientSearch, self.store, hide_footer=True)
 
     def on_SearchProduct__activate(self, button):
         self._search_product()
 
     def on_SearchCommission__activate(self, button):
-        self.run_dialog(CommissionSearch, self.conn)
+        self.run_dialog(CommissionSearch, self.store)
 
     def on_SearchClientCalls__activate(self, action):
-        self.run_dialog(ClientCallsSearch, self.conn)
+        self.run_dialog(ClientCallsSearch, self.store)
 
     def on_SearchCreditCheckHistory__activate(self, action):
-        self.run_dialog(CreditCheckHistorySearch, self.conn)
+        self.run_dialog(CreditCheckHistorySearch, self.store)
 
     def on_SearchService__activate(self, button):
-        self.run_dialog(ServiceSearch, self.conn, hide_toolbar=True)
+        self.run_dialog(ServiceSearch, self.store, hide_toolbar=True)
 
     def on_SearchSoldItemsByBranch__activate(self, button):
-        self.run_dialog(SoldItemsByBranchSearch, self.conn)
+        self.run_dialog(SoldItemsByBranchSearch, self.store)
 
     def on_SearchSalesByPaymentMethod__activate(self, button):
-        self.run_dialog(SalesByPaymentMethodSearch, self.conn)
+        self.run_dialog(SalesByPaymentMethodSearch, self.store)
 
     def on_SearchDelivery__activate(self, action):
-        self.run_dialog(DeliverySearch, self.conn)
+        self.run_dialog(DeliverySearch, self.store)
 
     def on_SearchSalesPersonSales__activate(self, action):
-        self.run_dialog(SalesPersonSalesSearch, self.conn)
+        self.run_dialog(SalesPersonSalesSearch, self.store)
 
     # Toolbar
 
