@@ -23,7 +23,6 @@
 ##
 """ Main gui definition for stock application.  """
 
-import gettext
 import decimal
 
 import pango
@@ -36,10 +35,10 @@ from kiwi.ui.objectlist import Column, SearchColumn
 from stoqlib.api import api
 from stoqlib.exceptions import DatabaseInconsistency
 from stoqlib.domain.person import Branch
-from stoqlib.domain.sellable import Sellable
 from stoqlib.domain.views import ProductFullStockView
 from stoqlib.lib.defaults import sort_sellable_code
 from stoqlib.lib.message import warning
+from stoqlib.lib.translation import stoqlib_gettext as _
 from stoqlib.gui.dialogs.initialstockdialog import InitialStockDialog
 from stoqlib.gui.dialogs.productstockdetails import ProductStockHistoryDialog
 from stoqlib.gui.dialogs.sellableimage import SellableImageViewer
@@ -62,7 +61,6 @@ from stoqlib.gui.stockicons import STOQ_RECEIVING
 
 from stoq.gui.application import SearchableAppWindow
 
-_ = gettext.gettext
 log = Logger('stoq.gui.stock')
 
 
@@ -141,7 +139,7 @@ class StockApp(SearchableAppWindow):
         self.ProductStockHistory.props.is_important = True
 
     def create_ui(self):
-        if api.sysparam(self.conn).SMART_LIST_LOADING:
+        if api.sysparam(self.store).SMART_LIST_LOADING:
             self.search.search.enable_lazy_search()
 
         self.popup = self.uimanager.get_widget('/StockSelection')
@@ -197,7 +195,7 @@ class StockApp(SearchableAppWindow):
         self._receive_purchase()
 
     def search_activate(self):
-        self.run_dialog(ProductStockSearch, self.conn)
+        self.run_dialog(ProductStockSearch, self.store)
 
     def set_open_inventory(self):
         self.set_sensitive(self._inventory_widgets, False)
@@ -216,7 +214,7 @@ class StockApp(SearchableAppWindow):
         self.set_text_field_columns(['description'])
         self.branch_filter = ComboSearchFilter(
             _('Show by:'), self._get_branches())
-        self.branch_filter.select(api.get_current_branch(self.conn))
+        self.branch_filter.select(api.get_current_branch(self.store))
         self.add_filter(self.branch_filter, position=SearchFilterPosition.TOP)
 
     def get_columns(self):
@@ -248,15 +246,13 @@ class StockApp(SearchableAppWindow):
     # Private API
     #
 
-    def _query(self, query, having, conn):
+    def _query(self, store):
         branch = self.branch_filter.get_state().value
-        return self.search_table.select_by_branch(query, branch,
-                                                  having=having,
-                                                  connection=conn)
+        return self.search_table.find_by_branch(store, branch)
 
     def _get_branches(self):
         items = [(b.person.name, b)
-                  for b in Branch.select(connection=self.conn)]
+                  for b in self.store.find(Branch)]
         if not items:
             raise DatabaseInconsistency('You should have at least one '
                                         'branch on your database.'
@@ -265,7 +261,7 @@ class StockApp(SearchableAppWindow):
         return items
 
     def _update_widgets(self):
-        branch = api.get_current_branch(self.conn)
+        branch = api.get_current_branch(self.store)
 
         is_main_branch = self.branch_filter.get_state().value is branch
         item = self.results.get_selected()
@@ -314,19 +310,19 @@ class StockApp(SearchableAppWindow):
     def _transfer_stock(self):
         if self.check_open_inventory():
             return
-        trans = api.new_transaction()
-        model = self.run_dialog(StockTransferWizard, trans)
-        api.finish_transaction(trans, model)
-        trans.close()
+        store = api.new_store()
+        model = self.run_dialog(StockTransferWizard, store)
+        store.confirm(model)
+        store.close()
         self.search.refresh()
 
     def _receive_purchase(self):
         if self.check_open_inventory():
             return
-        trans = api.new_transaction()
-        model = self.run_dialog(ReceivingOrderWizard, trans)
-        api.finish_transaction(trans, model)
-        trans.close()
+        store = api.new_store()
+        model = self.run_dialog(ReceivingOrderWizard, store)
+        store.confirm(model)
+        store.close()
         self.search.refresh()
 
     #
@@ -348,20 +344,20 @@ class StockApp(SearchableAppWindow):
 
     def on_ProductStockHistory__activate(self, button):
         selected = self.results.get_selected()
-        sellable = Sellable.get(selected.id, connection=self.conn)
-        self.run_dialog(ProductStockHistoryDialog, self.conn, sellable,
+        sellable = selected.sellable
+        self.run_dialog(ProductStockHistoryDialog, self.store, sellable,
                         branch=self.branch_filter.combo.get_selected())
 
     def on_EditProduct__activate(self, button):
         selected = self.results.get_selected()
         assert selected
 
-        trans = api.new_transaction()
-        product = trans.get(selected.product)
+        store = api.new_store()
+        product = store.fetch(selected.product)
 
-        model = self.run_dialog(ProductStockEditor, trans, product)
-        api.finish_transaction(trans, model)
-        trans.close()
+        model = self.run_dialog(ProductStockEditor, store, product)
+        store.confirm(model)
+        store.close()
 
     # Stock
 
@@ -374,20 +370,20 @@ class StockApp(SearchableAppWindow):
     def on_NewStockDecrease__activate(self, action):
         if self.check_open_inventory():
             return
-        trans = api.new_transaction()
-        model = self.run_dialog(StockDecreaseWizard, trans)
-        api.finish_transaction(trans, model)
-        trans.close()
+        store = api.new_store()
+        model = self.run_dialog(StockDecreaseWizard, store)
+        store.confirm(model)
+        store.close()
         self.search.refresh()
 
     def on_StockInitial__activate(self, action):
         if self.check_open_inventory():
             return
         branch = self.branch_filter.get_state().value
-        trans = api.new_transaction()
-        retval = self.run_dialog(InitialStockDialog, trans, branch)
-        api.finish_transaction(trans, retval)
-        trans.close()
+        store = api.new_store()
+        retval = self.run_dialog(InitialStockDialog, store, branch)
+        store.confirm(retval)
+        store.close()
         self.search.refresh()
 
     def on_StockPictureViewer__activate(self, button):
@@ -410,46 +406,46 @@ class StockApp(SearchableAppWindow):
     def on_LoanNew__activate(self, action):
         if self.check_open_inventory():
             return
-        trans = api.new_transaction()
-        model = self.run_dialog(NewLoanWizard, trans)
-        api.finish_transaction(trans, model)
-        trans.close()
+        store = api.new_store()
+        model = self.run_dialog(NewLoanWizard, store)
+        store.confirm(model)
+        store.close()
         self.search.refresh()
 
     def on_LoanClose__activate(self, action):
         if self.check_open_inventory():
             return
-        trans = api.new_transaction()
-        model = self.run_dialog(CloseLoanWizard, trans)
-        api.finish_transaction(trans, model)
-        trans.close()
+        store = api.new_store()
+        model = self.run_dialog(CloseLoanWizard, store)
+        store.confirm(model)
+        store.close()
         self.search.refresh()
 
     def on_LoanSearch__activate(self, action):
-        self.run_dialog(LoanSearch, self.conn)
+        self.run_dialog(LoanSearch, self.store)
 
     def on_LoanSearchItems__activate(self, action):
-        self.run_dialog(LoanItemSearch, self.conn)
+        self.run_dialog(LoanItemSearch, self.store)
 
     # Search
 
     def on_SearchPurchaseReceiving__activate(self, button):
-        self.run_dialog(PurchaseReceivingSearch, self.conn)
+        self.run_dialog(PurchaseReceivingSearch, self.store)
 
     def on_SearchTransfer__activate(self, action):
-        self.run_dialog(TransferOrderSearch, self.conn)
+        self.run_dialog(TransferOrderSearch, self.store)
 
     def on_SearchPurchasedStockItems__activate(self, action):
-        self.run_dialog(PurchasedItemsSearch, self.conn)
+        self.run_dialog(PurchasedItemsSearch, self.store)
 
     def on_SearchStockItems__activate(self, action):
-        self.run_dialog(ProductStockSearch, self.conn)
+        self.run_dialog(ProductStockSearch, self.store)
 
     def on_SearchClosedStockItems__activate(self, action):
-        self.run_dialog(ProductClosedStockSearch, self.conn)
+        self.run_dialog(ProductClosedStockSearch, self.store)
 
     def on_SearchProductHistory__activate(self, action):
-        self.run_dialog(ProductSearchQuantity, self.conn)
+        self.run_dialog(ProductSearchQuantity, self.store)
 
     def on_SearchStockDecrease__activate(self, action):
-        self.run_dialog(StockDecreaseSearch, self.conn)
+        self.run_dialog(StockDecreaseSearch, self.store)
