@@ -23,7 +23,6 @@
 ##
 """ Implementation of till application.  """
 
-import gettext
 import decimal
 from datetime import date
 
@@ -36,15 +35,17 @@ from kiwi.enums import SearchFilterPosition
 from kiwi.python import Settable
 from kiwi.ui.search import ComboSearchFilter
 from kiwi.ui.objectlist import Column, SearchColumn
+from storm.expr import And, Or
 
 from stoqlib.api import api
 from stoqlib.exceptions import (StoqlibError, TillError, SellError,
                                 ModelDataError)
-from stoqlib.database.orm import AND, OR, const
+from stoqlib.database.expr import Date
 from stoqlib.domain.sale import Sale, SaleView
 from stoqlib.domain.till import Till
 from stoqlib.lib.formatters import format_quantity
 from stoqlib.lib.message import yesno, warning
+from stoqlib.lib.translation import stoqlib_gettext as _
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.dialogs.tillhistory import TillHistoryDialog
 from stoqlib.gui.dialogs.saledetails import SaleDetailsDialog
@@ -52,6 +53,7 @@ from stoqlib.gui.dialogs.quotedialog import ConfirmSaleMissingDialog
 from stoqlib.gui.editors.tilleditor import CashInEditor, CashOutEditor
 from stoqlib.gui.fiscalprinter import FiscalPrinterHelper
 from stoqlib.gui.keybindings import get_accels
+from stoqlib.gui.search.paymentreceivingsearch import PaymentReceivingSearch
 from stoqlib.gui.search.personsearch import ClientSearch
 from stoqlib.gui.search.salesearch import (SaleWithToolbarSearch,
                                            SoldItemsByBranchSearch)
@@ -61,7 +63,6 @@ from stoqlib.reporting.sale import SalesReport
 
 from stoq.gui.application import SearchableAppWindow
 
-_ = gettext.gettext
 log = Logger('stoq.till')
 
 LOGO_WIDTH = 91
@@ -89,8 +90,13 @@ class TillApp(SearchableAppWindow):
              group.get('open_till')),
             ('TillClose', None, _('Close till...'),
              group.get('close_till')),
+            ('TillVerify', None, _('Verify till...'),
+             group.get('verify_till')),
             ('TillAddCash', None, _('Cash addition...'), ''),
             ('TillRemoveCash', None, _('Cash removal...'), ''),
+            ("PaymentReceive", None, _("Payment receival..."),
+             group.get('payment_receive'),
+             _("Receive payments")),
             ("SearchClient", None, _("Clients..."),
              group.get('search_clients'),
              _("Search for clients")),
@@ -133,7 +139,7 @@ class TillApp(SearchableAppWindow):
     def create_ui(self):
         self.popup = self.uimanager.get_widget('/TillSelection')
 
-        self.current_branch = api.get_current_branch(self.conn)
+        self.current_branch = api.get_current_branch(self.store)
         # Groups
         self.main_vbox.set_focus_chain([self.app_vbox])
         self.app_vbox.set_focus_chain([self.search_holder, self.list_vbox])
@@ -145,7 +151,7 @@ class TillApp(SearchableAppWindow):
 
     def get_title(self):
         return _('Stoq - Till for Branch %03d') % (
-            api.get_current_branch(self.conn).id, )
+            api.get_current_branch(self.store).id, )
 
     def activate(self, params):
         self.app.launcher.add_new_items([self.TillAddCash,
@@ -179,10 +185,10 @@ class TillApp(SearchableAppWindow):
     def create_filters(self):
         self.executer.set_query(self._query_executer)
         self.set_text_field_columns(['client_name', 'salesperson_name'])
-        status_filter = ComboSearchFilter(_(u"Show orders"),
-                                          self._get_status_values())
-        status_filter.select(Sale.STATUS_CONFIRMED)
-        self.add_filter(status_filter, position=SearchFilterPosition.TOP,
+        self.status_filter = ComboSearchFilter(_(u"Show orders"),
+                                               self._get_status_values())
+        self.status_filter.select(Sale.STATUS_CONFIRMED)
+        self.add_filter(self.status_filter, position=SearchFilterPosition.TOP,
                         columns=['status'])
 
     def get_columns(self):
@@ -209,27 +215,22 @@ class TillApp(SearchableAppWindow):
     # Private
     #
 
-    def _query_executer(self, query, having, conn):
+    def _query_executer(self, store):
         # We should only show Sales that
         # 1) In the current branch (FIXME: Should be on the same station.
                                     # See bug 4266)
         # 2) Are in the status QUOTE or ORDERED.
         # 3) For the order statuses, the date should be the same as today
 
-        new = AND(Sale.q.branch_id == self.current_branch.id,
-                 OR(Sale.q.status == Sale.STATUS_QUOTE,
-                    Sale.q.status == Sale.STATUS_ORDERED,
-                    const.DATE(Sale.q.open_date) == date.today()))
+        query = And(Sale.branch == self.current_branch,
+                 Or(Sale.status == Sale.STATUS_QUOTE,
+                    Sale.status == Sale.STATUS_ORDERED,
+                    Date(Sale.open_date) == date.today()))
 
-        if query:
-            query = AND(query, new)
-        else:
-            query = new
-
-        return self.search_table.select(query, having=having, connection=conn)
+        return store.find(self.search_table, query)
 
     def _setup_printer(self):
-        self._printer = FiscalPrinterHelper(self.conn,
+        self._printer = FiscalPrinterHelper(self.store,
                                             parent=self)
         self._printer.connect('till-status-changed',
                               self._on_PrinterHelper__till_status_changed)
@@ -246,9 +247,9 @@ class TillApp(SearchableAppWindow):
         if self.check_open_inventory():
             return
 
-        trans = api.new_transaction()
+        store = api.new_store()
         selected = self.results.get_selected()
-        sale = trans.get(selected.sale)
+        sale = store.fetch(selected.sale)
         expire_date = sale.expire_date
 
         if (sale.status == Sale.STATUS_QUOTE and
@@ -256,7 +257,7 @@ class TillApp(SearchableAppWindow):
             not yesno(_("This quote has expired. Confirm it anyway?"),
                       gtk.RESPONSE_YES,
                       _("Confirm quote"), _("Don't confirm"))):
-            trans.close()
+            store.close()
             return
 
         # Lets confirm that we can create the sale, before opening the coupon
@@ -285,17 +286,17 @@ class TillApp(SearchableAppWindow):
             retval = run_dialog(ConfirmSaleMissingDialog, self, sale, missing)
             if retval:
                 self.refresh()
-            trans.close()
+            store.close()
             return
 
         coupon = self._open_coupon()
         if not coupon:
-            trans.close()
+            store.close()
             return
-        self._add_sale_items(sale, coupon)
+        subtotal = self._add_sale_items(sale, coupon)
         try:
-            if coupon.confirm(sale, trans):
-                trans.commit()
+            if coupon.confirm(sale, store, subtotal=subtotal):
+                store.commit()
                 self.refresh()
             else:
                 coupon.cancel()
@@ -304,7 +305,7 @@ class TillApp(SearchableAppWindow):
         except ModelDataError as err:
             warning(str(err))
 
-        trans.close()
+        store.close()
 
     def _open_coupon(self):
         coupon = self._printer.create_coupon()
@@ -320,8 +321,11 @@ class TillApp(SearchableAppWindow):
         return coupon
 
     def _add_sale_items(self, sale, coupon):
+        subtotal = 0
         for sale_item in sale.get_items():
             coupon.add_item(sale_item)
+            subtotal += sale_item.price * sale_item.quantity
+        return subtotal
 
     def _update_total(self):
         balance = currency(self._get_till_balance())
@@ -331,7 +335,7 @@ class TillApp(SearchableAppWindow):
     def _get_till_balance(self):
         """Returns the balance of till operations"""
         try:
-            till = Till.get_current(self.conn)
+            till = Till.get_current(self.store)
         except TillError:
             till = None
 
@@ -376,24 +380,24 @@ class TillApp(SearchableAppWindow):
         return sale_view
 
     def _run_search_dialog(self, dialog_type, **kwargs):
-        trans = api.new_transaction()
-        self.run_dialog(dialog_type, trans, **kwargs)
-        trans.close()
+        store = api.new_store()
+        self.run_dialog(dialog_type, store, **kwargs)
+        store.close()
 
     def _run_details_dialog(self):
         sale_view = self._check_selected()
-        run_dialog(SaleDetailsDialog, self, self.conn, sale_view)
+        run_dialog(SaleDetailsDialog, self, self.store, sale_view)
 
     def _run_add_cash_dialog(self):
-        with api.trans() as trans:
+        with api.trans() as store:
             try:
-                run_dialog(CashInEditor, self, trans)
+                run_dialog(CashInEditor, self, store)
             except TillError as err:
                 # Inform the error to the user instead of crashing
                 warning(str(err))
                 return
 
-        if trans.committed:
+        if store.committed:
             self._update_total()
 
     def _return_sale(self):
@@ -402,10 +406,10 @@ class TillApp(SearchableAppWindow):
 
         sale_view = self._check_selected()
 
-        with api.trans() as trans:
-            return_sale(self.get_toplevel(), sale_view, trans)
+        with api.trans() as store:
+            return_sale(self.get_toplevel(), store.fetch(sale_view.sale), store)
 
-        if trans.committed:
+        if store.committed:
             self._update_total()
             self.refresh()
 
@@ -415,7 +419,7 @@ class TillApp(SearchableAppWindow):
             return
 
         # We dont have an ecf. Disable till related operations
-        widgets = [self.TillOpen, self.TillClose, self.TillAddCash,
+        widgets = [self.TillOpen, self.TillClose, self.TillVerify, self.TillAddCash,
                    self.TillRemoveCash, self.SearchTillHistory, self.app_vbox,
                    self.Confirm, self.Return, self.Details]
         self.set_sensitive(widgets, has_ecf)
@@ -430,9 +434,10 @@ class TillApp(SearchableAppWindow):
         # - Till was not closed the previous fiscal day (blocked)
 
         self.set_sensitive([self.TillOpen], closed)
-        self.set_sensitive([self.TillClose], not closed or blocked)
+        self.set_sensitive([self.TillClose, self.PaymentReceive],
+                           not closed or blocked)
 
-        widgets = [self.TillAddCash, self.TillRemoveCash,
+        widgets = [self.TillVerify, self.TillAddCash, self.TillRemoveCash,
                    self.SearchTillHistory, self.app_vbox]
         self.set_sensitive(widgets, not closed and not blocked)
 
@@ -443,7 +448,7 @@ class TillApp(SearchableAppWindow):
         elif blocked:
             text = _(u"Till blocked from previous day")
         else:
-            till = Till.get_current(self.conn)
+            till = Till.get_current(self.store)
             text = _(u"Till opened on %s") % till.opening_date.strftime('%x')
 
         self.till_status_label.set_text(text)
@@ -483,8 +488,14 @@ class TillApp(SearchableAppWindow):
     def _on_PrinterHelper__ecf_changed(self, printer, ecf):
         self._update_ecf(ecf)
 
+    def on_PaymentReceive__activate(self, action):
+        self.run_dialog(PaymentReceivingSearch, self.store)
+
     # Till
 
+    def on_TillVerify__activate(self, button):
+        self._printer.verify_till()
+
     def on_TillClose__activate(self, button):
         self._printer.close_till()
 
@@ -495,9 +506,9 @@ class TillApp(SearchableAppWindow):
         self._run_add_cash_dialog()
 
     def on_TillRemoveCash__activate(self, action):
-        with api.trans() as trans:
-            run_dialog(CashOutEditor, self, trans)
-        if trans.committed:
+        with api.trans() as store:
+            run_dialog(CashOutEditor, self, store)
+        if store.committed:
             self._update_total()
 
     # Search
@@ -516,7 +527,7 @@ class TillApp(SearchableAppWindow):
         self._run_search_dialog(SoldItemsByBranchSearch)
 
     def on_SearchTillHistory__activate(self, button):
-        self.run_dialog(TillHistoryDialog, self.conn)
+        self.run_dialog(TillHistoryDialog, self.store)
 
     def on_SearchFiscalTillOperations__activate(self, button):
         self._run_search_dialog(TillFiscalOperationsSearch)
