@@ -24,8 +24,6 @@
 ##
 """ Schema Update Wizard """
 
-import gettext
-
 import glib
 import gtk
 
@@ -34,11 +32,10 @@ from stoqlib.gui.base.wizards import BaseWizard, BaseWizardStep
 from stoqlib.gui.logo import render_logo_pixbuf
 from stoqlib.gui.processview import ProcessView
 from stoqlib.lib.message import info
+from stoqlib.lib.translation import stoqlib_gettext as _
 
 import stoq
 
-_ = gettext.gettext
-
 #
 # Wizard Steps
 #
@@ -95,7 +92,7 @@ class UpdateSchemaStep(BaseWizardStep):
         longer = None
         if line.startswith('PATCH:'):
             patch = line.split(':', 1)[1]
-            text = _("Applying patch %s ..." % (patch, ))
+            text = _("Applying patch %s ...") % (patch, )
         elif line.startswith('BACKUP-START:'):
             text = _("Creating a database backup")
             longer = _('Creating a database backup in case anything goes wrong.')
