@@ -25,25 +25,24 @@
 ##
 """ Database startup routines"""
 
-import gettext
 import os
 import sys
 
 from kiwi.component import provide_utility
 from kiwi.log import Logger
 from stoqlib.database.migration import StoqlibSchemaMigration
-from stoqlib.database.orm import orm_enable_debugging, orm_startup
-from stoqlib.database.runtime import (get_connection,
+from stoqlib.database.debug import enable as enable_debugging
+from stoqlib.database.runtime import (get_default_store,
                                       set_current_branch_station)
 from stoqlib.exceptions import DatabaseError
 from stoqlib.lib.configparser import register_config, StoqConfig
 from stoqlib.lib.interfaces import  IApplicationDescriptions
 from stoqlib.lib.message import error
 from stoqlib.lib.osutils import read_registry_key
+from stoqlib.lib.translation import stoqlib_gettext as _
 
 from stoq.lib.options import get_option_parser
 
-_ = gettext.gettext
 log = Logger('startup')
 
 
@@ -111,7 +110,7 @@ def setup(config=None, options=None, register_station=True, check_schema=True,
     register_config(config)
 
     if options and options.sqldebug:
-        orm_enable_debugging()
+        enable_debugging()
 
     from stoq.lib.applist import ApplicationDescriptions
     provide_utility(IApplicationDescriptions, ApplicationDescriptions(),
@@ -119,22 +118,20 @@ def setup(config=None, options=None, register_station=True, check_schema=True,
 
     if register_station:
         try:
-            conn = get_connection()
+            default_store = get_default_store()
         except DatabaseError, e:
             error(e.short, str(e.msg))
 
-        config.get_settings().check_version(conn)
+        config.get_settings().check_version(default_store)
 
         if check_schema:
             migration = StoqlibSchemaMigration()
             migration.check()
 
-        orm_startup()
-
         if options and options.sqldebug:
-            orm_enable_debugging()
+            enable_debugging()
 
-        set_current_branch_station(conn, station_name=None)
+        set_current_branch_station(default_store, station_name=None)
 
     if load_plugins:
         from stoqlib.lib.pluginmanager import get_plugin_manager
@@ -142,8 +139,8 @@ def setup(config=None, options=None, register_station=True, check_schema=True,
         manager.activate_installed_plugins()
 
     if check_schema:
-        conn = get_connection()
-        if not conn.tableExists('system_table'):
+        default_store = get_default_store()
+        if not default_store.table_exists('system_table'):
             error(
                 _("Database schema error"),
                 _("Table 'system_table' does not exist.\n"
@@ -152,5 +149,3 @@ def setup(config=None, options=None, register_station=True, check_schema=True,
         if check_schema:
             migration = StoqlibSchemaMigration()
             migration.check()
-
-        orm_startup()
