@@ -40,10 +40,10 @@ from kiwi.log import Logger
 from stoqdrivers.enum import TaxType, UnitType
 from stoqdrivers.constants import describe_constant
 
+from stoqlib.database.expr import TransactionTimestamp
 from stoqlib.database.interfaces import ICurrentBranch, ICurrentUser
 from stoqlib.database.migration import StoqlibSchemaMigration
-from stoqlib.database.orm import const
-from stoqlib.database.runtime import get_connection, new_transaction
+from stoqlib.database.runtime import get_default_store, new_store
 from stoqlib.database.settings import db_settings
 from stoqlib.domain.person import (Branch, Company, Employee, EmployeeRole,
                                    Individual, LoginUser, Person, SalesPerson)
@@ -61,23 +61,24 @@ _ = stoqlib_gettext
 
 log = Logger('stoqlib.admin')
 create_log = Logger('stoqlib.database.create')
-USER_ADMIN_DEFAULT_NAME = 'admin'
+USER_ADMIN_DEFAULT_NAME = u'admin'
 
 
 def ensure_admin_user(administrator_password):
     log.info("Creating administrator user")
 
-    conn = get_connection()
-    user = get_admin_user(conn)
+    default_store = get_default_store()
+    user = get_admin_user(default_store)
+
     if user is None:
-        trans = new_transaction()
-        person = Person(name=_('Administrator'), connection=trans)
+        store = new_store()
+        person = Person(name=_(u'Administrator'), store=store)
 
         # Dependencies to create an user.
-        role = EmployeeRole(name=_('System Administrator'), connection=trans)
-        Individual(person=person, connection=trans)
-        employee = Employee(person=person, role=role, connection=trans)
-        EmployeeRoleHistory(connection=trans,
+        role = EmployeeRole(name=_(u'System Administrator'), store=store)
+        Individual(person=person, store=store)
+        employee = Employee(person=person, role=role, store=store)
+        EmployeeRoleHistory(store=store,
                             role=role,
                             employee=employee,
                             is_active=True,
@@ -85,25 +86,25 @@ def ensure_admin_user(administrator_password):
 
         # This is usefull when testing a initial database. Admin user actually
         # must have all the facets.
-        SalesPerson(person=person, connection=trans)
+        SalesPerson(person=person, store=store)
 
-        profile = UserProfile.selectOneBy(name=_('Administrator'), connection=trans)
+        profile = store.find(UserProfile, name=_(u'Administrator')).one()
         # Backwards compatibility. this profile used to be in english
         # FIXME: Maybe its safe to assume the first profile in the table is
         # the admin.
         if not profile:
-            profile = UserProfile.selectOneBy(name='Administrator', connection=trans)
+            profile = store.find(UserProfile, name=u'Administrator').one()
 
         log.info("Attaching a LoginUser (%s)" % (USER_ADMIN_DEFAULT_NAME, ))
         LoginUser(person=person,
                   username=USER_ADMIN_DEFAULT_NAME,
                   password=administrator_password,
-                  profile=profile, connection=trans)
+                  profile=profile, store=store)
 
-        trans.commit(close=True)
+        store.commit(close=True)
 
     # Fetch the user again, this time from the right connection
-    user = get_admin_user(conn)
+    user = get_admin_user(default_store)
     assert user
 
     user.set_password(administrator_password)
@@ -113,27 +114,27 @@ def ensure_admin_user(administrator_password):
     provide_utility(ICurrentUser, user)
 
 
-def create_main_branch(trans, name):
+def create_main_branch(store, name):
     """Creates a new branch and sets it as the main branch for the system
-    :param trans: a database transaction
+    :param store: a store
     :param name: name of the new branch
     """
-    person = Person(name=name, connection=trans)
-    Company(person=person, connection=trans)
-    branch = Branch(person=person, connection=trans)
+    person = Person(name=name, store=store)
+    Company(person=person, store=store)
+    branch = Branch(person=person, store=store)
 
-    sysparam(trans).MAIN_COMPANY = branch.id
+    sysparam(store).MAIN_COMPANY = branch.id
 
     provide_utility(ICurrentBranch, branch)
-    admin = get_admin_user(trans)
+    admin = get_admin_user(store)
     admin.add_access_to(branch)
 
     return branch
 
 
-def populate_initial_data(trans):
+def populate_initial_data(store):
     from stoqlib.domain.system import SystemTable
-    generation = SystemTable.select(connection=trans).max('generation')
+    generation = store.find(SystemTable).max(SystemTable.generation)
     if generation < 4:
         # FIXME: Initial data can (and needs to) only be sourced on schemas
         #        greater or equal than 4. Remove this in the future.
@@ -142,10 +143,10 @@ def populate_initial_data(trans):
     log.info('Populating initial data')
     initial_data = environ.find_resource('sql', 'initial.sql')
     if db_settings.execute_sql(initial_data) != 0:
-        error('Failed to populate initial data')
+        error(u'Failed to populate initial data')
 
 
-def register_payment_methods(trans):
+def register_payment_methods(store):
     """Registers the payment methods and creates persistent
     domain classes associated with them.
     """
@@ -156,98 +157,89 @@ def register_payment_methods(trans):
     pom = get_payment_operation_manager()
 
     log.info("Creating domain objects for payment methods")
-    account = sysparam(trans).IMBALANCE_ACCOUNT
+    account = sysparam(store).IMBALANCE_ACCOUNT
     for operation_name in pom.get_operation_names():
         operation = pom.get(operation_name)
-        pm = PaymentMethod.selectOneBy(connection=trans,
-                                       method_name=operation_name)
+        pm = store.find(PaymentMethod, method_name=operation_name).one()
         if pm is None:
-            pm = PaymentMethod(connection=trans,
+            pm = PaymentMethod(store=store,
                                method_name=operation_name,
                                destination_account=account,
                                max_installments=operation.max_installments)
 
 
-def register_accounts(trans):
+def register_accounts(store):
     # FIXME: If you need to run this in a patch, you need to
-    #        make sure that selectOneBy is fixed, as accounts
+    #        make sure that .find().one() is fixed bellow, as accounts
     #        with the same names are allowed.
     #        It's for now okay to run this when creating a new
     #        database.
 
     from stoqlib.domain.account import Account
     log.info("Creating Accounts")
-    for name, atype in [(_("Assets"), Account.TYPE_ASSET),
-                        (_("Banks"), Account.TYPE_BANK),
-                        (_("Equity"), Account.TYPE_EQUITY),
-                        (_("Expenses"), Account.TYPE_EXPENSE),
-                        (_("Imbalance"), Account.TYPE_BANK),
-                        (_("Income"), Account.TYPE_INCOME),
-                        (_("Tills"), Account.TYPE_CASH),
+    for name, atype in [(_(u"Assets"), Account.TYPE_ASSET),
+                        (_(u"Banks"), Account.TYPE_BANK),
+                        (_(u"Equity"), Account.TYPE_EQUITY),
+                        (_(u"Expenses"), Account.TYPE_EXPENSE),
+                        (_(u"Imbalance"), Account.TYPE_BANK),
+                        (_(u"Income"), Account.TYPE_INCOME),
+                        (_(u"Tills"), Account.TYPE_CASH),
                         ]:
-        # FIXME: This needs to rewritten to not use selectOneBy,
+        # FIXME: This needs to rewritten to not use .find().one(),
         #        see comment above.
-        account = Account.selectOneBy(connection=trans,
-                                      description=name)
+        account = store.find(Account, description=name).one()
         if not account:
-            account = Account(connection=trans,
-                              description=name)
+            account = Account(store=store, description=name)
         account.account_type = atype
 
-    sparam = sysparam(trans)
-    sparam.BANKS_ACCOUNT = Account.selectOneBy(
-        connection=trans, description=_("Banks")).id
-    sparam.TILLS_ACCOUNT = Account.selectOneBy(
-        connection=trans, description=_("Tills")).id
-    sparam.IMBALANCE_ACCOUNT = Account.selectOneBy(
-        connection=trans, description=_("Imbalance")).id
+    sparam = sysparam(store)
+    sparam.BANKS_ACCOUNT = store.find(Account, description=_(u"Banks")).one().id
+    sparam.TILLS_ACCOUNT = store.find(Account, description=_(u"Tills")).one().id
+    sparam.IMBALANCE_ACCOUNT = store.find(Account,
+                                          description=_(u"Imbalance")).one().id
 
 
 def _ensure_card_providers():
     """ Creates a list of default card providers """
     log.info("Creating Card Providers")
-    from stoqlib.domain.person import CreditProvider
+    from stoqlib.domain.payment.card import CreditProvider
 
-    providers = ['VISANET', 'REDECARD', 'AMEX', 'HIPERCARD',
-                 'BANRISUL', 'PAGGO', 'CREDISHOP', 'CERTIF']
+    providers = [u'VISANET', u'REDECARD', u'AMEX', u'HIPERCARD',
+                 u'BANRISUL', u'PAGGO', u'CREDISHOP', u'CERTIF']
 
-    trans = new_transaction()
+    store = new_store()
     for name in providers:
-        person = CreditProvider.get_provider_by_provider_id(
-                        name, trans)
-        if person:
+        provider = CreditProvider.get_provider_by_provider_id(name, store)
+        if not provider.is_empty():
             continue
 
-        person = Person(name=name, connection=trans)
-        Company(person=person, connection=trans)
-        CreditProvider(person=person,
-                       short_name=name,
+        CreditProvider(short_name=name,
                        provider_id=name,
-                       open_contract_date=const.NOW(),
-                       connection=trans)
-    trans.commit(close=True)
+                       open_contract_date=TransactionTimestamp(),
+                       store=store)
+    store.commit(close=True)
 
 
-def get_admin_user(conn):
+def get_admin_user(store):
     """Retrieves the current administrator user for the system
-    :param conn: a database connection
+    :param store:  store
     :returns: the admin user for the system
     """
-    return LoginUser.selectOneBy(username=USER_ADMIN_DEFAULT_NAME,
-                                 connection=conn)
+    return store.find(LoginUser,
+                      username=USER_ADMIN_DEFAULT_NAME).one()
 
 
 def ensure_sellable_constants():
     """ Create native sellable constants. """
     log.info("Creating sellable units")
-    trans = new_transaction()
-    unit_list = [("Kg", UnitType.WEIGHT),
-                 ("Lt", UnitType.LITERS),
-                 ("m ", UnitType.METERS)]
+    store = new_store()
+    unit_list = [(u"Kg", UnitType.WEIGHT),
+                 (u"Lt", UnitType.LITERS),
+                 (u"m ", UnitType.METERS)]
     for desc, enum in unit_list:
         SellableUnit(description=desc,
                      unit_index=int(enum),
-                     connection=trans)
+                     store=store)
 
     log.info("Creating sellable tax constants")
     for enum in [TaxType.SUBSTITUTION,
@@ -258,42 +250,42 @@ def ensure_sellable_constants():
         SellableTaxConstant(description=desc,
                             tax_type=int(enum),
                             tax_value=None,
-                            connection=trans)
+                            store=store)
 
-    trans.commit(close=True)
+    store.commit(close=True)
 
 
-def user_has_usesuper(trans):
+def user_has_usesuper(store):
     """This method checks if the currently logged in postgres user has
     ``usesuper`` access which is necessary for certain operations
 
-    :param trans: a database connection
+    :param store: a store
     :returns: if the user has ``usesuper`` access
     """
 
-    results = trans.queryOne(
-        'SELECT usesuper FROM pg_user WHERE usename=CURRENT_USER')
+    results = store.execute(
+        'SELECT usesuper FROM pg_user WHERE usename=CURRENT_USER').get_one()
     return results[0] == 1
 
 
 def _create_procedural_languages():
     "Creates procedural SQL languages we're going to use in scripts"
 
-    trans = new_transaction()
-
+    store = new_store()
     log.info('Creating procedural SQL languages')
-    results = trans.queryAll('SELECT lanname FROM pg_language')
+    results = store.execute('SELECT lanname FROM pg_language').get_all()
     languages = [item[0] for item in results]
     if 'plpgsql' in languages:
         return
 
-    if not user_has_usesuper(trans):
+    if not user_has_usesuper(store):
         raise StoqlibError(
             _("The current database user does not have super user rights"))
 
     # Create the plpgsql language
-    trans.query('CREATE LANGUAGE plpgsql')
-    trans.commit(close=True)
+    store.execute('CREATE LANGUAGE plpgsql')
+    store.commit()
+    store.close()
 
 
 def _get_latest_schema():
@@ -314,17 +306,17 @@ def create_base_schema():
     # Functions
     functions = environ.find_resource('sql', 'functions.sql')
     if db_settings.execute_sql(functions) != 0:
-        error('Failed to create functions')
+        error(u'Failed to create functions')
 
     # A Base schema shared between all RDBMS implementations
     schema = _get_latest_schema()
     if db_settings.execute_sql(schema) != 0:
-        error('Failed to create base schema')
+        error(u'Failed to create base schema')
 
     try:
         schema = environ.find_resource('sql', '%s-schema.sql' % db_settings.rdbms)
         if db_settings.execute_sql(schema) != 0:
-            error('Failed to create %s specific schema' % (db_settings.rdbms, ))
+            error(u'Failed to create %s specific schema' % (db_settings.rdbms, ))
     except EnvironmentError:
         pass
 
@@ -333,28 +325,28 @@ def create_base_schema():
 
 
 def create_default_profiles():
-    trans = new_transaction()
+    store = new_store()
 
     log.info("Creating user default profiles")
-    UserProfile.create_profile_template(trans, _('Administrator'), True)
-    UserProfile.create_profile_template(trans, _('Manager'), True)
-    UserProfile.create_profile_template(trans, _('Salesperson'), False)
+    UserProfile.create_profile_template(store, _(u'Administrator'), True)
+    UserProfile.create_profile_template(store, _(u'Manager'), True)
+    UserProfile.create_profile_template(store, _(u'Salesperson'), False)
 
-    trans.commit(close=True)
+    store.commit(close=True)
 
 
 def create_default_profile_settings():
-    trans = new_transaction()
-    profile = UserProfile.selectOneBy(name=_('Salesperson'), connection=trans)
+    store = new_store()
+    profile = store.find(UserProfile, name=_(u'Salesperson')).one()
     # Not sure what is happening. If it doesnt exist, check if it was not
     # created in english. workaround for crash report 207 (bug 4587)
     if not profile:
-        profile = UserProfile.selectOneBy(name='Salesperson', connection=trans)
+        profile = store.find(UserProfile, name=u'Salesperson').one()
     assert profile
-    ProfileSettings.set_permission(trans, profile, 'pos', True)
-    ProfileSettings.set_permission(trans, profile, 'sales', True)
-    ProfileSettings.set_permission(trans, profile, 'till', True)
-    trans.commit(close=True)
+    ProfileSettings.set_permission(store, profile, u'pos', True)
+    ProfileSettings.set_permission(store, profile, u'sales', True)
+    ProfileSettings.set_permission(store, profile, u'till', True)
+    store.commit(close=True)
 
 
 def _install_invoice_templates():
@@ -375,13 +367,13 @@ def initialize_system(password=None, testsuite=False,
         db_settings.clean_database(db_settings.dbname, force=force)
         create_base_schema()
         create_log("INIT START")
-        trans = new_transaction()
-        populate_initial_data(trans)
-        register_accounts(trans)
-        register_payment_methods(trans)
+        store = new_store()
+        populate_initial_data(store)
+        register_accounts(store)
+        register_payment_methods(store)
         from stoqlib.domain.uiform import create_default_forms
-        create_default_forms(trans)
-        trans.commit(close=True)
+        create_default_forms(store)
+        store.commit(close=True)
         ensure_sellable_constants()
         ensure_system_parameters()
         _ensure_card_providers()
