@@ -30,7 +30,9 @@ This is just a layer on top of the Python DBAPI we're using to access the
 database
 """
 
-from psycopg2 import (Error, IntegrityError, OperationalError,
+from storm.exceptions import StormError
+
+from psycopg2 import (Error, IntegrityError, InterfaceError, OperationalError,
                       ProgrammingError)
 
 
@@ -38,7 +40,19 @@ PostgreSQLError = Error
 IntegrityError = IntegrityError
 OperationalError = OperationalError
 ProgrammingError = ProgrammingError
+InterfaceError = InterfaceError
 
 
 class SQLError(Exception):
     pass
+
+
+class ORMObjectNotFound(StormError):
+    # ORMObject.get raises this
+    pass
+
+
+class ORMTestError(Exception):
+    pass
+
+
