@@ -36,7 +36,8 @@ import traceback
 from kiwi.environ import environ
 from kiwi.log import Logger
 
-from stoqlib.database.runtime import new_transaction, get_connection
+from stoqlib.database.runtime import (get_default_store,
+                                      new_store)
 from stoqlib.database.settings import db_settings
 from stoqlib.domain.plugin import InstalledPlugin
 from stoqlib.domain.profile import update_profile_applications
@@ -81,37 +82,57 @@ class Patch(object):
     def __cmp__(self, other):
         return cmp(self.get_version(), other.get_version())
 
-    def apply(self, conn):
+    def apply(self, store):
         """Apply the patch
-        :param conn: A database connection
+        :param store: a store
         """
 
-        # Commit the connection since it may have queried the database, and we
-        # need to lock the tables.
-        conn.commit()
-        temporary = tempfile.mktemp(prefix="patch-%d-%d-" % self.get_version())
+        # Dont lock the database here, since StoqlibSchemaMigration.update has
+        # already did that before starting to apply the patches
+
+        # SQL statement to update the system_table
+        sql = self._migration.generate_sql_for_patch(self)
 
         if self.filename.endswith('.sql'):
+            # Create a temporary file used for writing SQL statements
+            temporary = tempfile.mktemp(prefix="patch-%d-%d-" % self.get_version())
+
+            # Overwrite the temporary file with the sql patch we want to apply
             shutil.copy(self.filename, temporary)
+
+            # After successfully executing the SQL statements, we need to
+            # make sure that the system_table is updated with the correct
+            # schema generation and patchlevel
+            open(temporary, 'a').write(sql)
+
+            retcode = db_settings.execute_sql(temporary)
+            if retcode != 0:
+                error('Failed to apply %s, psql returned error code: %d' % (
+                    os.path.basename(self.filename), retcode))
+
+            os.unlink(temporary)
         elif self.filename.endswith('.py'):
+            # Execute the patch, we cannot use __import__() since there are
+            # hyphens in the filename and data/sql lacks an __init__.py
             ns = {}
             execfile(self.filename, ns, ns)
             function = ns['apply_patch']
-            trans = new_transaction()
-            function(trans)
-            trans.commit(close=True)
+
+            # Create a new store that will be used to apply the patch and
+            # to update the system tables after the patch has been successfully
+            # applied
+            patch_store = new_store()
+
+            # Apply the patch itself
+            function(patch_store)
+
+            # After applying the patch, update the system_table within the same
+            # transaction
+            patch_store.execute(sql)
+            patch_store.commit(close=True)
         else:
             raise AssertionError("Unknown filename: %s" % (self.filename, ))
 
-        sql = self._migration.generate_sql_for_patch(self)
-        open(temporary, 'a').write(sql)
-        retcode = db_settings.execute_sql(temporary, lock_database=True)
-        if retcode != 0:
-            error('Failed to apply %s, psql returned error code: %d' % (
-                os.path.basename(self.filename), retcode))
-
-        os.unlink(temporary)
-
     def get_version(self):
         """Returns the patch version
         :returns: a tuple with the patch generation and level
@@ -140,7 +161,7 @@ class SchemaMigration(object):
             raise ValueError(
                 _("%s needs to have the patch_patterns class variable set") % (
                 self.__class__.__name__))
-        self.conn = get_connection()
+        self.default_store = get_default_store()
 
     def _patchname_is_valid(self, filename):
         # simple checking of the patch naming convention
@@ -196,7 +217,7 @@ class SchemaMigration(object):
             for patch in patches_to_apply:
                 create_log.info("PATCH:%d.%d" % (patch.generation,
                                                  patch.level))
-                patch.apply(self.conn)
+                patch.apply(self.default_store)
 
             assert patches_to_apply
             log.info("All patches (%s) applied." % (
@@ -263,7 +284,8 @@ class SchemaMigration(object):
         self._log("PATCHES:%d" % (len(to_apply), ))
         for i, patch in enumerate(to_apply):
             self._log("PATCH:%d" % (i, ))
-            patch.apply(self.conn)
+            patch.apply(self.default_store)
+
         self._log("PATCHES APPLIED")
 
     def update(self):
@@ -317,7 +339,7 @@ class StoqlibSchemaMigration(SchemaMigration):
     def check_uptodate(self):
         retval = super(StoqlibSchemaMigration, self).check_uptodate()
 
-        if not check_parameter_presence(self.conn):
+        if not check_parameter_presence(self.default_store):
             return False
 
         return retval
@@ -328,7 +350,7 @@ class StoqlibSchemaMigration(SchemaMigration):
 
         try:
             log.info("Locking database")
-            self.conn.lock_database()
+            self.default_store.lock_database()
         except DatabaseError:
             msg = _('Could not lock database. This means there are other clients '
                     'connected. Make sure to close every Stoq client '
@@ -338,7 +360,7 @@ class StoqlibSchemaMigration(SchemaMigration):
         # Database migration is actually run in subprocesses, We need to unlock
         # the tables again and let the upgrade continue
         log.info("Releasing database lock")
-        self.conn.unlock_database()
+        self.default_store.unlock_database()
 
         sucess = db_settings.test_connection()
         if not sucess:
@@ -411,27 +433,30 @@ class StoqlibSchemaMigration(SchemaMigration):
         return True
 
     def get_current_version(self):
-        return self.conn.queryOne(
+        result = self.default_store.execute(
             """SELECT generation, patchlevel
                  FROM system_table
              ORDER BY updated DESC
                 LIMIT 1;""")
+        value = result.get_one()
+        result.close()
+        return value
 
     def after_update(self):
         # checks if there is new applications and update all the user
         # profiles on the system
-        trans = new_transaction()
-        update_profile_applications(trans)
-        trans.commit(close=True)
+        store = new_store()
+        update_profile_applications(store)
+        store.commit(close=True)
 
         # Updating the parameter list
         ensure_system_parameters(update=True)
 
     def generate_sql_for_patch(self, patch):
-        return ("INSERT INTO system_table (updated, patchlevel, generation)"
-                "VALUES (NOW(), %s, %s);" % (
-            self.conn.sqlrepr(patch.level),
-            self.conn.sqlrepr(patch.generation)))
+        return self.default_store.quote_query(
+            "INSERT INTO system_table (updated, patchlevel, generation)"
+            "VALUES (NOW(), %s, %s);", (patch.level,
+                                        patch.generation))
 
 
 class PluginSchemaMigration(SchemaMigration):
@@ -450,19 +475,19 @@ class PluginSchemaMigration(SchemaMigration):
         self.patch_patterns = patterns
         SchemaMigration.__init__(self)
 
-        self._plugin = InstalledPlugin.selectOneBy(
-            plugin_name=self.plugin_name,
-            connection=self.conn)
+        self._plugin = self.default_store.find(
+            InstalledPlugin, plugin_name=self.plugin_name).one()
 
     def _log(self, msg):
         create_log.info('PLUGIN ' + msg)
 
     def generate_sql_for_patch(self, patch):
         assert self._plugin
-        return ("UPDATE installed_plugin "
-                "SET plugin_version = %s "
-                "WHERE id = %s;") % (self.conn.sqlrepr(patch.level),
-                                     self.conn.sqlrepr(self._plugin.id))
+        return self.default_store.quote_query(
+            "UPDATE installed_plugin "
+            "SET plugin_version = %s "
+            "WHERE id = %s;",
+            (patch.level, self._plugin.id))
 
     def get_current_version(self):
         if self._plugin:
@@ -487,6 +512,5 @@ def needs_schema_update():
     # otherwise the locking of the database will fail, since this connection has
     # already queried a few tables
     if update:
-        migration.conn.commit()
-        migration.conn.close()
+        migration.default_store.commit()
     return update
