@@ -29,16 +29,15 @@ from stoqlib.lib.kiwilibrary import library
 library  # pyflakes
 
 import os
-import socket
 
 from kiwi.component import provide_utility, utilities
 from kiwi.log import Logger
+from storm.expr import And
 
 from stoqlib.database.admin import initialize_system, ensure_admin_user
 from stoqlib.database.interfaces import (
     ICurrentBranch, ICurrentBranchStation, ICurrentUser)
-from stoqlib.database.orm import AND
-from stoqlib.database.runtime import new_transaction, get_connection
+from stoqlib.database.runtime import new_store, get_default_store
 from stoqlib.database.settings import db_settings
 from stoqlib.domain.person import Branch, LoginUser, Person
 from stoqlib.domain.station import BranchStation
@@ -49,6 +48,7 @@ from stoqlib.lib.osutils import get_username
 from stoqlib.lib.parameters import ParameterAccess
 from stoqlib.lib.pluginmanager import get_plugin_manager
 from stoqlib.lib.settings import get_settings
+from stoqlib.net.socketutils import get_hostname
 
 log = Logger('stoqlib.database.testsuite')
 
@@ -79,57 +79,57 @@ test_system_notifier = TestsuiteNotifier()
 
 
 def _provide_database_settings():
-    db_settings.username = os.environ.get('STOQLIB_TEST_USERNAME',
+    db_settings.username = os.environ.get(u'STOQLIB_TEST_USERNAME',
                                           get_username())
-    db_settings.hostname = os.environ.get('PGHOST', 'localhost')
-    db_settings.port = int(os.environ.get('PGPORT', '5432'))
-    db_settings.dbname = os.environ.get('STOQLIB_TEST_DBNAME',
-                                        '%s_test' % db_settings.username)
-    db_settings.password = ''
+    db_settings.hostname = os.environ.get(u'PGHOST', u'localhost')
+    db_settings.port = int(os.environ.get(u'PGPORT', u'5432'))
+    db_settings.dbname = os.environ.get(u'STOQLIB_TEST_DBNAME',
+                                        u'%s_test' % db_settings.username)
+    db_settings.password = u''
 
 
 def _provide_current_user():
-    user = LoginUser.selectOneBy(username='admin',
-                                 connection=get_connection())
+    default_store = get_default_store()
+    user = default_store.find(LoginUser, username=u'admin').one()
+    assert user
     provide_utility(ICurrentUser, user, replace=True)
 
 
 def _provide_current_station(station_name=None, branch_name=None):
     if not station_name:
-        station_name = socket.gethostname()
-    trans = new_transaction()
+        station_name = get_hostname()
+    store = new_store()
     if branch_name:
-        branch = Person.selectOne(
-            AND(Person.q.name == branch_name,
-                Branch.q.person_id == Person.q.id),
-            connection=trans)
+        branch = store.find(Person,
+            And(Person.name == branch_name,
+                Branch.person_id == Person.id)).one()
     else:
-        branches = Branch.select(connection=trans)
+        branches = store.find(Branch)
         if branches.count() == 0:
-            person = Person(name="test", connection=trans)
-            branch = Branch(person=person, connection=trans)
+            person = Person(name=u"test", store=store)
+            branch = Branch(person=person, store=store)
         else:
             branch = branches[0]
 
     provide_utility(ICurrentBranch, branch)
 
-    station = BranchStation.get_station(trans, branch, station_name)
+    station = BranchStation.get_station(store, branch, station_name)
     if not station:
-        station = BranchStation.create(trans, branch, station_name)
+        station = BranchStation.create(store, branch, station_name)
 
     assert station
     assert station.is_active
 
     provide_utility(ICurrentBranchStation, station)
-    trans.commit(close=True)
+    store.commit(close=True)
 
 
 def _provide_app_info():
     from stoqlib.lib.interfaces import IAppInfo
     from stoqlib.lib.appinfo import AppInfo
     info = AppInfo()
-    info.set("name", "Stoqlib")
-    info.set("version", "1.0.0")
+    info.set(u"name", u"Stoqlib")
+    info.set(u"version", u"1.0.0")
     provide_utility(IAppInfo, info)
 
 # Public API
@@ -149,13 +149,13 @@ def provide_database_settings(dbname=None, address=None, port=None, username=Non
     if not username:
         username = get_username()
     if not dbname:
-        dbname = username + '_test'
+        dbname = username + u'_test'
     if not address:
-        address = os.environ.get('PGHOST', '')
+        address = os.environ.get(u'PGHOST', u'')
     if not port:
-        port = os.environ.get('PGPORT', '5432')
+        port = os.environ.get(u'PGPORT', u'5432')
     if not password:
-        password = ""
+        password = u""
 
     # Remove all old utilities pointing to the previous database.
     utilities.clean()
@@ -171,13 +171,9 @@ def provide_database_settings(dbname=None, address=None, port=None, username=Non
     db_settings.password = password
 
     rv = False
-    if create:
-        conn = db_settings.get_default_connection()
-        if not conn.databaseExists(dbname):
-            log.warning('Database %s missing, creating it' % dbname)
-            conn.createEmptyDatabase(dbname)
-            rv = True
-        conn.close()
+    if create or not db_settings.database_exists(dbname):
+        db_settings.clean_database(dbname, force=True)
+        rv = True
 
     return rv
 
@@ -208,7 +204,7 @@ def provide_utilities(station_name, branch_name=None):
 
 def _enable_plugins():
     manager = get_plugin_manager()
-    for plugin in ['nfe', 'ecf']:
+    for plugin in [u'nfe', u'ecf']:
         if not manager.is_installed(plugin):
             # STOQLIB_TEST_QUICK won't let dropdb on testdb run. Just a
             # precaution to avoid trying to install it again
@@ -216,7 +212,7 @@ def _enable_plugins():
 
 
 def bootstrap_suite(address=None, dbname=None, port=5432, username=None,
-                    password="", station_name=None, quick=False):
+                    password=u"", station_name=None, quick=False):
     """
     Test.
     :param address:
@@ -228,29 +224,26 @@ def bootstrap_suite(address=None, dbname=None, port=5432, username=None,
     :param quick:
     """
 
-    # XXX: Rewrite docstring
-    try:
-        empty = provide_database_settings(
-            dbname, address, port, username, password)
+    empty = provide_database_settings(dbname, address, port, username, password,
+                                      create=not quick)
 
-        # Reset the user settings (loaded from ~/.stoq/settings), so that user
-        # preferences don't affect the tests.
-        settings = get_settings()
-        settings.reset()
+    # Reset the user settings (loaded from ~/.stoq/settings), so that user
+    # preferences don't affect the tests.
+    settings = get_settings()
+    settings.reset()
 
-        if quick and not empty:
-            provide_utilities(station_name)
-        else:
-            # XXX: Why clearing_cache if initialize_system will drop the
-            # database?!
-            ParameterAccess.clear_cache()
+    if quick and not empty:
+        provide_utilities(station_name)
+        return
 
-            initialize_system(testsuite=True, force=True)
-            _enable_plugins()
-            ensure_admin_user("")
-            create(utilities=True)
-    except Exception:
-        # Work around trial
-        import traceback
-        traceback.print_exc()
-        os._exit(1)
+    # XXX: Why clearing_cache if initialize_system will drop the
+    # database?!
+    ParameterAccess.clear_cache()
+
+    initialize_system(testsuite=True, force=True)
+
+    # Commit before trying to apply patches which requires an exclusive lock
+    # to all tables.
+    _enable_plugins()
+    ensure_admin_user(u"")
+    create(utilities=True)
