@@ -34,13 +34,16 @@ Finally there's a :class:`AccountTransactionView` that is used by
 the financial application to efficiently display a ledger.
 """
 
+from storm.expr import LeftJoin, Or
+from storm.info import ClassAlias
+from storm.references import Reference
 from zope.interface import implements
 
-from stoqlib.database.orm import PriceCol
-from stoqlib.database.orm import ForeignKey, IntCol, UnicodeCol
-from stoqlib.database.orm import DateTimeCol
-from stoqlib.database.orm import OR, SingleJoin
-from stoqlib.database.orm import Viewable, Alias, LeftJoin
+from stoqlib.database.expr import TransactionTimestamp
+from stoqlib.database.properties import PriceCol
+from stoqlib.database.properties import IntCol, UnicodeCol
+from stoqlib.database.properties import DateTimeCol
+from stoqlib.database.viewable import Viewable
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IDescribable
 from stoqlib.domain.station import BranchStation
@@ -58,14 +61,18 @@ class BillOption(Domain):
     `schema <http://doc.stoq.com.br/schema/tables/bill_option.html>`__
     """
 
+    __storm_table__ = 'bill_option'
+
     #: option name, such as nosso_numero
     option = UnicodeCol()
 
     #: value of the option
     value = UnicodeCol()
 
+    bank_account_id = IntCol()
+
     #: the |bankaccount| this option belongs to
-    bank_account = ForeignKey('BankAccount')
+    bank_account = Reference(bank_account_id, 'BankAccount.id')
 
 
 class BankAccount(Domain):
@@ -75,8 +82,12 @@ class BankAccount(Domain):
     `schema <http://doc.stoq.com.br/schema/tables/bank_account.html>`__
     """
 
+    __storm_table__ = 'bank_account'
+
+    account_id = IntCol()
+
     #: the |account| for this bank account
-    account = ForeignKey('Account', default=None)
+    account = Reference(account_id, 'Account.id')
 
     # FIXME: This is brazil specific, should probably be replaced by a
     #        bank reference to a separate class with name in addition to
@@ -96,8 +107,8 @@ class BankAccount(Domain):
         """Get the bill options for this bank account
         :returns: a list of :class:`BillOption`
         """
-        return BillOption.selectBy(connection=self.get_connection(),
-                                   bank_account=self)
+        return self.store.find(BillOption,
+                               bank_account=self)
 
 
 class Account(Domain):
@@ -108,6 +119,8 @@ class Account(Domain):
     `manual <http://doc.stoq.com.br/manual/account.html>`__
     """
 
+    __storm_table__ = 'account'
+
     #: Bank
     TYPE_BANK = 0
 
@@ -130,23 +143,23 @@ class Account(Domain):
     TYPE_EQUITY = 6
 
     account_labels = {
-        TYPE_BANK: (_("Deposit"), _("Withdrawal")),
-        TYPE_CASH: (_("Receive"), _("Spend")),
-        TYPE_ASSET: (_("Increase"), _("Decrease")),
-        TYPE_CREDIT: (_("Payment"), _("Charge")),
-        TYPE_INCOME: (_("Charge"), _("Income")),
-        TYPE_EXPENSE: (_("Expense"), _("Rebate")),
-        TYPE_EQUITY: (_("Increase"), _("Decrease")),
+        TYPE_BANK: (_(u"Deposit"), _(u"Withdrawal")),
+        TYPE_CASH: (_(u"Receive"), _(u"Spend")),
+        TYPE_ASSET: (_(u"Increase"), _(u"Decrease")),
+        TYPE_CREDIT: (_(u"Payment"), _(u"Charge")),
+        TYPE_INCOME: (_(u"Charge"), _(u"Income")),
+        TYPE_EXPENSE: (_(u"Expense"), _(u"Rebate")),
+        TYPE_EQUITY: (_(u"Increase"), _(u"Decrease")),
     }
 
     account_type_descriptions = [
-        (_("Bank"), TYPE_BANK),
-        (_("Cash"), TYPE_CASH),
-        (_("Asset"), TYPE_ASSET),
-        (_("Credit"), TYPE_CREDIT),
-        (_("Income"), TYPE_INCOME),
-        (_("Expense"), TYPE_EXPENSE),
-        (_("Equity"), TYPE_EQUITY),
+        (_(u"Bank"), TYPE_BANK),
+        (_(u"Cash"), TYPE_CASH),
+        (_(u"Asset"), TYPE_ASSET),
+        (_(u"Credit"), TYPE_CREDIT),
+        (_(u"Income"), TYPE_INCOME),
+        (_(u"Expense"), TYPE_EXPENSE),
+        (_(u"Equity"), TYPE_EQUITY),
         ]
 
     implements(IDescribable)
@@ -157,18 +170,23 @@ class Account(Domain):
     #: code which identifies the account
     code = UnicodeCol(default=None)
 
-    #: parent account, can be None
-    parent = ForeignKey('Account', default=None)
+    #: parent account id, can be None
+    parent_id = IntCol(default=None)
+
+    #: parent account
+    parent = Reference(parent_id, 'Account.id')
+
+    station_id = IntCol(default=None)
 
     #: the |branchstation| tied
     #: to this account, mainly for TYPE_CASH accounts
-    station = ForeignKey('BranchStation', default=None)
+    station = Reference(station_id, 'BranchStation.id')
 
     #: kind of account, one of the TYPE_* defines in this class
     account_type = IntCol(default=None)
 
     #: |bankaccount| for this account, used by TYPE_BANK accounts
-    bank = SingleJoin('BankAccount', joinColumn='account_id')
+    bank = Reference('id', 'BankAccount.account_id', on_remote=True)
 
     #
     # IDescribable implementation
@@ -182,10 +200,10 @@ class Account(Domain):
     #
 
     @classmethod
-    def get_by_station(cls, conn, station):
+    def get_by_station(cls, store, station):
         """Fetch the account assoicated with a station
 
-        :param conn: a connection
+        :param store: a store
         :param station: a |branchstation|
         :returns: the account
         """
@@ -194,7 +212,7 @@ class Account(Domain):
         if not isinstance(station, BranchStation):
             raise TypeError("station must be a BranchStation, not %r" %
                     (station, ))
-        return cls.selectOneBy(connection=conn, station=station)
+        return store.find(cls, station=station).one()
 
     @property
     def long_description(self):
@@ -203,9 +221,11 @@ class Account(Domain):
         parts = []
         account = self
         while account:
-            parts.append(account.description)
+            if account in parts:
+                break
+            parts.append(account)
             account = account.parent
-        return ':'.join(reversed(parts))
+        return u':'.join([a.description for a in reversed(parts)])
 
     @property
     def transactions(self):
@@ -213,17 +233,16 @@ class Account(Domain):
 
         :returns: list of |accounttransaction|
         """
-        return AccountTransaction.select(
-            OR(self.id == AccountTransaction.q.account_id,
-               self.id == AccountTransaction.q.source_account_id),
-            connection=self.get_connection())
+        return self.store.find(AccountTransaction,
+            Or(self.id == AccountTransaction.account_id,
+               self.id == AccountTransaction.source_account_id))
 
     def can_remove(self):
         """If the account can be removed.
         Not all accounts can be removed, some are internal to Stoq
         and cannot be removed"""
         # Can't remove accounts that are used in a parameter
-        sparam = sysparam(self.get_connection())
+        sparam = sysparam(self.store)
         if self in [sparam.IMBALANCE_ACCOUNT,
                     sparam.TILLS_ACCOUNT,
                     sparam.BANKS_ACCOUNT]:
@@ -239,43 +258,40 @@ class Account(Domain):
 
         return True
 
-    def remove(self, trans):
+    def remove(self, store):
         """Remove the current account. This updates all transactions which
         refers to this account and removes them.
 
-        :param: a transaction
+        :param store: a store
         """
         if not self.can_remove():
             raise TypeError("Account %r cannot be removed" % (self, ))
 
-        imbalance_account = sysparam(trans).IMBALANCE_ACCOUNT
+        imbalance_account = sysparam(store).IMBALANCE_ACCOUNT
 
-        for transaction in AccountTransaction.selectBy(
-            connection=trans,
-            account=self):
+        for transaction in store.find(AccountTransaction,
+                                      account=self):
             transaction.account = imbalance_account
-            transaction.sync()
+            store.flush()
 
-        for transaction in AccountTransaction.selectBy(
-            connection=trans,
-            source_account=self):
+        for transaction in store.find(AccountTransaction,
+                                      source_account=self):
             transaction.source_account = imbalance_account
-            transaction.sync()
+            store.flush()
 
         bank = self.bank
         if bank:
-            for options in bank.options:
-                options.delete(options.id, connection=trans)
-            bank.delete(bank.id, connection=trans)
+            for option in bank.options:
+                store.remove(option)
+            store.remove(bank)
 
-        self.delete(self.id, connection=trans)
+        self.delete(self.id, store=store)
 
     def has_child_accounts(self):
         """If this account has child accounts
 
         :returns: True if any other accounts has this account as a parent"""
-        return bool(Account.selectBy(connection=self.get_connection(),
-                                     parent=self))
+        return not self.store.find(Account, parent=self).is_empty()
 
     def get_type_label(self, out):
         """Returns the label to show for the increases/decreases
@@ -319,6 +335,8 @@ class AccountTransaction(Domain):
 
     """
 
+    __storm_table__ = 'account_transaction'
+
     # FIXME: It's way to tricky to calculate the direction and it's
     #        values for an AccountTransaction due to the fact that
     #        we're only store one value. We should store two values,
@@ -328,11 +346,15 @@ class AccountTransaction(Domain):
     #        want to store more values, so it might make sense to allow
     #        N values per transaction.
 
+    account_id = IntCol()
+
     #: destination |account|
-    account = ForeignKey('Account')
+    account = Reference(account_id, 'Account.id')
+
+    source_account_id = IntCol()
 
     #: source |account|
-    source_account = ForeignKey('Account')
+    source_account = Reference(source_account_id, 'Account.id')
 
     #: short human readable summary of the transaction
     description = UnicodeCol()
@@ -346,8 +368,10 @@ class AccountTransaction(Domain):
     #: date the transaction was done
     date = DateTimeCol()
 
+    payment_id = IntCol(default=None)
+
     #: |payment| this transaction relates to, can also be ``None``
-    payment = ForeignKey('Payment', default=None)
+    payment = Reference(payment_id, 'Payment.id')
 
     class sqlmeta:
         lazyUpdate = True
@@ -366,19 +390,45 @@ class AccountTransaction(Domain):
         """
         if not payment.is_paid():
             raise PaymentError(_("Payment needs to be paid"))
-        trans = payment.get_connection()
+        store = payment.store
         value = payment.paid_value
         if payment.is_outpayment():
             value = -value
-        return cls(source_account=sysparam(trans).IMBALANCE_ACCOUNT,
+        return cls(source_account=sysparam(store).IMBALANCE_ACCOUNT,
                    account=account or payment.method.destination_account,
                    value=value,
                    description=payment.description,
-                   code=str(payment.identifier),
+                   code=unicode(payment.identifier),
                    date=payment.paid_date,
-                   connection=trans,
+                   store=store,
                    payment=payment)
 
+    def create_reverse(self):
+        """Reverse this transaction, this happens when a payment
+        is set as not paid.
+
+        :returns: the newly created account transaction representing
+           the reversal
+        """
+
+        # We're effectively canceling the old transaction here,
+        # to avoid having more than one transaction referencing the same
+        # payment we reset the payment to None.
+        #
+        # It would be nice to have all of them reference the same payment,
+        # but it makes it harder to create the reversal.
+
+        self.payment = None
+        return AccountTransaction(
+            source_account=self.source_account,
+            account=self.account,
+            value=-self.value,
+            description=_(u"Reverted: %s") % (self.description),
+            code=self.code,
+            date=TransactionTimestamp(),
+            store=self.store,
+            payment=None)
+
     def get_other_account(self, account):
         """Get the other end of a transaction
 
@@ -398,7 +448,7 @@ class AccountTransaction(Domain):
         :param other: an |account| which we do not want to set
         :param account: the |account| to set
         """
-        other = self.get_connection().get(other)
+        other = self.store.fetch(other)
         if self.source_account == other:
             self.account = account
         elif self.account == other:
@@ -413,35 +463,36 @@ class AccountTransactionView(Viewable):
 
     It's mainly used to show a ledger.
     """
-    Account_Dest = Alias(Account, 'account_dest')
-    Account_Source = Alias(Account, 'account_source')
+    Account_Dest = ClassAlias(Account, 'account_dest')
+    Account_Source = ClassAlias(Account, 'account_source')
 
-    columns = dict(
-        id=AccountTransaction.q.id,
-        code=AccountTransaction.q.code,
-        description=AccountTransaction.q.description,
-        value=AccountTransaction.q.value,
-        date=AccountTransaction.q.date,
-        dest_account_id=Account_Dest.q.id,
-        dest_account_description=Account_Dest.q.description,
-        source_account_id=Account_Source.q.id,
-        source_account_description=Account_Source.q.description,
-        )
+    transaction = AccountTransaction
 
-    joins = [
+    id = AccountTransaction.id
+    code = AccountTransaction.code
+    description = AccountTransaction.description
+    value = AccountTransaction.value
+    date = AccountTransaction.date
+
+    dest_account_id = Account_Dest.id
+    dest_account_description = Account_Dest.description
+
+    source_account_id = Account_Source.id
+    source_account_description = Account_Source.description
+
+    tables = [
+        AccountTransaction,
         LeftJoin(Account_Dest,
-                   AccountTransaction.q.account_id == Account_Dest.q.id),
+                   AccountTransaction.account_id == Account_Dest.id),
         LeftJoin(Account_Source,
-                   AccountTransaction.q.source_account_id == Account_Source.q.id),
+                   AccountTransaction.source_account_id == Account_Source.id),
     ]
 
     @classmethod
-    def get_for_account(cls, account, conn):
+    def get_for_account(cls, account, store):
         """Get all transactions for this |account|, see Account.transaction"""
-        return cls.select(
-            OR(account.id == AccountTransaction.q.account_id,
-               account.id == AccountTransaction.q.source_account_id),
-            connection=conn)
+        return store.find(cls, Or(account.id == AccountTransaction.account_id,
+                           account.id == AccountTransaction.source_account_id))
 
     def get_account_description(self, account):
         """Get description of the other |account|, eg.
@@ -462,8 +513,3 @@ class AccountTransactionView(Viewable):
             return self.value
         else:
             return -self.value
-
-    @property
-    def transaction(self):
-        """Get the AccountTransaction for this view"""
-        return AccountTransaction.get(self.id, self.get_connection())
