@@ -31,11 +31,15 @@ street, district, postal code and a reference to a |person|.
 """
 
 from kiwi.argcheck import argcheck
+from storm.expr import And
+from storm.references import Reference
+from storm.store import AutoReload
 from zope.interface import implements
 
-from stoqlib.database.orm import (ORMObject, AND, UnicodeCol, IntCol,
-                                  BoolCol, ForeignKey, func)
-from stoqlib.database.runtime import StoqlibTransaction
+from stoqlib.database.expr import StoqNormalizeString
+from stoqlib.database.orm import ORMObject
+from stoqlib.database.properties import UnicodeCol, IntCol, BoolCol
+from stoqlib.database.runtime import StoqlibStore
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IDescribable
 from stoqlib.l10n.l10n import get_l10n_field
@@ -52,8 +56,8 @@ def _get_equal_clause(table, value):
     # and start to convert all APIs to use unicode instead of str.
     if isinstance(value, str):
         value = unicode(value, 'utf-8')
-    return (func.stoq_normalize_string(table) ==
-            func.stoq_normalize_string(value))
+    return (StoqNormalizeString(table) ==
+            StoqNormalizeString(value))
 
 
 class CityLocation(ORMObject):
@@ -72,6 +76,10 @@ class CityLocation(ORMObject):
 
     """
 
+    __storm_table__ = 'city_location'
+
+    id = IntCol(primary=True, default=AutoReload)
+
     #: the city
     city = UnicodeCol(default=u"")
 
@@ -94,39 +102,38 @@ class CityLocation(ORMObject):
     #
 
     @classmethod
-    @argcheck(StoqlibTransaction)
-    def get_default(cls, trans):
+    @argcheck(StoqlibStore)
+    def get_default(cls, store):
         """Get the default city location according to the database parameters.
         The is usually the same city as main branch.
 
         :returns: the default city location
         """
-        city = sysparam(trans).CITY_SUGGESTED
-        state = sysparam(trans).STATE_SUGGESTED
-        country = sysparam(trans).COUNTRY_SUGGESTED
+        city = sysparam(store).CITY_SUGGESTED
+        state = sysparam(store).STATE_SUGGESTED
+        country = sysparam(store).COUNTRY_SUGGESTED
 
-        return cls.get_or_create(trans, city, state, country)
+        return cls.get_or_create(store, city, state, country)
 
     @classmethod
-    @argcheck(StoqlibTransaction, basestring, basestring, basestring)
-    def get_or_create(cls, trans, city, state, country):
+    @argcheck(StoqlibStore, basestring, basestring, basestring)
+    def get_or_create(cls, store, city, state, country):
         """
         Get or create a city location. City locations are created lazily,
         so this is used when registering new addresses.
 
-        :param trans: a database transaction
+        :param store: a store
         :param city: a city
         :param state: a state
         :param country: a country
         :returns: the |citylocation| or ``None``
         """
 
-        # FIXME: This should use selectOne. See bug 5146
-        location = list(cls.select(
-            AND(_get_equal_clause(cls.q.city, city),
-                _get_equal_clause(cls.q.state, state),
-                _get_equal_clause(cls.q.country, country)),
-            connection=trans))
+        # FIXME: This should use find().one(). See bug 5146
+        location = list(store.find(cls,
+            And(_get_equal_clause(cls.city, city),
+                _get_equal_clause(cls.state, state),
+                _get_equal_clause(cls.country, country))))
 
         if len(location) == 1:
             return location[0]
@@ -141,46 +148,46 @@ class CityLocation(ORMObject):
         return cls(city=city,
                    state=state,
                    country=country,
-                   connection=trans)
+                   store=store)
 
     @classmethod
-    def get_cities_by(cls, conn, state=None, country=None):
+    def get_cities_by(cls, store, state=None, country=None):
         """Fetch a list of cities given a state and a country.
 
-        :param conn: a database connection
+        :param store: a store
         :param state: state or ``None``
         :param country: country or ``None``
         :returns: a list of cities
         :rtype: string
         """
-        clause = None
+        clauses = []
 
         if state:
-            clause_ = _get_equal_clause(cls.q.state, state)
-            clause = AND(clause, clause_) if clause else clause_
+            clauses.append(_get_equal_clause(cls.state, state))
         if country:
-            clause_ = _get_equal_clause(cls.q.country, country)
-            clause = AND(clause, clause_) if clause else clause_
+            clauses.append(_get_equal_clause(cls.country, country))
 
-        return set(result.city for result in
-                   cls.select(clause, connection=conn))
+        if clauses:
+            results = store.find(cls, And(*clauses))
+        else:
+            results = store.find(cls)
+        return set(result.city for result in results)
 
     @classmethod
-    def exists(cls, conn, city, state, country):
-        # FIXME: This should use selectOne, but its possible to register
+    def exists(cls, store, city, state, country):
+        # FIXME: This should use find().one(), but its possible to register
         # duplicate city locations (see bug 5146)
-        return bool(cls.select(
-            AND(_get_equal_clause(cls.q.city, city),
-                _get_equal_clause(cls.q.state, state),
-                _get_equal_clause(cls.q.country, country)),
-            connection=conn).count())
+        return bool(store.find(cls, And(
+            _get_equal_clause(cls.city, city),
+            _get_equal_clause(cls.state, state),
+            _get_equal_clause(cls.country, country))).count())
 
     #
     #  Public API
     #
 
     def is_valid_model(self):
-        city_l10n = get_l10n_field(self.get_connection(), 'city', self.country)
+        city_l10n = get_l10n_field(self.store, 'city', self.country)
         return bool(self.country and self.city and self.state and
                     city_l10n.validate(self.city,
                                        state=self.state, country=self.country))
@@ -199,30 +206,36 @@ class Address(Domain):
 
     implements(IDescribable)
 
+    __storm_table__ = 'address'
+
     #: street of the address, something like ``"Wall street"``
-    street = UnicodeCol(default='')
+    street = UnicodeCol(default=u'')
 
     #: streetnumber, eg ``100``
     streetnumber = IntCol(default=None)
 
     #: district, eg ``"Manhattan"``
-    district = UnicodeCol(default='')
+    district = UnicodeCol(default=u'')
 
     #: postal code, eg ``"12345-678"``
-    postal_code = UnicodeCol(default='')
+    postal_code = UnicodeCol(default=u'')
 
     #: complement, eg ``"apartment 35"``
-    complement = UnicodeCol(default='')
+    complement = UnicodeCol(default=u'')
 
     #: If this is the primary address for the |person|, this is set
     #: when you register a person for the first time.
     is_main_address = BoolCol(default=False)
 
+    person_id = IntCol()
+
     #: the |person| who resides at this address
-    person = ForeignKey('Person')
+    person = Reference(person_id, 'Person.id')
+
+    city_location_id = IntCol()
 
     #: the |citylocation| this address is in
-    city_location = ForeignKey('CityLocation')
+    city_location = Reference(city_location_id, 'CityLocation.id')
 
     #
     # IDescribable
@@ -278,7 +291,7 @@ class Address(Domain):
         if not self.postal_code:
             return 0
         return int(''.join([c for c in self.postal_code
-                                  if c in '1234567890']))
+                                 if c in u'1234567890']))
 
     def get_address_string(self):
         """Formats the address as a string
