@@ -2,7 +2,7 @@
 # vi:si:et:sw=4:sts=4:ts=4
 
 ##
-## Copyright (C) 2008 Async Open Source <http://www.async.com.br>
+## Copyright (C) 2008-2013 Async Open Source <http://www.async.com.br>
 ## All rights reserved
 ##
 ## This program is free software; you can redistribute it and/or modify
@@ -25,42 +25,63 @@
 
 import datetime
 from decimal import Decimal
+from storm.expr import And
+from storm.references import Reference
+from storm.store import AutoReload
 
-from stoqlib.database.orm import AutoReload
-from stoqlib.database.orm import QuantityCol, PriceCol
-from stoqlib.database.orm import ForeignKey, DateTimeCol, IntCol, UnicodeCol
-from stoqlib.database.orm import const, AND
+from stoqlib.database.expr import TransactionTimestamp
+from stoqlib.database.properties import QuantityCol, PriceCol
+from stoqlib.database.properties import DateTimeCol, IntCol, UnicodeCol
 from stoqlib.domain.base import Domain
 from stoqlib.domain.fiscal import FiscalBookEntry
 from stoqlib.domain.person import Branch
+from stoqlib.domain.product import StockTransactionHistory
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
 
 
 class InventoryItem(Domain):
-    """The InventoryItem belongs to an Inventory. It contains the
-    recorded quantity and the actual quantity related to a specific product.
+    """The InventoryItem belongs to an Inventory.
+    It contains the recorded quantity and the actual quantity related
+    to a specific product.
     If those quantities are not identitical, it will also contain a reason
     and a cfop describing that.
 
-    :attribute product: the item
-    :attribute recorded_quantity: the recorded quantity of a product
-    :attribute actual_quantity: the actual quantity of a product
-    :attribute product_cost: the product's cost when the product was adjusted.
-    :attribute inventory: the inventory process that contains this item
-    :attribute cfop: the cfop used to adjust this item, this is only set when
-        an adjustment is done
-    :attribute reason: the reason of why this item has been adjusted
+    See also:
+    `schema <http://doc.stoq.com.br/schema/tables/inventory_item.html>`__
     """
 
-    product = ForeignKey("Product")
+    __storm_table__ = 'inventory_item'
+
+    product_id = IntCol()
+
+    #: the item
+    product = Reference(product_id, 'Product.id')
+
+    #: the recorded quantity of a product
     recorded_quantity = QuantityCol()
+
+    #: the actual quantity of a product
     actual_quantity = QuantityCol(default=None)
+
+    #: the product's cost when the product was adjusted.
     product_cost = PriceCol()
+
+    #: the reason of why this item has been adjusted
     reason = UnicodeCol(default=u"")
-    cfop_data = ForeignKey("CfopData", default=None)
-    inventory = ForeignKey("Inventory")
+
+    cfop_data_id = IntCol(default=None)
+
+    #: the cfop used to adjust this item, this is only set when
+    #: an adjustment is done
+
+    cfop_data = Reference(cfop_data_id, 'CfopData.id')
+
+    inventory_id = IntCol()
+
+    #: the inventory process that contains this item
+    inventory = Reference(inventory_id, 'Inventory.id')
 
     def _add_inventory_fiscal_entry(self, invoice_number):
         inventory = self.inventory
@@ -69,12 +90,14 @@ class InventoryItem(Domain):
             invoice_number=inventory.invoice_number,
             branch=inventory.branch,
             cfop=self.cfop_data,
-            connection=self.get_connection())
+            store=self.store)
 
     def adjust(self, invoice_number):
         """Create an entry in fiscal book registering the adjustment
         with the related cfop data and change the product quantity
         available in stock.
+
+        :param invoice_number: invoice number to register
         """
         storable = self.product.storable
         if storable is None:
@@ -86,35 +109,41 @@ class InventoryItem(Domain):
             return
         elif adjustment_qty > 0:
             storable.increase_stock(adjustment_qty,
-                                    self.inventory.branch)
+                                    self.inventory.branch,
+                                    StockTransactionHistory.TYPE_INVENTORY_ADJUST,
+                                    self.id)
         else:
             storable.decrease_stock(abs(adjustment_qty),
-                                    self.inventory.branch)
+                                    self.inventory.branch,
+                                    StockTransactionHistory.TYPE_INVENTORY_ADJUST,
+                                    self.id)
 
         self._add_inventory_fiscal_entry(invoice_number)
 
     def adjusted(self):
-        """Returns True if the item have already been adjusted,
-        False otherwise.
+        """Find out if this item has been adjusted.
+
+        :returns: ``True`` if the item have already been adjusted,
+          ``False`` otherwise.
         """
         # We check reason and cfop_data attributes because they only
         # exist after the item be adjusted
         return self.reason and self.cfop_data
 
     def get_code(self):
-        """Returns the product code"""
-        sellable = self.product.sellable
-        return sellable.code
+        """Get the product code of this item
+
+        :returns: the product code
+        """
+        return self.product.sellable.code
 
     def get_description(self):
         """Returns the product description"""
-        sellable = self.product.sellable
-        return sellable.get_description()
+        return self.product.sellable.get_description()
 
     def get_fiscal_description(self):
         """Returns a description of the product tax constant"""
-        sellable = self.product.sellable
-        return sellable.tax_constant.get_description()
+        return self.product.sellable.tax_constant.get_description()
 
     def get_unit_description(self):
         """Returns the product unit description or None if it's not set
@@ -143,26 +172,40 @@ class InventoryItem(Domain):
 
 class Inventory(Domain):
     """ The Inventory handles the logic related to creating inventories
-    for the available products (or a group of) in a certain branch.
-    It has two different states:
+    for the available |product| (or a group of) in a certain |branch|.
 
-        - open: an inventory is opened, at this point the products which
-          are going to be counted (and eventually adjusted) are
-          selected.
-          And then, the inventory items are available for counting and
-          adjustment.
+    It has the following states:
 
-        - closed: all the inventory items have been counted (and
-          eventually) adjusted.
+    - STATUS_OPEN: an inventory is opened, at this point the products which
+      are going to be counted (and eventually adjusted) are
+      selected.
+      And then, the inventory items are available for counting and
+      adjustment.
 
-    :cvar STATUS_OPEN: The inventory process is open
-    :cvar STATUS_CLOSED: The inventory process is closed
-    :attribute open_date: the date inventory process was started
-    :attribute close_date: the date inventory process was closed
-    :attribute branch: branch where the inventory process was done
+    - STATUS_CLOSED: all the inventory items have been counted (and
+      eventually) adjusted.
+
+    - STATUS_CANCELLED: the process was cancelled before being finished,
+      this can only happen before any items are adjusted.
+
+    .. graphviz::
+
+       digraph inventory_status {
+         STATUS_OPEN -> STATUS_CLOSED;
+         STATUS_OPEN -> STATUS_CANCELLED;
+       }
     """
 
-    (STATUS_OPEN, STATUS_CLOSED, STATUS_CANCELLED) = range(3)
+    __storm_table__ = 'inventory'
+
+    #: The inventory process is open
+    STATUS_OPEN = 0
+
+    #: The inventory process is closed
+    STATUS_CLOSED = 1
+
+    #: The inventory process was cancelled, eg never finished
+    STATUS_CANCELLED = 2
 
     statuses = {STATUS_OPEN: _(u'Opened'),
                 STATUS_CLOSED: _(u'Closed'),
@@ -172,11 +215,24 @@ class Inventory(Domain):
     #: :obj:`.id` when displaying a numerical representation of this object to
     #: the user, in dialogs, lists, reports and such.
     identifier = IntCol(default=AutoReload)
+
+    #: status of the inventory, either STATUS_OPEN, STATUS_CLOSED or
+    #: STATUS_CANCELLED
     status = IntCol(default=STATUS_OPEN)
+
+    #: number of the invoice if this inventory generated an adjustment
     invoice_number = IntCol(default=None)
+
+    #: the date inventory process was started
     open_date = DateTimeCol(default_factory=datetime.datetime.now)
+
+    #: the date inventory process was closed
     close_date = DateTimeCol(default=None)
-    branch = ForeignKey("Branch")
+
+    branch_id = IntCol()
+
+    #: branch where the inventory process was done
+    branch = Reference(branch_id, 'Branch.id')
 
     #
     # Public API
@@ -195,7 +251,7 @@ class Inventory(Domain):
         :type: datetime.datetime
         """
         if not close_date:
-            close_date = const.NOW()
+            close_date = TransactionTimestamp()
 
         if not self.is_open():
             raise AssertionError("You can not close an inventory which is "
@@ -211,10 +267,9 @@ class Inventory(Domain):
         if self.status == self.STATUS_CLOSED:
             return False
 
-        conn = self.get_connection()
-        not_counted = InventoryItem.selectBy(inventory=self,
-                                             actual_quantity=None,
-                                             connection=conn)
+        store = self.store
+        not_counted = store.find(InventoryItem, inventory=self,
+                                 actual_quantity=None)
         return not_counted.count() == 0
 
     def get_items(self):
@@ -223,30 +278,30 @@ class Inventory(Domain):
         :returns: items
         :rtype: a sequence of :class:`InventoryItem`
         """
-        conn = self.get_connection()
-        return InventoryItem.selectBy(inventory=self, connection=conn)
+        store = self.store
+        return store.find(InventoryItem, inventory=self)
 
     @classmethod
-    def get_open_branches(cls, conn):
+    def get_open_branches(cls, store):
         """Retuns all the branches available to open the inventory
         process.
 
         :returns: branches
         :rtype: a sequence of :class:`Branch`
         """
-        for branch in Branch.select(connection=conn):
-            if not cls.selectOneBy(branch=branch, status=cls.STATUS_OPEN,
-                                   connection=conn):
+        for branch in store.find(Branch):
+            if not store.find(cls, branch=branch,
+                              status=cls.STATUS_OPEN).one():
                 yield branch
 
     @classmethod
-    def has_open(cls, conn, branch):
+    def has_open(cls, store, branch):
         """Returns if there is an inventory opened at the moment or not.
 
         :returns: The open inventory, if there is one. None otherwise.
         """
-        return cls.selectOneBy(status=Inventory.STATUS_OPEN,
-                               branch=branch, connection=conn)
+        return store.find(cls, status=Inventory.STATUS_OPEN,
+                          branch=branch).one()
 
     def get_items_for_adjustment(self):
         """Returns all the inventory items that needs adjustment, that is
@@ -255,13 +310,12 @@ class Inventory(Domain):
         :returns: items
         :rtype: a sequence of :class:`InventoryItem`
         """
-        query = AND(InventoryItem.q.inventory_id == self.id,
-                    InventoryItem.q.recorded_quantity !=
-                        InventoryItem.q.actual_quantity,
-                    InventoryItem.q.cfop_data_id == None,
-                    InventoryItem.q.reason == u"")
-        conn = self.get_connection()
-        return InventoryItem.select(query, connection=conn)
+        query = And(InventoryItem.inventory_id == self.id,
+                    InventoryItem.recorded_quantity !=
+                    InventoryItem.actual_quantity,
+                    InventoryItem.cfop_data_id == None,
+                    InventoryItem.reason == u"")
+        return self.store.find(InventoryItem, query)
 
     def has_adjusted_items(self):
         """Returns if we already have an item adjusted or not.
@@ -269,11 +323,10 @@ class Inventory(Domain):
         :returns: ``True`` if there is one or more items adjusted, False
           otherwise.
         """
-        query = AND(InventoryItem.q.inventory_id == self.id,
-                    InventoryItem.q.cfop_data_id != None,
-                    InventoryItem.q.reason != u"")
-        conn = self.get_connection()
-        return InventoryItem.select(query, connection=conn).count() > 0
+        query = And(InventoryItem.inventory_id == self.id,
+                    InventoryItem.cfop_data_id != None,
+                    InventoryItem.reason != u"")
+        return not self.store.find(InventoryItem, query).is_empty()
 
     def cancel(self):
         """Cancel this inventory. Notice that, to cancel an inventory no
