@@ -35,13 +35,16 @@ from decimal import Decimal
 
 from kiwi.argcheck import argcheck
 from kiwi.currency import currency
+from storm.references import Reference, ReferenceSet
+from storm.store import AutoReload
 from zope.interface import implements
 
-from stoqlib.database.orm import AutoReload
-from stoqlib.database.orm import ForeignKey, UnicodeCol, DateTimeCol, IntCol
-from stoqlib.database.orm import PriceCol, const, QuantityCol
+from stoqlib.database.expr import Round
+from stoqlib.database.properties import (UnicodeCol,
+                                  DateTimeCol, IntCol, PriceCol, QuantityCol)
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IContainer
+from stoqlib.domain.product import StockTransactionHistory
 from stoqlib.exceptions import DatabaseInconsistency
 from stoqlib.lib.defaults import DECIMAL_PRECISION
 from stoqlib.lib.translation import stoqlib_gettext
@@ -58,9 +61,8 @@ class LoanItem(Domain):
 
     See also:
     `schema <http://doc.stoq.com.br/schema/tables/loan_item.html>`__
-
     """
-    # FIXME: Implement lazy updates in here to avoid all the _set_* bellow
+    __storm_table__ = 'loan_item'
 
     #: The total quantity that was loaned. The product stock for this
     #: will be decreased when the loan stock is synchonized
@@ -78,12 +80,16 @@ class LoanItem(Domain):
     #: a :class:`sale <stoqlib.domain.sale.Sale>`
     price = PriceCol()
 
+    sellable_id = IntCol(allow_none=False)
+
     #: :class:`sellable <stoqlib.domain.sellable.Sellable>` that is loaned
     #: cannot be *None*
-    sellable = ForeignKey('Sellable', allow_none=False)
+    sellable = Reference(sellable_id, 'Sellable.id')
+
+    loan_id = IntCol()
 
     #: :class:`loan <Loan>` this item belongs to
-    loan = ForeignKey('Loan')
+    loan = Reference(loan_id, 'Loan.id')
 
     def __init__(self, *args, **kwargs):
         # stores the total quantity that was loaned before synching stock
@@ -98,6 +104,7 @@ class LoanItem(Domain):
         super(LoanItem, self).__init__(*args, **kwargs)
 
     def __storm_loaded__(self):
+        super(LoanItem, self).__storm_loaded__()
         self._original_quantity = self.quantity
         self._original_return_quantity = self.return_quantity
         self._original_sale_quantity = self.sale_quantity
@@ -127,10 +134,14 @@ class LoanItem(Domain):
         diff_quantity = loaned + returned + sold
 
         if diff_quantity > 0:
-            self.storable.increase_stock(diff_quantity, self.branch)
+            self.storable.increase_stock(diff_quantity, self.branch,
+                                         StockTransactionHistory.TYPE_RETURNED_LOAN,
+                                         self.id)
         elif diff_quantity < 0:
             diff_quantity = - diff_quantity
-            self.storable.decrease_stock(diff_quantity, self.branch)
+            self.storable.decrease_stock(diff_quantity, self.branch,
+                                         StockTransactionHistory.TYPE_LOANED,
+                                         self.id)
 
         # Reset the values used to calculate the stock quantity, just like
         # when the object as loaded from the database again.
@@ -138,8 +149,16 @@ class LoanItem(Domain):
         self._original_return_quantity = self.return_quantity
         self._original_sale_quantity = self.sale_quantity
 
+    def get_remaining_quantity(self):
+        """The remaining quantity that wasn't returned/sold yet
+
+        This is the same as
+        :obj:`.quantity` - :obj:`.sale_quantity` - :obj:`.return_quantity`
+        """
+        return self.quantity - self.sale_quantity - self.return_quantity
+
     def get_quantity_unit_string(self):
-        return "%s %s" % (self.quantity,
+        return u"%s %s" % (self.quantity,
                           self.sellable.get_unit_description())
 
     def get_total(self):
@@ -161,6 +180,8 @@ class Loan(Domain):
 
     implements(IContainer)
 
+    __storm_table__ = 'loan'
+
     #: The request for a loan has been added to the system,
     #: we know which of the items the client wishes to loan,
     #: it's not defined if the client has actually picked up
@@ -185,7 +206,7 @@ class Loan(Domain):
     status = IntCol(default=STATUS_OPEN)
 
     #: notes related to this loan.
-    notes = UnicodeCol(default='')
+    notes = UnicodeCol(default=u'')
 
     #: date loan was opened
     open_date = DateTimeCol(default_factory=datetime.datetime.now)
@@ -197,19 +218,25 @@ class Loan(Domain):
     #: to be returned by this date
     expire_date = DateTimeCol(default=None)
 
-    removed_by = UnicodeCol(default='')
+    removed_by = UnicodeCol(default=u'')
 
     #: branch where the loan was done
-    branch = ForeignKey('Branch')
+    branch_id = IntCol()
+    branch = Reference(branch_id, 'Branch.id')
 
     #: :class:`user <stoqlib.domain.person.LoginUser>` of the system
     #: that made the loan
     # FIXME: Should probably be a SalesPerson, we can find the
-    #        LoginUser via te_created.user
-    responsible = ForeignKey('LoginUser')
+    #        LoginUser via te.user_id
+    responsible_id = IntCol()
+    responsible = Reference(responsible_id, 'LoginUser.id')
 
     #: client that loaned the items
-    client = ForeignKey('Client', default=None)
+    client_id = IntCol(default=None)
+    client = Reference(client_id, 'Client.id')
+
+    #: a list of all items loaned in this loan
+    loaned_items = ReferenceSet('id', 'LoanItem.loan_id')
 
     #
     # Classmethods
@@ -231,11 +258,11 @@ class Loan(Domain):
         loan_item.loan = self
 
     def get_items(self):
-        return LoanItem.selectBy(loan=self, connection=self.get_connection())
+        return self.store.find(LoanItem, loan=self)
 
     @argcheck(LoanItem)
     def remove_item(self, loan_item):
-        LoanItem.delete(loan_item.id, connection=self.get_connection())
+        LoanItem.delete(loan_item.id, store=self.store)
 
     #
     # Public API
@@ -250,7 +277,7 @@ class Loan(Domain):
           from the sellable will be used
         """
         price = price or sellable.price
-        return LoanItem(connection=self.get_connection(),
+        return LoanItem(store=self.store,
                         quantity=quantity,
                         loan=self,
                         sellable=sellable,
@@ -273,7 +300,7 @@ class Loan(Domain):
         :returns: the total value
         """
         return currency(self.get_items().sum(
-            const.ROUND(LoanItem.q.price * LoanItem.q.quantity,
+            Round(LoanItem.price * LoanItem.quantity,
                         DECIMAL_PRECISION)) or 0)
 
     def get_client_name(self):
