@@ -24,16 +24,21 @@
 
 import datetime
 
+from storm.references import Reference
 from zope.interface import implements
 
 from stoqlib.domain.base import Domain
-from stoqlib.database.orm import ForeignKey, DateTimeCol, UnicodeCol
+from stoqlib.database.properties import IntCol, DateTimeCol, UnicodeCol
 from stoqlib.domain.interfaces import IDescribable
 
 
 class PaymentComment(Domain):
-    author = ForeignKey('LoginUser')
-    payment = ForeignKey('Payment')
+    __storm_table__ = 'payment_comment'
+
+    author_id = IntCol()
+    author = Reference(author_id, 'LoginUser.id')
+    payment_id = IntCol()
+    payment = Reference(payment_id, 'Payment.id')
     date = DateTimeCol(default_factory=datetime.datetime.now)
     comment = UnicodeCol()
 
@@ -44,4 +49,4 @@ class PaymentComment(Domain):
     #
 
     def get_description(self):
-        return "[%s] %s" % (self.author.person.name, self.comment)
+        return u"[%s] %s" % (self.author.person.name, self.comment)
