@@ -29,11 +29,13 @@ import operator
 
 from kiwi import ValueUnset
 from kiwi.argcheck import argcheck
+from storm.expr import And
+from storm.references import Reference
 from zope.interface import implements
 
-from stoqlib.database.orm import PercentCol, PriceCol
-from stoqlib.database.orm import IntCol, ForeignKey, BoolCol, StringCol
-from stoqlib.database.orm import const, AND
+from stoqlib.database.expr import TransactionTimestamp
+from stoqlib.database.properties import IntCol, BoolCol, UnicodeCol
+from stoqlib.database.properties import PercentCol
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IActive, IDescribable
 from stoqlib.domain.payment.group import PaymentGroup
@@ -56,49 +58,17 @@ class CheckData(Domain):
     devolutions.
     """
 
+    __storm_table__ = 'check_data'
+
+    payment_id = IntCol()
+
     #: the :class:`payment <stoqlib.domain.payment.Payment>`
-    payment = ForeignKey('Payment')
+    payment = Reference(payment_id, 'Payment.id')
+
+    bank_account_id = IntCol()
 
     #: the :class:`bank account <stoqlib.domain.account.BankAccount>`
-    bank_account = ForeignKey('BankAccount')
-
-
-class CreditCardData(Domain):
-    """Stores CreditCard specific state related to a payment
-    """
-    (TYPE_CREDIT,
-     TYPE_DEBIT,
-     TYPE_CREDIT_INSTALLMENTS_STORE,
-     TYPE_CREDIT_INSTALLMENTS_PROVIDER,
-     TYPE_DEBIT_PRE_DATED) = range(5)
-
-    types = {
-        TYPE_CREDIT: _('Credit Card'),
-        TYPE_DEBIT: _('Debit Card'),
-        TYPE_CREDIT_INSTALLMENTS_STORE: _('Credit Card Installments Store'),
-        TYPE_CREDIT_INSTALLMENTS_PROVIDER: _('Credit Card Installments '
-                                             'Provider'),
-        TYPE_DEBIT_PRE_DATED: _('Debit Card Pre-dated'),
-        }
-
-    #: the :class:`payment <stoqlib.domain.payment.Payment>`
-    payment = ForeignKey('Payment')
-
-    #: int, > 0, < 3
-    card_type = IntCol(default=TYPE_CREDIT)
-
-    # the :class:`credit provider <CreditProvider>` for this class
-    provider = ForeignKey('CreditProvider', default=None)
-    fee = PercentCol(default=0)
-    fee_value = PriceCol(default=0)
-    nsu = IntCol(default=None)
-    auth = IntCol(default=None)
-
-    #: the number of installments
-    installments = IntCol(default=1)
-
-    #: the value of the first installment (when installments > 1)
-    entrance_value = PriceCol(default=0)
+    bank_account = Reference(bank_account_id, 'BankAccount.id')
 
 
 class PaymentMethod(Domain):
@@ -118,15 +88,17 @@ class PaymentMethod(Domain):
 
     implements(IActive, IDescribable)
 
-    method_name = StringCol()
-    is_active = BoolCol(default=True)
-    daily_penalty = PercentCol(default=0)
+    __storm_table__ = 'payment_method'
 
-    #: a value for the interest. It must always be in the format::
+    method_name = UnicodeCol()
+    is_active = BoolCol(default=True)
+    daily_interest = PercentCol(default=0)
+
+    #: a value for the penalty. It must always be in the format::
     #:
-    #:  0 <= interest <= 100
+    #:  0 <= penalty <= 100
     #:
-    interest = PercentCol(default=0)
+    penalty = PercentCol(default=0)
 
     #: which day in the month is the credit provider going to pay the store?
     #: Usually they pay in the same day every month.
@@ -136,7 +108,8 @@ class PaymentMethod(Domain):
     #: payment_day? Sales after this day will be paid only in the next month.
     closing_day = IntCol(default=None)
     max_installments = IntCol(default=1)
-    destination_account = ForeignKey('Account', default=None)
+    destination_account_id = IntCol(default=None)
+    destination_account = Reference(destination_account_id, 'Account.id')
 
     #
     # IActive implementation
@@ -194,32 +167,32 @@ class PaymentMethod(Domain):
                 _('The number of installments can not be greater than %d '
                   'for payment method %r') % (maximum, self))
 
-    def _check_interest_value(self, interest):
-        interest = interest or Decimal(0)
-        if not isinstance(interest, (int, Decimal)):
-            raise TypeError('interest argument must be integer '
+    def _check_penalty_value(self, penalty):
+        penalty = penalty or Decimal(0)
+        if not isinstance(penalty, (int, Decimal)):
+            raise TypeError('penalty argument must be integer '
                             'or Decimal, got %s instead'
-                            % type(interest))
-        if not (0 <= interest <= 100):
-            raise ValueError(_("Argument interest must be "
-                               "between 0 and 100, got %s")
-                             % interest)
+                            % type(penalty))
+        if not (0 <= penalty <= 100):
+            raise ValueError(_("Penalty must be "
+                               "between 0 and 100, not %s")
+                             % penalty)
 
     def _calculate_payment_value(self, total_value, installments_number,
-                                 payment_type, interest=None):
+                                 payment_type, penalty=None):
         if not installments_number:
             raise ValueError(_('The payment_qty argument must be greater '
                                'than zero'))
         if payment_type == Payment.TYPE_IN:
             self._check_installments_number(installments_number)
 
-        self._check_interest_value(interest)
+        self._check_penalty_value(penalty)
 
-        if not interest:
+        if not penalty:
             return total_value / installments_number
 
-        interest_rate = interest / 100 + 1
-        return (total_value / installments_number) * interest_rate
+        penalty_rate = penalty / 100 + 1
+        return (total_value / installments_number) * penalty_rate
 
     #
     # Public API
@@ -251,18 +224,17 @@ class PaymentMethod(Domain):
         :param payment_number: optional
         :returns: a :class:`payment <stoqlib.domain.payment.Payment>`
         """
-        conn = self.get_connection()
+        store = self.store
 
         if due_date is None:
-            due_date = const.NOW()
+            due_date = TransactionTimestamp()
 
         if payment_type == Payment.TYPE_IN:
-            query = AND(Payment.q.group_id == payment_group.id,
-                        Payment.q.method_id == self.id,
-                        Payment.q.payment_type == Payment.TYPE_IN,
-                        Payment.q.status != Payment.STATUS_CANCELLED)
-            payment_count = Payment.select(query,
-                                connection=self.get_connection()).count()
+            query = And(Payment.group_id == payment_group.id,
+                        Payment.method_id == self.id,
+                        Payment.payment_type == Payment.TYPE_IN,
+                        Payment.status != Payment.STATUS_CANCELLED)
+            payment_count = store.find(Payment, query).count()
             if payment_count == self.max_installments:
                 raise PaymentMethodError(
                     _('You can not create more inpayments for this payment '
@@ -280,13 +252,13 @@ class PaymentMethod(Domain):
         if till is ValueUnset:
             # We only need a till for inpayments
             if payment_type == Payment.TYPE_IN:
-                till = Till.get_current(conn)
+                till = Till.get_current(store)
             elif payment_type == Payment.TYPE_OUT:
                 till = None
             else:
                 raise AssertionError(payment_type)
 
-        payment = Payment(connection=conn,
+        payment = Payment(store=store,
                           branch=branch,
                           payment_type=payment_type,
                           due_date=due_date,
@@ -320,16 +292,16 @@ class PaymentMethod(Domain):
         :returns: a list of :class:`payments <stoqlib.domain.payment.Payment>`
         """
         installments = len(due_dates)
-        interest = Decimal(0)
+        penalty = Decimal(0)
 
         normalized_value = self._calculate_payment_value(
-            value, installments, payment_type, interest)
+            value, installments, payment_type, penalty)
 
         normalized_value = quantize(normalized_value)
-        if interest:
-            interest_total = normalized_value * installments - value
+        if penalty:
+            penalty_total = normalized_value * installments - value
         else:
-            interest_total = Decimal(0)
+            penalty_total = Decimal(0)
 
         payments = []
         payments_total = Decimal(0)
@@ -341,7 +313,7 @@ class PaymentMethod(Domain):
             payments_total += normalized_value
 
         # Adjust the last payment so it the total will sum up nicely.
-        difference = -(payments_total - interest_total - value)
+        difference = -(payments_total - penalty_total - value)
         if difference:
             payment.value += difference
         return payments
@@ -362,7 +334,7 @@ class PaymentMethod(Domain):
 
         # TRANSLATORS: This will generate something like: 1/1 Money for sale 00001
         return _(u'{installment} {method_name} for {order_description}').format(
-                 installment='%s/%s' % (installment, installments),
+                 installment=u'%s/%s' % (installment, installments),
                  method_name=self.get_description(),
                  order_description=payment_group.get_description())
 
@@ -443,33 +415,41 @@ class PaymentMethod(Domain):
                                     branch, value, due_dates)
 
     @classmethod
-    def get_active_methods(cls, conn):
+    def get_active_methods(cls, store):
         """Returns a list of active payment methods
         """
-        methods = PaymentMethod.selectBy(is_active=True,
-                                         connection=conn)
+        methods = store.find(PaymentMethod, is_active=True)
         return locale_sorted(methods,
                              key=operator.attrgetter('description'))
 
     @classmethod
-    def get_by_name(cls, conn, name):
+    def get_by_name(cls, store, name):
         """Returns the Payment method associated by the nmae
 
         :param name: name of a payment method
         :returns: a :class:`payment methods <PaymentMethod>`
         """
-        return PaymentMethod.selectOneBy(connection=conn,
-                                         method_name=name)
+        return store.find(PaymentMethod, method_name=name).one()
 
     @classmethod
-    def get_creatable_methods(cls, conn, payment_type, separate):
+    def get_by_account(cls, store, account):
+        """Returns the Payment method associated with an account
+
+        :param account: |account| for which the payment methods are
+           associated with
+        :returns: a sequence :class:`payment methods <PaymentMethod>`
+        """
+        return store.find(PaymentMethod, destination_account=account)
+
+    @classmethod
+    def get_creatable_methods(cls, store, payment_type, separate):
         """Gets a list of methods that are creatable.
         Eg, you can use them to create new payments.
 
         :returns: a list of :class:`payment methods <PaymentMethod>`
         """
         methods = []
-        for method in cls.get_active_methods(conn):
+        for method in cls.get_active_methods(store):
             if not method.operation.creatable(method, payment_type,
                                               separate):
                 continue
@@ -477,7 +457,7 @@ class PaymentMethod(Domain):
         return methods
 
     @classmethod
-    def get_editable_methods(cls, conn):
+    def get_editable_methods(cls, store):
         """Gets a list of methods that are editable
         Eg, you can change the details such as maximum installments etc.
 
@@ -486,10 +466,9 @@ class PaymentMethod(Domain):
         # FIXME: Dont let users see online payments for now, to avoid
         #        confusions with active state. online is an exception to that
         #        logic. 'trade' for the same reason
-        clause = AND(cls.q.method_name != 'online',
-                     cls.q.method_name != 'trade')
-        methods = cls.select(connection=conn,
-                             clause=clause)
+        clause = And(cls.method_name != u'online',
+                     cls.method_name != u'trade')
+        methods = store.find(cls, clause)
         return locale_sorted(methods,
                              key=operator.attrgetter('description'))
 
