@@ -21,6 +21,7 @@
 ##
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
+
 """Payment management implementations.
 
 This module is centered around payments.
@@ -35,14 +36,16 @@ import datetime
 
 from kiwi.currency import currency
 from kiwi.log import Logger
+from storm.references import Reference, ReferenceSet
+from storm.store import AutoReload
 
-from stoqlib.database.orm import AutoReload
-from stoqlib.database.orm import (IntCol, DateTimeCol, UnicodeCol, ForeignKey,
-                                  PriceCol)
-from stoqlib.database.orm import const, MultipleJoin, SingleJoin
+from stoqlib.database.expr import TransactionTimestamp
+from stoqlib.database.properties import (DateTimeCol, IntCol, BoolCol,
+                                         PriceCol, UnicodeCol)
 from stoqlib.domain.account import AccountTransaction
 from stoqlib.domain.base import Domain
 from stoqlib.domain.event import Event
+from stoqlib.domain.interfaces import IPaymentTransaction
 from stoqlib.exceptions import DatabaseInconsistency, StoqlibError
 from stoqlib.lib.dateutils import create_date_interval
 from stoqlib.lib.translation import stoqlib_gettext
@@ -100,6 +103,8 @@ class Payment(Domain):
     `schema <http://doc.stoq.com.br/schema/tables/payment.html>`__
     """
 
+    __storm_table__ = 'payment'
+
     #: incoming to the company, accounts receivable, payment from
     #: a |client| to a |branch|
     TYPE_IN = 0
@@ -150,7 +155,7 @@ class Payment(Domain):
     #: description payment, usually something like "1/3 Money for Sale 1234"
     description = UnicodeCol(default=None)
 
-    # FIXME: use const.NOW() instead to avoid server/client date
+    # FIXME: use TransactionTimestamp() instead to avoid server/client date
     #        inconsistencies
 
     #: when this payment was opened
@@ -189,32 +194,62 @@ class Payment(Domain):
     #: number of the payment
     payment_number = UnicodeCol(default=None)
 
+    branch_id = IntCol(allow_none=False)
+
     #: |branch| associated with this payment.
     #: For a :obj:`.TYPE_IN` payment, this is the branch that will receive
     #: the money. For a :obj:`.TYPE_IN` payment, this is the branch that
     #: will make the payment
-    branch = ForeignKey('Branch', allow_none=False)
+    branch = Reference(branch_id, 'Branch.id')
+
+    method_id = IntCol()
 
     #: |paymentmethod| for this payment
     #: payment
-    method = ForeignKey('PaymentMethod')
+    method = Reference(method_id, 'PaymentMethod.id')
+
+    group_id = IntCol()
 
     #: |paymentgroup| for this payment
-    group = ForeignKey('PaymentGroup')
+    group = Reference(group_id, 'PaymentGroup.id')
+
+    till_id = IntCol()
 
     #: |till| that this payment belongs to
-    till = ForeignKey('Till')
+    till = Reference(till_id, 'Till.id')
 
-    #: |paymentmethod| this payment belongs to, can be None
-    category = ForeignKey('PaymentCategory')
+    category_id = IntCol()
+
+    #: |paymentcategory| this payment belongs to, can be None
+    category = Reference(category_id, 'PaymentCategory.id')
 
     #: list of :class:`comments <stoqlib.domain.payment.comments.PaymentComment>` for
     #: this payment
-    comments = MultipleJoin('PaymentComment', 'payment_id')
+    comments = ReferenceSet('id', 'PaymentComment.payment_id')
 
-    #: list of :class:`check data <stoqlib.domain.payment.method.CheckData>` for
+    #: :class:`check data <stoqlib.domain.payment.method.CheckData>` for
     #: this payment
-    check_data = SingleJoin('CheckData', joinColumn='payment_id')
+    check_data = Reference('id', 'CheckData.payment_id', on_remote=True)
+
+    #: |transaction| for this payment
+    transaction = Reference('id', 'AccountTransaction.payment_id', on_remote=True)
+
+    #: indicates if a bill has been received. They are usually delivered by
+    #: mail before the due date. This is not indicating whether the payment has
+    #: been paid, just that the receiver has notified the payer somehow.
+    bill_received = BoolCol(default=False)
+
+    attachment_id = IntCol()
+
+    #: |attachment| for this payment
+    attachment = Reference(attachment_id, 'Attachment.id')
+
+    def __init__(self, store=None, **kw):
+        if not 'value' in kw:
+            raise TypeError('You must provide a value argument')
+        if not 'base_value' in kw or not kw['base_value']:
+            kw['base_value'] = kw['value']
+        Domain.__init__(self, store=store, **kw)
 
     def _check_status(self, status, operation_name):
         assert self.status == status, ('Invalid status for %s '
@@ -225,31 +260,21 @@ class Payment(Domain):
     # ORMObject hooks
     #
 
-    def _create(self, id, **kw):
-        if not 'value' in kw:
-            raise TypeError('You must provide a value argument')
-        if not 'base_value' in kw or not kw['base_value']:
-            kw['base_value'] = kw['value']
-        Domain._create(self, id, **kw)
-
-    @classmethod
-    def delete(cls, obj_id, connection):
+    def delete(self):
         # First call hooks, do this first so the hook
         # have access to everything it needs
-        payment = cls.get(obj_id, connection)
-        payment.method.operation.payment_delete(payment)
-
-        super(cls, Payment).delete(obj_id, connection)
+        self.method.operation.payment_delete(self)
+        self.store.remove(self)
 
     @classmethod
-    def create_repeated(cls, trans, payment, repeat_type, start_date, end_date):
+    def create_repeated(cls, store, payment, repeat_type, start_date, end_date):
         """Create a set of repeated payments.
         Given a type of interval (*repeat_type*), a start date and an end_date,
         this creates a list of payments for that interval.
 
         Note, this will also update the description of the payment that's passed
         in.
-        :param trans: a database transaction
+        :param store: a store
         :param payment: the payment to repeat
         :param repeat_type: the kind of repetition (weekly, monthly etc)
         :param start_date: the date to start this repetition
@@ -263,7 +288,7 @@ class Payment(Domain):
         if n_dates == 1:
             raise AssertionError
         description = payment.description
-        payment.description = '1/%d %s' % (n_dates, description)
+        payment.description = u'1/%d %s' % (n_dates, description)
         payment.due_date = dates[0]
 
         payments = []
@@ -272,7 +297,7 @@ class Payment(Domain):
                         branch=payment.branch,
                         payment_type=payment.payment_type,
                         status=payment.status,
-                        description='%d/%d %s' % (i + 2, n_dates,
+                        description=u'%d/%d %s' % (i + 2, n_dates,
                                                   description),
                         value=payment.value,
                         base_value=payment.base_value,
@@ -281,7 +306,7 @@ class Payment(Domain):
                         group=payment.group,
                         till=payment.till,
                         category=payment.category,
-                        connection=trans)
+                        store=store)
             payments.append(p)
         return payments
 
@@ -300,7 +325,7 @@ class Payment(Domain):
         # This is used by test_payment_method, and is a convenience
         # property, ideally we should move it to payment operation
         # somehow
-        if self.method.method_name == 'check':
+        if self.method.method_name == u'check':
             data = self.method.operation.get_check_data_by_payment(self)
             bank_account = data.bank_account
             if bank_account:
@@ -308,7 +333,7 @@ class Payment(Domain):
 
     @property
     def installment_number(self):
-        payments = self.group.get_valid_payments().orderBy(Payment.q.id)
+        payments = self.group.get_valid_payments().order_by(Payment.id)
         for i, payment in enumerate(payments):
             if self == payment:
                 return i + 1
@@ -339,7 +364,7 @@ class Payment(Domain):
         This also means that this is valid payment and its owner
         actually can charge it
         """
-        self._check_status(self.STATUS_PREVIEW, 'set_pending')
+        self._check_status(self.STATUS_PREVIEW, u'set_pending')
         self.status = self.STATUS_PENDING
 
     def set_not_paid(self, change_entry):
@@ -349,7 +374,10 @@ class Payment(Domain):
         :param change_entry: a :class:`PaymentChangeHistory` object,
           that will hold the changes information
         """
-        self._check_status(self.STATUS_PAID, 'set_not_paid')
+        self._check_status(self.STATUS_PAID, u'set_not_paid')
+
+        if self.transaction:
+            self.transaction.create_reverse()
 
         change_entry.last_status = self.STATUS_PAID
         change_entry.new_status = self.STATUS_PENDING
@@ -361,27 +389,32 @@ class Payment(Domain):
     def pay(self, paid_date=None, paid_value=None, account=None):
         """Pay the current payment set its status as :obj:`.STATUS_PAID`"""
         if self.status != Payment.STATUS_PENDING:
-            raise ValueError(_("This payment is already paid."))
-        self._check_status(self.STATUS_PENDING, 'pay')
+            raise ValueError(_(u"This payment is already paid."))
+        self._check_status(self.STATUS_PENDING, u'pay')
 
         paid_value = paid_value or (self.value - self.discount +
                                     self.interest)
         self.paid_value = paid_value
-        self.paid_date = paid_date or const.NOW()
+        self.paid_date = paid_date or TransactionTimestamp()
         self.status = self.STATUS_PAID
 
         if (self.is_separate_payment() or
             self.method.operation.create_transaction()):
             AccountTransaction.create_from_payment(self, account)
 
+        sale = self.group and self.group.sale
+        if sale:
+            transaction = IPaymentTransaction(sale)
+            transaction.create_commission(self)
+
         if self.value == self.paid_value:
-            msg = _("{method} payment with value {value:.2f} was paid").format(
+            msg = _(u"{method} payment with value {value:.2f} was paid").format(
                     method=self.method.method_name,
                     value=self.value)
         else:
-            msg = _("{method} payment with value original value "
-                    "{original_value:.2f} was paid with value "
-                    "{value:.2f}").format(
+            msg = _(u"{method} payment with value original value "
+                    u"{original_value:.2f} was paid with value "
+                    u"{value:.2f}").format(
                     method=self.method.method_name,
                     original_value=self.value,
                     value=self.paid_value)
@@ -394,18 +427,21 @@ class Payment(Domain):
         # it's possible. Bug 2598
         if self.status not in [Payment.STATUS_PREVIEW, Payment.STATUS_PENDING,
                                Payment.STATUS_PAID]:
-            raise StoqlibError(_("Invalid status for cancel operation, "
-                                 "got %s") % self.get_status_str())
+            raise StoqlibError(_(u"Invalid status for cancel operation, "
+                                 u"got %s") % self.get_status_str())
+
+        if self.transaction:
+            self.transaction.create_reverse()
 
         old_status = self.status
         self.status = self.STATUS_CANCELLED
-        self.cancel_date = const.NOW()
+        self.cancel_date = TransactionTimestamp()
 
         if change_entry is not None:
             change_entry.last_status = old_status
             change_entry.new_status = self.status
 
-        msg = _("{method} payment with value {value:.2f} was cancelled").format(
+        msg = _(u"{method} payment with value {value:.2f} was cancelled").format(
                 method=self.method.method_name,
                 value=self.value)
         Event.log(Event.TYPE_PAYMENT, msg.capitalize())
@@ -416,8 +452,8 @@ class Payment(Domain):
         :rtype: datetime.date
         """
         if self.status in [Payment.STATUS_PAID, Payment.STATUS_CANCELLED]:
-            raise StoqlibError(_("Invalid status for change_due_date operation, "
-                                 "got %s") % self.get_status_str())
+            raise StoqlibError(_(u"Invalid status for change_due_date operation, "
+                                 u"got %s") % self.get_status_str())
         self.due_date = new_due_date
 
     def update_value(self, new_value):
@@ -427,9 +463,9 @@ class Payment(Domain):
         self.value = new_value
 
     def get_payable_value(self):
-        """Returns the calculated payment value with the daily penalty.
+        """Returns the calculated payment value with the daily interest.
 
-        Note that the payment group daily_penalty must be between 0 and 100.
+        Note that the payment group daily_interest must be between 0 and 100.
 
         :returns: the payable value
         """
@@ -439,7 +475,7 @@ class Payment(Domain):
                            self.STATUS_CONFIRMED]:
             return self.paid_value
 
-        return self.value + self.get_penalty()
+        return self.value + self.get_interest()
 
     def get_penalty(self, date=None):
         """Calculate the penalty in an absolute value
@@ -451,20 +487,19 @@ class Payment(Domain):
         if not date:
             date = datetime.date.today()
         elif date < self.open_date.date():
-            raise ValueError(_("Date can not be less then open date"))
+            raise ValueError(_(u"Date can not be less then open date"))
         elif date > datetime.date.today():
-            raise ValueError(_("Date can not be greather then future date"))
-
-        if not self.method.daily_penalty:
+            raise ValueError(_(u"Date can not be greather then future date"))
+        if not self.method.penalty:
             return currency(0)
 
-        days = (date - self.due_date.date()).days
-        if days <= 0:
+        # Don't add penalty if we pay in time!
+        if self.due_date.date() >= date:
             return currency(0)
 
-        return currency(days * self.method.daily_penalty / 100 * self.value)
+        return currency(self.method.penalty / 100 * self.value)
 
-    def get_interest(self, date=None):
+    def get_interest(self, date=None, pay_penalty=True):
         """Calculate the interest in an absolute value
 
         :param date: date of payment
@@ -474,17 +509,26 @@ class Payment(Domain):
         if not date:
             date = datetime.date.today()
         elif date < self.open_date.date():
-            raise ValueError(_("Date can not be less then open date"))
+            raise ValueError(_(u"Date can not be less then open date"))
         elif date > datetime.date.today():
-            raise ValueError(_("Date can not be greather then future date"))
-        if not self.method.interest:
+            raise ValueError(_(u"Date can not be greather then future date"))
+
+        if not self.method.daily_interest:
             return currency(0)
 
-        # Don't add interest if we pay in time!
-        if self.due_date.date() >= date:
+        days = (date - self.due_date.date()).days
+        if days <= 0:
             return currency(0)
 
-        return currency(self.method.interest / 100 * self.value)
+        base_value = self.value + (pay_penalty and self.get_penalty(date=date))
+
+        return currency(days * self.method.daily_interest / 100 * base_value)
+
+    def has_commission(self):
+        """Check if this |payment| already has a |commission|"""
+        from stoqlib.domain.commission import Commission
+        return self.store.find(Commission,
+                               payment=self).any()
 
     def is_paid(self):
         """Check if the payment is paid.
@@ -521,7 +565,7 @@ class Payment(Domain):
         """
         if self.paid_date:
             return self.paid_date.date().strftime('%x')
-        return _('NOT PAID')
+        return _(u'NOT PAID')
 
     def get_open_date_string(self):
         """Get a open date string
@@ -530,7 +574,7 @@ class Payment(Domain):
         """
         if self.open_date:
             return self.open_date.date().strftime('%x')
-        return ""
+        return u""
 
     def get_payment_number_str(self):
         return u'%05d' % self.identifier
@@ -577,7 +621,7 @@ class Payment(Domain):
 
         :returns: ``True`` if it's a money payment
         """
-        return self.method.method_name == 'money'
+        return self.method.method_name == u'money'
 
 
 class PaymentChangeHistory(Domain):
@@ -590,8 +634,12 @@ class PaymentChangeHistory(Domain):
     `schema <http://doc.stoq.com.br/schema/tables/payment_change_history.html>`__
     """
 
+    __storm_table__ = 'payment_change_history'
+
+    payment_id = IntCol()
+
     #: the changed |payment|
-    payment = ForeignKey('Payment')
+    payment = Reference(payment_id, 'Payment.id')
 
     #: the reason of the change
     change_reason = UnicodeCol(default=None)
