@@ -24,7 +24,7 @@
 
 
 from stoqlib.domain.base import Domain
-from stoqlib.database.orm import StringCol, IntCol
+from stoqlib.database.properties import UnicodeCol, IntCol
 
 
 class InstalledPlugin(Domain):
@@ -33,13 +33,15 @@ class InstalledPlugin(Domain):
     :cvar plugin_name: name of the plugin
     :cvar plugin_version: version of the plugin
     """
-    plugin_name = StringCol()
+    __storm_table__ = 'installed_plugin'
+
+    plugin_name = UnicodeCol()
     plugin_version = IntCol()
 
     @classmethod
-    def get_plugin_names(cls, conn):
+    def get_plugin_names(cls, store):
         """Fetchs a list of installed plugin names
-        :param conn: a connection
+        :param store: a store
         :returns: list of strings
         """
-        return [p.plugin_name for p in cls.select(connection=conn)]
+        return [p.plugin_name for p in store.find(cls)]
