@@ -26,12 +26,15 @@
 import datetime
 from decimal import Decimal
 
+from kiwi.currency import currency
+from storm.references import Reference, ReferenceSet
 from zope.interface import implements
 
-from stoqlib.database.orm import PriceCol, DecimalCol, QuantityCol
-from stoqlib.database.orm import (UnicodeCol, ForeignKey, MultipleJoin, DateTimeCol,
+from stoqlib.database.properties import PriceCol, DecimalCol, QuantityCol
+from stoqlib.database.properties import (UnicodeCol, DateTimeCol,
                                   BoolCol, IntCol, PercentCol)
-from stoqlib.database.orm import const, AND, LeftJoin
+from stoqlib.database.expr import TransactionTimestamp
+from stoqlib.database.runtime import get_current_user
 from stoqlib.domain.base import Domain
 from stoqlib.domain.events import (ProductCreateEvent, ProductEditEvent,
                                    ProductRemoveEvent, ProductStockUpdateEvent)
@@ -57,6 +60,8 @@ class ProductSupplierInfo(Domain):
     `schema <http://doc.stoq.com.br/schema/tables/product_supplier_info.html>`__
     """
 
+    __storm_table__ = 'product_supplier_info'
+
     #: the cost which helps the purchaser to define the main cost of a
     #: certain product. Each product can have multiple |suppliers| and for
     #: each |supplier| a base_cost is available. The purchaser in this case
@@ -64,7 +69,7 @@ class ProductSupplierInfo(Domain):
     #: of all suppliers.
     base_cost = PriceCol(default=0)
 
-    notes = UnicodeCol(default='')
+    notes = UnicodeCol(default=u'')
 
     #: if this object stores information for the main |supplier|.
     is_main_supplier = BoolCol(default=False)
@@ -79,34 +84,18 @@ class ProductSupplierInfo(Domain):
     #: de mercadorias e prestacao de servicos'
     icms = PercentCol(default=0)
 
+    supplier_id = IntCol()
+
     #: the |supplier|
-    supplier = ForeignKey('Supplier')
+    supplier = Reference(supplier_id, 'Supplier.id')
+
+    product_id = IntCol()
 
     #: the |product|
-    product = ForeignKey('Product')
+    product = Reference(product_id, 'Product.id')
 
-    #
-    # Classmethods
-    #
-
-    @classmethod
-    def get_info_by_supplier(cls, conn, supplier, consigned=False):
-        """Retuns all the products information provided by the given
-        |supplier|.
-
-        :param conn: a database connection
-        :param supplier: the |supplier|
-        :param consigned: the consigned |product|
-        """
-        if consigned:
-            join = LeftJoin(Product,
-                        ProductSupplierInfo.q.product_id == Product.q.id)
-            query = AND(ProductSupplierInfo.q.supplier_id == supplier.id,
-                        Product.q.consignment == consigned)
-        else:
-            join = None
-            query = AND(ProductSupplierInfo.q.supplier_id == supplier.id)
-        return cls.select(clause=query, join=join, connection=conn)
+    #: the product code in the supplier
+    supplier_code = UnicodeCol(default=u'')
 
     #
     # Auxiliary methods
@@ -124,7 +113,7 @@ class ProductSupplierInfo(Domain):
             day_str = _(u"Day")
             lead_time = self.lead_time or 0
 
-        return "%d %s" % (lead_time, day_str)
+        return u"%d %s" % (lead_time, day_str)
 
 
 class Product(Domain):
@@ -145,8 +134,14 @@ class Product(Domain):
     `schema <http://doc.stoq.com.br/schema/tables/product.html>`__
     """
 
+    __storm_table__ = 'product'
+
+    sellable_id = IntCol()
+
     #: |sellable| for this product
-    sellable = ForeignKey('Sellable')
+    sellable = Reference(sellable_id, 'Sellable.id')
+
+    suppliers = ReferenceSet('id', 'ProductSupplierInfo.product_id')
 
     #: if this product is loaned from the |supplier|
     consignment = BoolCol(default=False)
@@ -157,12 +152,12 @@ class Product(Domain):
     is_composed = BoolCol(default=False)
 
     #: physical location of this product, like a drawer or shelf number
-    location = UnicodeCol(default='')
+    location = UnicodeCol(default=u'')
 
-    model = UnicodeCol(default='')
+    model = UnicodeCol(default=u'')
 
     #: a number representing this part
-    part_number = UnicodeCol(default='')
+    part_number = UnicodeCol(default=u'')
 
     #: physical width of this product, unit not enforced
     width = DecimalCol(default=0)
@@ -188,27 +183,31 @@ class Product(Domain):
     #: NFE: see ncm
     genero = UnicodeCol(default=None)
 
+    manufacturer_id = IntCol(default=None)
+
     #: name of the manufacturer for this product
-    manufacturer = ForeignKey('ProductManufacturer', default=None)
+    manufacturer = Reference(manufacturer_id, 'ProductManufacturer.id')
 
-    #: ICMS tax template, brazil specific
-    icms_template = ForeignKey('ProductIcmsTemplate', default=None)
+    icms_template_id = IntCol(default=None)
 
-    #: IPI tax template, brazil specific
-    ipi_template = ForeignKey('ProductIpiTemplate', default=None)
+    icms_template = Reference(icms_template_id, 'ProductIcmsTemplate.id')
+
+    ipi_template_id = IntCol(default=None)
+
+    ipi_template = Reference(ipi_template_id, 'ProductIpiTemplate.id')
 
     #: Used for composed products only
-    quality_tests = MultipleJoin('ProductQualityTest', 'product_id')
+    quality_tests = ReferenceSet('id', 'ProductQualityTest.product_id')
 
     #: list of |suppliers| that sells this product
-    suppliers = MultipleJoin('ProductSupplierInfo', 'product_id')
+    suppliers = ReferenceSet('id', 'ProductSupplierInfo.product_id')
 
     #
     # General Methods
     #
 
     def has_quality_tests(self):
-        return bool(self.quality_tests)
+        return not self.quality_tests.find().is_empty()
 
     @property
     def description(self):
@@ -216,21 +215,20 @@ class Product(Domain):
 
     @property
     def storable(self):
-        return Storable.selectOneBy(product=self,
-                                    connection=self.get_connection())
+        return self.store.find(Storable, product=self).one()
 
     def remove(self):
         """Deletes this product from the database.
         """
         storable = self.storable
         if storable:
-            storable.delete(storable.id, self.get_connection())
+            self.store.remove(storable)
         for i in self.get_suppliers_info():
-            i.delete(i.id, self.get_connection())
+            self.store.remove(i)
         for i in self.get_components():
-            i.delete(i.id, self.get_connection())
+            self.store.remove(i)
 
-        self.delete(self.id, self.get_connection())
+        self.store.remove(self)
 
     def can_remove(self):
         """Whether we can delete this product and it's |sellable| from the
@@ -246,12 +244,12 @@ class Product(Domain):
         if storable and storable.get_stock_items().count():
             return False
         # Return False if the product is component of other.
-        elif ProductComponent.selectBy(connection=self.get_connection(),
-                                       component=self).count():
+        elif self.store.find(ProductComponent,
+                             component=self).count():
             return False
         # Return False if the component(product) is used in a production.
-        elif ProductionItem.selectBy(connection=self.get_connection(),
-                                     product=self).count():
+        elif self.store.find(ProductionItem,
+                             product=self).count():
             return False
         return True
 
@@ -299,13 +297,12 @@ class Product(Domain):
         if self.is_composed:
             return self.get_manufacture_time(quantity, branch)
         else:
-            return self.suppliers.max('lead_time') or 0
+            return self.suppliers.find().max(ProductSupplierInfo.lead_time) or 0
 
     def get_history(self):
         """Returns the list of :class:`ProductHistory` for this product.
         """
-        return ProductHistory.selectBy(sellable=self.sellable,
-                                       connection=self.get_connection())
+        return self.store.find(ProductHistory, sellable=self.sellable)
 
     def get_main_supplier_name(self):
         supplier_info = self.get_main_supplier_info()
@@ -319,10 +316,9 @@ class Product(Domain):
         :rtype: ProductSupplierInfo or None if a product lacks
            a main suppliers
         """
-        return ProductSupplierInfo.selectOneBy(
-            product=self,
-            is_main_supplier=True,
-            connection=self.get_connection())
+        store = self.store
+        return store.find(ProductSupplierInfo,
+                          product=self, is_main_supplier=True).one()
 
     def get_suppliers_info(self):
         """Returns a list of suppliers for this product
@@ -330,16 +326,15 @@ class Product(Domain):
         :returns: a list of suppliers
         :rtype: list of ProductSupplierInfo
         """
-        return ProductSupplierInfo.selectBy(
-            product=self, connection=self.get_connection())
+        return self.store.find(ProductSupplierInfo,
+                               product=self)
 
     def get_components(self):
         """Returns the products which are our |components|.
 
         :returns: a sequence of |components|
         """
-        return ProductComponent.selectBy(product=self,
-                                         connection=self.get_connection())
+        return self.store.find(ProductComponent, product=self)
 
     def has_components(self):
         """Returns if this product has a |component| or not.
@@ -359,9 +354,9 @@ class Product(Domain):
         """If this product is supplied by the given |supplier|, returns the
         object with the supplier information. Returns ``None`` otherwise
         """
-        return ProductSupplierInfo.selectOneBy(
-                        product=self, supplier=supplier,
-                        connection=self.get_connection()) is not None
+        store = self.store
+        return store.find(ProductSupplierInfo, product=self,
+                          supplier=supplier).one() is not None
 
     def is_composed_by(self, product):
         """Returns if we are composed by a given product or not.
@@ -392,16 +387,16 @@ class Product(Domain):
         ProductRemoveEvent.emit(self)
 
     def on_update(self):
-        trans = self.get_connection()
-        emitted_trans_list = getattr(self, '_emitted_trans_list', set())
+        store = self.store
+        emitted_store_list = getattr(self, '_emitted_store_list', set())
 
         # Since other classes can propagate this event (like Sellable),
-        # emit the event only once for each transaction.
-        if not trans in emitted_trans_list:
+        # emit the event only once for each store.
+        if not store in emitted_store_list:
             ProductEditEvent.emit(self)
-            emitted_trans_list.add(trans)
+            emitted_store_list.add(store)
 
-        self._emitted_trans_list = emitted_trans_list
+        self._emitted_store_list = emitted_store_list
 
 
 class ProductManufacturer(Domain):
@@ -413,6 +408,8 @@ class ProductManufacturer(Domain):
 
     implements(IDescribable)
 
+    __storm_table__ = 'product_manufacturer'
+
     #: manufacturer's name
     name = UnicodeCol()
 
@@ -425,12 +422,11 @@ class ProductManufacturer(Domain):
 
     def can_remove(self):
         """ Check if the manufacturer is used in some product."""
-        return not Product.selectBy(manufacturer=self,
-                                    connection=self.get_connection()).count()
+        return not self.store.find(Product, manufacturer=self).count()
 
     def remove(self):
         """Remove this registry from the database."""
-        self.delete(self.id, self.get_connection())
+        self.delete(self.id, self.store)
 
 
 class ProductHistory(Domain):
@@ -446,6 +442,8 @@ class ProductHistory(Domain):
               of the product id for consistency with interfaces that display
               both.
     """
+    __storm_table__ = 'product_history'
+
     quantity_sold = QuantityCol(default=None)
     quantity_received = QuantityCol(default=None)
     quantity_transfered = QuantityCol(default=None)
@@ -458,114 +456,118 @@ class ProductHistory(Domain):
     received_date = DateTimeCol(default=None)
     decreased_date = DateTimeCol(default=None)
 
+    branch_id = IntCol()
+
     #: the |branch|
-    branch = ForeignKey("Branch")
+    branch = Reference(branch_id, 'Branch.id')
+
+    sellable_id = IntCol()
 
     #: the |sellable|
-    sellable = ForeignKey("Sellable")
+    sellable = Reference(sellable_id, 'Sellable.id')
 
     @classmethod
-    def add_sold_item(cls, conn, branch, product_sellable_item):
+    def add_sold_item(cls, store, branch, product_sellable_item):
         """Adds a |saleitem| to the history. *product_sale_item* is an item
         that was created during a |sale|.
 
-        :param conn: a database connection
+        :param store: a store
         :param branch: the |branch|
         :param product_sellable_item: the |saleitem| for the sold |product|
         """
         cls(branch=branch,
             sellable=product_sellable_item.sellable,
             quantity_sold=product_sellable_item.quantity,
-            sold_date=const.NOW(),
-            connection=conn)
+            sold_date=TransactionTimestamp(),
+            store=store)
 
     @classmethod
-    def add_received_item(cls, conn, branch, receiving_order_item):
+    def add_received_item(cls, store, branch, receiving_order_item):
         """
         Adds a received item, populates the ProductHistory table using a
         *receiving_order_item* created during a |purchase|
 
-        :param conn: a database connection
+        :param store: a store
         :param branch: the |branch|
         :param receiving_order_item: the item received for |purchase|
         """
         cls(branch=branch, sellable=receiving_order_item.sellable,
             quantity_received=receiving_order_item.quantity,
             received_date=receiving_order_item.receiving_order.receival_date,
-            connection=conn)
+            store=store)
 
     @classmethod
-    def add_transfered_item(cls, conn, branch, transfer_order_item):
+    def add_transfered_item(cls, store, branch, transfer_order_item):
         """
         Adds a transfered_item, populates the ProductHistory table using a
         *transfered_order_item* created during a |transfer|.
 
-        :param conn: a database connection
+        :param store: a store
         :param branch: the source branch
         :param transfer_order_item: the item transfered from source branch
         """
         cls(branch=branch, sellable=transfer_order_item.sellable,
             quantity_transfered=transfer_order_item.quantity,
             received_date=transfer_order_item.transfer_order.receival_date,
-            connection=conn)
+            store=store)
 
     @classmethod
-    def add_consumed_item(cls, conn, branch, consumed_item):
+    def add_consumed_item(cls, store, branch, consumed_item):
         """
         Adds a consumed_item, populates the ProductHistory table using a
         production_material item that was used in a |production|.
 
-        :param conn: a database connection
+        :param store: a store
         :param branch: the source branch
         :param retained_item: a ProductionMaterial instance
         """
         cls(branch=branch, sellable=consumed_item.product.sellable,
             quantity_consumed=consumed_item.consumed,
             production_date=datetime.date.today(),
-            connection=conn)
+            store=store)
 
     @classmethod
-    def add_produced_item(cls, conn, branch, produced_item):
+    def add_produced_item(cls, store, branch, produced_item):
         """
         Adds a produced_item, populates the ProductHistory table using a
         production_item that was produced in a production order.
 
-        :param conn: a database connection
+        :param store: a store
         :param branch: the source branch
         :param retained_item: a ProductionItem instance
         """
         cls(branch=branch, sellable=produced_item.product.sellable,
             quantity_produced=produced_item.produced,
-            production_date=datetime.date.today(), connection=conn)
+            production_date=datetime.date.today(), store=store)
 
     @classmethod
-    def add_lost_item(cls, conn, branch, lost_item):
+    def add_lost_item(cls, store, branch, lost_item):
         """
         Adds a lost_item, populates the ProductHistory table using a
         production_item/product_material that was lost in a production order.
 
-        :param conn: a database connection
+        :param store: a store
         :param branch: the source branch
         :param lost_item: a ProductionItem or ProductionMaterial instance
         """
         cls(branch=branch, sellable=lost_item.product.sellable,
             quantity_lost=lost_item.lost,
-            production_date=datetime.date.today(), connection=conn)
+            production_date=datetime.date.today(), store=store)
 
     @classmethod
-    def add_decreased_item(cls, conn, branch, item):
+    def add_decreased_item(cls, store, branch, item):
         """
         Adds a decreased item, populates the ProductHistory table informing
         how many items wore manually decreased from stock.
 
-        :param conn: a database connection
+        :param store: a store
         :param branch: the source |branch|
         :param item: a StockDecreaseItem instance
         """
         cls(branch=branch, sellable=item.sellable,
             quantity_decreased=item.quantity,
             decreased_date=datetime.date.today(),
-            connection=conn)
+            store=store)
 
 
 class ProductStockItem(Domain):
@@ -576,6 +578,8 @@ class ProductStockItem(Domain):
     `schema <http://doc.stoq.com.br/schema/tables/product_stock_item.html>`__
     """
 
+    __storm_table__ = 'product_stock_item'
+
     #: the average stock price, will be updated as new stock items are
     #: received.
     stock_cost = PriceCol(default=0)
@@ -583,11 +587,15 @@ class ProductStockItem(Domain):
     #: number of storables in the stock item
     quantity = QuantityCol(default=0)
 
+    branch_id = IntCol()
+
     #: the |branch| this stock item belongs to
-    branch = ForeignKey('Branch')
+    branch = Reference(branch_id, 'Branch.id')
+
+    storable_id = IntCol()
 
     #: the |storable| the stock item refers to
-    storable = ForeignKey('Storable')
+    storable = Reference(storable_id, 'Storable.id')
 
     def update_cost(self, new_quantity, new_cost):
         """Update the stock_item according to new quantity and cost.
@@ -610,8 +618,12 @@ class Storable(Domain):
     `schema <http://doc.stoq.com.br/schema/tables/storable.html>`__
     '''
 
+    __storm_table__ = 'storable'
+
+    product_id = IntCol()
+
     #: the |product| the stock represents
-    product = ForeignKey('Product')
+    product = Reference(product_id, 'Product.id')
 
     #: minimum quantity of stock items allowed
     minimum_quantity = QuantityCol(default=0)
@@ -623,26 +635,31 @@ class Storable(Domain):
     # Properties
     #
 
-    def increase_stock(self, quantity, branch, unit_cost=None):
+    def increase_stock(self, quantity, branch, type, object_id, unit_cost=None):
         """When receiving a product, update the stock reference for this new
         item on a specific |branch|.
 
         :param quantity: amount to increase
         :param branch: |branch| that stores the stock
-        :param cost: unit cost of the new stock or `None`
+        :param type: the type of the stock increase. One of the
+            StockTransactionHistory.types
+        :param object_id: the id of the object responsible for the transaction
+        :param unit_cost: unit cost of the new stock or `None`
         """
+        assert isinstance(type, int)
+
         if quantity <= 0:
-            raise ValueError(_("quantity must be a positive number"))
+            raise ValueError(_(u"quantity must be a positive number"))
         if branch is None:
-            raise ValueError("branch cannot be None")
+            raise ValueError(u"branch cannot be None")
         stock_item = self.get_stock_item(branch)
         # If the stock_item is missing create a new one
         if stock_item is None:
-            conn = self.get_connection()
+            store = self.store
             stock_item = ProductStockItem(
                 storable=self,
-                branch=conn.get(branch),
-                connection=conn)
+                branch=store.fetch(branch),
+                store=store)
 
         # Unit cost must be updated here as
         # 1) we need the stock item which might not exist
@@ -660,21 +677,38 @@ class Storable(Domain):
             if sellable:
                 sellable.can_sell()
 
+        StockTransactionHistory(product_stock_item=stock_item,
+                                quantity=quantity,
+                                stock_cost=stock_item.stock_cost,
+                                responsible=get_current_user(self.store),
+                                type=type,
+                                object_id=object_id,
+                                store=self.store)
+
         ProductStockUpdateEvent.emit(self.product, branch, old_quantity,
                                      stock_item.quantity)
 
-    def decrease_stock(self, quantity, branch):
+    def decrease_stock(self, quantity, branch, type, object_id,
+                       cost_center=None):
         """When receiving a product, update the stock reference for the sold item
         this on a specific |branch|. Returns the stock item that was
         decreased.
 
         :param quantity: amount to decrease
         :param branch: a |branch|
+        :param type: the type of the stock increase. One of the
+            StockTransactionHistory.types
+        :param object_id: the id of the object responsible for the transaction
+        :param cost_center: the |costcenter| to which this stock decrease is
+            related, if any
         """
+        # FIXME: Put this back once 1.6 is released
+        #assert isinstance(type, int)
+
         if quantity <= 0:
-            raise ValueError(_("quantity must be a positive number"))
+            raise ValueError(_(u"quantity must be a positive number"))
         if branch is None:
-            raise ValueError("branch cannot be None")
+            raise ValueError(u"branch cannot be None")
 
         stock_item = self.get_stock_item(branch)
         if stock_item is None or quantity > stock_item.quantity:
@@ -687,45 +721,276 @@ class Storable(Domain):
         # We emptied the entire stock in all branches, we need to change
         # the status of the sellable to unavailable as we cannot sell
         # it anymore
-        if not ProductStockItem.selectBy(
-            storable=self,
-            connection=self.get_connection()).sum(ProductStockItem.q.quantity):
+        if not self.store.find(ProductStockItem,
+                    storable=self).sum(ProductStockItem.quantity):
             sellable = self.product.sellable
             if sellable:
                 sellable.set_unavailable()
 
+        stock_transaction = StockTransactionHistory(
+                                product_stock_item=stock_item,
+                                quantity=-quantity,
+                                stock_cost=stock_item.stock_cost,
+                                responsible=get_current_user(self.store),
+                                type=type,
+                                object_id=object_id,
+                                store=self.store)
+
+        if cost_center is not None:
+            cost_center.add_stock_transaction(stock_transaction)
+
         ProductStockUpdateEvent.emit(self.product, branch, old_quantity,
                                      stock_item.quantity)
+
         return stock_item
 
+    def register_initial_stock(self, quantity, branch):
+        """Register initial stock, by increasing the amount of this storable,
+        for the given |quantity| and |branch|
+
+        :param quantity: The inital stock quantity for this storable
+        :param branch: The branch where the given quantity is avaiable for this
+          storable
+        """
+        self.increase_stock(quantity, branch,
+                            StockTransactionHistory.TYPE_INITIAL,
+                            object_id=None)
+
     def get_balance_for_branch(self, branch):
         """Return the stock balance for the |product| in a |branch|.
 
         :param branch: the |branch| to get the stock balance for
         :returns: the amount of stock available in the |branch|
         """
-        conn = self.get_connection()
-        stock_items = ProductStockItem.selectBy(storable=self,
-                                                connection=conn,
-                                                branch=branch)
-        return stock_items.sum(ProductStockItem.q.quantity) or Decimal(0)
+        store = self.store
+        stock_items = store.find(ProductStockItem, storable=self,
+                                 branch=branch)
+        return stock_items.sum(ProductStockItem.quantity) or Decimal(0)
 
     def get_stock_items(self):
         """Fetches the stock items available for all |branches|.
 
         :returns: a sequence of stock items
         """
-        return ProductStockItem.selectBy(storable=self,
-                                         connection=self.get_connection())
+        return self.store.find(ProductStockItem, storable=self)
 
     def get_stock_item(self, branch):
         """Fetch a stock item for a specific |branch|
 
         :returns: a stock item
         """
-        return ProductStockItem.selectOneBy(branch=branch,
-                                            storable=self,
-                                            connection=self.get_connection())
+        store = self.store
+        return store.find(ProductStockItem, branch=branch, storable=self).one()
+
+
+class StockTransactionHistory(Domain):
+    """ This class stores information about all transactions made in the
+    stock
+
+    Everytime a |storable| has its stock increased or decreased, an object of
+    this class will be created, registering the quantity, cost, responsible and
+    reason for the transaction
+    """
+
+    __storm_table__ = 'stock_transaction_history'
+
+    #: the transaction is an initial stock adustment. Note that with this
+    #: transaction, there is no related object.
+    TYPE_INITIAL = 0
+
+    #: the transaction is a sale
+    TYPE_SELL = 1
+
+    #: the transaction is a return of a sale
+    TYPE_RETURNED_SALE = 2
+
+    #: the transaction is the cancellation of a sale
+    TYPE_CANCELED_SALE = 3
+
+    #: the transaction is the receival of a purchase
+    TYPE_RECEIVED_PURCHASE = 4
+
+    #: the transaction is the return of a loan
+    TYPE_RETURNED_LOAN = 5
+
+    #: the transaction is a loan
+    TYPE_LOANED = 6
+
+    #: the transaction is the allocation of a product to a production
+    TYPE_PRODUCTION_ALLOCATED = 7
+
+    #: the transaction is the production of a product
+    TYPE_PRODUCTION_PRODUCED = 8
+
+    #: the transaction is the return of an item from a production
+    TYPE_PRODUCTION_RETURNED = 9
+
+    #: the transaction is a stock decrease
+    TYPE_STOCK_DECREASE = 10
+
+    #: the transaction is a transfer from a branch
+    TYPE_TRANSFER_FROM = 11
+
+    #: the transaction is a transfer to a branch
+    TYPE_TRANSFER_TO = 12
+
+    #: the transaction is the adjustment of an inventory
+    TYPE_INVENTORY_ADJUST = 13
+
+    #: the transaction is the production of a product that didn't enter
+    #: stock right after its creation
+    TYPE_PRODUCTION_SENT = 14
+
+    #: this transaction was created automatically by an upgrade from a previous
+    #: version of Stoq, when this history didn't exist.
+    TYPE_IMPORTED = 15
+
+    #: the transaction is the return of a product to another company (ie, this
+    #: shop is giving the product back to the other company).
+    # FIXME: After 1.6 is released, create a patch to change the valid range and
+    # migrate the objects that have type=None
+    TYPE_CONSIGNMENT_RETURNED = None
+
+
+    types = {TYPE_INVENTORY_ADJUST: _(u'Adjustment for inventory %s'),
+             TYPE_RETURNED_LOAN: _(u'Returned from loan %s'),
+             TYPE_LOANED: _(u'Loaned for loan %s'),
+             TYPE_PRODUCTION_ALLOCATED: _(u'Allocated for production %s'),
+             TYPE_PRODUCTION_PRODUCED: _(u'Produced in production %s'),
+             TYPE_PRODUCTION_SENT: _(u'Produced in production %s'),
+             TYPE_PRODUCTION_RETURNED: _(u'Returned remaining from '
+                                         u'production %s'),
+             TYPE_RECEIVED_PURCHASE: _(u'Received for receiving order %s'),
+             TYPE_RETURNED_SALE: _(u'Returned sale %s'),
+             TYPE_CANCELED_SALE: _(u'Returned from canceled sale %s'),
+             TYPE_SELL: _(u'Sold in sale %s'),
+             TYPE_STOCK_DECREASE: _(u'Product removal for stock decrease %s'),
+             TYPE_TRANSFER_FROM: _(u'Transfered from branch in transfer '
+                                   u'order %s'),
+             TYPE_TRANSFER_TO: _(u'Transfered to this branch in transfer '
+                                 u'order %s'),
+             TYPE_INITIAL: _(u'Registred initial stock'),
+             TYPE_IMPORTED: _(u'Imported from previous version'),
+             TYPE_CONSIGNMENT_RETURNED: _(u'Consigned product returned.'),
+             }
+
+    #: the date and time the transaction was made
+    date = DateTimeCol(default_factory=datetime.datetime.now)
+
+    product_stock_item_id = IntCol()
+
+    #: the |productstockitem| used in the transaction
+    product_stock_item = Reference(product_stock_item_id, 'ProductStockItem.id')
+
+    #: the stock cost of the transaction on the time it was made
+    stock_cost = PriceCol()
+
+    #: The quantity that was removed or added to the stock.
+    #: Positive value if the value was increased, negative if decreased.
+    quantity = QuantityCol()
+
+    responsible_id = IntCol()
+
+    #: the |loginuser| responsible for the transaction
+    responsible = Reference(responsible_id, 'LoginUser.id')
+
+    #: the id of the object who altered the stock
+    object_id = IntCol()
+
+    #: the type of the transaction
+    type = IntCol()
+
+    @property
+    def total(self):
+        return currency(abs(self.stock_cost * self.quantity))
+
+    def get_object(self):
+        if self.type in [self.TYPE_INITIAL, self.TYPE_IMPORTED]:
+            return None
+        elif self.type in [self.TYPE_SELL, self.TYPE_CANCELED_SALE]:
+            from stoqlib.domain.sale import SaleItem
+            return self.store.get(SaleItem, self.object_id)
+        elif self.type == self.TYPE_RETURNED_SALE:
+            from stoqlib.domain.returnedsale import ReturnedSaleItem
+            return self.store.get(ReturnedSaleItem, self.object_id)
+        elif self.type == self.TYPE_PRODUCTION_PRODUCED:
+            from stoqlib.domain.production import ProductionItem
+            return self.store.get(ProductionItem, self.object_id)
+        elif self.type in [self.TYPE_PRODUCTION_ALLOCATED,
+                           self.TYPE_PRODUCTION_RETURNED]:
+            from stoqlib.domain.production import ProductionMaterial
+            return self.store.get(ProductionMaterial, self.object_id)
+        elif self.type == self.TYPE_RECEIVED_PURCHASE:
+            from stoqlib.domain.receiving import ReceivingOrderItem
+            return self.store.get(ReceivingOrderItem, self.object_id)
+        elif self.type in [self.TYPE_RETURNED_LOAN, self.TYPE_LOANED]:
+            from stoqlib.domain.loan import LoanItem
+            return self.store.get(LoanItem, self.object_id)
+        elif self.type == self.TYPE_STOCK_DECREASE:
+            from stoqlib.domain.stockdecrease import StockDecreaseItem
+            return self.store.get(StockDecreaseItem, self.object_id)
+        elif self.type in [self.TYPE_TRANSFER_FROM, self.TYPE_TRANSFER_TO]:
+            from stoqlib.domain.transfer import TransferOrderItem
+            return self.store.get(TransferOrderItem, self.object_id)
+        elif self.type == self.TYPE_INVENTORY_ADJUST:
+            from stoqlib.domain.inventory import InventoryItem
+            return self.store.get(InventoryItem, self.object_id)
+        elif self.type == self.TYPE_PRODUCTION_SENT:
+            from stoqlib.domain.production import ProductionProducedItem
+            return self.store.get(ProductionProducedItem, self.object_id)
+        elif self.type == self.TYPE_CONSIGNMENT_RETURNED:
+            from stoqlib.domain.purchase import PurchaseItem
+            return self.store.get(PurchaseItem, self.object_id)
+        else:
+            raise ValueError(_('%s has invalid type: %s.') % (self, self.type))
+
+    def get_object_parent(self):
+        obj = self.get_object()
+        if not obj:
+            return None
+
+        from stoqlib.domain.inventory import InventoryItem
+        from stoqlib.domain.loan import LoanItem
+        from stoqlib.domain.production import ProductionItem
+        from stoqlib.domain.production import ProductionMaterial
+        from stoqlib.domain.purchase import PurchaseItem
+        from stoqlib.domain.receiving import ReceivingOrderItem
+        from stoqlib.domain.returnedsale import ReturnedSaleItem
+        from stoqlib.domain.sale import SaleItem
+        from stoqlib.domain.stockdecrease import StockDecreaseItem
+        from stoqlib.domain.transfer import TransferOrderItem
+
+        if isinstance(obj, SaleItem):
+            return obj.sale
+        elif isinstance(obj, ReturnedSaleItem):
+            return obj.returned_sale
+        elif isinstance(obj, ProductionItem):
+            return obj.order
+        elif isinstance(obj, ProductionMaterial):
+            return obj.order
+        elif isinstance(obj, ReceivingOrderItem):
+            return obj.receiving_order
+        elif isinstance(obj, LoanItem):
+            return obj.loan
+        elif isinstance(obj, StockDecreaseItem):
+            return obj.stock_decrease
+        elif isinstance(obj, TransferOrderItem):
+            return obj.transfer_order
+        elif isinstance(obj, InventoryItem):
+            return obj.inventory
+        elif isinstance(obj, PurchaseItem):
+            return obj.inventory
+        else:
+            raise TypeError(_('Object %s has invalid type (%s)') %
+                            (obj, type(obj)))
+
+    def get_description(self):
+        """ Based on the type of the transaction, returns the string
+        description
+        """
+        if self.type in [self.TYPE_INITIAL, self.TYPE_IMPORTED]:
+            return self.types[self.type]
+        return self.types[self.type] % self.get_object_parent().identifier
 
 
 class ProductComponent(Domain):
@@ -734,9 +999,14 @@ class ProductComponent(Domain):
     See also:
     `schema <http://doc.stoq.com.br/schema/tables/product_component.html>`__
     """
+
+    __storm_table__ = 'product_component'
+
     quantity = QuantityCol(default=Decimal(1))
-    product = ForeignKey('Product')
-    component = ForeignKey('Product')
+    product_id = IntCol()
+    product = Reference(product_id, 'Product.id')
+    component_id = IntCol()
+    component = Reference(component_id, 'Product.id')
     design_reference = UnicodeCol(default=u'')
 
 
@@ -749,19 +1019,22 @@ class ProductQualityTest(Domain):
 
     implements(IDescribable)
 
+    __storm_table__ = 'product_quality_test'
+
     (TYPE_BOOLEAN,
      TYPE_DECIMAL) = range(2)
 
     types = {
-        TYPE_BOOLEAN: _('Boolean'),
-        TYPE_DECIMAL: _('Decimal'),
+        TYPE_BOOLEAN: _(u'Boolean'),
+        TYPE_DECIMAL: _(u'Decimal'),
     }
 
-    product = ForeignKey('Product')
+    product_id = IntCol()
+    product = Reference(product_id, 'Product.id')
     test_type = IntCol(default=TYPE_BOOLEAN)
-    description = UnicodeCol(default='')
-    notes = UnicodeCol(default='')
-    success_value = UnicodeCol(default='True')
+    description = UnicodeCol(default=u'')
+    notes = UnicodeCol(default=u'')
+    success_value = UnicodeCol(default=u'True')
 
     def get_description(self):
         return self.description
@@ -776,23 +1049,23 @@ class ProductQualityTest(Domain):
 
     def get_boolean_value(self):
         assert self.test_type == self.TYPE_BOOLEAN
-        if self.success_value == 'True':
+        if self.success_value == u'True':
             return True
-        elif self.success_value == 'False':
+        elif self.success_value == u'False':
             return False
         else:
             raise ValueError(self.success_value)
 
     def get_range_value(self):
         assert self.test_type == self.TYPE_DECIMAL
-        a, b = self.success_value.split(' - ')
+        a, b = self.success_value.split(u' - ')
         return Decimal(a), Decimal(b)
 
     def set_boolean_value(self, value):
-        self.success_value = str(value)
+        self.success_value = unicode(value)
 
     def set_range_value(self, min_value, max_value):
-        self.success_value = '%s - %s' % (min_value, max_value)
+        self.success_value = u'%s - %s' % (min_value, max_value)
 
     def result_value_passes(self, value):
         if self.test_type == self.TYPE_BOOLEAN:
@@ -803,7 +1076,6 @@ class ProductQualityTest(Domain):
 
     def can_remove(self):
         from stoqlib.domain.production import ProductionItemQualityResult
-        if ProductionItemQualityResult.selectBy(quality_test=self,
-                    connection=self.get_connection()).count():
+        if self.store.find(ProductionItemQualityResult, quality_test=self).count():
             return False
         return True
