@@ -26,14 +26,16 @@
 import datetime
 from decimal import Decimal
 
+from storm.expr import And, Join
+from storm.references import Reference, ReferenceSet
+from storm.store import AutoReload
 from zope.interface import implements
 
-from stoqlib.database.orm import AutoReload
-from stoqlib.database.orm import (UnicodeCol, ForeignKey, DateTimeCol, IntCol,
-                                  QuantityCol, BoolCol, MultipleJoin)
-from stoqlib.database.orm import AND, Join, Viewable
+from stoqlib.database.properties import (UnicodeCol, DateTimeCol, IntCol,
+                                  QuantityCol, BoolCol)
+from stoqlib.database.viewable import Viewable
 from stoqlib.domain.base import Domain
-from stoqlib.domain.product import ProductHistory
+from stoqlib.domain.product import ProductHistory, StockTransactionHistory
 from stoqlib.domain.interfaces import IContainer, IDescribable
 from stoqlib.lib.translation import stoqlib_gettext
 
@@ -59,6 +61,8 @@ class ProductionOrder(Domain):
     """
     implements(IContainer, IDescribable)
 
+    __storm_table__ = 'production_order'
+
     (ORDER_OPENED,
      ORDER_WAITING,
      ORDER_PRODUCING,
@@ -81,33 +85,33 @@ class ProductionOrder(Domain):
     expected_start_date = DateTimeCol(default=None)
     start_date = DateTimeCol(default=None)
     close_date = DateTimeCol(default=None)
-    description = UnicodeCol(default='')
-    responsible = ForeignKey('Employee', default=None)
-    branch = ForeignKey('Branch')
+    description = UnicodeCol(default=u'')
+    responsible_id = IntCol(default=None)
+    responsible = Reference(responsible_id, 'Employee.id')
+    branch_id = IntCol()
+    branch = Reference(branch_id, 'Branch.id')
 
-    produced_items = MultipleJoin('ProductionProducedItem',
-                                  joinColumn='order_id', orderBy='id')
+    produced_items = ReferenceSet('id', 'ProductionProducedItem.order_id')
 
     #
     # IContainer implmentation
     #
 
     def get_items(self):
-        return ProductionItem.selectBy(order=self,
-                                       connection=self.get_connection())
+        return self.store.find(ProductionItem, order=self)
 
     def add_item(self, sellable, quantity=Decimal(1)):
         return ProductionItem(order=self, product=sellable.product,
                               quantity=quantity,
-                              connection=self.get_connection())
+                              store=self.store)
 
     def remove_item(self, item):
         assert isinstance(item, ProductionItem)
         if item.order is not self:
-            raise ValueError(_('Argument item must have an order attribute '
-                               'associated with the current production '
-                               'order instance.'))
-        ProductionItem.delete(item.id, connection=self.get_connection())
+            raise ValueError(_(u'Argument item must have an order attribute '
+                               u'associated with the current production '
+                               u'order instance.'))
+        self.store.remove(item)
 
     #
     # Public API
@@ -118,24 +122,23 @@ class ProductionOrder(Domain):
 
         :returns: a sequence of :class:`ProductionService` instances.
         """
-        return ProductionService.selectBy(order=self,
-                                          connection=self.get_connection())
+        return self.store.find(ProductionService, order=self)
 
     def remove_service_item(self, item):
         assert isinstance(item, ProductionService)
         if item.order is not self:
-            raise ValueError(_('Argument item must have an order attribute '
-                               'associated with the current production '
-                               'order instance.'))
-        ProductionService.delete(item.id, connection=self.get_connection())
+            raise ValueError(_(u'Argument item must have an order attribute '
+                               u'associated with the current production '
+                               u'order instance.'))
+        self.store.remove(item)
 
     def get_material_items(self):
         """Returns all the material needed by this production.
 
         :returns: a sequence of :class:`ProductionMaterial` instances.
         """
-        return ProductionMaterial.selectBy(order=self,
-                                           connection=self.get_connection())
+        return self.store.find(ProductionMaterial, order=self,
+                                           )
 
     def start_production(self):
         """Start the production by allocating all the material needed.
@@ -169,7 +172,7 @@ class ProductionOrder(Domain):
         production to CLOSED.
         """
         assert (self.status == ProductionOrder.ORDER_PRODUCING or
-                self.status == ProductionOrder.ORDER_QA)
+                self.status == ProductionOrder.ORDER_QA), self.status
 
         is_produced = self.is_completely_produced()
         is_tested = self.is_completely_tested()
@@ -231,11 +234,15 @@ class ProductionItem(Domain):
     """
     implements(IDescribable)
 
+    __storm_table__ = 'production_item'
+
     quantity = QuantityCol(default=1)
     produced = QuantityCol(default=0)
     lost = QuantityCol(default=0)
-    order = ForeignKey('ProductionOrder')
-    product = ForeignKey('Product')
+    order_id = IntCol()
+    order = Reference(order_id, 'ProductionOrder.id')
+    product_id = IntCol()
+    product = Reference(product_id, 'Product.id')
 
     def get_description(self):
         return self.product.sellable.get_description()
@@ -245,9 +252,9 @@ class ProductionItem(Domain):
     #
 
     def _get_material_from_component(self, component):
-        return ProductionMaterial.selectOneBy(product=component.component,
-                                              order=self.order,
-                                              connection=self.get_connection())
+        store = self.store
+        return store.find(ProductionMaterial, product=component.component,
+                                              order=self.order).one()
 
     #
     # Public API
@@ -290,8 +297,8 @@ class ProductionItem(Domain):
             assert produced_by
             assert len(serials) == quantity
 
-        conn = self.get_connection()
-        conn.savepoint('before_produce')
+        store = self.store
+        store.savepoint(u'before_produce')
 
         for component in self.get_components():
             material = self._get_material_from_component(component)
@@ -300,12 +307,12 @@ class ProductionItem(Domain):
             try:
                 material.consume(needed_material)
             except ValueError:
-                conn.rollback_to_savepoint('before_produce')
+                store.rollback_to_savepoint(u'before_produce')
                 raise
 
         if self.product.has_quality_tests():
             for serial in serials:
-                ProductionProducedItem(connection=self.get_connection(),
+                ProductionProducedItem(store=self.store,
                                        order=self.order,
                                        product=self.product,
                                        produced_by=produced_by,
@@ -316,11 +323,12 @@ class ProductionItem(Domain):
             # There are no quality tests for this product. Increase stock
             # right now.
             storable = self.product.storable
-            storable.increase_stock(quantity, self.order.branch)
-
+            storable.increase_stock(quantity, self.order.branch,
+                        StockTransactionHistory.TYPE_PRODUCTION_PRODUCED,
+                        self.id)
         self.produced += quantity
         self.order.try_finalize_production()
-        ProductHistory.add_produced_item(conn, self.order.branch, self)
+        ProductHistory.add_produced_item(store, self.order.branch, self)
 
     def add_lost(self, quantity):
         """Adds a quantity that was lost. The maximum quantity that can be
@@ -330,22 +338,22 @@ class ProductionItem(Domain):
         """
         if self.lost + quantity > self.quantity - self.produced:
             raise ValueError(
-                _('Can not lost more items than the total production quantity.'))
+                _(u'Can not lost more items than the total production quantity.'))
 
-        conn = self.get_connection()
-        conn.savepoint('before_lose')
+        store = self.store
+        store.savepoint(u'before_lose')
 
         for component in self.get_components():
             material = self._get_material_from_component(component)
             try:
                 material.add_lost(quantity * component.quantity)
             except ValueError:
-                conn.rollback_to_savepoint('before_lose')
+                store.rollback_to_savepoint(u'before_lose')
                 raise
 
         self.lost += quantity
         self.order.try_finalize_production()
-        ProductHistory.add_lost_item(conn, self.order.branch, self)
+        ProductHistory.add_lost_item(store, self.order.branch, self)
 
 
 class ProductionMaterial(Domain):
@@ -361,8 +369,12 @@ class ProductionMaterial(Domain):
     """
     implements(IDescribable)
 
-    product = ForeignKey('Product')
-    order = ForeignKey('ProductionOrder')
+    __storm_table__ = 'production_material'
+
+    product_id = IntCol()
+    product = Reference(product_id, 'Product.id')
+    order_id = IntCol()
+    order = Reference(order_id, 'ProductionOrder.id')
     needed = QuantityCol(default=1)
     allocated = QuantityCol(default=0)
     consumed = QuantityCol(default=0)
@@ -410,11 +422,13 @@ class ProductionMaterial(Domain):
             else:
                 quantity = stock
         elif quantity > stock:
-            raise ValueError(_('Can not allocate this quantity.'))
+            raise ValueError(_(u'Can not allocate this quantity.'))
 
         if quantity > 0:
             self.allocated += quantity
-            storable.decrease_stock(quantity, self.order.branch)
+            storable.decrease_stock(quantity, self.order.branch,
+                        StockTransactionHistory.TYPE_PRODUCTION_ALLOCATED,
+                        self.id)
 
     # TESTME
     def return_remaining(self):
@@ -428,7 +442,9 @@ class ProductionMaterial(Domain):
         if not remaining:
             return
         storable = self.product.storable
-        storable.increase_stock(remaining, self.order.branch)
+        storable.increase_stock(remaining, self.order.branch,
+                    StockTransactionHistory.TYPE_PRODUCTION_RETURNED,
+                    self.id)
         self.allocated -= remaining
 
     def add_lost(self, quantity):
@@ -442,15 +458,15 @@ class ProductionMaterial(Domain):
         assert quantity > 0
 
         if self.lost + quantity > self.needed - self.consumed:
-            raise ValueError(_('Cannot loose this quantity.'))
+            raise ValueError(_(u'Cannot loose this quantity.'))
 
         required = self.consumed + self.lost + quantity
         if required > self.allocated:
             self.allocate(required - self.allocated)
 
         self.lost += quantity
-        conn = self.get_connection()
-        ProductHistory.add_lost_item(conn, self.order.branch, self)
+        store = self.store
+        ProductHistory.add_lost_item(store, self.order.branch, self)
 
     def consume(self, quantity):
         """Consumes a certain quantity of material. The maximum quantity
@@ -464,15 +480,15 @@ class ProductionMaterial(Domain):
 
         available = self.allocated - self.consumed - self.lost
         if quantity > available:
-            raise ValueError(_('Can not consume this quantity.'))
+            raise ValueError(_(u'Can not consume this quantity.'))
 
         required = self.consumed + self.lost + quantity
         if required > self.allocated:
             self.allocate(required - self.allocated)
 
         self.consumed += quantity
-        conn = self.get_connection()
-        ProductHistory.add_consumed_item(conn, self.order.branch, self)
+        store = self.store
+        ProductHistory.add_consumed_item(store, self.order.branch, self)
 
     #
     # IDescribable Implementation
@@ -501,8 +517,12 @@ class ProductionService(Domain):
     """
     implements(IDescribable)
 
-    service = ForeignKey('Service')
-    order = ForeignKey('ProductionOrder')
+    __storm_table__ = 'production_service'
+
+    service_id = IntCol()
+    service = Reference(service_id, 'Service.id')
+    order_id = IntCol()
+    order = Reference(order_id, 'ProductionOrder.id')
     quantity = QuantityCol(default=1)
 
     #
@@ -524,17 +544,21 @@ class ProductionProducedItem(Domain):
     process
     """
 
-    order = ForeignKey('ProductionOrder')
+    __storm_table__ = 'production_produced_item'
+
+    order_id = IntCol()
+    order = Reference(order_id, 'ProductionOrder.id')
     # ProductionItem already has a reference to Product, but we need it for
     # constraint checks UNIQUE(product_id, serial_number)
-    product = ForeignKey('Product')
-    produced_by = ForeignKey('LoginUser')
+    product_id = IntCol()
+    product = Reference(product_id, 'Product.id')
+    produced_by_id = IntCol()
+    produced_by = Reference(produced_by_id, 'LoginUser.id')
     produced_date = DateTimeCol()
     serial_number = IntCol()
     entered_stock = BoolCol(default=False)
     test_passed = BoolCol(default=False)
-    test_results = MultipleJoin('ProductionItemQualityResult',
-                                joinColumn='produced_item_id')
+    test_results = ReferenceSet('id', 'ProductionItemQualityResult.produced_item_id')
 
     def get_pending_tests(self):
         tests_done = set([t.quality_test for t in self.test_results])
@@ -542,17 +566,16 @@ class ProductionProducedItem(Domain):
         return list(all_tests.difference(tests_done))
 
     @classmethod
-    def get_last_serial_number(cls, product, conn):
-        return cls.selectBy(product=product,
-                    connection=conn).max('serial_number') or 0
+    def get_last_serial_number(cls, product, store):
+        return store.find(cls, product=product).max(cls.serial_number) or 0
 
     @classmethod
-    def is_valid_serial_range(cls, product, first, last, conn):
-        query = AND(cls.q.product_id == product.id,
-                    cls.q.serial_number >= first,
-                    cls.q.serial_number <= last)
+    def is_valid_serial_range(cls, product, first, last, store):
+        query = And(cls.product_id == product.id,
+                    cls.serial_number >= first,
+                    cls.serial_number <= last)
         # There should be no results for the range to be valid
-        return cls.select(query, connection=conn).count() == 0
+        return store.find(cls, query).is_empty()
 
     def send_to_stock(self):
         # Already is in stock
@@ -560,21 +583,23 @@ class ProductionProducedItem(Domain):
             return
 
         storable = self.product.storable
-        storable.increase_stock(1, self.order.branch)
+        storable.increase_stock(1, self.order.branch,
+                    StockTransactionHistory.TYPE_PRODUCTION_SENT,
+                    self.id)
         self.entered_stock = True
 
     def set_test_result_value(self, quality_test, value, tester):
-        result = ProductionItemQualityResult.selectOneBy(
-                            connection=self.get_connection(),
+        store = self.store
+        result = store.find(ProductionItemQualityResult,
                             quality_test=quality_test,
-                            produced_item=self)
+                            produced_item=self).one()
         if not result:
             result = ProductionItemQualityResult(
-                                connection=self.get_connection(),
+                                store=self.store,
                                 quality_test=quality_test,
                                 produced_item=self,
                                 tested_by=tester,
-                                result_value='')
+                                result_value=u'')
         else:
             result.tested_by = tester
 
@@ -583,10 +608,10 @@ class ProductionProducedItem(Domain):
         return result
 
     def get_test_result(self, quality_test):
-        return ProductionItemQualityResult.selectOneBy(
-                            connection=self.get_connection(),
-                            quality_test=quality_test,
-                            produced_item=self)
+        store = self.store
+        return store.find(ProductionItemQualityResult,
+                          quality_test=quality_test,
+                          produced_item=self).one()
 
     def check_tests(self):
         """Checks if all tests for this produced items passes.
@@ -608,9 +633,14 @@ class ProductionItemQualityResult(Domain):
 
     implements(IDescribable)
 
-    produced_item = ForeignKey('ProductionProducedItem')
-    quality_test = ForeignKey('ProductQualityTest')
-    tested_by = ForeignKey('LoginUser')
+    __storm_table__ = 'production_item_quality_result'
+
+    produced_item_id = IntCol()
+    produced_item = Reference(produced_item_id, 'ProductionProducedItem.id')
+    quality_test_id = IntCol()
+    quality_test = Reference(quality_test_id, 'ProductQualityTest.id')
+    tested_by_id = IntCol()
+    tested_by = Reference(tested_by_id, 'LoginUser.id')
     tested_date = DateTimeCol(default=None)
     result_value = UnicodeCol()
     test_passed = BoolCol(default=False)
@@ -623,9 +653,9 @@ class ProductionItemQualityResult(Domain):
         return _(self.result_value)
 
     def get_boolean_value(self):
-        if self.result_value == 'True':
+        if self.result_value == u'True':
             return True
-        elif self.result_value == 'False':
+        elif self.result_value == u'False':
             return False
         else:
             raise ValueError
@@ -641,28 +671,27 @@ class ProductionItemQualityResult(Domain):
 
     def set_boolean_value(self, value):
         self.test_passed = self.quality_test.result_value_passes(value)
-        self.result_value = str(value)
+        self.result_value = unicode(value)
         self.produced_item.check_tests()
 
     def set_decimal_value(self, value):
         self.test_passed = self.quality_test.result_value_passes(value)
-        self.result_value = '%s' % (value, )
+        self.result_value = u'%s' % (value, )
         self.produced_item.check_tests()
 
 
 class ProductionOrderProducingView(Viewable):
-    columns = dict(
-        id=ProductionOrder.q.id,
-        )
 
-    joins = [
-        Join(ProductionItem,
-               ProductionOrder.q.id == ProductionItem.q.order_id),
+    id = ProductionOrder.id
+
+    tables = [
+        ProductionOrder,
+        Join(ProductionItem, ProductionOrder.id == ProductionItem.order_id),
         ]
 
-    clause = (ProductionOrder.q.status == ProductionOrder.ORDER_PRODUCING)
+    clause = (ProductionOrder.status == ProductionOrder.ORDER_PRODUCING)
 
     @classmethod
     def is_product_being_produced(cls, product):
-        query = ProductionItem.q.product_id == product.id
-        return cls.select(query, connection=product.get_connection()).count() > 0
+        query = ProductionItem.product_id == product.id
+        return not product.store.find(cls, query).is_empty()
