@@ -25,9 +25,9 @@
 """ User profile management for applications"""
 
 from kiwi.component import get_utility
+from storm.references import Reference, ReferenceSet
 
-from stoqlib.database.orm import (UnicodeCol, ForeignKey,
-                                  MultipleJoin, BoolCol)
+from stoqlib.database.properties import UnicodeCol, IntCol, BoolCol
 from stoqlib.domain.base import Domain
 from stoqlib.lib.interfaces import IApplicationDescriptions
 from stoqlib.lib.translation import stoqlib_gettext as _
@@ -38,80 +38,82 @@ class ProfileSettings(Domain):
     class stores information about the access availability in a certain
     application."""
 
+    __storm_table__ = 'profile_settings'
     app_dir_name = UnicodeCol()
     has_permission = BoolCol(default=False)
-    user_profile = ForeignKey('UserProfile')
+    user_profile_id = IntCol()
+    user_profile = Reference(user_profile_id, 'UserProfile.id')
 
     @classmethod
-    def set_permission(cls, conn, profile, app, permission):
+    def set_permission(cls, store, profile, app, permission):
         """
         Set the permission for a user profile to use a application
-        :param conn: a database connection
+        :param store: a store
         :param profile: a UserProfile
         :param app: name of the application
         :param permission: a boolean of the permission
         """
-        setting = cls.selectOneBy(user_profile=profile,
-                                  app_dir_name=app,
-                                  connection=conn)
+        setting = store.find(cls, user_profile=profile,
+                             app_dir_name=app).one()
         setting.has_permission = permission
 
 
 class UserProfile(Domain):
     """User profile definition."""
 
+    __storm_table__ = 'user_profile'
     name = UnicodeCol()
-    profile_settings = MultipleJoin('ProfileSettings', 'user_profile_id')
+    profile_settings = ReferenceSet('id', 'ProfileSettings.user_profile_id')
 
     @classmethod
-    def create_profile_template(cls, conn, name,
+    def create_profile_template(cls, store, name,
                                 has_full_permission=False):
-        profile = cls(connection=conn, name=name)
+        profile = cls(store=store, name=name)
         descr = get_utility(IApplicationDescriptions)
         for app_dir in descr.get_application_names():
-            ProfileSettings(connection=conn,
+            ProfileSettings(store=store,
                             has_permission=has_full_permission,
                             app_dir_name=app_dir, user_profile=profile)
         return profile
 
     @classmethod
-    def get_default(cls, conn):
+    def get_default(cls, store):
         # FIXME: We need a way to set the default profile in the interface,
         # instead of relying on the name (the user may change it)
-        profile = cls.selectOneBy(name=_('Salesperson'), connection=conn)
+        profile = store.find(cls, name=_(u'Salesperson')).one()
         # regression: check if it was not created in english.
         if not profile:
-            profile = cls.selectOneBy(name='Salesperson', connection=conn)
+            profile = store.find(cls, name=u'Salesperson').one()
 
         # Just return any other profile, so that the user is created with
         # one.
         if not profile:
-            profile = cls.select(connection=conn)[0]
+            profile = store.find(cls).first()
         return profile
 
     def add_application_reference(self, app_name, has_permission=False):
-        conn = self.get_connection()
-        ProfileSettings(connection=conn, app_dir_name=app_name,
+        store = self.store
+        ProfileSettings(store=store, app_dir_name=app_name,
                         has_permission=has_permission, user_profile=self)
 
     def check_app_permission(self, app_name):
         """Check if the user has permission to use an application
         :param app_name: name of application to check
         """
-        return bool(ProfileSettings.selectOneBy(
+        store = self.store
+        return bool(store.find(ProfileSettings,
             user_profile=self,
             app_dir_name=app_name,
-            has_permission=True,
-            connection=self.get_connection()))
+            has_permission=True).one())
 
 
-def update_profile_applications(conn, profile=None):
+def update_profile_applications(store, profile=None):
     """This method checks for all available applications and perform a
     comparision with the application names stored in user profiles. If a
     certain application is not there it is added.
     """
     app_list = get_utility(IApplicationDescriptions).get_application_names()
-    profiles = profile and [profile] or UserProfile.select(connection=conn)
+    profiles = profile and [profile] or store.find(UserProfile)
     for app_name in app_list:
         for profile in profiles:
             settings = profile.profile_settings
