@@ -28,14 +28,18 @@ import datetime
 
 from kiwi.argcheck import argcheck
 from kiwi.currency import currency
+from kiwi.python import Settable
+from storm.expr import And, Count, Join, LeftJoin, Sum, Select, Alias
+from storm.info import ClassAlias
+from storm.references import Reference
+from storm.store import AutoReload
 from zope.interface import implements
 
-from stoqlib.database.orm import AutoReload
-from stoqlib.database.orm import ForeignKey, IntCol, DateTimeCol, UnicodeCol
-from stoqlib.database.orm import AND, Join, LeftJoin, const
-from stoqlib.database.orm import Viewable, Alias, Field
-from stoqlib.database.orm import PriceCol, BoolCol, QuantityCol
+from stoqlib.database.expr import Date, Field, TransactionTimestamp
+from stoqlib.database.properties import IntCol, DateTimeCol, UnicodeCol
+from stoqlib.database.properties import PriceCol, BoolCol, QuantityCol
 from stoqlib.database.runtime import get_current_user
+from stoqlib.database.viewable import Viewable
 from stoqlib.domain.base import Domain
 from stoqlib.domain.event import Event
 from stoqlib.domain.payment.method import PaymentMethod
@@ -59,6 +63,9 @@ _ = stoqlib_gettext
 class PurchaseItem(Domain):
     """This class stores information of the purchased items.
     """
+
+    __storm_table__ = 'purchase_item'
+
     quantity = QuantityCol(default=1)
     quantity_received = QuantityCol(default=0)
     quantity_sold = QuantityCol(default=0)
@@ -71,13 +78,17 @@ class PurchaseItem(Domain):
     cost = PriceCol()
     expected_receival_date = DateTimeCol(default=None)
 
+    sellable_id = IntCol()
+
     #: the |sellable|
-    sellable = ForeignKey('Sellable')
+    sellable = Reference(sellable_id, 'Sellable.id')
+
+    order_id = IntCol()
 
     #: the |purchase|
-    order = ForeignKey('PurchaseOrder')
+    order = Reference(order_id, 'PurchaseOrder.id')
 
-    def _create(self, id, **kw):
+    def __init__(self, store=None, **kw):
         if not 'sellable' in kw:
             raise TypeError('You must provide a sellable argument')
         if not 'order' in kw:
@@ -89,7 +100,7 @@ class PurchaseItem(Domain):
         if not 'cost' in kw:
             kw['cost'] = kw['sellable'].cost
 
-        Domain._create(self, id, **kw)
+        Domain.__init__(self, store=store, **kw)
 
     #
     # Accessors
@@ -117,28 +128,28 @@ class PurchaseItem(Domain):
 
     def get_quantity_as_string(self):
         unit = self.sellable.unit
-        return "%s %s" % (format_quantity(self.quantity),
+        return u"%s %s" % (format_quantity(self.quantity),
                           unit and unit.description or u"")
 
     def get_quantity_received_as_string(self):
         unit = self.sellable.unit
-        return "%s %s" % (format_quantity(self.quantity_received),
+        return u"%s %s" % (format_quantity(self.quantity_received),
                           unit and unit.description or u"")
 
     @classmethod
-    def get_ordered_quantity(cls, conn, sellable):
+    def get_ordered_quantity(cls, store, sellable):
         """Returns the quantity already ordered of a given sellable.
 
-        :param conn: a database connection
+        :param store: a store
         :param sellable: the sellable we want to know the quantity ordered.
         :returns: the quantity already ordered of a given sellable or zero if
           no quantity have been ordered.
         """
-        query = AND(PurchaseItem.q.sellable_id == sellable.id,
-                    PurchaseOrder.q.id == PurchaseItem.q.order_id,
-                    PurchaseOrder.q.status == PurchaseOrder.ORDER_CONFIRMED)
-        ordered_items = PurchaseItem.select(query, connection=conn)
-        return ordered_items.sum('quantity') or Decimal(0)
+        query = And(PurchaseItem.sellable_id == sellable.id,
+                    PurchaseOrder.id == PurchaseItem.order_id,
+                    PurchaseOrder.status == PurchaseOrder.ORDER_CONFIRMED)
+        ordered_items = store.find(PurchaseItem, query)
+        return ordered_items.sum(PurchaseItem.quantity) or Decimal(0)
 
 
 class PurchaseOrder(Domain, Adaptable):
@@ -146,6 +157,8 @@ class PurchaseOrder(Domain, Adaptable):
 
     implements(IContainer)
 
+    __storm_table__ = 'purchase_order'
+
     (ORDER_CANCELLED,
      ORDER_QUOTING,
      ORDER_PENDING,
@@ -178,42 +191,50 @@ class PurchaseOrder(Domain, Adaptable):
     expected_pay_date = DateTimeCol(default_factory=datetime.datetime.now)
     receival_date = DateTimeCol(default=None)
     confirm_date = DateTimeCol(default=None)
-    notes = UnicodeCol(default='')
-    salesperson_name = UnicodeCol(default='')
+    notes = UnicodeCol(default=u'')
+    salesperson_name = UnicodeCol(default=u'')
     freight_type = IntCol(default=FREIGHT_FOB)
     expected_freight = PriceCol(default=0)
     surcharge_value = PriceCol(default=0)
     discount_value = PriceCol(default=0)
     consigned = BoolCol(default=False)
-    supplier = ForeignKey('Supplier')
-    branch = ForeignKey('Branch')
-    transporter = ForeignKey('Transporter', default=None)
-    responsible = ForeignKey('LoginUser')
-    group = ForeignKey('PaymentGroup')
+    supplier_id = IntCol()
+    supplier = Reference(supplier_id, 'Supplier.id')
+    branch_id = IntCol()
+    branch = Reference(branch_id, 'Branch.id')
+    transporter_id = IntCol(default=None)
+    transporter = Reference(transporter_id, 'Transporter.id')
+    responsible_id = IntCol()
+    responsible = Reference(responsible_id, 'LoginUser.id')
+    group_id = IntCol()
+    group = Reference(group_id, 'PaymentGroup.id')
 
-    def _init(self, *args, **kwargs):
+    def __init__(self, **kwargs):
+        super(PurchaseOrder, self).__init__(**kwargs)
+        self.addFacet(IPaymentTransaction)
+
+    def __storm_loaded__(self):
+        super(PurchaseOrder, self).__storm_loaded__()
         self.addFacet(IPaymentTransaction)
-        Domain._init(self, *args, **kwargs)
 
     #
     # IContainer Implementation
     #
 
     def get_items(self):
-        return PurchaseItem.selectBy(order=self,
-                                     connection=self.get_connection())
+        return self.store.find(PurchaseItem, order=self)
 
     @argcheck(PurchaseItem)
     def remove_item(self, item):
-        conn = self.get_connection()
+        store = self.store
         if item.order is not self:
-            raise ValueError(_('Argument item must have an order attribute '
+            raise ValueError(_(u'Argument item must have an order attribute '
                                'associated with the current purchase instance'))
-        PurchaseItem.delete(item.id, connection=conn)
+        PurchaseItem.delete(item.id, store=store)
 
     def add_item(self, sellable, quantity=Decimal(1)):
-        conn = self.get_connection()
-        return PurchaseItem(connection=conn, order=self,
+        store = self.store
+        return PurchaseItem(store=store, order=self,
                             sellable=sellable, quantity=quantity)
 
     #
@@ -232,8 +253,8 @@ class PurchaseOrder(Domain, Adaptable):
         if not discount_value:
             return currency(0)
         subtotal = self.get_purchase_subtotal()
-        assert subtotal > 0, ('the subtotal should not be zero '
-                              'at this point')
+        assert subtotal > 0, (u'the subtotal should not be zero '
+                              u'at this point')
         total = subtotal - discount_value
         percentage = (1 - total / subtotal) * 100
         return quantize(percentage)
@@ -253,8 +274,8 @@ class PurchaseOrder(Domain, Adaptable):
         if not surcharge_value:
             return currency(0)
         subtotal = self.get_purchase_subtotal()
-        assert subtotal > 0, ('the subtotal should not be zero '
-                              'at this point')
+        assert subtotal > 0, (u'the subtotal should not be zero '
+                              u'at this point')
         total = subtotal + surcharge_value
         percentage = ((total / subtotal) - 1) * 100
         return quantize(percentage)
@@ -333,13 +354,13 @@ class PurchaseOrder(Domain, Adaptable):
         :param confirm_data: optional, datetime
         """
         if confirm_date is None:
-            confirm_date = const.NOW()
+            confirm_date = TransactionTimestamp()
 
         if self.status not in [PurchaseOrder.ORDER_PENDING,
                                PurchaseOrder.ORDER_CONSIGNED]:
             raise ValueError(
-                _('Invalid order status, it should be '
-                  'ORDER_PENDING or ORDER_CONSIGNED, got %s') % (
+                _(u'Invalid order status, it should be '
+                  u'ORDER_PENDING or ORDER_CONSIGNED, got %s') % (
                 self.get_status_str(), ))
 
         transaction = IPaymentTransaction(self)
@@ -348,13 +369,13 @@ class PurchaseOrder(Domain, Adaptable):
         if self.supplier:
             self.group.recipient = self.supplier.person
 
-        self.responsible = get_current_user(self.get_connection())
+        self.responsible = get_current_user(self.store)
         self.status = PurchaseOrder.ORDER_CONFIRMED
         self.confirm_date = confirm_date
 
         Event.log(Event.TYPE_ORDER,
-                _("Order %d, total value %2.2f, supplier '%s' "
-                  "is now confirmed") % (
+                _(u"Order %d, total value %2.2f, supplier '%s' "
+                  u"is now confirmed") % (
                     self.order_number,
                     self.get_purchase_total(),
                     self.supplier.person.name))
@@ -362,23 +383,23 @@ class PurchaseOrder(Domain, Adaptable):
     def set_consigned(self):
         if self.status != PurchaseOrder.ORDER_PENDING:
             raise ValueError(
-                _('Invalid order status, it should be '
-                  'ORDER_PENDING, got %s') % (self.get_status_str(), ))
+                _(u'Invalid order status, it should be '
+                  u'ORDER_PENDING, got %s') % (self.get_status_str(), ))
 
-        self.responsible = get_current_user(self.get_connection())
+        self.responsible = get_current_user(self.store)
         self.status = PurchaseOrder.ORDER_CONSIGNED
 
     def close(self):
         """Closes the purchase order
         """
         if self.status != PurchaseOrder.ORDER_CONFIRMED:
-            raise ValueError(_('Invalid status, it should be confirmed '
-                               'got %s instead') % self.get_status_str())
+            raise ValueError(_(u'Invalid status, it should be confirmed '
+                               u'got %s instead') % self.get_status_str())
         self.status = self.ORDER_CLOSED
 
         Event.log(Event.TYPE_ORDER,
-                _("Order %d, total value %2.2f, supplier '%s' "
-                  "is now closed") % (
+                _(u"Order %d, total value %2.2f, supplier '%s' "
+                  u"is now closed") % (
                     self.order_number,
                     self.get_purchase_total(),
                     self.supplier.person.name))
@@ -396,13 +417,13 @@ class PurchaseOrder(Domain, Adaptable):
 
     def receive_item(self, item, quantity_to_receive):
         if not item in self.get_pending_items():
-            raise StoqlibError(_('This item is not pending, hence '
-                                 'cannot be received'))
+            raise StoqlibError(_(u'This item is not pending, hence '
+                                 u'cannot be received'))
         quantity = item.quantity - item.quantity_received
         if quantity < quantity_to_receive:
-            raise StoqlibError(_('The quantity that you want to receive '
-                                 'is greater than the total quantity of '
-                                 'this item %r') % item)
+            raise StoqlibError(_(u'The quantity that you want to receive '
+                                 u'is greater than the total quantity of '
+                                 u'this item %r') % item)
         self.increase_quantity_received(item, quantity_to_receive)
 
     def increase_quantity_received(self, purchase_item, quantity_received):
@@ -411,8 +432,8 @@ class PurchaseOrder(Domain, Adaptable):
                     if item.sellable.id == sellable.id]
         qty = len(items)
         if not qty:
-            raise ValueError(_('There is no purchase item for '
-                               'sellable %r') % sellable)
+            raise ValueError(_(u'There is no purchase item for '
+                               u'sellable %r') % sellable)
 
         purchase_item.quantity_received += quantity_received
 
@@ -421,7 +442,7 @@ class PurchaseOrder(Domain, Adaptable):
 
     def get_freight_type_name(self):
         if not self.freight_type in self.freight_types.keys():
-            raise DatabaseInconsistency(_('Invalid freight_type, got %d')
+            raise DatabaseInconsistency(_(u'Invalid freight_type, got %d')
                                           % self.freight_type)
         return self.freight_types[self.freight_type]
 
@@ -448,13 +469,13 @@ class PurchaseOrder(Domain, Adaptable):
         The sum of all the items cost * items quantity
         """
         return currency(self.get_items().sum(
-            PurchaseItem.q.cost * PurchaseItem.q.quantity) or 0)
+            PurchaseItem.cost * PurchaseItem.quantity) or 0)
 
     def get_purchase_total(self):
         subtotal = self.get_purchase_subtotal()
         total = subtotal - self.discount_value + self.surcharge_value
         if total < 0:
-            raise ValueError(_('Purchase total can not be lesser than zero'))
+            raise ValueError(_(u'Purchase total can not be lesser than zero'))
         #XXX: Since the purchase_total value must have two digits
         # (at the moment) we need to format the value to a 2-digit number and
         # then convert it to currency data type, because the subtotal value
@@ -467,8 +488,8 @@ class PurchaseOrder(Domain, Adaptable):
         received items
         """
         return currency(self.get_items().sum(
-            PurchaseItem.q.cost *
-            PurchaseItem.q.quantity_received) or 0)
+            PurchaseItem.cost *
+            PurchaseItem.quantity_received) or 0)
 
     def get_remaining_total(self):
         """The total value to be paid for the items not received yet
@@ -479,28 +500,39 @@ class PurchaseOrder(Domain, Adaptable):
         """
         Returns a sequence of all items which we haven't received yet.
         """
-        return self.get_items().filter(
-            PurchaseItem.q.quantity_received < PurchaseItem.q.quantity)
+        return self.get_items().find(
+            PurchaseItem.quantity_received < PurchaseItem.quantity)
 
     def get_partially_received_items(self):
         """
         Returns a sequence of all items which are partially received.
         """
-        return self.get_items().filter(
-            PurchaseItem.q.quantity_received > 0)
+        return self.get_items().find(
+            PurchaseItem.quantity_received > 0)
 
     def get_open_date_as_string(self):
-        return self.open_date and self.open_date.strftime("%x") or ""
+        return self.open_date and self.open_date.strftime("%x") or u""
 
     def get_quote_deadline_as_string(self):
-        return self.quote_deadline and self.quote_deadline.strftime("%x") or ""
+        return self.quote_deadline and self.quote_deadline.strftime("%x") or u""
 
     def get_receiving_orders(self):
         """Returns all ReceivingOrder related to this purchase order
         """
         from stoqlib.domain.receiving import ReceivingOrder
-        return ReceivingOrder.selectBy(purchase=self,
-                                       connection=self.get_connection())
+        return self.store.find(ReceivingOrder, purchase=self)
+
+    def get_data_for_labels(self):
+        """ This function returns some necessary data to print the purchase's
+        items labels
+        """
+        for purchase_item in self.get_items():
+            sellable = purchase_item.sellable
+            label_data = Settable(barcode=sellable.barcode, code=sellable.code,
+                                  description=sellable.description,
+                                  price=sellable.price,
+                                  quantity=purchase_item.quantity)
+            yield label_data
 
     #
     # Classmethods
@@ -509,26 +541,31 @@ class PurchaseOrder(Domain, Adaptable):
     @classmethod
     def translate_status(cls, status):
         if not status in cls.statuses:
-            raise DatabaseInconsistency(_('Got an unexpected status value: '
-                                          '%s') % status)
+            raise DatabaseInconsistency(_(u'Got an unexpected status value: '
+                                          u'%s') % status)
         return cls.statuses[status]
 
 
 class Quotation(Domain):
+    __storm_table__ = 'quotation'
+
     #: A numeric identifier for this object. This value should be used instead of
     #: :obj:`.id` when displaying a numerical representation of this object to
     #: the user, in dialogs, lists, reports and such.
     identifier = IntCol(default=AutoReload)
 
-    group = ForeignKey('QuoteGroup')
-    purchase = ForeignKey('PurchaseOrder')
-    branch = ForeignKey('Branch')
+    group_id = IntCol()
+    group = Reference(group_id, 'QuoteGroup.id')
+    purchase_id = IntCol()
+    purchase = Reference(purchase_id, 'PurchaseOrder.id')
+    branch_id = IntCol()
+    branch = Reference(branch_id, 'Branch.id')
 
     implements(IDescribable)
 
     def get_description(self):
         supplier = self.purchase.supplier.person.name
-        return "Group %04d - %s" % (self.group.identifier, supplier)
+        return u"Group %04d - %s" % (self.group.identifier, supplier)
 
     #
     # Public API
@@ -553,45 +590,48 @@ class QuoteGroup(Domain):
 
     implements(IContainer, IDescribable)
 
+    __storm_table__ = 'quote_group'
+
     #: A numeric identifier for this object. This value should be used instead of
     #: :obj:`.id` when displaying a numerical representation of this object to
     #: the user, in dialogs, lists, reports and such.
     identifier = IntCol(default=AutoReload)
 
-    branch = ForeignKey('Branch')
+    branch_id = IntCol()
+    branch = Reference(branch_id, 'Branch.id')
 
     #
     # IContainer
     #
 
     def get_items(self):
-        return Quotation.selectBy(group=self, connection=self.get_connection())
+        return self.store.find(Quotation, group=self)
 
     @argcheck(Quotation)
     def remove_item(self, item):
-        conn = self.get_connection()
+        store = self.store
         if item.group is not self:
-            raise ValueError(_('You can not remove an item which does not '
-                               'belong to this group.'))
+            raise ValueError(_(u'You can not remove an item which does not '
+                               u'belong to this group.'))
 
         order = item.purchase
-        Quotation.delete(item.id, connection=conn)
+        Quotation.delete(item.id, store=store)
         for order_item in order.get_items():
             order.remove_item(order_item)
-        PurchaseOrder.delete(order.id, connection=conn)
+        PurchaseOrder.delete(order.id, store=store)
 
     @argcheck(PurchaseOrder)
     def add_item(self, item):
-        conn = self.get_connection()
+        store = self.store
         return Quotation(purchase=item, group=self, branch=self.branch,
-                         connection=conn)
+                         store=store)
 
     #
     # IDescribable
     #
 
     def get_description(self):
-        return _(u"quote number %04d" % self.identifier)
+        return _(u"quote number %04d") % self.identifier
 
     #
     # Public API
@@ -599,10 +639,10 @@ class QuoteGroup(Domain):
 
     def cancel(self):
         """Cancel a quote group."""
-        conn = self.get_connection()
+        store = self.store
         for quote in self.get_items():
             quote.close()
-            Quotation.delete(quote.id, connection=conn)
+            Quotation.delete(quote.id, store=store)
 
 
 class PurchaseOrderAdaptToPaymentTransaction(object):
@@ -634,6 +674,9 @@ class PurchaseOrderAdaptToPaymentTransaction(object):
     def return_(self, renegotiation):
         pass
 
+    def create_commission(self, payment):
+        pass
+
     #
     # Private API
     #
@@ -645,11 +688,11 @@ class PurchaseOrderAdaptToPaymentTransaction(object):
         if not paid_value:
             return
 
-        money = PaymentMethod.get_by_name(self.purchase.get_connection(), 'money')
+        money = PaymentMethod.get_by_name(self.purchase.store, u'money')
         payment = money.create_inpayment(
             self.purchase.group, self.purchase.branch, paid_value,
-            description=_('%s Money Returned for Purchase %d') % (
-            '1/1', self.purchase.identifier))
+            description=_(u'%s Money Returned for Purchase %d') % (
+            u'1/1', self.purchase.identifier))
         payment.set_pending()
         payment.pay()
 
@@ -673,69 +716,62 @@ class PurchaseItemView(Viewable):
     :param description: description of the sellable
     :param unit: unit as a string or None if the product has no unit
     """
-    columns = dict(
-        id=PurchaseItem.q.id,
-        purchase_id=PurchaseOrder.q.id,
-        sellable=Sellable.q.id,
-        code=Sellable.q.code,
-        cost=PurchaseItem.q.cost,
-        quantity=PurchaseItem.q.quantity,
-        quantity_received=PurchaseItem.q.quantity_received,
-        quantity_sold=PurchaseItem.q.quantity_sold,
-        quantity_returned=PurchaseItem.q.quantity_returned,
-        total=PurchaseItem.q.cost * PurchaseItem.q.quantity,
-        total_received=PurchaseItem.q.cost * PurchaseItem.q.quantity_received,
-        total_sold=PurchaseItem.q.cost * PurchaseItem.q.quantity_sold,
-        description=Sellable.q.description,
-        unit=SellableUnit.q.description,
-        )
 
-    joins = [
-        Join(PurchaseOrder,
-                    PurchaseOrder.q.id == PurchaseItem.q.order_id),
-        Join(Sellable,
-                    Sellable.q.id == PurchaseItem.q.sellable_id),
-        LeftJoin(SellableUnit,
-                   SellableUnit.q.id == Sellable.q.unit_id),
+    purchase_item = PurchaseItem
+
+    id = PurchaseItem.id
+    cost = PurchaseItem.cost
+    quantity = PurchaseItem.quantity
+    quantity_received = PurchaseItem.quantity_received
+    quantity_sold = PurchaseItem.quantity_sold
+    quantity_returned = PurchaseItem.quantity_returned
+    total = PurchaseItem.cost * PurchaseItem.quantity
+    total_received = PurchaseItem.cost * PurchaseItem.quantity_received
+    total_sold = PurchaseItem.cost * PurchaseItem.quantity_sold
+
+    purchase_id = PurchaseOrder.id
+    sellable = Sellable.id
+    code = Sellable.code
+    description = Sellable.description
+    unit = SellableUnit.description
+
+    tables = [
+        PurchaseItem,
+        Join(PurchaseOrder, PurchaseOrder.id == PurchaseItem.order_id),
+        Join(Sellable, Sellable.id == PurchaseItem.sellable_id),
+        LeftJoin(SellableUnit, SellableUnit.id == Sellable.unit_id),
         ]
 
     def get_quantity_as_string(self):
-        return "%s %s" % (format_quantity(self.quantity),
+        return u"%s %s" % (format_quantity(self.quantity),
                           self.unit or u"")
 
     def get_quantity_received_as_string(self):
-        return "%s %s" % (format_quantity(self.quantity_received),
+        return u"%s %s" % (format_quantity(self.quantity_received),
                           self.unit or u"")
 
     @classmethod
-    def select_by_purchase(cls, purchase, connection):
-        return PurchaseItemView.select(PurchaseOrder.q.id == purchase.id,
-                                       connection=connection).orderBy(PurchaseItem.q.id)
-
-    @property
-    def purchase_item(self):
-        return PurchaseItem.get(self.id, self.get_connection())
+    def find_by_purchase(cls, store, purchase):
+        return store.find(cls, purchase_id=purchase.id).order_by(PurchaseItem.id)
 
 
 #
 # Views
 #
 
-class _PurchaseItemSummary(Viewable):
-    """Summary for Purchased items
-
-    Its faster to do the SUM() bellow in a subselect, since aggregate
-    functions require group by for every other column, and grouping all the
-    columns in PurchaseOrderView is extremelly slow, as it requires sorting all
-    those columns
-    """
-
-    columns = dict(
-        id=PurchaseItem.q.order_id,
-        ordered_quantity=const.SUM(PurchaseItem.q.quantity),
-        received_quantity=const.SUM(PurchaseItem.q.quantity_received),
-        subtotal=const.SUM(PurchaseItem.q.cost * PurchaseItem.q.quantity),
-    )
+# Summary for Purchased items
+# Its faster to do the SUM() bellow in a subselect, since aggregate
+# functions require group by for every other column, and grouping all the
+# columns in PurchaseOrderView is extremelly slow, as it requires sorting all
+# those columns
+_ItemSummary = Select(columns=[PurchaseItem.order_id,
+                           Alias(Sum(PurchaseItem.quantity), 'ordered_quantity'),
+                           Alias(Sum(PurchaseItem.quantity_received), 'received_quantity'),
+                           Alias(Sum(PurchaseItem.quantity *
+                                     PurchaseItem.cost), 'subtotal')],
+                      tables=[PurchaseItem],
+                      group_by=[PurchaseItem.order_id])
+PurchaseItemSummary = Alias(_ItemSummary, '_purchase_item')
 
 
 class PurchaseOrderView(Viewable):
@@ -762,75 +798,60 @@ class PurchaseOrderView(Viewable):
     :cvar total: subtotal - discount_value + surcharge_value
     """
 
-    Person_Supplier = Alias(Person, 'person_supplier')
-    Person_Transporter = Alias(Person, 'person_transporter')
-    Person_Branch = Alias(Person, 'person_branch')
-    Person_Responsible = Alias(Person, 'person_responsible')
-    PurchaseItemSummary = Alias(_PurchaseItemSummary, '_purchase_item')
+    Person_Supplier = ClassAlias(Person, 'person_supplier')
+    Person_Transporter = ClassAlias(Person, 'person_transporter')
+    Person_Branch = ClassAlias(Person, 'person_branch')
+    Person_Responsible = ClassAlias(Person, 'person_responsible')
 
-    columns = dict(
-        id=PurchaseOrder.q.id,
-        identifier=PurchaseOrder.q.identifier,
-        status=PurchaseOrder.q.status,
-        open_date=PurchaseOrder.q.open_date,
-        quote_deadline=PurchaseOrder.q.quote_deadline,
-        expected_receival_date=PurchaseOrder.q.expected_receival_date,
-        expected_pay_date=PurchaseOrder.q.expected_pay_date,
-        receival_date=PurchaseOrder.q.receival_date,
-        confirm_date=PurchaseOrder.q.confirm_date,
-        salesperson_name=PurchaseOrder.q.salesperson_name,
-        expected_freight=PurchaseOrder.q.expected_freight,
-        surcharge_value=PurchaseOrder.q.surcharge_value,
-        discount_value=PurchaseOrder.q.discount_value,
+    purchase = PurchaseOrder
 
-        supplier_name=Person_Supplier.q.name,
-        transporter_name=Person_Transporter.q.name,
-        branch_name=Person_Branch.q.name,
-        responsible_name=Person_Responsible.q.name,
+    id = PurchaseOrder.id
+    identifier = PurchaseOrder.identifier
+    status = PurchaseOrder.status
+    open_date = PurchaseOrder.open_date
+    quote_deadline = PurchaseOrder.quote_deadline
+    expected_receival_date = PurchaseOrder.expected_receival_date
+    expected_pay_date = PurchaseOrder.expected_pay_date
+    receival_date = PurchaseOrder.receival_date
+    confirm_date = PurchaseOrder.confirm_date
+    salesperson_name = PurchaseOrder.salesperson_name
+    expected_freight = PurchaseOrder.expected_freight
+    surcharge_value = PurchaseOrder.surcharge_value
+    discount_value = PurchaseOrder.discount_value
 
-        ordered_quantity=Field('_purchase_item', 'ordered_quantity'),
-        received_quantity=Field('_purchase_item', 'received_quantity'),
-        subtotal=Field('_purchase_item', 'subtotal'),
-        total=Field('_purchase_item', 'subtotal') - \
-            PurchaseOrder.q.discount_value + PurchaseOrder.q.surcharge_value
-    )
+    supplier_id = Supplier.id
+    supplier_name = Person_Supplier.name
+    transporter_name = Person_Transporter.name
+    branch_name = Person_Branch.name
+    responsible_name = Person_Responsible.name
 
-    joins = [
+    ordered_quantity = Field('_purchase_item', 'ordered_quantity')
+    received_quantity = Field('_purchase_item', 'received_quantity')
+    subtotal = Field('_purchase_item', 'subtotal')
+    total = Field('_purchase_item', 'subtotal') - \
+        PurchaseOrder.discount_value + PurchaseOrder.surcharge_value
+
+    tables = [
+        PurchaseOrder,
         Join(PurchaseItemSummary,
-                    Field('_purchase_item', 'id') == PurchaseOrder.q.id),
+             Field('_purchase_item', 'order_id') == PurchaseOrder.id),
 
-        LeftJoin(Supplier,
-                   PurchaseOrder.q.supplier_id == Supplier.q.id),
-        LeftJoin(Transporter,
-                   PurchaseOrder.q.transporter_id == Transporter.q.id),
-        LeftJoin(Branch,
-                   PurchaseOrder.q.branch_id == Branch.q.id),
-        LeftJoin(LoginUser,
-                   PurchaseOrder.q.responsible_id == LoginUser.q.id),
+        LeftJoin(Supplier, PurchaseOrder.supplier_id == Supplier.id),
+        LeftJoin(Transporter, PurchaseOrder.transporter_id == Transporter.id),
+        LeftJoin(Branch, PurchaseOrder.branch_id == Branch.id),
+        LeftJoin(LoginUser, PurchaseOrder.responsible_id == LoginUser.id),
 
-        LeftJoin(Person_Supplier,
-                   Supplier.q.person_id == Person_Supplier.q.id),
-        LeftJoin(Person_Transporter,
-                   Transporter.q.person_id == Person_Transporter.q.id),
-        LeftJoin(Person_Branch,
-                   Branch.q.person_id == Person_Branch.q.id),
-       LeftJoin(Person_Responsible,
-                   LoginUser.q.person_id == Person_Responsible.q.id),
+        LeftJoin(Person_Supplier, Supplier.person_id == Person_Supplier.id),
+        LeftJoin(Person_Transporter, Transporter.person_id == Person_Transporter.id),
+        LeftJoin(Person_Branch, Branch.person_id == Person_Branch.id),
+        LeftJoin(Person_Responsible, LoginUser.person_id == Person_Responsible.id),
     ]
 
     @classmethod
     def post_search_callback(cls, sresults):
-        select = sresults.get_select_expr(const.COUNT(1), const.SUM(cls.total))
+        select = sresults.get_select_expr(Count(1), Sum(cls.total))
         return ('count', 'sum'), select
 
-    #
-    # Properties
-    #
-
-    @property
-    def purchase(self):
-        return PurchaseOrder.get(self.id, self.get_connection())
-
     #
     # Public API
     #
@@ -842,13 +863,13 @@ class PurchaseOrderView(Viewable):
         return currency(self.subtotal)
 
     def get_branch_name(self):
-        return unicode(self.branch_name or "")
+        return unicode(self.branch_name or u"")
 
     def get_supplier_name(self):
-        return unicode(self.supplier_name or "")
+        return unicode(self.supplier_name or u"")
 
     def get_transporter_name(self):
-        return unicode(self.transporter_name or "")
+        return unicode(self.transporter_name or u"")
 
     def get_open_date_as_string(self):
         return self.open_date.strftime("%x")
@@ -857,16 +878,16 @@ class PurchaseOrderView(Viewable):
         return PurchaseOrder.translate_status(self.status)
 
     @classmethod
-    def select_confirmed(cls, due_date=None, connection=None):
-        query = cls.q.status == PurchaseOrder.ORDER_CONFIRMED
+    def find_confirmed(cls, store, due_date=None):
+        query = cls.status == PurchaseOrder.ORDER_CONFIRMED
 
         if due_date:
             if isinstance(due_date, tuple):
-                date_query = AND(const.DATE(cls.q.expected_receival_date) >= due_date[0],
-                                 const.DATE(cls.q.expected_receival_date) <= due_date[1])
+                date_query = And(Date(cls.expected_receival_date) >= due_date[0],
+                                 Date(cls.expected_receival_date) <= due_date[1])
             else:
-                date_query = const.DATE(cls.q.expected_receival_date) == due_date
+                date_query = Date(cls.expected_receival_date) == due_date
 
-            query = AND(query, date_query)
+            query = And(query, date_query)
 
-        return cls.select(query, connection=connection)
+        return store.find(cls, query)
