@@ -30,12 +30,12 @@ from decimal import Decimal
 
 from kiwi.currency import currency
 from stoqdrivers.enum import TaxType, UnitType
+from storm.expr import And, In, Or
+from storm.references import Reference, ReferenceSet
 from zope.interface import implements
 
-from stoqlib.database.orm import BoolCol, PriceCol, PercentCol
-from stoqlib.database.orm import DateTimeCol, UnicodeCol, IntCol, ForeignKey
-from stoqlib.database.orm import SingleJoin, MultipleJoin
-from stoqlib.database.orm import AND, IN, OR
+from stoqlib.database.properties import BoolCol, PriceCol, PercentCol
+from stoqlib.database.properties import DateTimeCol, UnicodeCol, IntCol
 from stoqlib.domain.base import Domain
 from stoqlib.domain.events import CategoryCreateEvent, CategoryEditEvent
 from stoqlib.domain.interfaces import IDescribable
@@ -60,6 +60,8 @@ class SellableUnit(Domain):
     """ A class used to represent the sellable unit.
 
     """
+    __storm_table__ = 'sellable_unit'
+
     implements(IDescribable)
 
     #: The values on the list are enums used to fill
@@ -100,15 +102,17 @@ class SellableTaxConstant(Domain):
     """
     implements(IDescribable)
 
+    __storm_table__ = 'sellable_tax_constant'
+
     description = UnicodeCol()
     tax_type = IntCol()
     tax_value = PercentCol(default=None)
 
     _mapping = {
-        int(TaxType.NONE): 'TAX_NONE',                      # Não tributado - ICMS
-        int(TaxType.EXEMPTION): 'TAX_EXEMPTION',            # Isento - ICMS
-        int(TaxType.SUBSTITUTION): 'TAX_SUBSTITUTION',      # Substituição tributária - ICMS
-        int(TaxType.SERVICE): 'TAX_SERVICE',                # ISS
+        int(TaxType.NONE): u'TAX_NONE',                      # Não tributado - ICMS
+        int(TaxType.EXEMPTION): u'TAX_EXEMPTION',            # Isento - ICMS
+        int(TaxType.SUBSTITUTION): u'TAX_SUBSTITUTION',      # Substituição tributária - ICMS
+        int(TaxType.SERVICE): u'TAX_SERVICE',                # ISS
         }
 
     def get_value(self):
@@ -116,15 +120,13 @@ class SellableTaxConstant(Domain):
             self.tax_type, self.tax_value)
 
     @classmethod
-    def get_by_type(cls, tax_type, conn):
+    def get_by_type(cls, tax_type, store):
         """Fetch the tax constant for tax_type
         :param tax_type: the tax constant to fetch
-        :param conn: a database connection
+        :param store: a store
         :returns: a |sellabletaxconstant| or ``None`` if none is found
         """
-        return SellableTaxConstant.selectOneBy(
-            tax_type=int(tax_type),
-            connection=conn)
+        return store.find(SellableTaxConstant, tax_type=int(tax_type)).one()
 
     # IDescribable
 
@@ -138,6 +140,7 @@ class SellableCategory(Domain):
 
     This class can represents a sellable's category as well its base category.
     """
+    __storm_table__ = 'sellable_category'
 
     #: The category description
     description = UnicodeCol()
@@ -149,12 +152,16 @@ class SellableCategory(Domain):
     #: belongs to this category.
     salesperson_commission = PercentCol(default=0)
 
-    #: base category of this category, ``None`` for base categories themselves
-    category = ForeignKey('SellableCategory', default=None)
-    tax_constant = ForeignKey('SellableTaxConstant', default=None)
+    category_id = IntCol(default=None)
 
-    children = MultipleJoin('SellableCategory',
-                            joinColumn='category_id')
+    #: base category of this category, ``None`` for base categories themselves
+    category = Reference(category_id, 'SellableCategory.id')
+
+    tax_constant_id = IntCol(default=None)
+
+    tax_constant = Reference(tax_constant_id, 'SellableTaxConstant.id')
+
+    children = ReferenceSet('id', 'SellableCategory.category_id')
 
     implements(IDescribable)
 
@@ -171,7 +178,7 @@ class SellableCategory(Domain):
             descriptions.append(parent.description)
             parent = parent.category
 
-        return ':'.join(reversed(descriptions))
+        return u':'.join(reversed(descriptions))
 
     #
     #  Public API
@@ -235,11 +242,6 @@ class SellableCategory(Domain):
             return self.tax_constant or self.category.get_tax_constant()
         return self.tax_constant
 
-    def check_category_description_exists(self, description, conn):
-        category = SellableCategory.selectOneBy(description=description,
-                                                connection=conn)
-        return category is None or category is self
-
     #
     #  IDescribable
     #
@@ -252,12 +254,12 @@ class SellableCategory(Domain):
     #
 
     @classmethod
-    def get_base_categories(cls, conn):
+    def get_base_categories(cls, store):
         """Returns all available base categories
-        :param conn: a database connection
+        :param store: a store
         :returns: categories
         """
-        return cls.select(cls.q.category_id == None, connection=conn)
+        return store.find(cls, category_id=None)
 
     #
     # Domain hooks
@@ -277,12 +279,17 @@ class ClientCategoryPrice(Domain):
     """A table that stores special prices for clients based on their
     category.
     """
+    __storm_table__ = 'client_category_price'
+
+    sellable_id = IntCol()
 
     #: The sellable that has a special price
-    sellable = ForeignKey('Sellable')
+    sellable = Reference(sellable_id, 'Sellable.id')
+
+    category_id = IntCol()
 
     #: The category that has the special price
-    category = ForeignKey('ClientCategory')
+    category = Reference(category_id, 'ClientCategory.id')
 
     #: The price for this (sellable, category)
     price = PriceCol(default=0)
@@ -306,20 +313,20 @@ class ClientCategoryPrice(Domain):
 
     def remove(self):
         """Removes this client category price from the database."""
-        self.delete(self.id, self.get_connection())
+        self.store.remove(self)
 
 
 def _validate_code(sellable, attr, code):
     if sellable.check_code_exists(code):
         raise SellableError(
-            _("The sellable code %r already exists") % (code, ))
+            _(u"The sellable code %r already exists") % (code, ))
     return code
 
 
 def _validate_barcode(sellable, attr, barcode):
     if sellable.check_barcode_exists(barcode):
         raise SellableError(
-            _("The sellable barcode %r already exists") % (barcode, ))
+            _(u"The sellable barcode %r already exists") % (barcode, ))
     return barcode
 
 
@@ -329,6 +336,7 @@ class Sellable(Domain):
     only its reference as a sellable. Concrete items are created by
     IContainer routines.
     """
+    __storm_table__ = 'sellable'
 
     implements(IDescribable)
 
@@ -343,11 +351,11 @@ class Sellable(Domain):
                 STATUS_BLOCKED: _(u'Blocked')}
 
     #: an internal code identifying the sellable in Stoq
-    code = UnicodeCol(default='', validator=_validate_code)
+    code = UnicodeCol(default=u'', validator=_validate_code)
 
     #: barcode, mostly for products, usually printed and attached to the
     #: package.
-    barcode = UnicodeCol(default='', validator=_validate_barcode)
+    barcode = UnicodeCol(default=u'', validator=_validate_barcode)
 
     # This default status is used when a new sellable is created,
     # so it must be *always* UNAVAILABLE (that means no stock for it).
@@ -361,7 +369,7 @@ class Sellable(Domain):
     base_price = PriceCol(default=0)
 
     #: full description of sallable
-    description = UnicodeCol(default='')
+    description = UnicodeCol(default=u'')
 
     #: maximum discount allowed
     max_discount = PercentCol(default=0)
@@ -369,21 +377,28 @@ class Sellable(Domain):
     #: commission to pay after selling this sellable
     commission = PercentCol(default=0)
 
-    notes = UnicodeCol(default='')
+    notes = UnicodeCol(default=u'')
+
+    unit_id = IntCol(default=None)
 
     #: unit of the sellable, kg/l etc
-    unit = ForeignKey("SellableUnit", default=None)
+    unit = Reference(unit_id, 'SellableUnit.id')
 
-    image = ForeignKey('Image', default=None)
+    image_id = IntCol(default=None)
+    image = Reference(image_id, 'Image.id')
+
+    category_id = IntCol(default=None)
 
     #: a reference to category table
-    category = ForeignKey('SellableCategory', default=None)
-    tax_constant = ForeignKey('SellableTaxConstant', default=None)
+    category = Reference(category_id, 'SellableCategory.id')
+    tax_constant_id = IntCol(default=None)
+    tax_constant = Reference(tax_constant_id, 'SellableTaxConstant.id')
 
-    product = SingleJoin('Product', joinColumn='sellable_id')
-    service = SingleJoin('Service', joinColumn='sellable_id')
+    product = Reference('id', 'Product.sellable_id', on_remote=True)
+    service = Reference('id', 'Service.sellable_id', on_remote=True)
 
-    default_sale_cfop = ForeignKey("CfopData", default=None)
+    default_sale_cfop_id = IntCol(default=None)
+    default_sale_cfop = Reference(default_sale_cfop_id, 'CfopData.id')
 
     #: A special price used when we have a "on sale" state, this
     #: can be used for promotions
@@ -391,30 +406,44 @@ class Sellable(Domain):
     on_sale_start_date = DateTimeCol(default=None)
     on_sale_end_date = DateTimeCol(default=None)
 
-    def _create(self, id, **kw):
-        markup = None
-        if not 'kw' in kw:
-            # markup specification must to reflect in the sellable price, since
-            # there is no such column -- but we can only change the price right
-            # after Domain._create() get executed.
-            markup = kw.pop('markup', None)
+    def __init__(self, store=None,
+                 category=None,
+                 cost=None,
+                 commission=None,
+                 description=None,
+                 price=None):
+        """Creates a new sellable
+        :param store: a store
+        :param category: category of this sellable
+        :param cost: the cost, defaults to 0
+        :param commission: commission for this sellable
+        :param description: readable description of the sellable
+        :param price: the price, defaults to 0
+        """
 
-        category = kw.get('category', None)
-        if 'price' not in kw and 'cost' in kw and category:
-            markup = markup or category.get_markup()
-            cost = kw.get('cost', currency(0))
-            kw['price'] = cost * (markup / currency(100) + 1)
-        if 'commission' not in kw and category:
-            kw['commission'] = category.get_commission()
+        Domain.__init__(self, store=store)
 
-        Domain._create(self, id, **kw)
+        if category:
+            if commission is None:
+                commission = category.get_commission()
+            if price is None and cost is not None:
+                markup = category.get_markup()
+                price = self._get_price_by_markup(markup, cost=cost)
+
+        self.category = category
+        self.commission = commission or currency(0)
+        self.cost = cost or currency(0)
+        self.description = description
+        self.price = price or currency(0)
 
     #
     # Helper methods
     #
 
-    def _get_price_by_markup(self, markup):
-        return self.cost + (self.cost * (markup / currency(100)))
+    def _get_price_by_markup(self, markup, cost=None):
+        if cost is None:
+            cost = self.cost
+        return cost + (cost * (markup / currency(100)))
 
     def _get_status_string(self):
         if not self.status in self.statuses:
@@ -435,9 +464,8 @@ class Sellable(Domain):
         :returns: The |storable| or ``None`` if there isn't one
         """
         from stoqlib.domain.product import Product, Storable
-        return Storable.selectOne(AND(Storable.q.product_id == Product.q.id,
-                                      Product.q.sellable_id == self.id),
-                                  connection=self.get_connection())
+        return self.store.find(Storable, And(Storable.product_id == Product.id,
+                                             Product.sellable_id == self.id)).one()
 
     @property
     def has_image(self):
@@ -490,7 +518,7 @@ class Sellable(Domain):
         :rtype: boolean
         """
         # FIXME: Perhaps this should be done elsewhere. Johan 2008-09-26
-        if self.service == sysparam(self.get_connection()).DELIVERY_SERVICE:
+        if self.service == sysparam(self.store).DELIVERY_SERVICE:
             return True
         return self.status == self.STATUS_AVAILABLE
 
@@ -544,8 +572,7 @@ class Sellable(Domain):
           - The |product| is in a |purchase|
         """
         from stoqlib.domain.sale import SaleItem
-        if SaleItem.selectBy(connection=self.get_connection(),
-                             sellable=self).count():
+        if self.store.find(SaleItem, sellable=self).count():
             # FIXME: Find a better way of doing this.
             # Quotes (and maybe other cases) don't go to the history,
             # so make sure there's nothing left on SaleItem referencing
@@ -554,8 +581,7 @@ class Sellable(Domain):
 
         # If the product is in a purchase.
         from stoqlib.domain.purchase import PurchaseItem
-        if PurchaseItem.selectBy(connection=self.get_connection(),
-                                 sellable=self).count():
+        if self.store.find(PurchaseItem, sellable=self).count():
             return False
 
         if self.product:
@@ -626,8 +652,7 @@ class Sellable(Domain):
     def get_category_prices(self):
         """Returns all client category prices associated with this sellable.
         """
-        return ClientCategoryPrice.selectBy(sellable=self,
-                                            connection=self.get_connection())
+        return self.store.find(ClientCategoryPrice, sellable=self)
 
     def get_category_price_info(self, category):
         """Returns the :class:`ClientCategoryPrice` information for the given
@@ -635,9 +660,8 @@ class Sellable(Domain):
 
         :returns: the :class:`ClientCategoryPrice` or None
         """
-        info = ClientCategoryPrice.selectOneBy(sellable=self,
-                                        category=category,
-                                        connection=self.get_connection())
+        info = self.store.find(ClientCategoryPrice, sellable=self,
+                                     category=category).one()
         return info
 
     def get_price_for_category(self, category):
@@ -656,13 +680,13 @@ class Sellable(Domain):
         """Returns ``True`` if we already have a sellable with the given code
         in the database.
         """
-        return self.check_unique_value_exists('code', code)
+        return self.check_unique_value_exists(Sellable.code, code)
 
     def check_barcode_exists(self, barcode):
         """Returns ``True`` if we already have a sellable with the given barcode
         in the database.
         """
-        return self.check_unique_value_exists('barcode', barcode)
+        return self.check_unique_value_exists(Sellable.barcode, barcode)
 
     def check_taxes_validity(self):
         """Check if icms taxes are valid.
@@ -725,7 +749,7 @@ class Sellable(Domain):
     def get_description(self, full_description=False):
         desc = self.description
         if full_description and self.get_category_description():
-            desc = "[%s] %s" % (self.get_category_description(), desc)
+            desc = u"[%s] %s" % (self.get_category_description(), desc)
 
         return desc
 
@@ -757,123 +781,125 @@ class Sellable(Domain):
         elif self.service:
             self.service.remove()
 
-        conn = self.get_connection()
-        self.delete(self.id, conn)
+        self.store.remove(self)
 
     @classmethod
-    def get_available_sellables_for_quote_query(cls, conn):
-        service_sellable = sysparam(conn).DELIVERY_SERVICE.sellable
-        return AND(cls.q.id != service_sellable.id,
-                   OR(cls.q.status == cls.STATUS_AVAILABLE,
-                      cls.q.status == cls.STATUS_UNAVAILABLE))
+    def get_available_sellables_for_quote_query(cls, store):
+        service_sellable = sysparam(store).DELIVERY_SERVICE.sellable
+        return And(cls.id != service_sellable.id,
+                   Or(cls.status == cls.STATUS_AVAILABLE,
+                      cls.status == cls.STATUS_UNAVAILABLE))
 
     @classmethod
-    def get_available_sellables_query(cls, conn):
-        service = sysparam(conn).DELIVERY_SERVICE
-        return AND(cls.q.id != service.id,
-                   cls.q.status == cls.STATUS_AVAILABLE)
+    def get_available_sellables_query(cls, store):
+        service = sysparam(store).DELIVERY_SERVICE
+        return And(cls.id != service.id,
+                   cls.status == cls.STATUS_AVAILABLE)
 
     @classmethod
-    def get_available_sellables(cls, conn):
+    def get_available_sellables(cls, store):
         """Returns sellable objects which can be added in a |sale|. By
         default a delivery sellable can not be added manually by users
         since a separate dialog is responsible for that.
         """
-        query = cls.get_available_sellables_query(conn)
-        return cls.select(query, connection=conn)
+        query = cls.get_available_sellables_query(store)
+        return store.find(cls, query)
 
     @classmethod
-    def get_unblocked_sellables_query(cls, conn, storable=False, supplier=None,
+    def get_unblocked_sellables_query(cls, store, storable=False, supplier=None,
                                       consigned=False):
-        """Helper method for get_unblocked_sellables"""
+        """Helper method for get_unblocked_sellables
+
+        When supplier is not None, you should use this query only with Viewables
+        that join with supplier, like ProductFullStockSupplierView
+        """
         from stoqlib.domain.product import Product, ProductSupplierInfo
-        query = AND(OR(cls.get_available_sellables_query(conn),
-                       cls.q.status == cls.STATUS_UNAVAILABLE),
-                    cls.q.id == Product.q.sellable_id,
-                    Product.q.consignment == consigned)
+        query = And(Or(cls.get_available_sellables_query(store),
+                       cls.status == cls.STATUS_UNAVAILABLE),
+                    cls.id == Product.sellable_id,
+                    Product.consignment == consigned)
         if storable:
             from stoqlib.domain.product import Storable
-            query = AND(query,
-                        Sellable.q.id == Product.q.sellable_id,
-                        Storable.q.product_id == Product.q.id)
+            query = And(query,
+                        Sellable.id == Product.sellable_id,
+                        Storable.product_id == Product.id)
 
-        # FIXME: Inserting ProductSupplierInfo in this query breaks storm
         if supplier:
-            query = AND(query,
-                        Sellable.q.id == Product.q.sellable_id,
-                        Product.q.id == ProductSupplierInfo.q.product_id,
-                        ProductSupplierInfo.q.supplier_id == supplier.id)
+            query = And(query,
+                        Sellable.id == Product.sellable_id,
+                        Product.id == ProductSupplierInfo.product_id,
+                        ProductSupplierInfo.supplier_id == supplier.id)
 
         return query
 
     @classmethod
-    def get_unblocked_sellables(cls, conn, storable=False, supplier=None,
+    def get_unblocked_sellables(cls, store, storable=False, supplier=None,
                                 consigned=False):
         """
         Returns unblocked sellable objects, which means the
         available sellables plus the sold ones.
 
-        :param conn: a database connection
+        :param store: a store
         :param storable: if `True`, only return sellables that also are
           |storable|
         :param supplier: a |supplier| or ``None``, if set limit the returned
           object to this |supplier|
         """
-        query = cls.get_unblocked_sellables_query(conn, storable, supplier,
+        query = cls.get_unblocked_sellables_query(store, storable, supplier,
                                                   consigned)
-        return cls.select(query, connection=conn)
+        return store.find(cls, query)
 
     @classmethod
-    def get_unavailable_sellables(cls, conn):
+    def get_unavailable_sellables(cls, store):
         """Returns sellable objects which can be added in a |sale|. By
         default a |delivery| sellable can not be added manually by users
         since a separate dialog is responsible for that.
         """
-        return cls.selectBy(status=cls.STATUS_UNAVAILABLE, connection=conn)
+        return store.find(cls, status=cls.STATUS_UNAVAILABLE)
 
     @classmethod
-    def _get_sellables_by_barcode(cls, conn, barcode, extra_query):
-        sellable = cls.selectOne(
-            AND(Sellable.q.barcode == barcode,
-                extra_query), connection=conn)
+    def _get_sellables_by_barcode(cls, store, barcode, extra_query):
+        sellable = store.find(cls,
+            And(Sellable.barcode == barcode,
+                extra_query)).one()
         if sellable is None:
             raise BarcodeDoesNotExists(
-                _("The sellable with barcode '%s' doesn't exists or is "
-                  "not available to be sold") % barcode)
+                _(u"The sellable with barcode '%s' doesn't exists or is "
+                  u"not available to be sold") % barcode)
         return sellable
 
     @classmethod
-    def get_availables_by_barcode(cls, conn, barcode):
+    def get_availables_by_barcode(cls, store, barcode):
         """Returns a list of avaliable sellables that can be sold.
         A sellable that can be sold can have only one possible
         status: STATUS_AVAILABLE
 
-        :param conn: a orm Transaction instance
+        :param store: a store
         :param barcode: a string representing a sellable barcode
         """
         return cls._get_sellables_by_barcode(
-            conn, barcode,
-            Sellable.q.status == Sellable.STATUS_AVAILABLE)
+            store, barcode,
+            Sellable.status == Sellable.STATUS_AVAILABLE)
 
     @classmethod
-    def get_availables_and_unavailable_by_barcode(cls, conn, barcode):
+    def get_availables_and_unavailable_by_barcode(cls, store, barcode):
         """Returns a list of avaliable sellables and also sellables that
         can be sold.  Here we will get sellables with the following
         statuses: STATUS_AVAILABLE, STATUS_UNAVAILABLE
 
-        :param conn: a orm Transaction instance
+        :param store: a store
         :param barcode: a string representing a sellable barcode
         """
         statuses = [cls.STATUS_AVAILABLE, cls.STATUS_UNAVAILABLE]
-        return cls._get_sellables_by_barcode(conn, barcode,
-                                             IN(cls.q.status, statuses))
+        return cls._get_sellables_by_barcode(store, barcode,
+                                             In(cls.status, statuses))
 
     @classmethod
-    def get_unblocked_by_categories(cls, conn, categories,
+    def get_unblocked_by_categories(cls, store, categories,
                                     include_uncategorized=True):
         """Returns the available sellables by a list of categories.
 
-        :param conn: a orm Transaction instance
+        :param store: a store
         :param categories: a list of SellableCategory instances
         :param include_uncategorized: whether or not include the sellables
             without a category
@@ -882,6 +908,6 @@ class Sellable(Domain):
 
         if include_uncategorized:
             categories.append(None)
-        for sellable in cls.get_unblocked_sellables(conn):
+        for sellable in cls.get_unblocked_sellables(store):
             if sellable.category in categories:
                 yield sellable
