@@ -26,14 +26,16 @@
 import datetime
 
 from kiwi.argcheck import argcheck
+from kiwi.currency import currency
+from storm.references import Reference
+from storm.store import AutoReload
 from zope.interface import implements
 
-from stoqlib.database.orm import AutoReload
-from stoqlib.database.orm import ForeignKey, UnicodeCol, DateTimeCol, IntCol
-from stoqlib.database.orm import QuantityCol
+from stoqlib.database.properties import UnicodeCol, DateTimeCol, IntCol
+from stoqlib.database.properties import PriceCol, QuantityCol
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IContainer
-from stoqlib.domain.product import ProductHistory
+from stoqlib.domain.product import ProductHistory, StockTransactionHistory
 from stoqlib.exceptions import DatabaseInconsistency
 from stoqlib.lib.translation import stoqlib_gettext
 
@@ -49,34 +51,49 @@ class StockDecreaseItem(Domain):
     """An item in a stock decrease object.
     """
 
+    __storm_table__ = 'stock_decrease_item'
+
+    stock_decrease_id = IntCol(default=None)
+
     #: The stock decrease this item belongs to
-    stock_decrease = ForeignKey('StockDecrease', default=None)
+    stock_decrease = Reference(stock_decrease_id, 'StockDecrease.id')
+
+    sellable_id = IntCol()
 
     #: the |sellable| for this decrease
-    sellable = ForeignKey('Sellable')
+    sellable = Reference(sellable_id, 'Sellable.id')
+
+    #: the cost of the |sellable| on the moment this decrease was created
+    cost = PriceCol(default=0)
 
     #: the quantity decreased for this item
     quantity = QuantityCol()
 
-    def _create(self, id, **kw):
+    def __init__(self, store=None, **kw):
         if not 'kw' in kw:
             if not 'sellable' in kw:
                 raise TypeError('You must provide a sellable argument')
-        Domain._create(self, id, **kw)
+        Domain.__init__(self, store=store, **kw)
 
     def decrease(self, branch):
         assert branch
 
         storable = self.sellable.product_storable
         if storable:
-            storable.decrease_stock(self.quantity, branch)
+            storable.decrease_stock(self.quantity, branch,
+                                    StockTransactionHistory.TYPE_STOCK_DECREASE,
+                                    self.id,
+                                    cost_center=self.stock_decrease.cost_center)
 
     #
     # Accessors
     #
 
+    def get_total(self):
+        return currency(self.cost * self.quantity)
+
     def get_quantity_unit_string(self):
-        return "%s %s" % (self.quantity, self.sellable.get_unit_description())
+        return u"%s %s" % (self.quantity, self.sellable.get_unit_description())
 
     def get_description(self):
         return self.sellable.get_description()
@@ -92,6 +109,8 @@ class StockDecrease(Domain):
 
     implements(IContainer)
 
+    __storm_table__ = 'stock_decrease'
+
     #: Stock Decrease is still being edited
     STATUS_INITIAL = 0
 
@@ -109,23 +128,44 @@ class StockDecrease(Domain):
     #: status of the sale
     status = IntCol(default=STATUS_INITIAL)
 
-    reason = UnicodeCol(default='')
+    reason = UnicodeCol(default=u'')
 
     #: Some optional additional information related to this sale.
-    notes = UnicodeCol(default='')
+    notes = UnicodeCol(default=u'')
 
     #: the date sale was created
     confirm_date = DateTimeCol(default_factory=datetime.datetime.now)
 
-    #: who should be blamed for this
-    responsible = ForeignKey('LoginUser')
+    responsible_id = IntCol()
 
-    removed_by = ForeignKey('Employee')
+    #: who should be blamed for this
+    responsible = Reference(responsible_id, 'LoginUser.id')
+
+    removed_by_id = IntCol()
+
+    removed_by = Reference(removed_by_id, 'Employee.id')
+
+    branch_id = IntCol()
 
     #: branch where the sale was done
-    branch = ForeignKey('Branch')
+    branch = Reference(branch_id, 'Branch.id')
 
-    cfop = ForeignKey('CfopData')
+    cfop_id = IntCol()
+
+    cfop = Reference(cfop_id, 'CfopData.id')
+
+    group_id = IntCol()
+
+    #: the payment group related to this stock decrease
+    group = Reference(group_id, 'PaymentGroup.id')
+
+    cost_center_id = IntCol()
+
+    #: the |costcenter| that the cost of the products decreased in this stock
+    #: decrease should be accounted for. When confirming a stock decrease with
+    #: a |costcenter| set, a |costcenterentry| will be created for each product
+    #: decreased.
+    cost_center = Reference(cost_center_id, 'CostCenter.id')
 
     #
     # Classmethods
@@ -134,7 +174,7 @@ class StockDecrease(Domain):
     @classmethod
     def get_status_name(cls, status):
         if not status in cls.statuses:
-            raise DatabaseInconsistency(_("Invalid status %d") % status)
+            raise DatabaseInconsistency(_(u"Invalid status %d") % status)
         return cls.statuses[status]
 
     @argcheck(StockDecreaseItem)
@@ -143,12 +183,11 @@ class StockDecrease(Domain):
         item.stock_decrease = self
 
     def get_items(self):
-        return StockDecreaseItem.selectBy(stock_decrease=self,
-                                          connection=self.get_connection())
+        return self.store.find(StockDecreaseItem, stock_decrease=self)
 
     @argcheck(StockDecreaseItem)
     def remove_item(self, item):
-        StockDecreaseItem.delete(item.id, connection=self.get_connection())
+        self.store.remove(item)
 
     # Status
 
@@ -166,15 +205,18 @@ class StockDecrease(Domain):
         assert self.can_confirm()
         assert self.branch
 
-        conn = self.get_connection()
+        store = self.store
         branch = self.branch
         for item in self.get_items():
             if item.sellable.product:
-                ProductHistory.add_decreased_item(conn, branch, item)
+                ProductHistory.add_decreased_item(store, branch, item)
             item.decrease(branch)
 
         self.status = StockDecrease.STATUS_CONFIRMED
 
+        if self.group:
+            self.group.confirm()
+
     #
     # Accessors
     #
@@ -200,19 +242,28 @@ class StockDecrease(Domain):
     def get_cfop_description(self):
         return self.cfop.get_description()
 
+    def get_total_cost(self):
+        return self.get_items().sum(StockDecreaseItem.cost *
+                                    StockDecreaseItem.quantity)
+
     # Other methods
 
-    def add_sellable(self, sellable, quantity=1):
+    def add_sellable(self, sellable, cost=None, quantity=1):
         """Adds a new sellable item to a stock decrease
 
         :param sellable: the |sellable|
+        :param cost: the cost for the decrease. If ``None``, sellable.cost
+            will be used instead
         :param quantity: quantity to add, defaults to ``1``
         """
-        return StockDecreaseItem(connection=self.get_connection(),
+        if cost is None:
+            cost = sellable.cost
+
+        return StockDecreaseItem(store=self.store,
                                  quantity=quantity,
                                  stock_decrease=self,
                                  sellable=sellable,
-                                 )
+                                 cost=cost)
 
     @property
     def order_number(self):
