@@ -39,40 +39,40 @@ class TestAccount(DomainTest):
 
     def testAccountGetByStation(self):
         station = self.create_station()
-        account = Account.get_by_station(self.trans, station)
+        account = Account.get_by_station(self.store, station)
         self.failIf(account)
         account = self.create_account()
         account.station = station
 
-        account = Account.get_by_station(self.trans, station)
+        account = Account.get_by_station(self.store, station)
         self.failUnless(account)
 
         self.assertRaises(TypeError, Account.get_by_station,
-                          self.trans, None)
+                          self.store, None)
         self.assertRaises(TypeError, Account.get_by_station,
-                          self.trans, object())
+                          self.store, object())
 
     def testAccountLongDescription(self):
         a1 = self.create_account()
-        a1.description = "first"
+        a1.description = u"first"
         a2 = self.create_account()
-        a2.description = "second"
+        a2.description = u"second"
         a2.parent = a1
         a3 = self.create_account()
-        a3.description = "third"
+        a3.description = u"third"
         a3.parent = a2
 
-        self.assertEquals(a1.long_description, 'first')
-        self.assertEquals(a2.long_description, 'first:second')
-        self.assertEquals(a3.long_description, 'first:second:third')
+        self.assertEquals(a1.long_description, u'first')
+        self.assertEquals(a2.long_description, u'first:second')
+        self.assertEquals(a3.long_description, u'first:second:third')
 
     def testAccountTransactions(self):
         account = self.create_account()
-        self.failIf(account.transactions)
+        self.assertTrue(account.transactions.is_empty())
 
         transaction = self.create_account_transaction(account)
 
-        self.failUnless(account.transactions)
+        self.assertFalse(account.transactions.is_empty())
         self.failUnless(transaction in account.transactions)
 
         a2 = self.create_account()
@@ -81,7 +81,7 @@ class TestAccount(DomainTest):
         self.failIf(t2 in account.transactions)
 
         t2.source_account = account
-        t2.sync()
+        self.store.flush()
 
         self.failUnless(t2 in account.transactions)
 
@@ -89,9 +89,9 @@ class TestAccount(DomainTest):
         account = self.create_account()
         self.failUnless(account.can_remove())
 
-        self.failIf(sysparam(self.trans).TILLS_ACCOUNT.can_remove())
-        self.failIf(sysparam(self.trans).IMBALANCE_ACCOUNT.can_remove())
-        self.failIf(sysparam(self.trans).BANKS_ACCOUNT.can_remove())
+        self.failIf(sysparam(self.store).TILLS_ACCOUNT.can_remove())
+        self.failIf(sysparam(self.store).IMBALANCE_ACCOUNT.can_remove())
+        self.failIf(sysparam(self.store).BANKS_ACCOUNT.can_remove())
 
         station = self.create_station()
         account.station = station
@@ -114,21 +114,21 @@ class TestAccount(DomainTest):
         a1 = self.create_account()
         a2 = self.create_account()
 
-        imbalance_account = sysparam(self.trans).IMBALANCE_ACCOUNT
+        imbalance_account = sysparam(self.store).IMBALANCE_ACCOUNT
 
         t1 = self.create_account_transaction(a1)
         t1.source_account = a2
-        t1.sync()
+        self.store.flush()
 
         t2 = self.create_account_transaction(a2)
         t2.source_account = a1
-        t2.sync()
+        self.store.flush()
 
         a1.station = self.create_station()
         self.assertRaises(TypeError, a1.remove)
         a1.station = None
 
-        a1.remove(self.trans)
+        a1.remove(self.store)
 
         self.assertEquals(t1.account, imbalance_account)
         self.assertEquals(t2.source_account, imbalance_account)
@@ -136,11 +136,11 @@ class TestAccount(DomainTest):
     def testAccountRemoveWithBankAccount(self):
         account = self.create_account()
         bank = self.create_bank_account(account=account)
-        BillOption(option='foo',
-                   value='bar',
+        BillOption(option=u'foo',
+                   value=u'bar',
                    bank_account=bank,
-                   connection=self.trans)
-        account.remove(self.trans)
+                   store=self.store)
+        account.remove(self.store)
 
     def testHasChildAccounts(self):
         a1 = self.create_account()
@@ -161,12 +161,12 @@ class TestAccount(DomainTest):
     def testGetTypeLabel(self):
         a = self.create_account()
         a.account_type = Account.TYPE_CASH
-        self.assertEquals(a.get_type_label(True), "Spend")
-        self.assertEquals(a.get_type_label(False), "Receive")
+        self.assertEquals(a.get_type_label(True), u"Spend")
+        self.assertEquals(a.get_type_label(False), u"Receive")
 
         a.account_type = Account.TYPE_BANK
-        self.assertEquals(a.get_type_label(True), "Withdrawal")
-        self.assertEquals(a.get_type_label(False), "Deposit")
+        self.assertEquals(a.get_type_label(True), u"Withdrawal")
+        self.assertEquals(a.get_type_label(False), u"Deposit")
 
 
 class TestAccountTransaction(DomainTest):
@@ -181,8 +181,7 @@ class TestAccountTransaction(DomainTest):
         t1.source_account = a2
         t2.source_account = a1
 
-        t1.sync()
-        t2.sync()
+        self.store.flush()
 
         self.assertEquals(t1.get_other_account(a1), a2)
         self.assertEquals(t1.get_other_account(a2), a1)
@@ -196,34 +195,34 @@ class TestAccountTransaction(DomainTest):
 
         t1 = self.create_account_transaction(a1)
         t1.source_account = a2
-        t1.sync()
+        self.store.flush()
 
         t2 = self.create_account_transaction(a2)
         t2.source_account = a1
-        t2.sync()
+        self.store.flush()
 
         t1.set_other_account(a1, a2)
-        t1.syncUpdate()
+        self.store.flush()
         self.assertEquals(t1.account, a1)
         self.assertEquals(t1.source_account, a2)
         t1.set_other_account(a2, a2)
-        t1.syncUpdate()
+        self.store.flush()
         self.assertEquals(t1.account, a2)
         self.assertEquals(t1.source_account, a2)
 
         t2.set_other_account(a1, a2)
-        t2.syncUpdate()
+        self.store.flush()
         self.assertEquals(t2.account, a2)
         self.assertEquals(t2.source_account, a1)
         t2.set_other_account(a2, a2)
-        t2.syncUpdate()
+        self.store.flush()
         self.assertEquals(t2.account, a2)
         self.assertEquals(t2.source_account, a2)
 
     def testCreateFromPayment(self):
         sale = self.create_sale()
         self.add_product(sale)
-        payment = self.add_payments(sale, method_type='check')[0]
+        payment = self.add_payments(sale, method_type=u'check')[0]
         sale.order()
         sale.confirm()
         account = self.create_account()
@@ -233,7 +232,7 @@ class TestAccountTransaction(DomainTest):
         payment.pay()
         transaction = AccountTransaction.create_from_payment(payment)
 
-        imbalance_account = sysparam(self.trans).IMBALANCE_ACCOUNT
+        imbalance_account = sysparam(self.store).IMBALANCE_ACCOUNT
         self.assertEquals(transaction.source_account, imbalance_account)
         self.assertEquals(transaction.account, account)
         self.assertEquals(transaction.payment, payment)
@@ -245,8 +244,8 @@ class TestAccountTransactionView(DomainTest):
         t = self.create_account_transaction(a)
         t.value = 100
         t.source_account = a
-        t.sync()
-        views = AccountTransactionView.get_for_account(a, self.trans)
+        self.store.flush()
+        views = AccountTransactionView.get_for_account(a, self.store)
         self.assertEquals(views.count(), 1)
         v1 = views[0]
         self.assertEquals(v1.value, t.value)
@@ -256,33 +255,33 @@ class TestAccountTransactionView(DomainTest):
 
     def testGetAccountDescription(self):
         a1 = self.create_account()
-        a1.description = "Source Account"
+        a1.description = u"Source Account"
         a2 = self.create_account()
-        a2.description = "Account"
+        a2.description = u"Account"
 
         t = self.create_account_transaction(a1)
         t.value = 100
         t.source_account = a1
         t.account = a2
-        t.sync()
-
-        views = AccountTransactionView.get_for_account(a1, self.trans)
-        self.assertEquals(views[0].get_account_description(a1), "Account")
-        self.assertEquals(views[0].get_account_description(a2), "Source Account")
+        self.store.flush()
+        self.store.autoreload(t)
+        views = AccountTransactionView.get_for_account(a1, self.store)
+        self.assertEquals(views[0].get_account_description(a1), u"Account")
+        self.assertEquals(views[0].get_account_description(a2), u"Source Account")
 
     def testGetValue(self):
         a1 = self.create_account()
-        a1.description = "Source Account"
+        a1.description = u"Source Account"
         a2 = self.create_account()
-        a2.description = "Account"
+        a2.description = u"Account"
 
         t = self.create_account_transaction(a1)
         t.value = 100
         t.source_account = a1
         t.account = a2
-        t.sync()
+        self.store.flush()
 
-        views = AccountTransactionView.get_for_account(a1, self.trans)
+        views = AccountTransactionView.get_for_account(a1, self.store)
         self.assertEquals(views[0].get_value(a1), -100)
         self.assertEquals(views[0].get_value(a2), 100)
 
@@ -290,5 +289,5 @@ class TestAccountTransactionView(DomainTest):
         a = self.create_account()
         t = self.create_account_transaction(a)
 
-        views = AccountTransactionView.get_for_account(a, self.trans)
+        views = AccountTransactionView.get_for_account(a, self.store)
         self.assertEquals(views[0].transaction, t)
