@@ -34,101 +34,101 @@ class TestCityLocation(DomainTest):
     def testIsValidModel(self):
         location = self.create_city_location()
         self.failUnless(location.is_valid_model())
-        invalid_location = CityLocation(connection=self.trans)
+        invalid_location = CityLocation(store=self.store)
         self.failIf(invalid_location.is_valid_model())
 
     def testGetOrCreate(self):
-        loc = CityLocation.get_or_create(self.trans, 'City',
-                                         'State', 'Country')
+        loc = CityLocation.get_or_create(self.store, u'City',
+                                         u'State', u'Country')
         self.failUnless(loc)
-        self.assertEqual(loc.city, 'City')
-        self.assertEqual(loc.state, 'State')
-        self.assertEqual(loc.country, 'Country')
+        self.assertEqual(loc.city, u'City')
+        self.assertEqual(loc.state, u'State')
+        self.assertEqual(loc.country, u'Country')
 
-        loc2 = CityLocation.get_or_create(self.trans, 'city',
-                                          'state', 'country')
+        loc2 = CityLocation.get_or_create(self.store, u'city',
+                                          u'state', u'country')
         self.failUnless(loc2)
-        self.assertEqual(loc2.city, 'City')
-        self.assertEqual(loc2.state, 'State')
-        self.assertEqual(loc2.country, 'Country')
+        self.assertEqual(loc2.city, u'City')
+        self.assertEqual(loc2.state, u'State')
+        self.assertEqual(loc2.country, u'Country')
         self.assertEqual(loc2, loc)
 
-        location = CityLocation.get_or_create(self.trans, 'São Carlos',
-                                              'SP', 'Brazil')
+        location = CityLocation.get_or_create(self.store, u'São Carlos',
+                                              u'SP', u'Brazil')
         for city, state, country in [
-            ('sao carlos', 'SP', 'Brazil'),
-            ('Sao carlos', 'SP', 'Brazil'),
-            ('São carlos', 'SP', 'Brazil'),
-            ('sao Carlos', 'SP', 'Brazil'),
-            ('sao Carlos', 'sp', 'Brazil'),
-            ('sao Carlos', 'sp', 'brazil'),
-            ('sao Carlos', 'Sp', 'brazil'),
+            (u'sao carlos', u'SP', u'Brazil'),
+            (u'Sao carlos', u'SP', u'Brazil'),
+            (u'São carlos', u'SP', u'Brazil'),
+            (u'sao Carlos', u'SP', u'Brazil'),
+            (u'sao Carlos', u'sp', u'Brazil'),
+            (u'sao Carlos', u'sp', u'brazil'),
+            (u'sao Carlos', u'Sp', u'brazil'),
             ]:
-            self.assertEqual(CityLocation.get_or_create(self.trans, city,
+            self.assertEqual(CityLocation.get_or_create(self.store, city,
                                                         state, country),
                              location)
         for city, state, country in [
-            ('Sao', 'SP', 'Brazil'),
-            ('sao', 'SP', 'Brazil'),
-            ('Carlos', 'SP', 'Brazil'),
-            ('carlos', 'SP', 'Brazil'),
+            (u'Sao', u'SP', u'Brazil'),
+            (u'sao', u'SP', u'Brazil'),
+            (u'Carlos', u'SP', u'Brazil'),
+            (u'carlos', u'SP', u'Brazil'),
             ]:
-            self.assertNotEqual(CityLocation.get_or_create(self.trans, city,
+            self.assertNotEqual(CityLocation.get_or_create(self.store, city,
                                                            state, country),
                                 location)
 
     def testGetCitiesBy(self):
-        location = CityLocation.get_or_create(self.trans, 'Sao Carlos',
-                                              'SP', 'Brazil')
+        location = CityLocation.get_or_create(self.store, u'Sao Carlos',
+                                              u'SP', u'Brazil')
         for state, country in [
-            ('SP', 'Brazil'),
-            ('Sp', 'brazil'),
-            ('SP', 'brazil'),
-            ('sp', 'Brazil'),
-            ('sp', 'BraZIL'),
-            (None, 'Brazil'),
-            ('SP', None),
+            (u'SP', u'Brazil'),
+            (u'Sp', u'brazil'),
+            (u'SP', u'brazil'),
+            (u'sp', u'Brazil'),
+            (u'sp', u'BraZIL'),
+            (None, u'Brazil'),
+            (u'SP', None),
             (None, None),
             ]:
             self.assertTrue(location.city in
-                            CityLocation.get_cities_by(self.trans,
+                            CityLocation.get_cities_by(self.store,
                                                        state=state,
                                                        country=country))
         for state, country in [
-            ('SP', 'Brazi'),
-            ('RJ', 'Brazil'),
-            ('RJ', None),
-            ('BA', None),
-            ('SP', 'Albânia'),
+            (u'SP', u'Brazi'),
+            (u'RJ', u'Brazil'),
+            (u'RJ', None),
+            (u'BA', None),
+            (u'SP', u'Albânia'),
             ]:
             self.assertFalse(location.city in
-                             CityLocation.get_cities_by(self.trans,
+                             CityLocation.get_cities_by(self.store,
                                                         state=state,
                                                         country=country))
 
         # Make sure no duplicates are returned
-        CityLocation.get_or_create(self.trans, 'Sao Carlos', 'SP', 'BR')
-        CityLocation.get_or_create(self.trans, 'Sao Carlos', 'SP', 'BR_')
-        CityLocation.get_or_create(self.trans, 'Sao Carlos', 'SP', 'BR__')
-        cities = list(CityLocation.get_cities_by(self.trans, state='SP'))
+        CityLocation.get_or_create(self.store, u'Sao Carlos', u'SP', u'BR')
+        CityLocation.get_or_create(self.store, u'Sao Carlos', u'SP', u'BR_')
+        CityLocation.get_or_create(self.store, u'Sao Carlos', u'SP', u'BR__')
+        cities = list(CityLocation.get_cities_by(self.store, state=u'SP'))
         self.assertEqual(len(cities), len(set(cities)))
 
     def testGetDefault(self):
-        location = CityLocation.get_default(self.trans)
+        location = CityLocation.get_default(self.store)
         self.failUnless(isinstance(location, CityLocation))
         self.assertEquals(location.city,
-                          sysparam(self.trans).CITY_SUGGESTED)
+                          sysparam(self.store).CITY_SUGGESTED)
         self.assertEquals(location.state,
-                          sysparam(self.trans).STATE_SUGGESTED)
+                          sysparam(self.store).STATE_SUGGESTED)
         self.assertEquals(location.country,
-                          sysparam(self.trans).COUNTRY_SUGGESTED)
+                          sysparam(self.store).COUNTRY_SUGGESTED)
 
 
 class TestAddress(DomainTest):
     def testIsValidModel(self):
         person = self.create_person()
-        empty_location = CityLocation(connection=self.trans)
-        empty_address = Address(connection=self.trans,
+        empty_location = CityLocation(store=self.store)
+        empty_address = Address(store=self.store,
                                 person=person,
                                 city_location=empty_location)
         is_valid_model = empty_address.is_valid_model()
@@ -136,37 +136,37 @@ class TestAddress(DomainTest):
 
     def test_get_city_location_attributes(self):
         person = self.create_person()
-        city = 'Acapulco'
-        country = 'Brazil'
-        state = 'Cracovia'
+        city = u'Acapulco'
+        country = u'Brazil'
+        state = u'Cracovia'
         location = CityLocation(city=city, state=state, country=country,
-                                connection=self.trans)
+                                store=self.store)
         address = Address(person=person, city_location=location,
-                          connection=self.trans)
-        self.assertEquals(address.get_city(), 'Acapulco')
-        self.assertEquals(address.get_country(), 'Brazil')
-        self.assertEquals(address.get_state(), 'Cracovia')
+                          store=self.store)
+        self.assertEquals(address.get_city(), u'Acapulco')
+        self.assertEquals(address.get_country(), u'Brazil')
+        self.assertEquals(address.get_state(), u'Cracovia')
 
     def test_get_address_string(self):
         person = self.create_person()
         location = self.create_city_location()
 
-        street = 'Rua das Couves'
+        street = u'Rua das Couves'
         streetnumber = 283
-        district = 'Federal'
+        district = u'Federal'
         address = Address(person=person, city_location=location,
                           street=street, streetnumber=streetnumber,
                           district=district,
-                          connection=self.trans)
+                          store=self.store)
         string = address.get_address_string()
         self.assertEquals(string, u'%s %s, %s' % (street, streetnumber,
                                                   district))
 
         address.streetnumber = None
         string = address.get_address_string()
-        self.assertEquals(string, u'%s %s, %s' % (street, 'N/A', district))
+        self.assertEquals(string, u'%s %s, %s' % (street, u'N/A', district))
 
-        address.street = ""
+        address.street = u""
         string = address.get_address_string()
         self.assertEquals(string, u'')
 
@@ -174,30 +174,30 @@ class TestAddress(DomainTest):
         person = self.create_person()
         location = self.create_city_location()
         address = Address(person=person, city_location=location,
-                          postal_code='12345-678', connection=self.trans)
+                          postal_code=u'12345-678', store=self.store)
 
         self.assertEquals(address.get_postal_code_number(), 12345678)
 
     def testGetDetailsString(self):
         person = self.create_person()
-        city = 'Stoqlandia'
-        state = 'SP'
-        country = 'Brazil'
-        postal_code = '12345-678'
+        city = u'Stoqlandia'
+        state = u'SP'
+        country = u'Brazil'
+        postal_code = u'12345-678'
         location = CityLocation(city=city, state=state, country=country,
-                                connection=self.trans)
+                                store=self.store)
         address = Address(person=person, city_location=location,
-                          postal_code=postal_code, connection=self.trans)
+                          postal_code=postal_code, store=self.store)
         string = address.get_details_string()
         self.assertEquals(string, u'%s - %s - %s' % (postal_code,
                                                      city, state))
-        location.city = ''
+        location.city = u''
         string = address.get_details_string()
         self.assertEquals(string, u'%s' % postal_code)
-        location.state = ''
+        location.state = u''
         string = address.get_details_string()
         self.assertEquals(string, u'%s' % postal_code)
-        address.postal_code = ''
+        address.postal_code = u''
         string = address.get_details_string()
         self.assertEquals(string, u'')
         location.city = city
