@@ -27,9 +27,11 @@ from decimal import Decimal
 
 from kiwi.currency import currency
 
+from stoqlib.domain.account import AccountTransaction
+from stoqlib.domain.commission import Commission
 from stoqlib.domain.payment.comment import PaymentComment
 from stoqlib.domain.payment.method import PaymentMethod
-from stoqlib.domain.payment.payment import Payment
+from stoqlib.domain.payment.payment import Payment, PaymentChangeHistory
 from stoqlib.domain.test.domaintest import DomainTest
 from stoqlib.lib.dateutils import INTERVALTYPE_MONTH
 
@@ -43,14 +45,52 @@ class TestPayment(DomainTest):
                           till=None,
                           category=None,
                           payment_type=Payment.TYPE_OUT,
-                          connection=self.trans)
+                          store=self.store)
         self.failUnless(payment.status == Payment.STATUS_PREVIEW)
 
     def _get_relative_day(self, days):
         return datetime.datetime.today() + datetime.timedelta(days)
 
     def testGetPenalty(self):
-        method = PaymentMethod.get_by_name(self.trans, 'check')
+        method = PaymentMethod.get_by_name(self.store, u'check')
+        payment = Payment(value=currency(100),
+                          branch=self.create_branch(),
+                          due_date=datetime.datetime.now(),
+                          method=method,
+                          group=None,
+                          till=None,
+                          category=None,
+                          payment_type=Payment.TYPE_OUT,
+                          store=self.store)
+
+        for day, expected_value in [(0, 0),
+                                    (-1, 0),
+                                    (-30, 0),
+                                    (30, 0)]:
+            payment.due_date = self._get_relative_day(day)
+            self.assertEqual(payment.get_penalty(), currency(expected_value))
+
+        method.penalty = Decimal(20)
+
+        for day, expected_value in [(0, 0),
+                                    (-1, 20),
+                                    (-30, 20),
+                                    (30, 0)]:
+            payment.due_date = self._get_relative_day(day)
+            self.assertEqual(payment.get_penalty(), currency(expected_value))
+
+        due_date = self._get_relative_day(-15)
+        paid_date = self._get_relative_day(-5)
+        payment.due_date = payment.open_date = due_date
+        self.assertEqual(payment.get_penalty(paid_date.date()), currency(20))
+        self.assertEqual(payment.get_penalty(due_date.date()), currency(0))
+
+        for day in (18, -18):
+            paid_date = self._get_relative_day(day)
+            self.assertRaises(ValueError, payment.get_penalty, paid_date.date())
+
+    def testGetInterest(self):
+        method = PaymentMethod.get_by_name(self.store, u'check')
         payment = Payment(value=currency(100),
                           branch=self.create_branch(),
                           due_date=datetime.datetime.now(),
@@ -60,66 +100,28 @@ class TestPayment(DomainTest):
                           till=None,
                           category=None,
                           payment_type=Payment.TYPE_OUT,
-                          connection=self.trans)
+                          store=self.store)
 
         for day, expected_value in [(0, 0),
                                     (-1, 0),
                                     (-30, 0),
                                     (30, 0)]:
             payment.due_date = self._get_relative_day(day)
-            self.assertEqual(payment.get_penalty(), currency(expected_value))
+            self.assertEqual(payment.get_interest(), currency(expected_value))
 
-        method.daily_penalty = Decimal(1)
+        method.daily_interest = Decimal(1)
 
         for day, expected_value in [(0, 0),
                                     (-1, 1),
                                     (-30, 30),
                                     (30, 0)]:
             payment.due_date = self._get_relative_day(day)
-            self.assertEqual(payment.get_penalty(), currency(expected_value))
-
-        due_date = self._get_relative_day(-15)
-        paid_date = self._get_relative_day(-5)
-        payment.due_date = payment.open_date = due_date
-        method.daily_penalty = Decimal(2)
-        self.assertEqual(payment.get_penalty(paid_date.date()), currency(20))
-        self.assertEqual(payment.get_penalty(due_date.date()), currency(0))
-
-        for day in (18, -18):
-            paid_date = self._get_relative_day(day)
-            self.assertRaises(ValueError, payment.get_penalty, paid_date.date())
-
-    def testGetInterest(self):
-        method = PaymentMethod.get_by_name(self.trans, 'check')
-        payment = Payment(value=currency(100),
-                          branch=self.create_branch(),
-                          due_date=datetime.datetime.now(),
-                          method=method,
-                          group=None,
-                          till=None,
-                          category=None,
-                          payment_type=Payment.TYPE_OUT,
-                          connection=self.trans)
-
-        for day, expected_value in [(0, 0),
-                                    (-1, 0),
-                                    (-30, 0),
-                                    (30, 0)]:
-            payment.due_date = self._get_relative_day(day)
-            self.assertEqual(payment.get_interest(), currency(expected_value))
-
-        method.interest = Decimal(20)
-
-        for day, expected_value in [(0, 0),
-                                    (-1, 20),
-                                    (-30, 20),
-                                    (30, 0)]:
-            payment.due_date = self._get_relative_day(day)
             self.assertEqual(payment.get_interest(), currency(expected_value))
 
         due_date = self._get_relative_day(-15)
         paid_date = self._get_relative_day(-5)
         payment.due_date = payment.open_date = due_date
+        method.daily_interest = Decimal(2)
         self.assertEqual(payment.get_interest(paid_date.date()), currency(20))
         self.assertEqual(payment.get_interest(due_date.date()), currency(0))
 
@@ -127,8 +129,20 @@ class TestPayment(DomainTest):
             paid_date = self._get_relative_day(day)
             self.assertRaises(ValueError, payment.get_interest, paid_date.date())
 
+    def testHasCommission(self):
+        sale = self.create_sale()
+        self.add_payments(sale, method_type=u'check', installments=2)
+
+        for p in sale.payments:
+            self.assertFalse(p.has_commission())
+            Commission(store=self.store,
+                       payment=p,
+                       sale=sale,
+                       salesperson=sale.salesperson)
+            self.assertTrue(p.has_commission())
+
     def testIsPaid(self):
-        method = PaymentMethod.get_by_name(self.trans, 'check')
+        method = PaymentMethod.get_by_name(self.store, u'check')
         payment = Payment(value=currency(100),
                           branch=self.create_branch(),
                           due_date=datetime.datetime.now(),
@@ -137,7 +151,7 @@ class TestPayment(DomainTest):
                           till=None,
                           category=None,
                           payment_type=Payment.TYPE_OUT,
-                          connection=self.trans)
+                          store=self.store)
         self.failIf(payment.is_paid())
         payment.set_pending()
         self.failIf(payment.is_paid())
@@ -145,7 +159,7 @@ class TestPayment(DomainTest):
         self.failUnless(payment.is_paid())
 
     def testIsCancelled(self):
-        method = PaymentMethod.get_by_name(self.trans, 'check')
+        method = PaymentMethod.get_by_name(self.store, u'check')
         payment = Payment(value=currency(100),
                           branch=self.create_branch(),
                           due_date=datetime.datetime.now(),
@@ -154,7 +168,7 @@ class TestPayment(DomainTest):
                           till=None,
                           category=None,
                           payment_type=Payment.TYPE_OUT,
-                          connection=self.trans)
+                          store=self.store)
         self.failIf(payment.is_cancelled())
         payment.set_pending()
         self.failIf(payment.is_cancelled())
@@ -164,7 +178,7 @@ class TestPayment(DomainTest):
         self.failUnless(payment.is_cancelled())
 
     def testGetPaidDateString(self):
-        method = PaymentMethod.get_by_name(self.trans, 'check')
+        method = PaymentMethod.get_by_name(self.store, u'check')
         payment = Payment(value=currency(100),
                           branch=self.create_branch(),
                           due_date=datetime.datetime.now(),
@@ -173,15 +187,15 @@ class TestPayment(DomainTest):
                           till=None,
                           category=None,
                           payment_type=Payment.TYPE_OUT,
-                          connection=self.trans)
-        today = datetime.datetime.today().strftime('%x')
+                          store=self.store)
+        today = datetime.datetime.today().strftime(u'%x')
         self.failIf(payment.get_paid_date_string() == today)
         payment.set_pending()
         payment.pay()
         self.failUnless(payment.get_paid_date_string() == today)
 
     def testGetOpenDateString(self):
-        method = PaymentMethod.get_by_name(self.trans, 'check')
+        method = PaymentMethod.get_by_name(self.store, u'check')
         payment = Payment(value=currency(100),
                           branch=self.create_branch(),
                           due_date=datetime.datetime.now(),
@@ -190,11 +204,11 @@ class TestPayment(DomainTest):
                           till=None,
                           category=None,
                           payment_type=Payment.TYPE_OUT,
-                          connection=self.trans)
-        self.assertNotEqual(payment.get_open_date_string(), "")
+                          store=self.store)
+        self.assertNotEqual(payment.get_open_date_string(), u"")
 
     def testGetDaysLate(self):
-        method = PaymentMethod.get_by_name(self.trans, 'check')
+        method = PaymentMethod.get_by_name(self.store, u'check')
         open_date = due_date = self._get_relative_day(-4)
         payment = Payment(value=currency(100),
                           branch=self.create_branch(),
@@ -205,14 +219,14 @@ class TestPayment(DomainTest):
                           till=None,
                           category=None,
                           payment_type=Payment.TYPE_OUT,
-                          connection=self.trans)
+                          store=self.store)
         payment.set_pending()
         self.assertEqual(payment.get_days_late(), 4)
         payment.pay()
         self.assertEqual(payment.get_days_late(), 0)
 
     def testCancel(self):
-        method = PaymentMethod.get_by_name(self.trans, 'check')
+        method = PaymentMethod.get_by_name(self.store, u'check')
         payment = Payment(value=currency(100),
                           branch=self.create_branch(),
                           due_date=datetime.datetime.now(),
@@ -221,7 +235,7 @@ class TestPayment(DomainTest):
                           till=None,
                           category=None,
                           payment_type=Payment.TYPE_OUT,
-                          connection=self.trans)
+                          store=self.store)
         payment.set_pending()
         payment.pay()
         payment.cancel()
@@ -229,22 +243,58 @@ class TestPayment(DomainTest):
 
     def testCreateRepeatedMonth(self):
         p = self.create_payment()
-        p.description = 'Rent'
+        p.description = u'Rent'
         p.category = self.create_payment_category()
-        payments = Payment.create_repeated(self.trans, p,
+        payments = Payment.create_repeated(self.store, p,
                                            INTERVALTYPE_MONTH,
                                            datetime.date(2012, 1, 1),
                                            datetime.date(2012, 12, 31))
         self.assertEquals(len(payments), 11)
         self.assertEquals(p.due_date, datetime.datetime(2012, 1, 1))
-        self.assertEquals(p.description, '1/12 Rent')
+        self.assertEquals(p.description, u'1/12 Rent')
 
         self.assertEquals(payments[0].due_date, datetime.datetime(2012, 2, 1))
         self.assertEquals(payments[1].due_date, datetime.datetime(2012, 3, 1))
         self.assertEquals(payments[10].due_date, datetime.datetime(2012, 12, 1))
 
-        self.assertEquals(payments[0].description, '2/12 Rent')
-        self.assertEquals(payments[10].description, '12/12 Rent')
+        self.assertEquals(payments[0].description, u'2/12 Rent')
+        self.assertEquals(payments[10].description, u'12/12 Rent')
+
+    def test_set_not_paid(self):
+        sale = self.create_sale()
+        self.add_product(sale)
+        payment = self.add_payments(sale, method_type=u'check')[0]
+        sale.order()
+        sale.confirm()
+
+        account = self.create_account()
+        payment.method.destination_account = account
+
+        payment.pay()
+
+        self.assertEquals(
+            self.store.find(AccountTransaction, payment=payment).count(), 1)
+        self.assertEquals(account.transactions.count(), 1)
+        self.assertEquals(account.transactions.sum(AccountTransaction.value),
+                          payment.value)
+
+        entry = PaymentChangeHistory(payment=payment,
+                                     change_reason=u'foo',
+                                     store=self.store)
+        payment.set_not_paid(entry)
+
+        self.assertEquals(account.transactions.count(), 2)
+        self.assertEquals(account.transactions.sum(AccountTransaction.value), 0)
+        self.assertEquals(
+            self.store.find(AccountTransaction, payment=payment).count(), 0)
+
+        payment.pay()
+
+        self.assertEquals(
+            self.store.find(AccountTransaction, payment=payment).count(), 1)
+        self.assertEquals(account.transactions.count(), 3)
+        self.assertEquals(account.transactions.sum(AccountTransaction.value),
+                          payment.value)
 
 
 class TestPaymentComment(DomainTest):
@@ -252,7 +302,7 @@ class TestPaymentComment(DomainTest):
         payment = self.create_payment(Payment.TYPE_OUT)
         self.assertEqual(payment.comments_number, 0)
         user = self.create_user()
-        comment = PaymentComment(author=user, payment=payment, comment='',
-                                 connection=self.trans)
+        comment = PaymentComment(author=user, payment=payment, comment=u'',
+                                 store=self.store)
         self.assertEqual(payment.comments_number, 1)
-        self.assertEqual(payment.comments[0], comment)
+        self.assertEqual(list(payment.comments)[0], comment)
