@@ -30,11 +30,13 @@ from stoqlib.database.runtime import get_current_branch
 from stoqlib.domain.commission import CommissionSource, Commission
 from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.payment.payment import Payment
-from stoqlib.domain.product import Storable
+from stoqlib.domain.stockdecrease import StockDecrease
 from stoqlib.domain.sale import Sale
 from stoqlib.domain.test.domaintest import DomainTest
 from stoqlib.lib.parameters import sysparam
 
+StockDecrease # pyflakes
+
 
 class TestPaymentGroup(DomainTest):
 
@@ -50,17 +52,17 @@ class TestPaymentGroup(DomainTest):
         super(TestPaymentGroup, self).setUp()
 
     def _payComissionWhenConfirmed(self):
-        sysparam(self.trans).update_parameter(
-            "SALE_PAY_COMMISSION_WHEN_CONFIRMED",
-            "1")
+        sysparam(self.store).update_parameter(
+            u"SALE_PAY_COMMISSION_WHEN_CONFIRMED",
+            u"1")
         self.failUnless(
-            sysparam(self.trans).SALE_PAY_COMMISSION_WHEN_CONFIRMED)
+            sysparam(self.store).SALE_PAY_COMMISSION_WHEN_CONFIRMED)
 
     def testConfirm(self):
         branch = self.create_branch()
         group = self.create_payment_group()
 
-        method = PaymentMethod.get_by_name(self.trans, 'bill')
+        method = PaymentMethod.get_by_name(self.store, u'bill')
         payment1 = method.create_inpayment(group, branch, Decimal(10))
         payment2 = method.create_inpayment(group, branch, Decimal(10))
 
@@ -76,7 +78,7 @@ class TestPaymentGroup(DomainTest):
         branch = self.create_branch()
         group = self.create_payment_group()
 
-        method = PaymentMethod.get_by_name(self.trans, 'bill')
+        method = PaymentMethod.get_by_name(self.store, u'bill')
         payment1 = method.create_inpayment(group, branch, Decimal(10))
         payment2 = method.create_inpayment(group, branch, Decimal(10))
         group.confirm()
@@ -94,10 +96,10 @@ class TestPaymentGroup(DomainTest):
         branch = self.create_branch()
         group = self.create_payment_group()
 
-        method = PaymentMethod.get_by_name(self.trans, 'bill')
+        method = PaymentMethod.get_by_name(self.store, u'bill')
         payment1 = method.create_inpayment(group, branch, Decimal(10))
         payment2 = method.create_inpayment(group, branch, Decimal(10))
-        method = PaymentMethod.get_by_name(self.trans, 'money')
+        method = PaymentMethod.get_by_name(self.store, u'money')
         method.max_installments = 2
         payment3 = method.create_inpayment(group, branch, Decimal(10))
         payment4 = method.create_inpayment(group, branch, Decimal(10))
@@ -120,7 +122,7 @@ class TestPaymentGroup(DomainTest):
         branch = self.create_branch()
         group = self.create_payment_group()
 
-        method = PaymentMethod.get_by_name(self.trans, 'bill')
+        method = PaymentMethod.get_by_name(self.store, u'bill')
         payment1 = method.create_inpayment(group, branch, Decimal(10))
         payment2 = method.create_inpayment(group, branch, Decimal(10))
         payment3 = method.create_inpayment(group, branch, Decimal(10))
@@ -145,17 +147,17 @@ class TestPaymentGroup(DomainTest):
         CommissionSource(sellable=sellable,
                          direct_value=12,
                          installments_value=5,
-                         connection=self.trans)
+                         store=self.store)
 
-        method = PaymentMethod.get_by_name(self.trans, 'check')
+        method = PaymentMethod.get_by_name(self.store, u'check')
         method.create_inpayment(sale.group, sale.branch, Decimal(100))
         method.create_inpayment(sale.group, sale.branch, Decimal(200))
-        self.failIf(Commission.selectBy(sale=sale, connection=self.trans))
+        self.assertTrue(self.store.find(Commission, sale=sale).is_empty())
         sale.confirm()
-        self.failUnless(Commission.selectBy(sale=sale, connection=self.trans))
+        self.assertFalse(self.store.find(Commission, sale=sale).is_empty())
 
-        commissions = Commission.selectBy(sale=sale,
-                                          connection=self.trans).orderBy('value')
+        commissions = self.store.find(Commission,
+            sale=sale).order_by(Commission.value)
         self.assertEquals(commissions.count(), 2)
         for c in commissions:
             self.failUnless(c.commission_type == Commission.INSTALLMENTS)
@@ -177,19 +179,18 @@ class TestPaymentGroup(DomainTest):
         CommissionSource(sellable=sellable,
                          direct_value=12,
                          installments_value=5,
-                         connection=self.trans)
+                         store=self.store)
 
-        method = PaymentMethod.get_by_name(self.trans, 'check')
+        method = PaymentMethod.get_by_name(self.store, u'check')
         method.create_inpayment(sale.group, sale.branch, Decimal(300))
         method.create_inpayment(sale.group, sale.branch, Decimal(450))
         method.create_inpayment(sale.group, sale.branch, Decimal(150))
-        self.failIf(Commission.selectBy(sale=sale, connection=self.trans))
+        self.assertTrue(self.store.find(Commission, sale=sale).is_empty())
 
         sale.confirm()
 
-        commissions = Commission.selectBy(
-            sale=sale,
-            connection=self.trans).orderBy('value')
+        commissions = self.store.find(Commission,
+            sale=sale).order_by(Commission.value)
         self.assertEquals(commissions.count(), 3)
         for c in commissions:
             self.failUnless(c.commission_type == Commission.INSTALLMENTS)
@@ -205,8 +206,8 @@ class TestPaymentGroup(DomainTest):
         self.assertEquals(commissions[2].value, Decimal("22.50"))
 
     def testInstallmentsCommissionAmountWhenSaleReturn(self):
-        raise SkipTest("See stoqlib.domain.returnedsale.ReturnedSale.return_ "
-                       "and bug 5215.")
+        raise SkipTest(u"See stoqlib.domain.returnedsale.ReturnedSale.return_ "
+                       u"and bug 5215.")
 
         self._payComissionWhenConfirmed()
         sale = self.create_sale()
@@ -214,15 +215,15 @@ class TestPaymentGroup(DomainTest):
         CommissionSource(sellable=sellable,
                          direct_value=12,
                         installments_value=5,
-                         connection=self.trans)
+                         store=self.store)
 
         sale.add_sellable(sellable, quantity=3, price=300)
         product = sellable.product
-        storable = Storable(product=product, connection=self.trans)
-        storable.increase_stock(100, get_current_branch(self.trans))
+        branch = get_current_branch(self.store)
+        self.create_storable(product, branch, 100)
 
         sale.order()
-        method = PaymentMethod.get_by_name(self.trans, 'check')
+        method = PaymentMethod.get_by_name(self.store, u'check')
         payment1 = method.create_inpayment(sale.group, sale.branch, Decimal(300))
         payment2 = method.create_inpayment(sale.group, sale.branch, Decimal(450))
         payment3 = method.create_inpayment(sale.group, sale.branch, Decimal(150))
@@ -237,15 +238,14 @@ class TestPaymentGroup(DomainTest):
         returned_sale.return_()
         self.assertEqual(sale.status, Sale.STATUS_RETURNED)
 
-        commissions = Commission.selectBy(sale=sale,
-                                          connection=self.trans)
+        commissions = self.store.find(Commission, sale=sale)
         value = sum([c.value for c in commissions])
         self.assertEqual(value, Decimal(0))
         self.assertEqual(commissions.count(), 4)
         self.failIf(commissions[-1].value >= 0)
 
     def testGetTotalValue(self):
-        method = PaymentMethod.get_by_name(self.trans, 'check')
+        method = PaymentMethod.get_by_name(self.store, u'check')
 
         # Test for a group in a sale
         # On sale's group, total value should return
@@ -280,7 +280,7 @@ class TestPaymentGroup(DomainTest):
         self.assertEqual(group.get_total_value(), Decimal(250))
 
     def testGetTotalDiscount(self):
-        method = PaymentMethod.get_by_name(self.trans, 'check')
+        method = PaymentMethod.get_by_name(self.store, u'check')
 
         # Test for a group in a sale
         # On sale's group, total value should return
@@ -321,7 +321,7 @@ class TestPaymentGroup(DomainTest):
         self.assertEqual(group.get_total_discount(), Decimal(20))
 
     def testGetTotalInterest(self):
-        method = PaymentMethod.get_by_name(self.trans, 'check')
+        method = PaymentMethod.get_by_name(self.store, u'check')
 
         # Test for a group in a sale
         # On sale's group, total value should return
@@ -362,7 +362,7 @@ class TestPaymentGroup(DomainTest):
         self.assertEqual(group.get_total_interest(), Decimal(20))
 
     def testGetTotalPenalty(self):
-        method = PaymentMethod.get_by_name(self.trans, 'check')
+        method = PaymentMethod.get_by_name(self.store, u'check')
 
         # Test for a group in a sale
         # On sale's group, total value should return
@@ -405,26 +405,57 @@ class TestPaymentGroup(DomainTest):
     def testGetPaymentByMethodName(self):
         group = self.create_payment_group()
 
-        method = PaymentMethod.get_by_name(self.trans, 'money')
+        method = PaymentMethod.get_by_name(self.store, u'money')
         money_payment1 = self.create_payment(method=method)
         group.add_item(money_payment1)
         money_payment2 = self.create_payment(method=method)
         group.add_item(money_payment2)
 
-        method = PaymentMethod.get_by_name(self.trans, 'check')
+        method = PaymentMethod.get_by_name(self.store, u'check')
         check_payment1 = self.create_payment(method=method)
         group.add_item(check_payment1)
         check_payment2 = self.create_payment(method=method)
         group.add_item(check_payment2)
 
-        money_payments = group.get_payments_by_method_name('money')
+        money_payments = group.get_payments_by_method_name(u'money')
         for payment in [money_payment1, money_payment2]:
             self.assertTrue(payment in money_payments)
         for payment in [check_payment1, check_payment2]:
             self.assertFalse(payment in money_payments)
 
-        check_payments = group.get_payments_by_method_name('check')
+        check_payments = group.get_payments_by_method_name(u'check')
         for payment in [check_payment1, check_payment2]:
             self.assertTrue(payment in check_payments)
         for payment in [money_payment1, money_payment2]:
             self.assertFalse(payment in check_payments)
+
+    def test_get_parent(self):
+        sale = self.create_sale()
+        purchase = self.create_purchase_order()
+        renegotiation = self.create_payment_renegotiation()
+        group = self.create_payment_group()
+        decrease = self.create_stock_decrease(group=group)
+
+        self.assertEquals(sale, sale.group.get_parent())
+        self.assertEquals(purchase, purchase.group.get_parent())
+        self.assertEquals(renegotiation, renegotiation.group.get_parent())
+        self.assertEquals(decrease, decrease.group.get_parent())
+
+    def test_get_description(self):
+        sale = self.create_sale()
+        purchase = self.create_purchase_order()
+        renegotiation = self.create_payment_renegotiation()
+        group = self.create_payment_group()
+        decrease = self.create_stock_decrease(group=group)
+
+        sale.identifier = 77777
+        purchase.identifier = 88888
+        renegotiation.identifier = 99999
+        decrease.identifier = 12345
+
+        self.assertEquals(sale.group.get_description(), u'sale 77777')
+        self.assertEquals(purchase.group.get_description(), u'order 88888')
+        self.assertEquals(renegotiation.group.get_description(),
+                          u'renegotiation 99999')
+        self.assertEquals(decrease.group.get_description(),
+                          u'stock decrease 12345')
