@@ -26,12 +26,14 @@
 import datetime
 from dateutil.relativedelta import relativedelta
 from decimal import Decimal
+from storm.exceptions import NotOneError
+from storm.expr import And
 from storm.store import AutoReload
 
 from kiwi.currency import currency
 
-from stoqlib.database.orm import ORMObjectIntegrityError, AND
-from stoqlib.domain.person import Calls, Liaison
+from stoqlib.database.expr import Age, Case, Date, DateTrunc, Interval
+from stoqlib.domain.person import Calls, ContactInfo
 from stoqlib.domain.address import Address, CityLocation
 from stoqlib.domain.exampledata import ExampleCreator
 from stoqlib.domain.fiscal import CfopData
@@ -39,7 +41,7 @@ from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.person import (Branch, Client, ClientCategory,
                                    ClientSalaryHistory, Company,
-                                   CreditProvider, Employee, EmployeeRole,
+                                   Employee, EmployeeRole,
                                    EmployeeRoleHistory, Individual,
                                    LoginUser, Person, SalesPerson, Supplier,
                                    Transporter)
@@ -58,19 +60,19 @@ _ = stoqlib_gettext
 
 class TestEmployeeRoleHistory(DomainTest):
     def testCreate(self):
-        EmployeeRole(connection=self.trans, name='ajudante')
+        EmployeeRole(store=self.store, name=u'ajudante')
 
     def testHasRole(self):
-        role = EmployeeRole(connection=self.trans, name='role')
+        role = EmployeeRole(store=self.store, name=u'role')
         self.failIf(role.has_other_role(u'Role'))
-        role = EmployeeRole(connection=self.trans, name='Role')
+        role = EmployeeRole(store=self.store, name=u'Role')
         self.failUnless(role.has_other_role(u'role'))
 
 
 class TestEmployeeRole(DomainTest):
     def testGetdescription(self):
         role = self.create_employee_role()
-        role.name = 'manager'
+        role.name = u'manager'
         self.assertEquals(role.name, role.get_description())
 
 
@@ -79,61 +81,61 @@ class TestPerson(DomainTest):
     def testAddresses(self):
         person = self.create_person()
         assert not person.get_main_address()
-        ctlocs = CityLocation.select(connection=self.trans)
-        assert ctlocs
+        ctlocs = self.store.find(CityLocation)
+        assert not ctlocs.is_empty()
         ctloc = ctlocs[0]
-        address = Address(connection=self.trans, person=person,
+        address = Address(store=self.store, person=person,
                           city_location=ctloc, is_main_address=True)
         self.assertEquals(person.get_main_address(), address)
 
         self.assertEquals(len(list(person.addresses)), 1)
-        self.assertEquals(person.addresses[0], address)
+        self.assertEquals(list(person.addresses)[0], address)
 
     def testCalls(self):
         person = self.create_person()
         user = self.create_user()
         self.assertEquals(len(list(person.calls)), 0)
 
-        call = Calls(connection=self.trans, date=datetime.datetime.today(),
-                     description='', message='', person=person, attendant=user)
+        call = Calls(store=self.store, date=datetime.datetime.today(),
+                     description=u'', message=u'', person=person, attendant=user)
         self.assertEquals(len(list(person.calls)), 1)
-        self.assertEquals(person.calls[0], call)
+        self.assertEquals(list(person.calls)[0], call)
 
-    def testLiaison(self):
+    def testContactInfo(self):
         person = self.create_person()
-        self.assertEquals(len(list(person.liaisons)), 0)
+        self.assertEquals(len(list(person.contact_infos)), 0)
 
-        contact = Liaison(connection=self.trans, person=person)
-        self.assertEquals(len(list(person.liaisons)), 1)
-        self.assertEquals(person.liaisons[0], contact)
+        contact_info = ContactInfo(store=self.store, person=person)
+        self.assertEquals(len(list(person.contact_infos)), 1)
+        self.assertEquals(list(person.contact_infos)[0], contact_info)
 
     def testGetaddressString(self):
         person = self.create_person()
-        ctloc = CityLocation(connection=self.trans)
-        address = Address(connection=self.trans, person=person,
-                          city_location=ctloc, street='bla', streetnumber=2,
-                          district='fed', is_main_address=True)
+        ctloc = CityLocation(store=self.store)
+        address = Address(store=self.store, person=person,
+                          city_location=ctloc, street=u'bla', streetnumber=2,
+                          district=u'fed', is_main_address=True)
         self.assertEquals(person.get_address_string(), _(u'%s %s, %s') % (
             address.street, address.streetnumber, address.district))
 
     def testGetMobileNumberNumber(self):
         person = self.create_person()
-        person.mobile_number = '0321-12345'
-        self.assertEquals(person.mobile_number, '032112345')
+        person.mobile_number = u'0321-12345'
+        self.assertEquals(person.mobile_number, u'032112345')
 
     def testGetPhoneNumberNumber(self):
         person = self.create_person()
-        person.phone_number = '0321-12345'
+        person.phone_number = u'0321-12345'
         self.assertEquals(person.get_phone_number_number(), 32112345)
-        self.assertEquals(person.phone_number, '032112345')
+        self.assertEquals(person.phone_number, u'032112345')
 
         person.phone_number = None
         self.assertEquals(person.get_phone_number_number(), 0)
 
     def testGetFaxNumberNumber(self):
         person = self.create_person()
-        person.fax_number = '0321-12345'
-        self.assertEquals(person.fax_number, '032112345')
+        person.fax_number = u'0321-12345'
+        self.assertEquals(person.fax_number, u'032112345')
         self.assertEquals(person.get_fax_number_number(), 32112345)
 
         person.fax_number = None
@@ -141,26 +143,41 @@ class TestPerson(DomainTest):
 
     def testGetFormattedPhoneNumber(self):
         person = self.create_person()
-        self.assertEquals(person.get_formatted_phone_number(), "")
-        phone = '0321-1234'
+        self.assertEquals(person.get_formatted_phone_number(), u"")
+        phone = u'0321-1234'
         person.phone_number = phone
         self.assertEquals(person.get_formatted_phone_number(),
                           phone)
 
     def testGetFormattedFaxNumber(self):
         person = self.create_person()
-        self.assertEquals(person.get_formatted_fax_number(), "")
-        fax = '0321-1234'
+        self.assertEquals(person.get_formatted_fax_number(), u"")
+        fax = u'0321-1234'
         person.fax_number = fax
         self.assertEquals(person.get_formatted_fax_number(),
                           fax)
 
+    def testGetByPhoneNumber(self):
+        person = self.create_person()
+
+        self.assertTrue(Person.get_by_phone_number(
+            self.store, u'1138').is_empty())
+        person.phone_number = u'1138'
+        self.assertFalse(Person.get_by_phone_number(
+            self.store, u'1138').is_empty())
+        person.phone_number = u'0'
+        self.assertTrue(Person.get_by_phone_number(
+            self.store, u'1138').is_empty())
+        person.mobile_number = u'1138'
+        self.assertFalse(Person.get_by_phone_number(
+            self.store, u'1138').is_empty())
+
 
 class _PersonFacetTest(object):
     facet = None
 
     def _create_person_facet(self):
-        return ExampleCreator.create(self.trans, self.facet.__name__)
+        return ExampleCreator.create(self.store, self.facet.__name__)
 
     def testInactivate(self):
         facet = self._create_person_facet()
@@ -187,7 +204,7 @@ class TestIndividual(_PersonFacetTest, DomainTest):
 
     def testIndividual(self):
         person = self.create_person()
-        individual = Individual(person=person, connection=self.trans)
+        individual = Individual(person=person, store=self.store)
 
         statuses = individual.get_marital_statuses()
         self.assertEqual(type(statuses), list)
@@ -198,18 +215,92 @@ class TestIndividual(_PersonFacetTest, DomainTest):
 
     def testGetCPFNumber(self):
         individual = self.create_individual()
-        individual.cpf = ''
+        individual.cpf = u''
         self.assertEquals(individual.get_cpf_number(), 0)
-        individual.cpf = '123.456.789-203'
+        individual.cpf = u'123.456.789-203'
         self.assertEquals(individual.get_cpf_number(), 123456789203)
 
+    def testGetBirthdayDateQuery(self):
+        start = datetime.datetime(2000, 3, 4)
+
+        query = Individual.get_birthday_query(start)
+
+        start_year = DateTrunc(u'year', Date(start))
+        age_in_year = Age(Individual.birth_date,
+                          DateTrunc(u'year', Individual.birth_date))
+        test_query = (
+            start_year + age_in_year +
+            Case(condition=age_in_year < Age(Date(start), start_year),
+                 result=Interval(u'1 year'),
+                 else_=Interval(u'0 year'))
+        )
+        test_query = (test_query == Date(start))
+
+        self.assertEquals(query, test_query)
+
+        individuals = list(self.store.find(Individual, test_query))
+        self.assertEquals(len(individuals), 0)
+
+        client1 = self.create_client(u'Junio C. Hamano')
+        client1.person.individual.birth_date = datetime.date(1972, 10, 15)
+        client2 = self.create_client(u'Richard Stallman')
+        client2.person.individual.birth_date = datetime.date(1989, 3, 4)
+        client3 = self.create_client(u'Linus Torvalds')
+        client3.person.individual.birth_date = datetime.date(2000, 3, 4)
+        client4 = self.create_client(u'Guido van Rossum')
+        client4.person.individual.birth_date = datetime.date(2005, 3, 4)
+
+        individuals = list(self.store.find(Individual, test_query))
+        self.assertEquals(len(individuals), 3)
+        self.assertTrue(client2.person.individual in individuals)
+        self.assertTrue(client3.person.individual in individuals)
+        self.assertTrue(client4.person.individual in individuals)
+
+    def testGetBirthdayIntervalQuery(self):
+        start = datetime.datetime(2000, 3, 1)
+        end = datetime.datetime(2000, 3, 25)
+
+        query = Individual.get_birthday_query(start, end)
+
+        start_year = DateTrunc(u'year', Date(start))
+        age_in_year = Age(Individual.birth_date,
+                          DateTrunc(u'year', Individual.birth_date))
+        test_query = (
+            start_year + age_in_year +
+            Case(condition=age_in_year < Age(Date(start), start_year),
+                 result=Interval(u'1 year'),
+                 else_=Interval(u'0 year'))
+        )
+        test_query = And(test_query >= Date(start),
+                         test_query <= Date(end))
+
+        self.assertEquals(query, test_query)
+
+        individuals = list(self.store.find(Individual, test_query))
+        self.assertEquals(len(individuals), 0)
+
+        client1 = self.create_client(u'Junio C. Hamano')
+        client1.person.individual.birth_date = datetime.date(1972, 10, 15)
+        client2 = self.create_client(u'Richard Stallman')
+        client2.person.individual.birth_date = datetime.date(1989, 3, 7)
+        client3 = self.create_client(u'Linus Torvalds')
+        client3.person.individual.birth_date = datetime.date(2000, 3, 4)
+        client4 = self.create_client(u'Guido van Rossum')
+        client4.person.individual.birth_date = datetime.date(2005, 3, 20)
+
+        individuals = list(self.store.find(Individual, test_query))
+        self.assertEquals(len(individuals), 3)
+        self.assertTrue(client2.person.individual in individuals)
+        self.assertTrue(client3.person.individual in individuals)
+        self.assertTrue(client4.person.individual in individuals)
+
 
 class TestCompany(_PersonFacetTest, DomainTest):
     facet = Company
 
     def testGetCnpjNumberNumber(self):
         company = self.create_company()
-        company.cnpj = '111.222.333.444'
+        company.cnpj = u'111.222.333.444'
         self.assertEquals(company.get_cnpj_number(), 111222333444)
 
 
@@ -229,67 +320,64 @@ class TestClient(_PersonFacetTest, DomainTest):
 
     def testGetactiveClients(self):
         table = Client
-        active_clients = table.get_active_clients(self.trans).count()
+        active_clients = table.get_active_clients(self.store).count()
         client = self.create_client()
         client.status = table.STATUS_SOLVENT
-        one_more_active_client = table.get_active_clients(self.trans).count()
+        one_more_active_client = table.get_active_clients(self.store).count()
         self.assertEquals(active_clients + 1, one_more_active_client)
 
     def testGetclient_sales(self):
-        client = Client.select(connection=self.trans)
-        assert client
+        client = self.store.find(Client)
+        assert not client.is_empty()
         client = client[0]
-        CfopData(code='123', description='bla', connection=self.trans)
-        branches = Branch.select(connection=self.trans)
-        assert branches
-        people = SalesPerson.select(connection=self.trans)
-        assert people
+        CfopData(code=u'123', description=u'bla', store=self.store)
+        branches = self.store.find(Branch)
+        assert not branches.is_empty()
+        people = self.store.find(SalesPerson)
+        assert not people.is_empty()
         count_sales = client.get_client_sales().count()
         sale = self.create_sale()
         sale.client = client
-        products = Product.select(connection=self.trans)
-        assert products
+        products = self.store.find(Product)
+        assert not products.is_empty()
         product = products[0]
         sale.add_sellable(product.sellable)
         one_more_sale = client.get_client_sales().count()
         self.assertEquals(count_sales + 1, one_more_sale)
 
     def testClientCategory(self):
-        categories = ClientCategory.selectBy(name='Category',
-                                             connection=self.trans)
+        categories = self.store.find(ClientCategory, name=u'Category')
         self.assertEquals(categories.count(), 0)
 
-        category = self.create_client_category('Category')
-        categories = ClientCategory.selectBy(name='Category',
-                                             connection=self.trans)
+        category = self.create_client_category(u'Category')
+        categories = self.store.find(ClientCategory, name=u'Category')
         self.assertEquals(categories.count(), 1)
 
         self.assertTrue(category.can_remove())
         category.remove()
-        categories = ClientCategory.selectBy(name='Category',
-                                             connection=self.trans)
+        categories = self.store.find(ClientCategory, name=u'Category')
         self.assertEquals(categories.count(), 0)
 
         sellable = self.create_sellable(price=50)
-        category = self.create_client_category('Category')
+        category = self.create_client_category(u'Category')
         ClientCategoryPrice(sellable=sellable,
                             category=category,
                             price=75,
-                            connection=self.trans)
+                            store=self.store)
         self.assertFalse(category.can_remove())
 
     def test_can_purchase_allow_all(self):
         #: This parameter always allows the client to purchase, no matter if he
         #: has late payments
-        sysparam(self.trans).update_parameter('LATE_PAYMENTS_POLICY',
-                                str(int(LatePaymentPolicy.ALLOW_SALES)))
+        sysparam(self.store).update_parameter(u'LATE_PAYMENTS_POLICY',
+                                unicode(int(LatePaymentPolicy.ALLOW_SALES)))
 
         client = self.create_client()
-        bill_method = PaymentMethod.get_by_name(self.trans, 'bill')
-        check_method = PaymentMethod.get_by_name(self.trans, 'check')
-        money_method = PaymentMethod.get_by_name(self.trans, 'money')
-        store_credit_method = PaymentMethod.get_by_name(self.trans,
-                                                        'store_credit')
+        bill_method = PaymentMethod.get_by_name(self.store, u'bill')
+        check_method = PaymentMethod.get_by_name(self.store, u'check')
+        money_method = PaymentMethod.get_by_name(self.store, u'money')
+        store_credit_method = PaymentMethod.get_by_name(self.store,
+                                                        u'store_credit')
         today = datetime.date.today()
 
         # client can pay if he doesn't have any payments
@@ -315,15 +403,15 @@ class TestClient(_PersonFacetTest, DomainTest):
     def test_can_purchase_disallow_store_credit(self):
         #: This parameter disallows the client to purchase with store credit
         #: when he has late payments
-        sysparam(self.trans).update_parameter('LATE_PAYMENTS_POLICY',
-                                str(int(LatePaymentPolicy.DISALLOW_STORE_CREDIT)))
+        sysparam(self.store).update_parameter(u'LATE_PAYMENTS_POLICY',
+                                unicode(int(LatePaymentPolicy.DISALLOW_STORE_CREDIT)))
 
         client = self.create_client()
-        bill_method = PaymentMethod.get_by_name(self.trans, 'bill')
-        check_method = PaymentMethod.get_by_name(self.trans, 'check')
-        money_method = PaymentMethod.get_by_name(self.trans, 'money')
-        store_credit_method = PaymentMethod.get_by_name(self.trans,
-                                                        'store_credit')
+        bill_method = PaymentMethod.get_by_name(self.store, u'bill')
+        check_method = PaymentMethod.get_by_name(self.store, u'check')
+        money_method = PaymentMethod.get_by_name(self.store, u'money')
+        store_credit_method = PaymentMethod.get_by_name(self.store,
+                                                        u'store_credit')
         today = datetime.date.today()
 
         # client can pay if he doesn't have any payments
@@ -351,15 +439,15 @@ class TestClient(_PersonFacetTest, DomainTest):
     def test_can_purchase_disallow_all(self):
         #: This parameter disallows the client to purchase with store credit
         #: when he has late payments
-        sysparam(self.trans).update_parameter('LATE_PAYMENTS_POLICY',
-                                str(int(LatePaymentPolicy.DISALLOW_SALES)))
+        sysparam(self.store).update_parameter(u'LATE_PAYMENTS_POLICY',
+                                unicode(int(LatePaymentPolicy.DISALLOW_SALES)))
 
         client = self.create_client()
-        bill_method = PaymentMethod.get_by_name(self.trans, 'bill')
-        check_method = PaymentMethod.get_by_name(self.trans, 'check')
-        money_method = PaymentMethod.get_by_name(self.trans, 'money')
-        store_credit_method = PaymentMethod.get_by_name(self.trans,
-                                                        'store_credit')
+        bill_method = PaymentMethod.get_by_name(self.store, u'bill')
+        check_method = PaymentMethod.get_by_name(self.store, u'check')
+        money_method = PaymentMethod.get_by_name(self.store, u'money')
+        store_credit_method = PaymentMethod.get_by_name(self.store,
+                                                        u'store_credit')
         today = datetime.date.today()
 
         # client can pay if he doesn't have any payments
@@ -386,7 +474,7 @@ class TestClient(_PersonFacetTest, DomainTest):
                                      currency("0"))
 
     def test_can_purchase_total_amount(self):
-        method = PaymentMethod.get_by_name(self.trans, 'store_credit')
+        method = PaymentMethod.get_by_name(self.store, u'store_credit')
 
         # client can not buy if he does not have enough store credit
         client = self.create_client()
@@ -404,24 +492,24 @@ class TestClient(_PersonFacetTest, DomainTest):
 
         # just setting paramater to a value that won't interfere in
         # the tests
-        sysparam(self.trans).update_parameter(
-            "CREDIT_LIMIT_SALARY_PERCENT",
-            "5")
+        sysparam(self.store).update_parameter(
+            u"CREDIT_LIMIT_SALARY_PERCENT",
+            u"5")
 
         # testing if updates
-        Client.update_credit_limit(10, self.trans)
+        Client.update_credit_limit(10, self.store)
         client.credit_limit = AutoReload
         self.assertEquals(client.credit_limit, 10)
 
         # testing if it does not update
         client.credit_limit = 200
-        Client.update_credit_limit(0, self.trans)
+        Client.update_credit_limit(0, self.store)
         self.assertEquals(client.credit_limit, 200)
 
     def test_set_salary(self):
-        sysparam(self.trans).update_parameter(
-            "CREDIT_LIMIT_SALARY_PERCENT",
-            "10")
+        sysparam(self.store).update_parameter(
+            u"CREDIT_LIMIT_SALARY_PERCENT",
+            u"10")
 
         client = self.create_client()
 
@@ -433,9 +521,9 @@ class TestClient(_PersonFacetTest, DomainTest):
         self.assertEquals(client.salary, 100)
         self.assertEquals(client.credit_limit, 10)
 
-        sysparam(self.trans).update_parameter(
-            "CREDIT_LIMIT_SALARY_PERCENT",
-            "0")
+        sysparam(self.store).update_parameter(
+            u"CREDIT_LIMIT_SALARY_PERCENT",
+            u"0")
         client.credit_limit = 100
         client.salary = 200
 
@@ -447,21 +535,21 @@ class TestSupplier(_PersonFacetTest, DomainTest):
     facet = Supplier
 
     def testGetActiveSuppliers(self):
-        for supplier in Supplier.get_active_suppliers(self.trans):
+        for supplier in Supplier.get_active_suppliers(self.store):
             self.assertEquals(supplier.status,
                               Supplier.STATUS_ACTIVE)
 
     def testGetAllSuppliers(self):
-        query = AND(Person.q.name == "test",
-                    Supplier.q.person_id == Person.q.id)
+        query = And(Person.name == u"test",
+                    Supplier.person_id == Person.id)
 
-        suppliers = Person.select(query, connection=self.trans)
+        suppliers = self.store.find(Person, query)
         self.assertEqual(suppliers.count(), 0)
 
         supplier = self.create_supplier()
-        supplier.person.name = "test"
+        supplier.person.name = u"test"
 
-        suppliers = Person.select(query, connection=self.trans)
+        suppliers = self.store.find(Person, query)
         self.assertEqual(suppliers.count(), 1)
 
     def testGetSupplierPurchase(self):
@@ -490,13 +578,13 @@ class TestEmployee(_PersonFacetTest, DomainTest):
         employee = self.create_employee()
         EmployeeRoleHistory(role=employee.role,
                             employee=employee,
-                            connection=self.trans,
+                            store=self.store,
                             salary=currency(500),
                             is_active=False)
         old_count = employee.get_role_history().count()
         EmployeeRoleHistory(role=employee.role,
                             employee=employee,
-                            connection=self.trans,
+                            store=self.store,
                             salary=currency(900))
         new_count = employee.get_role_history().count()
         self.assertEquals(old_count + 1, new_count)
@@ -507,14 +595,13 @@ class TestEmployee(_PersonFacetTest, DomainTest):
         #creating 2 active role history, asserting it fails
         EmployeeRoleHistory(role=employee.role,
                             employee=employee,
-                            connection=self.trans,
+                            store=self.store,
                             salary=currency(230))
         EmployeeRoleHistory(role=employee.role,
                             employee=employee,
-                            connection=self.trans,
+                            store=self.store,
                             salary=currency(320))
-        self.assertRaises(ORMObjectIntegrityError,
-                          employee.get_active_role_history)
+        self.assertRaises(NotOneError, employee.get_active_role_history)
 
         #now with one employeerolehistory
         #FIXME: this breaks in buildbot, figure out why.
@@ -526,8 +613,8 @@ class TestUser(_PersonFacetTest, DomainTest):
     facet = LoginUser
 
     def testGetstatusStr(self):
-        users = LoginUser.select(connection=self.trans)
-        assert users
+        users = self.store.find(LoginUser)
+        assert not users.is_empty()
         user = users[0]
         user.is_active = False
         string = user.get_status_string()
@@ -538,8 +625,8 @@ class TestBranch(_PersonFacetTest, DomainTest):
     facet = Branch
 
     def testGetstatusStr(self):
-        branches = Branch.select(connection=self.trans)
-        assert branches
+        branches = self.store.find(Branch)
+        assert not branches.is_empty()
         branch = branches[0]
         branch.is_active = False
         string = branch.get_status_string()
@@ -547,43 +634,33 @@ class TestBranch(_PersonFacetTest, DomainTest):
 
     def testGetactiveBranches(self):
         person = self.create_person()
-        Company(person=person, connection=self.trans)
-        count = Branch.get_active_branches(self.trans).count()
+        Company(person=person, store=self.store)
+        count = Branch.get_active_branches(self.store).count()
         manager = self.create_employee()
-        branch = Branch(person=person, connection=self.trans,
+        branch = Branch(person=person, store=self.store,
                         manager=manager, is_active=True)
-        assert branch.get_active_branches(self.trans).count() == count + 1
+        assert branch.get_active_branches(self.store).count() == count + 1
 
     def test_is_from_same_company(self):
         branch1 = self.create_branch()
-        branch1.person.company.cnpj = '111.222.333/0001-11'
+        branch1.person.company.cnpj = u'111.222.333/0001-11'
 
         branch2 = self.create_branch()
-        branch2.person.company.cnpj = '555.666.777/0001-11'
+        branch2.person.company.cnpj = u'555.666.777/0001-11'
         self.assertFalse(branch1.is_from_same_company(branch2))
 
-        branch2.person.company.cnpj = '111.222.333/0002-22'
+        branch2.person.company.cnpj = u'111.222.333/0002-22'
         self.assertTrue(branch1.is_from_same_company(branch2))
 
 
-class TestCreditProvider(_PersonFacetTest, DomainTest):
-    facet = CreditProvider
-
-    def testGetCardProviders(self):
-        count = CreditProvider.get_card_providers(self.trans).count()
-        facet = self._create_person_facet()
-        self.assertEqual(facet.get_card_providers(self.trans).count(),
-                         count + 1)
-
-
 class SalesPersonTest(_PersonFacetTest, DomainTest):
 
     facet = SalesPerson
 
     def testGetactiveSalespersons(self):
-        count = SalesPerson.get_active_salespersons(self.trans).count()
+        count = SalesPerson.get_active_salespersons(self.store).count()
         salesperson = self.create_sales_person()
-        one_more = salesperson.get_active_salespersons(self.trans).count()
+        one_more = salesperson.get_active_salespersons(self.store).count()
         assert count + 1 == one_more
 
     def testGetStatusString(self):
@@ -602,9 +679,9 @@ class TransporterTest(_PersonFacetTest, DomainTest):
         self.assertEquals(string, _(u'Active'))
 
     def testGetActiveTransporters(self):
-        count = Transporter.get_active_transporters(self.trans).count()
+        count = Transporter.get_active_transporters(self.store).count()
         transporter = self.create_transporter()
-        one_more = transporter.get_active_transporters(self.trans).count()
+        one_more = transporter.get_active_transporters(self.store).count()
         self.assertEqual(count + 1, one_more)
 
 
@@ -614,9 +691,9 @@ class TestClientSalaryHistory(DomainTest):
         user = self.create_user()
 
         client.salary = 20
-        ClientSalaryHistory.add(self.trans, 10, client, user)
-        salary_histories = ClientSalaryHistory.select(connection=self.trans)
-        last_salary_history = salary_histories[-1]
+        ClientSalaryHistory.add(self.store, 10, client, user)
+        salary_histories = self.store.find(ClientSalaryHistory)
+        last_salary_history = salary_histories.order_by(ClientSalaryHistory.id).last()
 
         self.assertEquals(last_salary_history.client, client)
         self.assertEquals(last_salary_history.new_salary, 20)
