@@ -28,14 +28,15 @@ import datetime
 
 # Import domaintest first so that externals is setup properly
 from stoqlib.domain.test.domaintest import DomainTest
-from stoqlib.database.runtime import get_current_branch, new_transaction
+from stoqlib.database.runtime import get_current_branch, new_store
 from stoqlib.domain.events import (ProductCreateEvent, ProductEditEvent,
                                    ProductRemoveEvent)
 from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.product import (ProductSupplierInfo, Product,
                                     ProductHistory, ProductComponent,
-                                    ProductQualityTest, Storable)
-from stoqlib.domain.production import (ProductionProducedItem,
+                                    ProductQualityTest, Storable,
+                                    StockTransactionHistory)
+from stoqlib.domain.production import (ProductionOrder, ProductionProducedItem,
                                        ProductionItemQualityResult)
 from stoqlib.domain.purchase import PurchaseOrder
 from stoqlib.domain.sellable import Sellable
@@ -46,7 +47,7 @@ class TestProductSupplierInfo(DomainTest):
     def testGetName(self):
         product = self.create_product()
         supplier = self.create_supplier()
-        info = ProductSupplierInfo(connection=self.trans,
+        info = ProductSupplierInfo(store=self.store,
                                    product=product,
                                    supplier=supplier)
         self.assertEqual(info.get_name(), supplier.get_description())
@@ -54,7 +55,7 @@ class TestProductSupplierInfo(DomainTest):
     def testDefaultLeadTimeValue(self):
         product = self.create_product()
         supplier = self.create_supplier()
-        info = ProductSupplierInfo(connection=self.trans,
+        info = ProductSupplierInfo(store=self.store,
                                    product=product,
                                    supplier=supplier)
         default_lead_time = 1
@@ -95,12 +96,12 @@ class TestProduct(DomainTest):
         DomainTest.setUp(self)
         sellable = self.create_sellable()
         self.product = Product(sellable=sellable,
-                               connection=self.trans)
+                               store=self.store)
 
     def test_get_main_supplier_info(self):
         self.failIf(self.product.get_main_supplier_info())
         supplier = self.create_supplier()
-        ProductSupplierInfo(connection=self.trans, supplier=supplier,
+        ProductSupplierInfo(store=self.store, supplier=supplier,
                             product=self.product, is_main_supplier=True)
         self.failUnless(self.product.get_main_supplier_info())
 
@@ -112,7 +113,7 @@ class TestProduct(DomainTest):
             component = self.create_product()
             product_component = ProductComponent(product=self.product,
                                                  component=component,
-                                                 connection=self.trans)
+                                                 store=self.store)
             components.append(product_component)
         self.assertEqual(list(self.product.get_components()),
                         components)
@@ -123,7 +124,7 @@ class TestProduct(DomainTest):
         component = self.create_product()
         ProductComponent(product=self.product,
                          component=component,
-                         connection=self.trans)
+                         store=self.store)
         self.assertTrue(self.product.has_components())
 
     def testGetProductionCost(self):
@@ -138,18 +139,18 @@ class TestProduct(DomainTest):
         self.assertEqual(self.product.is_composed_by(component), False)
 
         ProductComponent(product=self.product, component=component,
-                         connection=self.trans)
+                         store=self.store)
         self.assertEqual(self.product.is_composed_by(component), True)
 
         component2 = self.create_product()
         ProductComponent(product=component, component=component2,
-                         connection=self.trans)
+                         store=self.store)
         self.assertEqual(self.product.is_composed_by(component2), True)
         self.assertEqual(component.is_composed_by(component2), True)
 
         component3 = self.create_product()
         ProductComponent(product=self.product, component=component3,
-                         connection=self.trans)
+                         store=self.store)
         self.assertEqual(self.product.is_composed_by(component3), True)
         self.assertEqual(component.is_composed_by(component3), False)
         self.assertEqual(component2.is_composed_by(component3), False)
@@ -158,7 +159,7 @@ class TestProduct(DomainTest):
         product = self.create_product()
         supplier = self.create_supplier()
 
-        info = ProductSupplierInfo(connection=self.trans,
+        info = ProductSupplierInfo(store=self.store,
                                    product=product,
                                    supplier=supplier)
 
@@ -176,17 +177,17 @@ class TestProduct(DomainTest):
 
     def testCanRemove(self):
         product = self.create_product()
-        storable = Storable(product=product, connection=self.trans)
+        storable = Storable(product=product, store=self.store)
         self.assertTrue(product.can_remove())
 
-        storable.increase_stock(1, get_current_branch(self.trans))
+        storable.increase_stock(1, get_current_branch(self.store), 0, 0)
         self.assertFalse(product.can_remove())
 
         # Product was sold.
         sale = self.create_sale()
         sale.add_sellable(product.sellable, quantity=1, price=10)
 
-        method = PaymentMethod.get_by_name(self.trans, 'money')
+        method = PaymentMethod.get_by_name(self.store, u'money')
         method.create_inpayment(sale.group, sale.branch, sale.get_sale_subtotal())
 
         sale.order()
@@ -198,79 +199,78 @@ class TestProduct(DomainTest):
         from stoqlib.domain.product import ProductComponent
         product = self.create_product(10)
         component = self.create_product(5)
-        Storable(product=component, connection=self.trans)
+        Storable(product=component, store=self.store)
         self.assertTrue(component.can_remove())
 
         ProductComponent(product=product,
                          component=component,
-                         connection=self.trans)
+                         store=self.store)
 
         self.assertFalse(component.can_remove())
 
         # Product is used in a production.
         from stoqlib.domain.production import ProductionItem
         product = self.create_product()
-        storable = Storable(product=product, connection=self.trans)
+        Storable(product=product, store=self.store)
         self.assertTrue(product.can_remove())
         order = self.create_production_order()
         ProductionItem(product=product,
                        order=order,
                        quantity=1,
-                       connection=self.trans)
+                       store=self.store)
 
         self.assertFalse(product.can_remove())
 
     def testRemove(self):
         product = self.create_product()
-        Storable(product=product, connection=self.trans)
+        Storable(product=product, store=self.store)
 
-        total = Product.selectBy(id=product.id, connection=self.trans).count()
+        total = self.store.find(Product, id=product.id).count()
         self.assertEquals(total, 1)
 
         product.remove()
-        total = Product.selectBy(id=product.id, connection=self.trans).count()
+        total = self.store.find(Product, id=product.id).count()
         self.assertEquals(total, 0)
 
     def testIncreaseDecreaseStock(self):
-        branch = get_current_branch(self.trans)
+        branch = get_current_branch(self.store)
         product = self.create_product()
-        storable = Storable(product=product, connection=self.trans)
+        storable = Storable(product=product, store=self.store)
         stock_item = storable.get_stock_item(branch)
         self.failIf(stock_item is not None)
 
-        storable.increase_stock(1, branch)
+        storable.increase_stock(1, branch, 0, 0)
         stock_item = storable.get_stock_item(branch)
         self.assertEquals(stock_item.stock_cost, 0)
 
-        storable.increase_stock(1, branch, unit_cost=10)
+        storable.increase_stock(1, branch, 0, 0, unit_cost=10)
         stock_item = storable.get_stock_item(branch)
         self.assertEquals(stock_item.stock_cost, 5)
 
-        stock_item = storable.decrease_stock(1, branch)
+        stock_item = storable.decrease_stock(1, branch, 0, 0)
         self.assertEquals(stock_item.stock_cost, 5)
 
-        storable.increase_stock(1, branch)
+        storable.increase_stock(1, branch, 0, 0)
         stock_item = storable.get_stock_item(branch)
         self.assertEquals(stock_item.stock_cost, 5)
 
-        storable.increase_stock(2, branch, unit_cost=15)
+        storable.increase_stock(2, branch, 0, 0, unit_cost=15)
         stock_item = storable.get_stock_item(branch)
         self.assertEquals(stock_item.stock_cost, 10)
 
     def test_lead_time(self):
         product = self.create_product()
-        Storable(product=product, connection=self.trans)
-        branch = get_current_branch(self.trans)
-        #storable.increase_stock(1, get_current_branch(self.trans))
+        Storable(product=product, store=self.store)
+        branch = get_current_branch(self.store)
 
         supplier1 = self.create_supplier()
-        ProductSupplierInfo(connection=self.trans, product=product,
+        ProductSupplierInfo(store=self.store, product=product,
                             supplier=supplier1, lead_time=10)
 
         self.assertEqual(product.get_max_lead_time(1, branch), 10)
 
         supplier2 = self.create_supplier()
-        ProductSupplierInfo(connection=self.trans, product=product,
+        ProductSupplierInfo(store=self.store, product=product,
                             supplier=supplier2, lead_time=20)
         self.assertEqual(product.get_max_lead_time(1, branch), 20)
 
@@ -278,21 +278,21 @@ class TestProduct(DomainTest):
         product = self.create_product(create_supplier=False)
         product.is_composed = True
         product.production_time = 5
-        Storable(product=product, connection=self.trans)
+        Storable(product=product, store=self.store)
 
         component = self.create_product(create_supplier=False)
-        Storable(product=component, connection=self.trans)
-        ProductSupplierInfo(connection=self.trans, product=component,
+        Storable(product=component, store=self.store)
+        ProductSupplierInfo(store=self.store, product=component,
                             supplier=supplier1, lead_time=7)
         self.assertEqual(component.get_max_lead_time(1, branch), 7)
 
         pc = ProductComponent(product=product, component=component, quantity=1,
-                         connection=self.trans)
+                         store=self.store)
 
         self.assertEqual(product.get_max_lead_time(1, branch), 12)
 
         # Increase the component stock
-        component.storable.increase_stock(1, branch)
+        component.storable.increase_stock(1, branch, 0, 0)
 
         self.assertEqual(product.get_max_lead_time(1, branch), 5)
 
@@ -305,22 +305,21 @@ class TestProductSellableItem(DomainTest):
 
     def testSell(self):
         sale = self.create_sale()
-        sellable = Sellable(barcode='xyz',
-                            connection=self.trans)
-        product = Product(sellable=sellable, connection=self.trans)
+        sellable = Sellable(store=self.store)
+        sellable.barcode = u'xyz'
+        product = Product(sellable=sellable, store=self.store)
         sale_item = sale.add_sellable(product.sellable)
-        storable = Storable(product=product, connection=self.trans)
+        branch = get_current_branch(self.store)
+        storable = self.create_storable(product, branch, 2)
 
-        branch = get_current_branch(self.trans)
-        storable.increase_stock(2, branch)
         stock_item = storable.get_stock_item(branch)
         assert stock_item is not None
         current_stock = stock_item.quantity
         if current_stock:
-            storable.decrease_stock(current_stock, branch)
+            storable.decrease_stock(current_stock, branch, 0, 0)
         assert not storable.get_stock_item(branch).quantity
         sold_qty = 2
-        storable.increase_stock(sold_qty, branch)
+        storable.increase_stock(sold_qty, branch, 0, 0)
         assert storable.get_stock_item(branch) is not None
         assert storable.get_stock_item(branch).quantity == sold_qty
         # now setting the proper sold quantity in the sellable item
@@ -336,11 +335,11 @@ class TestProductHistory(DomainTest):
         order_item.receiving_order.purchase.status = PurchaseOrder.ORDER_PENDING
         order_item.receiving_order.purchase.confirm()
         self.failIf(
-            ProductHistory.selectOneBy(connection=self.trans,
-                                       sellable=order_item.sellable))
+            self.store.find(ProductHistory,
+                            sellable=order_item.sellable).one())
         order_item.receiving_order.confirm()
-        prod_hist = ProductHistory.selectOneBy(connection=self.trans,
-                                               sellable=order_item.sellable)
+        prod_hist = self.store.find(ProductHistory,
+                                    sellable=order_item.sellable).one()
         self.failUnless(prod_hist)
         self.assertEqual(prod_hist.quantity_received,
                          order_item.quantity)
@@ -350,19 +349,18 @@ class TestProductHistory(DomainTest):
         sellable = self.create_sellable()
         sellable.status = Sellable.STATUS_AVAILABLE
         product = sellable.product
-        storable = Storable(product=product, connection=self.trans)
-        storable.increase_stock(100, get_current_branch(self.trans))
+        branch = get_current_branch(self.store)
+        self.create_storable(product, branch, 100)
         sale_item = sale.add_sellable(sellable, quantity=5)
 
-        method = PaymentMethod.get_by_name(self.trans, 'money')
+        method = PaymentMethod.get_by_name(self.store, u'money')
         method.create_inpayment(sale.group, sale.branch, sale.get_sale_subtotal())
 
-        self.failIf(ProductHistory.selectOneBy(connection=self.trans,
-                                               sellable=sellable))
+        self.failIf(self.store.find(ProductHistory,
+                                    sellable=sellable).one())
         sale.order()
         sale.confirm()
-        prod_hist = ProductHistory.selectOneBy(connection=self.trans,
-                                               sellable=sellable)
+        prod_hist = self.store.find(ProductHistory, sellable=sellable).one()
         self.failUnless(prod_hist)
         self.assertEqual(prod_hist.quantity_sold, 5)
         self.assertEqual(prod_hist.quantity_sold,
@@ -372,13 +370,13 @@ class TestProductHistory(DomainTest):
         qty = 10
         order = self.create_transfer_order()
         transfer_item = self.create_transfer_order_item(order, quantity=qty)
-        self.failIf(ProductHistory.selectOneBy(
-                    connection=self.trans, sellable=transfer_item.sellable))
+        self.failIf(self.store.find(ProductHistory,
+                                    sellable=transfer_item.sellable).one())
 
         order.send_item(transfer_item)
         order.receive()
-        prod_hist = ProductHistory.selectOneBy(connection=self.trans,
-                                               sellable=transfer_item.sellable)
+        prod_hist = self.store.find(ProductHistory,
+                                    sellable=transfer_item.sellable).one()
         self.failUnless(prod_hist)
         self.assertEqual(prod_hist.quantity_transfered, qty)
 
@@ -387,14 +385,14 @@ class TestProductQuality(DomainTest):
 
     def test_quality_tests(self):
         product = self.create_product()
-        Storable(product=product, connection=self.trans)
+        Storable(product=product, store=self.store)
 
         # There are still no tests for this product
         self.assertEqual(product.quality_tests.count(), 0)
 
-        test1 = ProductQualityTest(connection=self.trans, product=product,
+        test1 = ProductQualityTest(store=self.store, product=product,
                                    test_type=ProductQualityTest.TYPE_BOOLEAN,
-                                   success_value='True')
+                                   success_value=u'True')
         # Now there sould be one
         self.assertEqual(product.quality_tests.count(), 1)
         # and it should be the one we created
@@ -402,12 +400,12 @@ class TestProductQuality(DomainTest):
 
         # Different product
         product2 = self.create_product()
-        Storable(product=product2, connection=self.trans)
+        Storable(product=product2, store=self.store)
 
         # With different test
-        test2 = ProductQualityTest(connection=self.trans, product=product2,
+        test2 = ProductQualityTest(store=self.store, product=product2,
                                    test_type=ProductQualityTest.TYPE_BOOLEAN,
-                                   success_value='True')
+                                   success_value=u'True')
 
         # First product still should have only one
         self.assertEqual(product.quality_tests.count(), 1)
@@ -416,7 +414,7 @@ class TestProductQuality(DomainTest):
 
     def test_boolean_value(self):
         product = self.create_product()
-        bool_test = ProductQualityTest(connection=self.trans, product=product,
+        bool_test = ProductQualityTest(store=self.store, product=product,
                                    test_type=ProductQualityTest.TYPE_BOOLEAN)
         bool_test.set_boolean_value(True)
         self.assertEqual(bool_test.get_boolean_value(), True)
@@ -432,7 +430,7 @@ class TestProductQuality(DomainTest):
 
     def test_decimal_value(self):
         product = self.create_product()
-        test = ProductQualityTest(connection=self.trans, product=product,
+        test = ProductQualityTest(store=self.store, product=product,
                                    test_type=ProductQualityTest.TYPE_DECIMAL)
         test.set_range_value(Decimal(10), Decimal(20))
         self.assertEqual(test.get_range_value(), (Decimal(10), Decimal(20)))
@@ -456,7 +454,7 @@ class TestProductQuality(DomainTest):
 
     def test_can_remove(self):
         product = self.create_product()
-        test = ProductQualityTest(connection=self.trans, product=product)
+        test = ProductQualityTest(store=self.store, product=product)
 
         # Test has never been used
         self.assertTrue(test.can_remove())
@@ -468,22 +466,22 @@ class TestProductQuality(DomainTest):
                                       produced_by=user,
                                       produced_date=datetime.date.today(),
                                       serial_number=1,
-                                      connection=self.trans)
+                                      store=self.store)
         self.assertTrue(test.can_remove())
 
         # Test has been used in a production
         ProductionItemQualityResult(produced_item=item,
                                     quality_test=test,
                                     tested_by=user,
-                                    result_value='True',
+                                    result_value=u'True',
                                     test_passed=True,
-                                    connection=self.trans)
+                                    store=self.store)
         self.assertFalse(test.can_remove())
 
 
 class TestProductEvent(DomainTest):
     def testCreateEvent(self):
-        trans_list = []
+        store_list = []
         p_data = _ProductEventData()
         ProductCreateEvent.connect(p_data.on_create)
         ProductEditEvent.connect(p_data.on_edit)
@@ -491,18 +489,18 @@ class TestProductEvent(DomainTest):
 
         try:
             # Test product being created
-            trans = new_transaction()
-            trans_list.append(trans)
+            store = new_store()
+            store_list.append(store)
             sellable = Sellable(
-                connection=trans,
-                description='Test 1234',
+                store=store,
+                description=u'Test 1234',
                 price=Decimal(2),
                 )
             product = Product(
-                connection=trans,
+                store=store,
                 sellable=sellable,
                 )
-            trans.commit()
+            store.commit()
             self.assertTrue(p_data.was_created)
             self.assertFalse(p_data.was_edited)
             self.assertFalse(p_data.was_deleted)
@@ -510,14 +508,14 @@ class TestProductEvent(DomainTest):
             p_data.reset()
 
             # Test product being edited and emmiting the event just once
-            trans = new_transaction()
-            trans_list.append(trans)
-            sellable = trans.get(sellable)
-            product = trans.get(product)
-            sellable.notes = 'Notes'
-            sellable.description = 'Test 666'
+            store = new_store()
+            store_list.append(store)
+            sellable = store.fetch(sellable)
+            product = store.fetch(product)
+            sellable.notes = u'Notes'
+            sellable.description = u'Test 666'
             product.weight = Decimal(10)
-            trans.commit()
+            store.commit()
             self.assertTrue(p_data.was_edited)
             self.assertFalse(p_data.was_created)
             self.assertFalse(p_data.was_deleted)
@@ -526,12 +524,12 @@ class TestProductEvent(DomainTest):
             p_data.reset()
 
             # Test product being edited, editing Sellable
-            trans = new_transaction()
-            trans_list.append(trans)
-            sellable = trans.get(sellable)
-            product = trans.get(product)
-            sellable.notes = 'Notes for test'
-            trans.commit()
+            store = new_store()
+            store_list.append(store)
+            sellable = store.fetch(sellable)
+            product = store.fetch(product)
+            sellable.notes = u'Notes for test'
+            store.commit()
             self.assertTrue(p_data.was_edited)
             self.assertFalse(p_data.was_created)
             self.assertFalse(p_data.was_deleted)
@@ -540,12 +538,12 @@ class TestProductEvent(DomainTest):
             p_data.reset()
 
             # Test product being edited, editing Product itself
-            trans = new_transaction()
-            trans_list.append(trans)
-            sellable = trans.get(sellable)
-            product = trans.get(product)
+            store = new_store()
+            store_list.append(store)
+            sellable = store.fetch(sellable)
+            product = store.fetch(product)
             product.weight = Decimal(1)
-            trans.commit()
+            store.commit()
             self.assertTrue(p_data.was_edited)
             self.assertFalse(p_data.was_created)
             self.assertFalse(p_data.was_deleted)
@@ -554,12 +552,12 @@ class TestProductEvent(DomainTest):
             p_data.reset()
 
             # Test product being edited, editing Product itself
-            trans = new_transaction()
-            trans_list.append(trans)
-            sellable = trans.get(sellable)
-            product = trans.get(product)
+            store = new_store()
+            store_list.append(store)
+            sellable = store.fetch(sellable)
+            product = store.fetch(product)
             product.weight = Decimal(1)
-            trans.commit()
+            store.commit()
             #self.assertTrue(p_data.was_edited)
             self.assertFalse(p_data.was_created)
             self.assertFalse(p_data.was_deleted)
@@ -569,12 +567,12 @@ class TestProductEvent(DomainTest):
 
         finally:
             # Test product being removed
-            trans = new_transaction()
-            trans_list.append(trans)
-            sellable = trans.get(sellable)
-            product = trans.get(product)
+            store = new_store()
+            store_list.append(store)
+            sellable = store.fetch(sellable)
+            product = store.fetch(product)
             sellable.remove()
-            trans.commit()
+            store.commit()
             self.assertTrue(p_data.was_deleted)
             self.assertFalse(p_data.was_created)
             self.assertFalse(p_data.was_edited)
@@ -582,5 +580,222 @@ class TestProductEvent(DomainTest):
             self.assertEqual(p_data.emmit_count, 1)
             p_data.reset()
 
-            for trans in trans_list:
-                trans.close()
+            for store in store_list:
+                store.close()
+
+
+class TestStockTransactionHistory(DomainTest):
+    def setUp(self):
+        DomainTest.setUp(self)
+        self.branch = get_current_branch(self.store)
+
+    def _check_stock(self, product):
+        storable = product.storable or self.create_storable(product)
+        if not storable.get_stock_item(self.branch):
+            storable.increase_stock(100, self.branch, 0, 0)
+
+    def test_initial_stock(self):
+        storable = self.create_storable()
+
+        history_before = self.store.find(StockTransactionHistory).count()
+        storable.register_initial_stock(10, self.branch)
+        history_after = self.store.find(StockTransactionHistory).count()
+        self.assertEquals(history_after, history_before + 1)
+
+        history = self.store.find(StockTransactionHistory,
+                                  type=StockTransactionHistory.TYPE_INITIAL).one()
+        self.assertEquals(history.product_stock_item.storable, storable)
+        self.assertEquals(history.get_description(), u'Registred initial stock')
+
+    def test_imported(self):
+        storable = self.create_storable()
+        stock_item = self.create_product_stock_item(quantity=15,
+                                                    storable=storable)
+
+        # patch-04-09 creates this for us
+        history = StockTransactionHistory(product_stock_item=stock_item,
+                                        stock_cost=stock_item.stock_cost,
+                                        quantity=stock_item.quantity,
+                                        type=StockTransactionHistory.TYPE_IMPORTED,
+                                        store=self.store)
+
+        self.assertEquals(history.get_description(),
+                          u'Imported from previous version')
+
+    def _check_stock_history(self, product, quantity, item, parent, type):
+        stock_item = product.storable.get_stock_item(self.branch)
+        transaction = self.store.find(StockTransactionHistory,
+                        product_stock_item=stock_item).order_by(
+                            StockTransactionHistory.date).last()
+        self.assertEquals(transaction.quantity, quantity)
+        self.assertEquals(transaction.type, type)
+        self.assertEquals(item, transaction.get_object())
+        self.assertEquals(parent, transaction.get_object_parent())
+
+    def test_stock_decrease(self):
+        decrease_item = self.create_stock_decrease_item()
+        product = decrease_item.sellable.product
+
+        self._check_stock(product)
+        decrease_item.decrease(self.branch)
+        self._check_stock_history(product, -1, decrease_item,
+                    decrease_item.stock_decrease,
+                    StockTransactionHistory.TYPE_STOCK_DECREASE)
+
+    def test_sale_cancel(self):
+        sale_item = self.create_sale_item()
+        product = sale_item.sellable.product
+
+        self._check_stock(product)
+        sale_item.cancel(self.branch)
+        self._check_stock_history(product, 1, sale_item, sale_item.sale,
+                    StockTransactionHistory.TYPE_CANCELED_SALE)
+
+    def test_sell(self):
+        sale_item = self.create_sale_item()
+        product = sale_item.sellable.product
+        sale_item.sellable.status = Sellable.STATUS_AVAILABLE
+
+        self._check_stock(product)
+        sale_item.sell(self.branch)
+        self._check_stock_history(product, -1, sale_item, sale_item.sale,
+                    StockTransactionHistory.TYPE_SELL)
+
+    def test_retrun_sale(self):
+        sale_item = self.create_sale_item()
+        returned_sale = sale_item.sale.create_sale_return_adapter()
+        returned_sale_item = returned_sale.get_items().any()
+        product = returned_sale_item.sellable.product
+
+        self._check_stock(product)
+        returned_sale_item.return_(self.branch)
+        self._check_stock_history(product, 1, returned_sale_item, returned_sale,
+                    StockTransactionHistory.TYPE_RETURNED_SALE)
+
+    def test_produce(self):
+        material = self.create_production_material()
+        production_item = material.order.get_items().any()
+        product = production_item.product
+
+        production_item.order.status = ProductionOrder.ORDER_PRODUCING
+        material.allocated = 10
+        material.consumed = 1
+
+        self._check_stock(product)
+        production_item.produce(1)
+        self._check_stock_history(product, 1, production_item,
+                    production_item.order,
+                    StockTransactionHistory.TYPE_PRODUCTION_PRODUCED)
+
+    def test_receiving_order(self):
+        receiving_item = self.create_receiving_order_item()
+        product = receiving_item.sellable.product
+
+        receiving_item.quantity = 5
+
+        self._check_stock(product)
+        receiving_item.add_stock_items()
+        self._check_stock_history(product, 5, receiving_item,
+                    receiving_item.receiving_order,
+                    StockTransactionHistory.TYPE_RECEIVED_PURCHASE)
+
+    def test_loan_decrease(self):
+        loan_item = self.create_loan_item()
+        product = loan_item.sellable.product
+
+        loan_item.quantity = 10
+        loan_item.returned = 0
+        loan_item.sold = 0
+
+        self._check_stock(product)
+        loan_item.sync_stock()
+        self._check_stock_history(product, -10, loan_item, loan_item.loan,
+                    StockTransactionHistory.TYPE_LOANED)
+
+    def test_inventory_adjust(self):
+        item = self.create_inventory_item()
+        product = item.product
+
+        item.inventory.branch = self.branch
+        item.actual_quantity = 10
+        item.recorded_quantity = 0
+        increase_quantity = item.actual_quantity - item.recorded_quantity
+
+        self._check_stock(product)
+        item.adjust(123)
+        self._check_stock_history(product, increase_quantity, item,
+                    item.inventory,
+                    StockTransactionHistory.TYPE_INVENTORY_ADJUST)
+
+    def test_production_produced(self):
+        production_item = self.create_production_item()
+        production = production_item.order
+        material = production.get_material_items().any()
+
+        self._check_stock(production_item.product)
+        self._check_stock(material.product)
+
+        production.start_production()
+        production_item.produce(1)
+        self._check_stock_history(production_item.product, 1, production_item,
+                    production,
+                    StockTransactionHistory.TYPE_PRODUCTION_PRODUCED)
+
+    def test_production_allocated(self):
+        production_item = self.create_production_item()
+        production = production_item.order
+        material = production.get_material_items().any()
+        production.branch = self.branch
+
+        self._check_stock(production_item.product)
+        self._check_stock(material.product)
+
+        material.allocate(5)
+        self._check_stock_history(material.product, -5, material, production,
+                    StockTransactionHistory.TYPE_PRODUCTION_ALLOCATED)
+
+    def test_production_returned(self):
+        production_item = self.create_production_item()
+        production = production_item.order
+        material = production.get_material_items().any()
+        production.branch = self.branch
+
+        production.status = ProductionOrder.ORDER_CLOSED
+
+        self._check_stock(production_item.product)
+        self._check_stock(material.product)
+
+        material.allocated = 10
+        material.lost = 0
+        material.consumed = 5
+
+        material.return_remaining()
+        self._check_stock_history(material.product, 5, material, production,
+                    StockTransactionHistory.TYPE_PRODUCTION_RETURNED)
+
+    def test_transfer_to(self):
+        transfer_item = self.create_transfer_order_item()
+        transfer = transfer_item.transfer_order
+        product = transfer_item.sellable.product
+
+        self._check_stock(product)
+
+        transfer.source_branch = self.branch
+        transfer.send_item(transfer_item)
+
+        self._check_stock_history(product, -5, transfer_item, transfer,
+                    StockTransactionHistory.TYPE_TRANSFER_TO)
+
+    def test_transfer_from(self):
+        transfer_item = self.create_transfer_order_item()
+        transfer = transfer_item.transfer_order
+        product = transfer_item.sellable.product
+
+        self._check_stock(product)
+
+        transfer_item.quantity = 2
+        transfer.destination_branch = self.branch
+        transfer.receive(datetime.date.today())
+
+        self._check_stock_history(product, 2, transfer_item, transfer,
+                    StockTransactionHistory.TYPE_TRANSFER_FROM)
