@@ -26,12 +26,14 @@ import datetime
 from decimal import Decimal
 
 from kiwi.currency import currency
+import mock
 from nose.exc import SkipTest
 
 from stoqlib.api import api
 from stoqlib.database.runtime import get_current_branch
 from stoqlib.domain.commission import CommissionSource, Commission
 from stoqlib.domain.fiscal import FiscalBookEntry
+from stoqlib.domain.interfaces import IPaymentTransaction
 from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.payment.payment import Payment
 from stoqlib.domain.sale import Sale, SalePaymentMethodView
@@ -44,7 +46,7 @@ class TestSale(DomainTest):
 
     def testSalePaymentsOrdered(self):
         sale = self.create_sale()
-        self.add_payments(sale, method_type='check', installments=10)
+        self.add_payments(sale, method_type=u'check', installments=10)
         initial_date = datetime.datetime(2012, 10, 15)
         for i, p in enumerate(sale.payments):
             p.open_date = initial_date - datetime.timedelta(i)
@@ -113,7 +115,7 @@ class TestSale(DomainTest):
         sellable = self.create_sellable()
         sale.add_sellable(sellable, quantity=5)
 
-        item = 'test purpose'
+        item = u'test purpose'
         self.failUnlessRaises(TypeError, sale.remove_item, item)
         item = sale.get_items()[0]
         sale.remove_item(item)
@@ -122,7 +124,7 @@ class TestSale(DomainTest):
     def test_get_status_name(self):
         sale = self.create_sale()
         self.failUnlessRaises(TypeError,
-                              sale.get_status_name, 'invalid status')
+                              sale.get_status_name, u'invalid status')
 
     def testOrder(self):
         sale = self.create_sale()
@@ -147,29 +149,26 @@ class TestSale(DomainTest):
         self.add_product(sale)
         sale.order()
 
-        self.add_payments(sale, method_type='money')
-        self.failIf(FiscalBookEntry.selectOneBy(
+        self.add_payments(sale, method_type=u'money')
+        self.failIf(self.store.find(FiscalBookEntry,
             entry_type=FiscalBookEntry.TYPE_PRODUCT,
-            payment_group=sale.group,
-            connection=self.trans))
+            payment_group=sale.group).one())
         self.failUnless(sale.can_confirm())
         sale.confirm()
         self.failIf(sale.can_confirm())
         self.assertEqual(sale.status, Sale.STATUS_CONFIRMED)
         self.assertEqual(sale.confirm_date.date(), datetime.date.today())
 
-        book_entry = FiscalBookEntry.selectOneBy(
+        book_entry = self.store.find(FiscalBookEntry,
             entry_type=FiscalBookEntry.TYPE_PRODUCT,
-            payment_group=sale.group,
-            connection=self.trans)
+            payment_group=sale.group).one()
         self.failUnless(book_entry)
-        self.assertEqual(book_entry.cfop.code, '5.102')
+        self.assertEqual(book_entry.cfop.code, u'5.102')
         self.assertEqual(book_entry.icms_value, Decimal("1.8"))
 
         for payment in sale.payments:
             self.assertEquals(payment.status, Payment.STATUS_PAID)
-            entry = TillEntry.selectOneBy(payment=payment,
-                                          connection=self.trans)
+            entry = self.store.find(TillEntry, payment=payment).one()
             self.assertEquals(entry.value, payment.value)
 
     def testConfirmCheck(self):
@@ -177,29 +176,26 @@ class TestSale(DomainTest):
         self.add_product(sale)
         sale.order()
 
-        self.add_payments(sale, method_type='check')
-        self.failIf(FiscalBookEntry.selectOneBy(
+        self.add_payments(sale, method_type=u'check')
+        self.failIf(self.store.find(FiscalBookEntry,
             entry_type=FiscalBookEntry.TYPE_PRODUCT,
-            payment_group=sale.group,
-            connection=self.trans))
+            payment_group=sale.group).one())
         self.failUnless(sale.can_confirm())
         sale.confirm()
         self.failIf(sale.can_confirm())
         self.assertEqual(sale.status, Sale.STATUS_CONFIRMED)
         self.assertEqual(sale.confirm_date.date(), datetime.date.today())
 
-        book_entry = FiscalBookEntry.selectOneBy(
+        book_entry = self.store.find(FiscalBookEntry,
             entry_type=FiscalBookEntry.TYPE_PRODUCT,
-            payment_group=sale.group,
-            connection=self.trans)
+            payment_group=sale.group).one()
         self.failUnless(book_entry)
-        self.assertEqual(book_entry.cfop.code, '5.102')
+        self.assertEqual(book_entry.cfop.code, u'5.102')
         self.assertEqual(book_entry.icms_value, Decimal("1.8"))
 
         for payment in sale.payments:
             self.assertEquals(payment.status, Payment.STATUS_PENDING)
-            entry = TillEntry.selectOneBy(payment=payment,
-                                          connection=self.trans)
+            entry = self.store.find(TillEntry, payment=payment).one()
             self.assertEquals(entry.value, payment.value)
 
     def testConfirmClient(self):
@@ -231,7 +227,7 @@ class TestSale(DomainTest):
         self.assertEqual(sale.close_date.date(), datetime.date.today())
 
     def testTotalReturn(self):
-        sale = self.create_sale(branch=get_current_branch(self.trans))
+        sale = self.create_sale(branch=get_current_branch(self.store))
         sellable = self.add_product(sale)
         storable = sellable.product_storable
         balance_before_confirm = storable.get_balance_for_branch(sale.branch)
@@ -258,7 +254,7 @@ class TestSale(DomainTest):
                          balance_before_confirm)
 
     def testPartialReturn(self):
-        sale = self.create_sale(branch=get_current_branch(self.trans))
+        sale = self.create_sale(branch=get_current_branch(self.store))
         sellable = self.add_product(sale, quantity=5)
         storable = sellable.product_storable
         balance_before_confirm = storable.get_balance_for_branch(sale.branch)
@@ -272,7 +268,7 @@ class TestSale(DomainTest):
 
         self.failUnless(sale.can_return())
         returned_sale = sale.create_sale_return_adapter()
-        returned_sale.returned_items[0].quantity = 2
+        list(returned_sale.returned_items)[0].quantity = 2
         returned_sale.return_()
         self.failUnless(sale.can_return())
         self.assertEqual(sale.status, Sale.STATUS_CONFIRMED)
@@ -285,7 +281,7 @@ class TestSale(DomainTest):
 
         returned_sale = sale.create_sale_return_adapter()
         # Since we already returned 2 above, this should be created with 3
-        self.assertEqual(returned_sale.returned_items[0].quantity, 3)
+        self.assertEqual(list(returned_sale.returned_items)[0].quantity, 3)
         # Now this is the final return and will be considered as a total return
         returned_sale.return_()
         self.failIf(sale.can_return())
@@ -324,16 +320,14 @@ class TestSale(DomainTest):
         payment = sale.payments[1]
         self.assertEqual(payment.value, paid_payment.value)
         self.assertEqual(payment.status, Payment.STATUS_PENDING)
-        self.assertEqual(payment.method.method_name, 'money')
+        self.assertEqual(payment.method.method_name, u'money')
 
-        fbe = FiscalBookEntry.selectOneBy(
-            payment_group=sale.group,
-            is_reversal=False,
-            connection=self.trans)
-        rfbe = FiscalBookEntry.selectOneBy(
-            payment_group=sale.group,
-            is_reversal=True,
-            connection=self.trans)
+        fbe = self.store.find(FiscalBookEntry,
+                              payment_group=sale.group,
+                              is_reversal=False).one()
+        rfbe = self.store.find(FiscalBookEntry,
+                               payment_group=sale.group,
+                               is_reversal=True).one()
         # The fiscal entries should be totally reversed
         self.assertEqual(fbe.icms_value - rfbe.icms_value, 0)
         self.assertEqual(fbe.iss_value - rfbe.iss_value, 0)
@@ -358,7 +352,7 @@ class TestSale(DomainTest):
         self.assertEqual(payment.value, 20)
 
         returned_sale = sale.create_sale_return_adapter()
-        returned_sale.returned_items[0].quantity = 1
+        list(returned_sale.returned_items)[0].quantity = 1
         returned_sale.return_()
         self.assertTrue(sale.can_return())
         self.assertEqual(sale.status, Sale.STATUS_PAID)
@@ -370,16 +364,14 @@ class TestSale(DomainTest):
         # value should be reverted to the client
         self.assertEqual(returned_payment.value, paid_payment.value / 2)
         self.assertEqual(returned_payment.status, Payment.STATUS_PENDING)
-        self.assertEqual(returned_payment.method.method_name, 'money')
+        self.assertEqual(returned_payment.method.method_name, u'money')
 
-        fbe = FiscalBookEntry.selectOneBy(
-            payment_group=sale.group,
-            is_reversal=False,
-            connection=self.trans)
-        rfbe = FiscalBookEntry.selectOneBy(
-            payment_group=sale.group,
-            is_reversal=True,
-            connection=self.trans)
+        fbe = self.store.find(FiscalBookEntry,
+                              payment_group=sale.group,
+                              is_reversal=False).one()
+        rfbe = self.store.find(FiscalBookEntry,
+                               payment_group=sale.group,
+                               is_reversal=True).one()
         # Since a half of the products were returned, half of the
         # taxes should be reverted. That is,
         # actual_value - reverted_value = actual_value / 2
@@ -398,7 +390,7 @@ class TestSale(DomainTest):
         sale.order()
         self.failIf(sale.can_return())
 
-        method = PaymentMethod.get_by_name(self.trans, 'check')
+        method = PaymentMethod.get_by_name(self.store, u'check')
         payment = method.create_inpayment(sale.group, sale.branch, Decimal(300))
         sale.confirm()
         self.failUnless(sale.can_return())
@@ -423,13 +415,13 @@ class TestSale(DomainTest):
         sale.order()
         self.failIf(sale.can_return())
 
-        method = PaymentMethod.get_by_name(self.trans, 'check')
+        method = PaymentMethod.get_by_name(self.store, u'check')
         payment = method.create_inpayment(sale.group, sale.branch, Decimal(600))
         sale.confirm()
         self.failUnless(sale.can_return())
 
         returned_sale = sale.create_sale_return_adapter()
-        returned_sale.returned_items[0].quantity = 1
+        list(returned_sale.returned_items)[0].quantity = 1
 
         # Mimic what is done on sale return wizard that is to cancel
         # the existing payment and create another one with the new
@@ -456,7 +448,7 @@ class TestSale(DomainTest):
         self.failIf(sale.can_return())
 
         # Add 3 check payments of 100 each
-        method = PaymentMethod.get_by_name(self.trans, 'check')
+        method = PaymentMethod.get_by_name(self.store, u'check')
         payment1 = method.create_inpayment(sale.group, sale.branch, Decimal(100))
         method.create_inpayment(sale.group, sale.branch, Decimal(100))
         method.create_inpayment(sale.group, sale.branch, Decimal(100))
@@ -493,7 +485,7 @@ class TestSale(DomainTest):
         self.failIf(sale.can_return())
 
         # Add 3 check payments of 100 each
-        method = PaymentMethod.get_by_name(self.trans, 'check')
+        method = PaymentMethod.get_by_name(self.store, u'check')
         payment1 = method.create_inpayment(sale.group, sale.branch, Decimal(100))
         method.create_inpayment(sale.group, sale.branch, Decimal(100))
         method.create_inpayment(sale.group, sale.branch, Decimal(100))
@@ -521,7 +513,7 @@ class TestSale(DomainTest):
         self.assertEqual(payment.value, returned_amount)
 
     def testTrade(self):
-        sale = self.create_sale(branch=get_current_branch(self.trans))
+        sale = self.create_sale(branch=get_current_branch(self.store))
         self.failIf(sale.can_return())
 
         sellable = self.add_product(sale)
@@ -607,7 +599,7 @@ class TestSale(DomainTest):
         sale = self.create_sale()
         sellable = self.add_product(sale)
         storable = sellable.product_storable
-        branch = api.get_current_branch(self.trans)
+        branch = api.get_current_branch(self.store)
         initial_quantity = storable.get_balance_for_branch(branch)
         sale.order()
 
@@ -627,7 +619,7 @@ class TestSale(DomainTest):
         self.assertEquals(initial_quantity, final_quantity)
 
     def testCancelNotPaid(self):
-        branch = api.get_current_branch(self.trans)
+        branch = api.get_current_branch(self.store)
         sale = self.create_sale()
         sellable = self.add_product(sale, price=300)
         storable = sellable.product_storable
@@ -664,7 +656,7 @@ class TestSale(DomainTest):
         self.add_product(sale)
         sale.order()
 
-        self.add_payments(sale, method_type='check')
+        self.add_payments(sale, method_type=u'check')
         sale.confirm()
 
         self.failUnless(sale.can_set_renegotiated())
@@ -679,7 +671,7 @@ class TestSale(DomainTest):
         self.add_product(sale)
         sale.order()
 
-        self.add_payments(sale, method_type='check')
+        self.add_payments(sale, method_type=u'check')
         sale.confirm()
 
         self.failUnless(sale.can_set_renegotiated())
@@ -693,35 +685,35 @@ class TestSale(DomainTest):
 
     def testProducts(self):
         sale = self.create_sale()
-        self.failIf(sale.products)
+        self.assertTrue(sale.products.is_empty())
 
         service = self.create_service()
         sellable = service.sellable
         sale.add_sellable(sellable, quantity=1)
 
-        self.failIf(sale.products)
+        self.assertTrue(sale.products.is_empty())
 
         product = self.create_product()
         sellable = product.sellable
         sale.add_sellable(sellable, quantity=1)
 
-        self.failUnless(sale.products)
+        self.assertFalse(sale.products.is_empty())
 
     def testServices(self):
         sale = self.create_sale()
-        self.failIf(sale.services)
+        self.assertTrue(sale.services.is_empty())
 
         product = self.create_product()
         sellable = product.sellable
         sale.add_sellable(sellable, quantity=1)
 
-        self.failIf(sale.services)
+        self.assertTrue(sale.services.is_empty())
 
         service = self.create_service()
         sellable = service.sellable
         sale.add_sellable(sellable, quantity=1)
 
-        self.failUnless(sale.services)
+        self.assertFalse(sale.services.is_empty())
 
     def testSaleWithDelivery(self):
         sale = self.create_sale()
@@ -729,7 +721,7 @@ class TestSale(DomainTest):
 
         self.add_product(sale)
 
-        sellable = sysparam(self.trans).DELIVERY_SERVICE.sellable
+        sellable = sysparam(self.store).DELIVERY_SERVICE.sellable
         sale.add_sellable(sellable, quantity=1)
         sale.order()
         self.failIf(sale.can_set_paid())
@@ -743,16 +735,14 @@ class TestSale(DomainTest):
         CommissionSource(sellable=sellable,
                          direct_value=10,
                          installments_value=5,
-                         connection=self.trans)
+                         store=self.store)
         sale.order()
         # payment method: money
         # installments number: 1
         self.add_payments(sale)
-        self.failIf(Commission.selectBy(sale=sale,
-                                        connection=self.trans))
+        self.assertTrue(self.store.find(Commission, sale=sale).is_empty())
         sale.confirm()
-        commissions = Commission.selectBy(sale=sale,
-                                          connection=self.trans)
+        commissions = self.store.find(Commission, sale=sale)
         self.assertEquals(commissions.count(), 1)
         self.assertEquals(commissions[0].value, Decimal('20.00'))
 
@@ -762,79 +752,74 @@ class TestSale(DomainTest):
         CommissionSource(sellable=sellable,
                          direct_value=10,
                          installments_value=5,
-                         connection=self.trans)
+                         store=self.store)
         sellable = self.add_product(sale, price=300)
         CommissionSource(sellable=sellable,
                          direct_value=12,
                          installments_value=5,
-                         connection=self.trans)
+                         store=self.store)
         sale.order()
         # payment method: money
         # installments number: 1
         self.add_payments(sale)
-        self.failIf(Commission.selectBy(sale=sale,
-                                        connection=self.trans))
+        self.assertTrue(self.store.find(Commission, sale=sale).is_empty())
         sale.confirm()
-        commissions = Commission.selectBy(sale=sale,
-                                          connection=self.trans)
+        commissions = self.store.find(Commission, sale=sale)
         self.assertEquals(commissions.count(), 1)
         self.assertEquals(commissions[0].value, Decimal('56.00'))
 
     def testCommissionAmountWhenSaleReturnsCompletly(self):
-        raise SkipTest("See stoqlib.domain.returned_sale.ReturnedSale.return_ "
-                       "and bug 5215.")
+        raise SkipTest(u"See stoqlib.domain.returned_sale.ReturnedSale.return_ "
+                       u"and bug 5215.")
 
         sale = self.create_sale()
         sellable = self.add_product(sale, price=200)
         CommissionSource(sellable=sellable,
                          direct_value=10,
                          installments_value=5,
-                         connection=self.trans)
+                         store=self.store)
         sale.order()
         # payment method: money
         # installments number: 1
         self.add_payments(sale)
-        self.failIf(Commission.selectBy(sale=sale,
-                                        connection=self.trans))
+        self.failIf(self.store.find(Commission, sale=sale))
         sale.confirm()
         returned_sale = sale.create_sale_return_adapter()
         returned_sale.return_()
         self.assertEqual(sale.status, Sale.STATUS_RETURNED)
 
-        commissions = Commission.selectBy(sale=sale,
-                                          connection=self.trans)
+        commissions = self.store.find(Commission, sale=sale,
+                                          )
         value = sum([c.value for c in commissions])
         self.assertEqual(value, Decimal(0))
         self.assertEqual(commissions.count(), 2)
         self.failIf(commissions[-1].value >= 0)
 
     def testCommissionAmountWhenSaleReturnsPartially(self):
-        raise SkipTest("See stoqlib.domain.returnedsale.ReturnedSale.return_ "
-                       "and bug 5215.")
+        raise SkipTest(u"See stoqlib.domain.returnedsale.ReturnedSale.return_ "
+                       u"and bug 5215.")
 
         sale = self.create_sale()
         sellable = self.add_product(sale, quantity=2, price=200)
         CommissionSource(sellable=sellable,
                          direct_value=10,
                          installments_value=5,
-                         connection=self.trans)
+                         store=self.store)
         sale.order()
         # payment method: money
         # installments number: 1
         self.add_payments(sale)
-        self.failIf(Commission.selectBy(sale=sale,
-                                        connection=self.trans))
+        self.failIf(self.store.find(Commission, sale=sale))
         sale.confirm()
-        commission_value_before_return = Commission.selectBy(
-            connection=self.trans, sale=sale).sum(Commission.value)
+        commission_value_before_return = self.store.find(Commission,
+             sale=sale).sum(Commission.value)
 
         returned_sale = sale.create_sale_return_adapter()
-        returned_sale.returned_items[0].quantity = 1
+        list(returned_sale.returned_items)[0].quantity = 1
         returned_sale.return_()
         self.assertEqual(sale.status, Sale.STATUS_CONFIRMED)
 
-        commissions = Commission.selectBy(sale=sale,
-                                          connection=self.trans)
+        commissions = self.store.find(Commission, sale=sale)
         # Since we returned half of the products, commission should
         # be reverted by half too
         self.assertEqual(commissions.sum(Commission.value),
@@ -842,6 +827,99 @@ class TestSale(DomainTest):
         self.assertEqual(commissions.count(), 2)
         self.failIf(commissions[-1].value >= 0)
 
+    def testCommissionCreateOnConfirm(self):
+        api.sysparam(self.store).update_parameter(
+            u'SALE_PAY_COMMISSION_WHEN_CONFIRMED', u'1')
+
+        sale = self.create_sale()
+        self.add_product(sale, quantity=1, price=200)
+        sale.order()
+        self.add_payments(sale, method_type=u'bill', installments=10)
+
+        for p in sale.payments:
+            self.assertEqual(
+                self.store.find(Commission, payment=p).count(), 0)
+
+        sale.confirm()
+        for p in sale.payments:
+            # Confirming should create commissions
+            self.assertEqual(
+                self.store.find(Commission, payment=p).count(), 1)
+            # Paying should not create another commission
+            p.pay()
+            self.assertEqual(
+                self.store.find(Commission, payment=p).count(), 1)
+
+        # Setting as paid should not create another commission
+        sale.set_paid()
+        for p in sale.payments:
+            self.assertEqual(
+                self.store.find(Commission, payment=p).count(), 1)
+
+    def testCommissionCreateOnPay(self):
+        api.sysparam(self.store).update_parameter(
+            u'SALE_PAY_COMMISSION_WHEN_CONFIRMED', u'0')
+
+        sale = self.create_sale()
+        self.add_product(sale, quantity=1, price=200)
+        sale.order()
+        self.add_payments(sale, method_type=u'bill', installments=10)
+
+        for p in sale.payments:
+            self.assertEqual(
+                self.store.find(Commission, payment=p).count(), 0)
+
+        sale.confirm()
+        for p in sale.payments:
+            # Confirming should not create commissions
+            self.assertEqual(
+                self.store.find(Commission, payment=p).count(), 0)
+            # Paying should create the commission
+            p.pay()
+            self.assertEqual(
+                self.store.find(Commission, payment=p).count(), 1)
+
+        # Setting as paid should not create another commission
+        sale.set_paid()
+        for p in sale.payments:
+            self.assertEqual(
+                self.store.find(Commission, payment=p).count(), 1)
+
+    def testCommissionCreateAtEnd(self):
+        api.sysparam(self.store).update_parameter(
+            u'SALE_PAY_COMMISSION_WHEN_CONFIRMED', u'0')
+
+        sale = self.create_sale()
+        self.add_product(sale, quantity=1, price=200)
+        sale.order()
+        self.add_payments(sale, method_type=u'bill', installments=10)
+
+        for p in sale.payments:
+            self.assertEqual(
+                self.store.find(Commission, payment=p).count(), 0)
+
+        sale.confirm()
+        transaction = IPaymentTransaction(sale)
+        fake = lambda p: None
+        # Mimic out old behaviour of only creating commissions for payments
+        # when all payments on a sale are set as paid.
+        with mock.patch.object(transaction, 'create_commission', new=fake):
+            for p in sale.payments:
+                # Confirming should not create commissions
+                self.assertEqual(
+                    self.store.find(Commission, payment=p).count(), 0)
+                # Since we are mimicking the old behaviour, commission
+                # should not be created here.
+                p.pay()
+                self.assertEqual(
+                    self.store.find(Commission, payment=p).count(), 0)
+
+        # Setting as paid should create all the missing commissions
+        sale.set_paid()
+        for p in sale.payments:
+            self.assertEqual(
+                self.store.find(Commission, payment=p).count(), 1)
+
     def testGetClientRole(self):
         sale = self.create_sale()
         client_role = sale.get_client_role()
@@ -855,7 +933,7 @@ class TestSale(DomainTest):
         sale = self.create_sale()
         self.add_product(sale)
         sale.order()
-        self.add_payments(sale, method_type='money')
+        self.add_payments(sale, method_type=u'money')
         sale.confirm()
 
         self.failUnless(sale.only_paid_with_money())
@@ -863,7 +941,7 @@ class TestSale(DomainTest):
         sale = self.create_sale()
         self.add_product(sale)
         sale.order()
-        self.add_payments(sale, method_type='check')
+        self.add_payments(sale, method_type=u'check')
         sale.confirm()
 
         self.failIf(sale.only_paid_with_money())
@@ -884,18 +962,18 @@ class TestSale(DomainTest):
         self.add_product(sale)
         sale.order()
 
-        payment = self.add_payments(sale, method_type='check')[0]
+        payment = self.add_payments(sale, method_type=u'check')[0]
 
         account = self.create_account()
         payment.method.destination_account = account
 
-        self.failIf(account.transactions)
+        self.assertTrue(account.transactions.is_empty())
 
         paid_date = datetime.datetime(2010, 1, 2)
         sale.confirm()
         payment.pay(paid_date)
 
-        self.failUnless(account.transactions)
+        self.assertFalse(account.transactions.is_empty())
         self.assertEquals(account.transactions.count(), 1)
 
         t = account.transactions[0]
@@ -907,19 +985,19 @@ class TestSale(DomainTest):
         sale = self.create_sale()
         self.add_product(sale)
         sale.order()
-        payment = self.add_payments(sale, method_type='money')[0]
+        payment = self.add_payments(sale, method_type=u'money')[0]
         account = self.create_account()
         payment.method.destination_account = account
-        self.failIf(account.transactions)
+        self.assertTrue(account.transactions.is_empty())
         sale.confirm()
-        self.failUnless(account.transactions)
+        self.assertFalse(account.transactions.is_empty())
 
     def testPayments(self):
         sale = self.create_sale()
         self.add_product(sale)
         sale.order()
 
-        check_payment = self.add_payments(sale, method_type='check')[0]
+        check_payment = self.add_payments(sale, method_type=u'check')[0]
         self.assertEqual(sale.payments.count(), 1)
         self.assertTrue(check_payment in sale.payments)
         self.assertEqual(sale.group.payments.count(), 1)
@@ -932,12 +1010,34 @@ class TestSale(DomainTest):
         self.assertEqual(sale.group.payments.count(), 1)
         self.assertTrue(check_payment in sale.group.payments)
 
-        money_payment = self.add_payments(sale, method_type='money')[0]
+        money_payment = self.add_payments(sale, method_type=u'money')[0]
         self.assertEqual(sale.payments.count(), 1)
         self.assertTrue(money_payment in sale.payments)
         self.assertEqual(sale.group.payments.count(), 2)
         self.assertTrue(money_payment in sale.group.payments)
 
+    def test_get_total_sale_amount(self):
+        sale = self.create_sale()
+        product = self.create_product(price=10)
+        sale.add_sellable(product.sellable, quantity=5)
+
+        # Normal
+        self.assertEqual(sale.get_total_sale_amount(), 50)
+        sale.discount_value = 10
+        self.assertEqual(sale.get_total_sale_amount(), 40)
+        sale.surcharge_value = 5
+        self.assertEqual(sale.get_total_sale_amount(), 45)
+
+        # Pre-calculated
+        subtotal = 50
+        sale.surcharge_value = 0
+        sale.discount_value = 0
+        self.assertEqual(sale.get_total_sale_amount(subtotal), 50)
+        sale.discount_value = 10
+        self.assertEqual(sale.get_total_sale_amount(subtotal), 40)
+        sale.surcharge_value = 5
+        self.assertEqual(sale.get_total_sale_amount(subtotal), 45)
+
 
 class TestSaleItem(DomainTest):
     def testGetTotal(self):
@@ -951,7 +1051,7 @@ class TestSaleItem(DomainTest):
         sale = self.create_sale()
         product = self.create_product()
         sale_item = sale.add_sellable(product.sellable)
-        self.assertEqual(sale_item.get_description(), 'Description')
+        self.assertEqual(sale_item.get_description(), u'Description')
 
     def testIsService(self):
         sale = self.create_sale()
@@ -969,17 +1069,15 @@ class TestSalePaymentMethodView(DomainTest):
         # Let's create two sales: one with money and another with bill.
         sale_money = self.create_sale()
         self.add_product(sale_money)
-        self.add_payments(sale_money, method_type='money')
+        self.add_payments(sale_money, method_type=u'money')
 
         sale_bill = self.create_sale()
         self.add_product(sale_bill)
-        self.add_payments(sale_bill, method_type='bill')
+        self.add_payments(sale_bill, method_type=u'bill')
 
         # If we search for sales that have money payment...
-        method = PaymentMethod.get_by_name(self.trans, 'money')
-        res = SalePaymentMethodView.select_by_payment_method(
-                                                connection=self.trans,
-                                                method=method)
+        method = PaymentMethod.get_by_name(self.store, u'money')
+        res = SalePaymentMethodView.find_by_payment_method(self.store, method)
         # Initial database already has a money payment
         self.assertEquals(res.count(), 2)
         # Only the first sale should be in the results.
@@ -987,33 +1085,27 @@ class TestSalePaymentMethodView(DomainTest):
         self.assertFalse(sale_bill in [r.sale for r in res])
 
         # We don't have any sale with deposit payment method.
-        method = PaymentMethod.get_by_name(self.trans, 'deposit')
-        res = SalePaymentMethodView.select_by_payment_method(
-                                                connection=self.trans,
-                                                method=method)
+        method = PaymentMethod.get_by_name(self.store, u'deposit')
+        res = SalePaymentMethodView.find_by_payment_method(self.store, method)
         self.assertEquals(res.count(), 0)
 
     def test_with_two_payment_method_sales(self):
         # Create sale with two payments with different methods: money and bill.
         sale_two_methods = self.create_sale()
         self.add_product(sale_two_methods)
-        self.add_payments(sale_two_methods, method_type='money')
-        self.add_payments(sale_two_methods, method_type='bill')
+        self.add_payments(sale_two_methods, method_type=u'money')
+        self.add_payments(sale_two_methods, method_type=u'bill')
 
         # The sale should appear when searching for money payments...
-        method = PaymentMethod.get_by_name(self.trans, 'money')
-        res = SalePaymentMethodView.select_by_payment_method(
-                                                connection=self.trans,
-                                                method=method)
+        method = PaymentMethod.get_by_name(self.store, u'money')
+        res = SalePaymentMethodView.find_by_payment_method(self.store, method)
         # Initial database already has a money payment
         self.assertEquals(res.count(), 2)
         self.assertTrue(sale_two_methods in [r.sale for r in res])
 
         # And bill payments...
-        method = PaymentMethod.get_by_name(self.trans, 'bill')
-        res = SalePaymentMethodView.select_by_payment_method(
-                                                connection=self.trans,
-                                                method=method)
+        method = PaymentMethod.get_by_name(self.store, u'bill')
+        res = SalePaymentMethodView.find_by_payment_method(self.store, method)
         # Initial database already has a bill payment
         self.assertEquals(res.count(), 2)
         self.assertTrue(sale_two_methods in [r.sale for r in res])
@@ -1023,11 +1115,9 @@ class TestSalePaymentMethodView(DomainTest):
         # once in the results.
         sale_two_inst = self.create_sale()
         self.add_product(sale_two_inst)
-        self.add_payments(sale_two_inst, method_type='deposit', installments=2)
+        self.add_payments(sale_two_inst, method_type=u'deposit', installments=2)
 
-        method = PaymentMethod.get_by_name(self.trans, 'deposit')
-        res = SalePaymentMethodView.select_by_payment_method(
-                                                connection=self.trans,
-                                                method=method)
+        method = PaymentMethod.get_by_name(self.store, u'deposit')
+        res = SalePaymentMethodView.find_by_payment_method(self.store, method)
         self.assertEquals(res.count(), 1)
         self.assertTrue(sale_two_inst in [r.sale for r in res])
