@@ -22,7 +22,8 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 
-from stoqlib.domain.product import Storable
+from kiwi.currency import currency
+
 from stoqlib.domain.test.domaintest import DomainTest
 
 
@@ -42,7 +43,7 @@ class TestStockDecrease(DomainTest):
         sellable = self.create_sellable()
         decrease.add_sellable(sellable, quantity=5)
 
-        item = 'test purpose'
+        item = u'test purpose'
         self.failUnlessRaises(TypeError, decrease.remove_item, item)
         item = decrease.get_items()[0]
         decrease.remove_item(item)
@@ -51,7 +52,7 @@ class TestStockDecrease(DomainTest):
     def test_get_status_name(self):
         decrease = self.create_stock_decrease()
         self.failUnlessRaises(TypeError,
-                              decrease.get_status_name, 'invalid status')
+                              decrease.get_status_name, u'invalid status')
 
     def testConfirm(self):
         decrease = self.create_stock_decrease()
@@ -59,9 +60,7 @@ class TestStockDecrease(DomainTest):
         decrease.add_sellable(sellable, quantity=5)
 
         branch = decrease.branch
-
-        storable = Storable(product=sellable.product, connection=self.trans)
-        storable.increase_stock(100, branch)
+        storable = self.create_storable(sellable.product, branch, 100)
 
         self.assertEqual(storable.get_stock_item(branch).quantity, 100)
 
@@ -71,6 +70,17 @@ class TestStockDecrease(DomainTest):
 
         self.assertEqual(storable.get_stock_item(branch).quantity, 95)
 
+    def test_get_total_cost(self):
+        decrease = self.create_stock_decrease()
+        sellable1 = self.create_sellable()
+        sellable1.cost = currency('100')
+        sellable2 = self.create_sellable()
+        sellable2.cost = currency('10')
+        decrease.add_sellable(sellable1, quantity=2)
+        decrease.add_sellable(sellable2, quantity=5)
+
+        self.assertEquals(decrease.get_total_cost(), 250)
+
 
 class TestStockDecreaseItem(DomainTest):
 
@@ -78,4 +88,10 @@ class TestStockDecreaseItem(DomainTest):
         decrease = self.create_stock_decrease()
         product = self.create_product()
         decrease_item = decrease.add_sellable(product.sellable)
-        self.assertEqual(decrease_item.get_description(), 'Description')
+        self.assertEqual(decrease_item.get_description(), u'Description')
+
+    def test_get_total(self):
+        item = self.create_stock_decrease_item()
+        item.cost = currency('100')
+        item.quantity = 10
+        self.assertEqual(item.get_total(), 1000)
