@@ -57,16 +57,14 @@ class TestTransferOrder(DomainTest):
         item = self.create_transfer_order_item(order, quantity=2)
         self.assertEqual(order.can_close(), True)
 
-        product = Product.selectOneBy(sellable=item.sellable,
-                                      connection=self.trans)
+        product = self.store.find(Product, sellable=item.sellable).one()
         storable = product.storable
         before_qty = storable.get_balance_for_branch(order.source_branch)
         order.send_item(item)
         after_qty = storable.get_balance_for_branch(order.source_branch)
         self.assertEqual(after_qty, before_qty - sent_qty)
 
-        history = ProductHistory.selectOneBy(sellable=item.sellable,
-                                             connection=self.trans)
+        history = self.store.find(ProductHistory, sellable=item.sellable).one()
         self.failIf(history is None)
         self.assertEqual(history.quantity_transfered, sent_qty)
 
@@ -105,22 +103,22 @@ class TestTransferOrder(DomainTest):
 
     def testGetSourceBranchName(self):
         order = self.create_transfer_order()
-        self.assertEquals(order.get_source_branch_name(), 'Source')
+        self.assertEquals(order.get_source_branch_name(), u'Source')
 
     def testGetDestinationBranchName(self):
         order = self.create_transfer_order()
         self.assertEquals(order.get_destination_branch_name(),
-                          'Dest')
+                          u'Dest')
 
     def testGetSourceResponsibleName(self):
         order = self.create_transfer_order()
         self.assertEquals(order.get_source_responsible_name(),
-                          'Ipswich')
+                          u'Ipswich')
 
     def testGetDestinationResponsibleName(self):
         order = self.create_transfer_order()
         self.assertEquals(order.get_destination_responsible_name(),
-                          'Bolton')
+                          u'Bolton')
 
     def testGetTotalItemsTransfer(self):
         order = self.create_transfer_order()
