@@ -25,14 +25,15 @@
 import datetime
 from decimal import Decimal
 
-from stoqlib.database.orm import Viewable
 from stoqlib.database.runtime import get_current_branch
+from stoqlib.database.viewable import Viewable
 from stoqlib.domain.purchase import PurchaseOrder, QuoteGroup
 from stoqlib.domain.test.domaintest import DomainTest
 from stoqlib.domain.views import AccountView
 from stoqlib.domain.views import ProductComponentView
 from stoqlib.domain.views import ProductFullStockView
 from stoqlib.domain.views import ProductFullStockItemView
+from stoqlib.domain.views import ProductFullStockItemSupplierView
 from stoqlib.domain.views import QuotationView
 from stoqlib.domain.views import SellableCategoryView
 from stoqlib.domain.views import SellableFullStockView
@@ -56,7 +57,7 @@ class TestViewsGeneric(DomainTest):
     """Generic tests for views"""
 
     def _test_view(self, view):
-        results_list = list(view.select(connection=self.trans))
+        results_list = self.store.find(view)
 
         # See if there are no duplicates
         ids_set = set()
@@ -78,62 +79,56 @@ class TestProductFullStockView(DomainTest):
         branch = self.create_branch()
         p1 = self.create_product(branch=branch, stock=1)
 
-        results = ProductFullStockView.select_by_branch(
-            None, branch, connection=self.trans)
+        results = ProductFullStockView.find_by_branch(self.store, branch)
         self.failUnless(list(results))
         # FIXME: Storm does not support count() with group_by
         #self.assertEquals(results.count(), 1)
         self.assertEquals(len(list(results)), 1)
 
-        results = ProductFullStockView.select_by_branch(
-            ProductFullStockView.q.product_id == p1.id,
-            branch, connection=self.trans)
+        results = ProductFullStockView.find_by_branch(self.store, branch)
+        results = results.find(ProductFullStockView.product_id == p1.id)
         self.failUnless(list(results))
         self.assertEquals(len(list(results)), 1)
 
     def testUnitDescription(self):
         p1 = self.create_product()
         p1.sellable.unit = self.create_sellable_unit()
-        p1.sellable.unit.description = "kg"
+        p1.sellable.unit.description = u"kg"
 
         p2 = self.create_product()
 
-        results = ProductFullStockView.select_by_branch(
-            ProductFullStockView.q.product_id == p1.id,
-            None, connection=self.trans)
+        results = ProductFullStockView.find_by_branch(self.store, None)
+        results = results.find(ProductFullStockView.product_id == p1.id)
         self.failUnless(list(results))
         product_view = results[0]
-        self.assertEquals(product_view.get_unit_description(), "kg")
+        self.assertEquals(product_view.get_unit_description(), u"kg")
 
-        results = ProductFullStockView.select_by_branch(
-            ProductFullStockView.q.product_id == p2.id,
-            None, connection=self.trans)
+        results = ProductFullStockView.find_by_branch(self.store, None).find(
+                                            ProductFullStockView.product_id == p2.id)
         self.failUnless(list(results))
         product_view = results[0]
-        self.assertEquals(product_view.get_unit_description(), "un")
+        self.assertEquals(product_view.get_unit_description(), u"un")
 
     def testGetProductAndCategoryDescription(self):
         p1 = self.create_product()
         p1.sellable.category = self.create_sellable_category()
-        p1.sellable.category.description = "category"
+        p1.sellable.category.description = u"category"
 
         p2 = self.create_product()
 
-        results = ProductFullStockView.select_by_branch(
-            ProductFullStockView.q.product_id == p1.id,
-            None, connection=self.trans)
+        results = ProductFullStockView.find_by_branch(self.store, None).find(
+                                    ProductFullStockView.product_id == p1.id)
         self.failUnless(list(results))
         pv = results[0]
         desc = pv.get_product_and_category_description()
-        self.assertEquals(desc, "[category] Description")
+        self.assertEquals(desc, u"[category] Description")
 
-        results = ProductFullStockView.select_by_branch(
-            ProductFullStockView.q.product_id == p2.id,
-            None, connection=self.trans)
+        results = ProductFullStockView.find_by_branch(self.store, None).find(
+                                    ProductFullStockView.product_id == p2.id)
         self.failUnless(list(results))
         pv = results[0]
         desc = pv.get_product_and_category_description()
-        self.assertEquals(desc, "Description")
+        self.assertEquals(desc, u"Description")
 
     def testStockCost(self):
         branch = self.create_branch()
@@ -141,26 +136,23 @@ class TestProductFullStockView(DomainTest):
 
         p2 = self.create_product()
 
-        results = ProductFullStockView.select_by_branch(
-            ProductFullStockView.q.product_id == p1.id,
-            None, connection=self.trans)
+        results = ProductFullStockView.find_by_branch(self.store, None).find(
+                                    ProductFullStockView.product_id == p1.id)
         self.failUnless(list(results))
         pv = results[0]
         self.assertEquals(pv.stock_cost, 10)
 
-        branch = get_current_branch(self.trans)
-        results = ProductFullStockView.select_by_branch(
-            ProductFullStockView.q.product_id == p2.id,
-            None, connection=self.trans)
+        branch = get_current_branch(self.store)
+        results = ProductFullStockView.find_by_branch(self.store, None).find(
+                                    ProductFullStockView.product_id == p2.id)
         self.failUnless(list(results))
         pv = results[0]
         self.assertEquals(pv.stock_cost, 0)
 
     def testPrice(self):
         p1 = self.create_product()
-        results = ProductFullStockView.select_by_branch(
-            ProductFullStockView.q.product_id == p1.id,
-            None, connection=self.trans)
+        results = ProductFullStockView.find_by_branch(self.store, None).find(
+                                    ProductFullStockView.product_id == p1.id)
         self.failUnless(list(results))
         pv = results[0]
         self.assertEquals(pv.price, 10)
@@ -175,9 +167,8 @@ class TestProductFullStockView(DomainTest):
         sellable.on_sale_start_date = yesterday
         sellable.on_sale_end_date = tomorrow
 
-        results = ProductFullStockView.select_by_branch(
-            ProductFullStockView.q.product_id == p1.id,
-            None, connection=self.trans)
+        results = ProductFullStockView.find_by_branch(self.store, None).find(
+                                    ProductFullStockView.product_id == p1.id)
         self.assertEquals(results[0].price, Decimal('5.55'))
 
         # Testing with a sale price set, but in the past
@@ -186,9 +177,8 @@ class TestProductFullStockView(DomainTest):
         sellable.on_sale_start_date = date1
         sellable.on_sale_end_date = date2
 
-        results = ProductFullStockView.select_by_branch(
-            ProductFullStockView.q.product_id == p1.id,
-            None, connection=self.trans)
+        results = ProductFullStockView.find_by_branch(self.store, None).find(
+                                    ProductFullStockView.product_id == p1.id)
         self.assertEquals(results[0].price, 10)
 
     def test_with_unblocked_sellables_query(self):
@@ -200,40 +190,42 @@ class TestProductFullStockView(DomainTest):
         supplier = self.create_supplier()
 
         # Product should appear when querying without a supplier
-        query = Sellable.get_unblocked_sellables_query(self.trans)
-        results = ProductFullStockView.select(query, connection=self.trans)
+        query = Sellable.get_unblocked_sellables_query(self.store)
+        results = self.store.find(ProductFullStockView, query)
         self.assertTrue(p1.id in [p.product_id for p in results])
 
         # But should not appear when querying with a supplier
-        query = Sellable.get_unblocked_sellables_query(self.trans,
+        # When querying using the supplier, we should use the
+        # ProductFullStockSupplierView instead.
+        query = Sellable.get_unblocked_sellables_query(self.store,
                                                        supplier=supplier)
-        results = ProductFullStockView.select(query, connection=self.trans)
+        results = self.store.find(ProductFullStockItemSupplierView, query)
         self.assertFalse(p1.id in [p.id for p in results])
 
         # Now relate the two
-        ProductSupplierInfo(connection=self.trans,
+        ProductSupplierInfo(store=self.store,
                             supplier=supplier,
                             product=p1,
                             is_main_supplier=True)
 
         # And it should appear now
-        query = Sellable.get_unblocked_sellables_query(self.trans,
+        query = Sellable.get_unblocked_sellables_query(self.store,
                                                        supplier=supplier)
-        results = ProductFullStockView.select(query, connection=self.trans)
+        results = self.store.find(ProductFullStockItemSupplierView, query)
         self.assertTrue(p1.id in [s.product_id for s in results])
 
         # But should not appear for a different supplier
         other_supplier = self.create_supplier()
-        query = Sellable.get_unblocked_sellables_query(self.trans,
+        query = Sellable.get_unblocked_sellables_query(self.store,
                                                        supplier=other_supplier)
-        results = ProductFullStockView.select(query, connection=self.trans)
+        results = self.store.find(ProductFullStockItemSupplierView, query)
         self.assertFalse(p1.id in [s.product_id for s in results])
 
 
 class TestProductComponentView(DomainTest):
     def testSellable(self):
         pc1 = self.create_product_component()
-        results = ProductComponentView.select(connection=self.trans)
+        results = self.store.find(ProductComponentView)
         self.failUnless(list(results))
         pcv = results[0]
         self.assertEquals(pcv.sellable, pc1.product.sellable)
@@ -245,14 +237,12 @@ class TestSellableFullStockView(DomainTest):
         p1 = self.create_product(branch=branch, stock=1)
         p2 = self.create_product()
 
-        results = SellableFullStockView.select_by_branch(
-            SellableFullStockView.q.product_id == p1.id,
-            branch, connection=self.trans)
+        results = SellableFullStockView.find_by_branch(self.store, branch).find(
+                                        SellableFullStockView.product_id == p1.id)
         self.failUnless(list(results))
 
-        results = SellableFullStockView.select_by_branch(
-            ProductFullStockView.q.product_id == p2.id,
-            branch, connection=self.trans)
+        results = SellableFullStockView.find_by_branch(self.store, branch).find(
+                                        ProductFullStockView.product_id == p2.id,)
         self.failUnless(list(results))
         # FIXME: Storm does not support count() with group_by
         #self.assertEquals(results.count(), 1)
@@ -262,9 +252,8 @@ class TestSellableFullStockView(DomainTest):
         branch = self.create_branch()
         p1 = self.create_product(branch=branch, stock=1)
 
-        results = SellableFullStockView.select_by_branch(
-            SellableFullStockView.q.product_id == p1.id,
-            branch, connection=self.trans)
+        results = SellableFullStockView.find_by_branch(self.store, branch).find(
+                                        SellableFullStockView.product_id == p1.id)
         self.failUnless(list(results))
 
         self.assertEquals(results[0].sellable, p1.sellable)
@@ -272,9 +261,8 @@ class TestSellableFullStockView(DomainTest):
     def testPrice(self):
         branch = self.create_branch()
         p1 = self.create_product(branch=branch, stock=1, price=Decimal('10.15'))
-        results = SellableFullStockView.select_by_branch(
-            SellableFullStockView.q.product_id == p1.id,
-            branch, connection=self.trans)
+        results = SellableFullStockView.find_by_branch(self.store, branch).find(
+                                        SellableFullStockView.product_id == p1.id)
         self.failUnless(list(results))
 
         self.assertEquals(results[0].price, Decimal('10.15'))
@@ -289,9 +277,8 @@ class TestSellableFullStockView(DomainTest):
         sellable.on_sale_start_date = yesterday
         sellable.on_sale_end_date = tomorrow
 
-        results = SellableFullStockView.select_by_branch(
-            SellableFullStockView.q.product_id == p1.id,
-            branch, connection=self.trans)
+        results = SellableFullStockView.find_by_branch(self.store, branch).find(
+                                        SellableFullStockView.product_id == p1.id)
         self.assertEquals(results[0].price, Decimal('5.55'))
 
         # Testing with a sale price set, but in the past
@@ -300,70 +287,55 @@ class TestSellableFullStockView(DomainTest):
         sellable.on_sale_start_date = date1
         sellable.on_sale_end_date = date2
 
-        results = SellableFullStockView.select_by_branch(
-            SellableFullStockView.q.product_id == p1.id,
-            branch, connection=self.trans)
+        results = SellableFullStockView.find_by_branch(self.store, branch).find(
+                                        SellableFullStockView.product_id == p1.id)
         self.assertEquals(results[0].price, Decimal('10.15'))
 
 
 class TestSellableCategoryView(DomainTest):
     def testCategory(self):
         category = self.create_sellable_category()
-        results = SellableCategoryView.select(
-            SellableCategoryView.q.id == category.id,
-            connection=self.trans)
+        results = self.store.find(SellableCategoryView, id=category.id)
         self.failUnless(list(results))
         self.assertEquals(results[0].category, category)
 
     def testGetCommission(self):
         category = self.create_sellable_category()
-        results = SellableCategoryView.select(
-            SellableCategoryView.q.id == category.id,
-            connection=self.trans)
+        results = self.store.find(SellableCategoryView, id=category.id)
         self.failUnless(list(results))
         self.assertEquals(results[0].get_commission(), None)
 
         base_category = self.create_sellable_category()
         self.create_commission_source(category=base_category)
         category.category = base_category
-        results = SellableCategoryView.select(
-            SellableCategoryView.q.id == category.id,
-            connection=self.trans)
+        results = self.store.find(SellableCategoryView, id=category.id)
         self.assertEquals(results[0].get_commission(), 10)
 
         self.create_commission_source(category=category)
-        results = SellableCategoryView.select(
-            SellableCategoryView.q.id == category.id,
-            connection=self.trans)
+        results = self.store.find(SellableCategoryView, id=category.id)
         self.assertEquals(results[0].get_commission(), 10)
 
     def testGetInstallmentsCommission(self):
         category = self.create_sellable_category()
-        results = SellableCategoryView.select(
-            SellableCategoryView.q.id == category.id,
-            connection=self.trans)
+        results = self.store.find(SellableCategoryView, id=category.id)
         self.failUnless(list(results))
         self.assertEquals(results[0].get_installments_commission(), None)
 
         base_category = self.create_sellable_category()
         category.category = base_category
         self.create_commission_source(category=base_category)
-        results = SellableCategoryView.select(
-            SellableCategoryView.q.id == category.id,
-            connection=self.trans)
+        results = self.store.find(SellableCategoryView, id=category.id)
         self.assertEquals(results[0].get_installments_commission(), 1)
 
         self.create_commission_source(category=category)
-        results = SellableCategoryView.select(
-            SellableCategoryView.q.id == category.id,
-            connection=self.trans)
+        results = self.store.find(SellableCategoryView, id=category.id)
         self.assertEquals(results[0].get_installments_commission(), 1)
 
 
 class TestQuotationView(DomainTest):
     def testGroupQuotationPurchase(self):
         order = self.create_purchase_order()
-        quote = QuoteGroup(connection=self.trans, branch=order.branch)
+        quote = QuoteGroup(store=self.store, branch=order.branch)
         order.status = PurchaseOrder.ORDER_QUOTING
         quote.add_item(order)
 
@@ -374,8 +346,7 @@ class TestQuotationView(DomainTest):
         self.assertFalse(quotations[0].is_closed())
         quotations[0].close()
 
-        results = QuotationView.select(
-                QuotationView.q.id == quotations[0].id, connection=self.trans)
+        results = self.store.find(QuotationView, id=quotations[0].id)
         self.failUnless(list(results))
         self.assertEquals(results.count(), 1)
         self.assertEquals(results[0].group, quote)
@@ -385,83 +356,73 @@ class TestQuotationView(DomainTest):
 
 class TestSoldItemView(DomainTest):
     def testSelectByBranchData(self):
-        branch = get_current_branch(self.trans)
+        branch = get_current_branch(self.store)
         sale = self.create_sale()
         sale.branch = branch
         sellable = self.add_product(sale)
         sale.order()
-        self.add_payments(sale, method_type='money')
+        self.add_payments(sale, method_type=u'money')
         sale.confirm()
 
-        results = SoldItemView.select_by_branch_date(None, None, None,
-                                                     connection=self.trans)
-        self.failUnless(results)
+        results = SoldItemView.find_by_branch_date(self.store, None, None)
+        self.assertFalse(results.is_empty())
 
-        results = SoldItemView.select_by_branch_date(None, branch, None,
-                                                     connection=self.trans)
-        self.failUnless(results)
+        results = SoldItemView.find_by_branch_date(self.store, branch, None)
+        self.assertFalse(results.is_empty())
 
-        results = SoldItemView.select_by_branch_date(
-            SoldItemView.q.id == sellable.id, branch, None,
-            connection=self.trans)
+        results = SoldItemView.find_by_branch_date(self.store, branch, None).find(
+                                                    SoldItemView.id == sellable.id)
         # FIXME: Storm does not support count() with group_by
         #self.assertEquals(results.count(), 1)
         self.assertEquals(len(list(results)), 1)
 
         today = datetime.date.today()
-        results = SoldItemView.select_by_branch_date(
-            SoldItemView.q.id == sellable.id, None, today,
-            connection=self.trans)
+        results = SoldItemView.find_by_branch_date(self.store, None, today).find(
+                                                    SoldItemView.id == sellable.id)
         self.assertEquals(len(list(results)), 1)
 
         yesterday = today - datetime.timedelta(days=1)
-        results = SoldItemView.select_by_branch_date(
-            SoldItemView.q.id == sellable.id, None, (yesterday, today),
-            connection=self.trans)
+        results = SoldItemView.find_by_branch_date(self.store, None,
+                                                     (yesterday, today)).find(
+                                    SoldItemView.id == sellable.id)
         self.assertEquals(len(list(results)), 1)
 
         yesterday = today - datetime.timedelta(days=1)
-        results = SoldItemView.select_by_branch_date(
-            None, None, (yesterday, today),
-            connection=self.trans)
+        results = SoldItemView.find_by_branch_date(self.store, None,
+                                                     (yesterday, today))
 
-        self.failUnless(results)
+        self.assertFalse(results.is_empty())
 
     def testAverageCost(self):
         sale = self.create_sale()
         sellable = self.add_product(sale)
         sale.order()
-        self.add_payments(sale, method_type='money')
+        self.add_payments(sale, method_type=u'money')
         sale.confirm()
 
-        results = SoldItemView.select(
-            SoldItemView.q.id == sellable.id,
-            connection=self.trans)
-        self.failUnless(results)
+        results = self.store.find(SoldItemView, id=sellable.id)
+        self.assertFalse(results.is_empty())
         self.assertEquals(results[0].average_cost, 0)
 
 
 class TestAccountView(DomainTest):
     def testAccount(self):
         account = self.create_account()
-        results = AccountView.select(AccountView.q.id == account.id,
-                                     connection=self.trans)
+        results = self.store.find(AccountView, id=account.id)
         self.failUnless(list(results))
         self.assertEquals(results[0].account, account)
 
     def testParentAccount(self):
         account = self.create_account()
         account.parent = self.create_account()
-        results = AccountView.select(AccountView.q.id == account.id,
-                                     connection=self.trans)
+        results = self.store.find(AccountView, id=account.id)
         self.failUnless(list(results))
         self.assertEquals(results[0].parent_account, account.parent)
 
     def testMatches(self):
         account = self.create_account()
         account.parent = self.create_account()
-        results = AccountView.select(AccountView.q.id == account.id,
-                                     connection=self.trans)
+        results = self.store.find(AccountView, id=account.id)
         self.failUnless(list(results))
         self.failUnless(results[0].matches(account.id))
         self.failUnless(results[0].matches(account.parent.id))
@@ -469,22 +430,20 @@ class TestAccountView(DomainTest):
     def testGetCombinedValue(self):
         a1 = self.create_account()
         a2 = self.create_account()
-        results = AccountView.select(AccountView.q.id == a1.id,
-                                     connection=self.trans)
+        results = self.store.find(AccountView, id=a1.id)
         self.failUnless(list(results))
         self.assertEquals(results[0].get_combined_value(), 0)
 
         t1 = self.create_account_transaction(a1, 1)
         t1.source_account = a1
         t1.account = a2
-        t1.sync()
+        self.store.flush()
         t2 = self.create_account_transaction(a1, 9)
         t2.source_account = a1
         t2.account = a2
-        t2.sync()
+        self.store.flush()
 
-        results = AccountView.select(AccountView.q.id == a1.id,
-                                     connection=self.trans)
+        results = self.store.find(AccountView, id=a1.id)
         self.failUnless(list(results))
         self.assertEquals(results.count(), 1)
         # The negative sum of t1 and t2
@@ -493,14 +452,13 @@ class TestAccountView(DomainTest):
         t3 = self.create_account_transaction(a2, 10)
         t3.source_account = a2
         t3.account = a1
-        t3.sync()
+        self.store.flush()
         t4 = self.create_account_transaction(a2, 90)
         t4.source_account = a2
         t4.account = a1
-        t4.sync()
+        self.store.flush()
 
-        results = AccountView.select(AccountView.q.id == a1.id,
-                                     connection=self.trans)
+        results = self.store.find(AccountView, id=a1.id)
         self.failUnless(list(results))
         self.assertEquals(results.count(), 1)
         # The negative sum of t1 and t2 plus the sum of t3 and t4
@@ -508,17 +466,16 @@ class TestAccountView(DomainTest):
 
     def testRepr(self):
         a1 = self.create_account()
-        results = AccountView.select(AccountView.q.id == a1.id,
-                                     connection=self.trans)
+        results = self.store.find(AccountView, id=a1.id)
         self.failUnless(list(results))
-        self.assertEquals(repr(results[0]), '<AccountView Test Account>')
+        self.assertEquals(repr(results[0]), u'<AccountView Test Account>')
 
 
 class TestProductFullStockItemView(DomainTest):
 
     def testSelect(self):
         from stoqlib.domain.product import Product
-        product = Product.select(connection=self.trans)[0]
+        product = self.store.find(Product)[0]
 
         order = self.create_purchase_order()
         order.add_item(product.sellable, 1)
@@ -530,6 +487,6 @@ class TestProductFullStockItemView(DomainTest):
 
         # This viewable should return only one item for each existing product,
         # event if there is more than one purchase order for the product.
-        results = ProductFullStockItemView.select(connection=self.trans)
+        results = self.store.find(ProductFullStockItemView)
         ids = [r.id for r in results]
         self.assertEquals(ids.count(product.sellable.id), 1)
