@@ -28,11 +28,13 @@ import datetime
 
 from kiwi.currency import currency
 from kiwi.log import Logger
+from storm.expr import And, LeftJoin, Or
+from storm.references import Reference
+from storm.store import AutoReload
 
-from stoqlib.database.orm import AutoReload
-from stoqlib.database.orm import PriceCol
-from stoqlib.database.orm import IntCol, DateTimeCol, ForeignKey, UnicodeCol
-from stoqlib.database.orm import AND, const, OR, LeftJoin
+from stoqlib.database.expr import Date, TransactionTimestamp
+from stoqlib.database.properties import (PriceCol, DateTimeCol, IntCol,
+                                  UnicodeCol)
 from stoqlib.database.runtime import get_current_station
 from stoqlib.domain.base import Domain
 from stoqlib.domain.payment.payment import Payment
@@ -64,6 +66,8 @@ class Till(Domain):
     till before you closed the previously opened one.
     """
 
+    __storm_table__ = 'till'
+
     #: this till is created, but not yet opened
     STATUS_PENDING = 0
 
@@ -92,27 +96,27 @@ class Till(Domain):
     #: When the till was closed or None if it has not yet been closed
     closing_date = DateTimeCol(default=None)
 
+    station_id = IntCol()
+
     #: the |branchstation| associated with the till, eg the computer
     #: which opened it.
-    station = ForeignKey('BranchStation')
+    station = Reference(station_id, 'BranchStation.id')
 
     #
     # Classmethods
     #
 
     @classmethod
-    def get_current(cls, conn):
+    def get_current(cls, store):
         """Fetches the Till for the current station.
 
-        :param conn: a database connection
+        :param store: a store
         :returns: a Till instance or None
         """
-        station = get_current_station(conn)
+        station = get_current_station(store)
         assert station is not None
 
-        till = cls.selectOneBy(status=Till.STATUS_OPEN,
-                               station=station,
-                               connection=conn)
+        till = store.find(cls, status=Till.STATUS_OPEN, station=station).one()
         if till and till.needs_closing():
             raise TillError(
                 _("You need to close the till opened at %s before "
@@ -122,34 +126,33 @@ class Till(Domain):
         return till
 
     @classmethod
-    def get_last_opened(cls, conn):
+    def get_last_opened(cls, store):
         """Fetches the last Till which was opened.
         If in doubt, use Till.get_current instead. This method is a special case
         which is used to be able to close a till without calling get_current()
 
-        :param conn: a database connection
+        :param store: a store
         """
 
-        result = Till.selectBy(status=Till.STATUS_OPEN,
-                               station=get_current_station(conn),
-                               connection=conn).orderBy('opening_date')
-        if result:
+        result = store.find(Till,
+                            status=Till.STATUS_OPEN,
+                            station=get_current_station(store))
+        result = result.order_by(Till.opening_date)
+        if not result.is_empty():
             return result[0]
 
     @classmethod
-    def get_last(cls, conn):
-        result = Till.selectBy(station=get_current_station(conn),
-                               connection=conn).orderBy('opening_date')
-        if result:
-            return result[-1]
+    def get_last(cls, store):
+        station = get_current_station(store)
+        result = store.find(Till, station=station).order_by(Till.opening_date)
+        return result.last()
 
     @classmethod
-    def get_last_closed(cls, conn):
-        results = Till.selectBy(status=Till.STATUS_CLOSED,
-                                station=get_current_station(conn),
-                                connection=conn).orderBy('opening_date')
-        if results:
-            return results[-1]
+    def get_last_closed(cls, store):
+        station = get_current_station(store)
+        result = store.find(Till, station=station,
+                            status=Till.STATUS_CLOSED).order_by(Till.opening_date)
+        return result.last()
 
     #
     # Till methods
@@ -167,9 +170,9 @@ class Till(Domain):
 
         # Make sure that the till has not been opened today
         today = datetime.date.today()
-        if Till.select(AND(const.date(Till.q.opening_date) >= today,
-                           Till.q.station_id == self.station.id),
-                       connection=self.get_connection()):
+        if not self.store.find(Till,
+            And(Date(Till.opening_date) >= today,
+                Till.station_id == self.station.id)).is_empty():
             raise TillError(_("A till has already been opened today"))
 
         last_till = self._get_last_closed_till()
@@ -183,7 +186,7 @@ class Till(Domain):
 
         self.initial_cash_amount = initial_cash_amount
 
-        self.opening_date = const.NOW()
+        self.opening_date = TransactionTimestamp()
         self.status = Till.STATUS_OPEN
 
     def close_till(self):
@@ -202,7 +205,7 @@ class Till(Domain):
                                "assistance"))
 
         self.final_cash_amount = self.get_balance()
-        self.closing_date = const.NOW()
+        self.closing_date = TransactionTimestamp()
         self.status = Till.STATUS_CLOSED
 
     def add_entry(self, payment):
@@ -263,7 +266,7 @@ class Till(Domain):
         :returns: the balance
         :rtype: currency
         """
-        total = self.get_entries().sum('value') or 0
+        total = self.get_entries().sum(TillEntry.value) or 0
         return currency(self.initial_cash_amount + total)
 
     def get_cash_amount(self):
@@ -274,59 +277,54 @@ class Till(Domain):
         :rtype: currency
         """
         from stoqlib.domain.payment.method import PaymentMethod
-        conn = self.get_connection()
-        money = PaymentMethod.get_by_name(conn, 'money')
+        store = self.store
+        money = PaymentMethod.get_by_name(store, u'money')
 
-        results = TillEntry.select(
-            join=LeftJoin(Payment, Payment.q.id == TillEntry.q.payment_id),
-            clause=AND(OR(TillEntry.q.payment_id == None,
-                          Payment.q.method_id == money.id),
-                       TillEntry.q.till_id == self.id),
-            connection=conn)
+        clause = And(Or(TillEntry.payment_id == None,
+                          Payment.method_id == money.id),
+                       TillEntry.till_id == self.id)
+
+        join = LeftJoin(Payment, Payment.id == TillEntry.payment_id)
+        results = store.using(TillEntry, join).find(TillEntry, clause)
 
         return currency(self.initial_cash_amount +
-                        (results.sum('till_entry.value') or 0))
+                        (results.sum(TillEntry.value) or 0))
 
     def get_entries(self):
         """Fetches all the entries related to this till
         :returns: all entries
         :rtype: sequence of |tillentry|
         """
-        return TillEntry.selectBy(
-            till=self, connection=self.get_connection())
+        return self.store.find(TillEntry, till=self)
 
     def get_credits_total(self):
         """Calculates the total credit for all entries in this till
         :returns: total credit
         :rtype: currency
         """
-        results = TillEntry.select(AND(TillEntry.q.value > 0,
-                                       TillEntry.q.till_id == self.id),
-                                   connection=self.get_connection())
-        return currency(results.sum('value') or 0)
+        results = self.store.find(
+            TillEntry, And(TillEntry.value > 0,
+                           TillEntry.till_id == self.id))
+        return currency(results.sum(TillEntry.value) or 0)
 
     def get_debits_total(self):
         """Calculates the total debit for all entries in this till
         :returns: total debit
         :rtype: currency
         """
-        results = TillEntry.select(AND(TillEntry.q.value < 0,
-                                       TillEntry.q.till_id == self.id),
-                                   connection=self.get_connection())
-        return currency(results.sum('value') or 0)
+        results = self.store.find(
+            TillEntry, And(TillEntry.value < 0,
+                           TillEntry.till_id == self.id))
+        return currency(results.sum(TillEntry.value) or 0)
 
     #
     # Private
     #
 
     def _get_last_closed_till(self):
-        results = Till.selectBy(
-            status=Till.STATUS_CLOSED,
-            station=self.station,
-            connection=self.get_connection()).orderBy('opening_date')
-
-        if results:
-            return results[-1]
+        results = self.store.find(Till, status=Till.STATUS_CLOSED,
+                                  station=self.station).order_by(Till.opening_date)
+        return results.last()
 
     def _add_till_entry(self, value, description, payment=None):
         assert value != 0
@@ -335,7 +333,7 @@ class Till(Domain):
                          payment=payment,
                          till=self,
                          branch=self.station.branch,
-                         connection=self.get_connection())
+                         store=self.store)
 
 
 class TillEntry(Domain):
@@ -343,6 +341,7 @@ class TillEntry(Domain):
      * A positive value represents addition.
      * A negative value represents removal.
     """
+    __storm_table__ = 'till_entry'
 
     #: A numeric identifier for this object. This value should be used instead of
     #: :obj:`.id` when displaying a numerical representation of this object to
@@ -358,11 +357,27 @@ class TillEntry(Domain):
     #: value of transaction
     value = PriceCol()
 
+    till_id = IntCol(allow_none=False)
+
     #: the |till| the entry takes part of
-    till = ForeignKey("Till", allow_none=False)
+    till = Reference(till_id, 'Till.id')
+
+    payment_id = IntCol(default=None)
 
     #: |payment| of this entry, if any
-    payment = ForeignKey("Payment", default=None)
+    payment = Reference(payment_id, 'Payment.id')
+
+    branch_id = IntCol()
 
     #: |branch| that received or gave money
-    branch = ForeignKey('Branch')
+    branch = Reference(branch_id, 'Branch.id')
+
+    @property
+    def time(self):
+        """The time of the entry
+
+        Note that this is the same as :obj:`.date.time()`, but with
+        microseconds replaced to *0*.
+        """
+        time = self.date.time()
+        return time.replace(microsecond=0)
