@@ -34,6 +34,7 @@ from kiwi.ui.views import BaseView
 from kiwi.utils import gsignal
 from zope.interface import implements
 
+from stoqlib.lib.decorators import public
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.interfaces import ISystemNotifier
 from stoqlib.gui.base.gtkadds import change_button_appearance
@@ -209,11 +210,11 @@ class BasicDialog(GladeDelegate, RunnableView):
             show_section(section)
 
         self.action_area.set_layout(gtk.BUTTONBOX_END)
-        button = gtk.Button(stock=gtk.STOCK_HELP)
-        button.connect('clicked', on_help__clicked)
-        self.action_area.add(button)
-        self.action_area.set_child_secondary(button, True)
-        button.show()
+        self.help_button = gtk.Button(stock=gtk.STOCK_HELP)
+        self.help_button.connect('clicked', on_help__clicked)
+        self.action_area.pack_start(self.help_button, expand=False, fill=False)
+        self.action_area.set_child_secondary(self.help_button, True)
+        self.help_button.show()
 
     #
     # Public API
@@ -345,6 +346,7 @@ def get_dialog(parent, dialog, *args, **kwargs):
     return dialog
 
 
+@public(since="1.5.0")
 def run_dialog(dialog, parent=None, *args, **kwargs):
     """Runs a dialog and return the return value of it.
     If dialog is a class it will be instantiated before running the dialog.
@@ -381,7 +383,10 @@ def run_dialog(dialog, parent=None, *args, **kwargs):
         toplevel.set_transient_for(parent)
         toplevel.set_position(gtk.WIN_POS_CENTER_ON_PARENT)
     else:
-        toplevel.set_position(gtk.WIN_POS_CENTER_ON_PARENT)
+        if parent:
+            toplevel.set_position(gtk.WIN_POS_CENTER_ON_PARENT)
+        else:
+            toplevel.set_position(gtk.WIN_POS_CENTER)
         # FIXME: This should not be necessary, but gnome shell hides window
         # decorations for HINT_DIALOG. We should study what dialogs should
         # have HINT_NORMAL (with window decorations) and what can have
