@@ -35,10 +35,11 @@ from kiwi.ui.delegates import GladeSlaveDelegate
 from kiwi.ui.search import (ComboSearchFilter, SearchSlaveDelegate,
                             DateSearchOption)
 from kiwi.utils import gsignal
+from storm.store import Store
 
 from stoqlib.api import api
-from stoqlib.database.orm import ORMObject, ORMObjectQueryExecuter
-from stoqlib.exceptions import DatabaseInconsistency
+from stoqlib.database.orm import ORMObject
+from stoqlib.database.queryexecuter import StoqlibQueryExecuter
 from stoqlib.gui.base.dialogs import BasicDialog, run_dialog
 from stoqlib.gui.base.gtkadds import button_set_image_with_label
 from stoqlib.gui.editors.baseeditor import BaseEditor
@@ -78,7 +79,7 @@ class StoqlibSearchSlaveDelegate(SearchSlaveDelegate):
     def __init__(self, columns, tree=False, restore_name=None):
         self._restore_name = restore_name
         self._settings_key = 'search-columns-%s' % (
-            api.get_current_user(api.get_connection()).username, )
+            api.get_current_user(api.get_default_store()).username, )
         self._columns = self.restore_columns(columns)
 
         SearchSlaveDelegate.__init__(self, self._columns, tree=tree)
@@ -162,12 +163,18 @@ class StoqlibSearchSlaveDelegate(SearchSlaveDelegate):
     def set_message(self, message):
         self.search.results.set_message(message)
 
+    def get_column_by_attribute(self, attribute):
+        """Returns a column by its model attribute."""
+        for column in self._columns:
+            if column.attribute == attribute:
+                return column
+
     #
     #  Private
     #
 
     def _migrate_from_pickle(self):
-        username = api.get_current_user(api.get_connection()).username
+        username = api.get_current_user(api.get_default_store()).username
         filename = os.path.join(get_application_dir(), 'columns-%s' % username,
                                 self._restore_name + '.pickle')
         log.info("Migrating columns from pickle: %s" % (filename, ))
@@ -204,6 +211,21 @@ class SearchDialogPrintSlave(GladeSlaveDelegate):
         self.emit('print')
 
 
+class SearchDialogButtonSlave(GladeSlaveDelegate):
+    """ Slave for internal use of SearchEditor, offering an eventbox for a
+    toolbar and managing buttons. """
+
+    gladefile = 'SearchDialogButtonSlave'
+
+    gsignal('click')
+
+    #
+    # Kiwi handlers
+    #
+
+    def on_button__clicked(self, button):
+        self.emit('click')
+
 #
 # Base dialogs for search.
 #
@@ -246,12 +268,12 @@ class SearchDialog(BasicDialog):
     tree = False
 
     @argcheck(object, object, object, bool, basestring, int, bool)
-    def __init__(self, conn, table=None, search_table=None, hide_footer=True,
+    def __init__(self, store, table=None, search_table=None, hide_footer=True,
                  title='', selection_mode=None, double_click_confirm=False):
         """
         A base class for search dialog inheritance
 
-        :param conn:
+        :param store: a store
         :param table:
         :param search_table:
         :param hide_footer:
@@ -261,7 +283,7 @@ class SearchDialog(BasicDialog):
           automatically confirm
         """
 
-        self.conn = conn
+        self.store = store
         self.search_table = self._setup_search_table(table, search_table)
         self.selection_mode = self._setup_selection_mode(selection_mode)
         self.summary_label = None
@@ -272,12 +294,12 @@ class SearchDialog(BasicDialog):
                              title=title or self.title,
                              size=self.size)
 
-        self.executer = ORMObjectQueryExecuter(conn)
+        self.executer = StoqlibQueryExecuter(store)
         # FIXME: Remove this limit, but we need to migrate all existing
         #        searches to use lazy lists first. That in turn require
         #        us to rewrite the queries in such a way that count(*)
         #        will work properly.
-        self.executer.set_limit(sysparam(self.conn).MAX_SEARCH_RESULTS)
+        self.executer.set_limit(sysparam(self.store).MAX_SEARCH_RESULTS)
         self.set_table(self.search_table)
 
         self.enable_window_controls()
@@ -462,7 +484,7 @@ class SearchDialog(BasicDialog):
 
     def create_branch_filter(self, label=None):
         from stoqlib.domain.person import Branch
-        branches = Branch.get_active_branches(self.conn)
+        branches = Branch.get_active_branches(self.store)
         items = [(b.person.name, b.id) for b in branches]
         #if not items:
         #    raise ValueError('You should have at least one branch at '
@@ -472,7 +494,7 @@ class SearchDialog(BasicDialog):
         if not label:
             label = _('Branch:')
         branch_filter = ComboSearchFilter(label, items)
-        current = api.get_current_branch(self.conn)
+        current = api.get_current_branch(self.store)
         if current:
             branch_filter.select(current.id)
 
@@ -480,7 +502,7 @@ class SearchDialog(BasicDialog):
 
     def create_payment_filter(self, label=None):
         from stoqlib.domain.payment.method import PaymentMethod
-        methods = PaymentMethod.get_active_methods(self.conn)
+        methods = PaymentMethod.get_active_methods(self.store)
         items = [(_('Any'), None)]
         for method in methods:
             if method.method_name == 'multiple':
@@ -495,9 +517,9 @@ class SearchDialog(BasicDialog):
         return payment_filter
 
     def create_provider_filter(self, label=None):
-        from stoqlib.domain.person import CreditProvider
-        providers = CreditProvider.get_active_providers(self.conn)
-        items = [(p.person.name, p) for p in providers]
+        from stoqlib.domain.payment.card import CreditProvider
+        providers = CreditProvider.get_card_providers(self.store)
+        items = [(p.short_name, p) for p in providers]
         items.insert(0, (_("Any"), None))
 
         if not label:
@@ -583,31 +605,35 @@ class SearchEditor(SearchDialog):
 
     Simple example:
 
-    >>> class CarSearch(SearchEditor):
-    ...     title = _("Car Search")
-    ...     table = Car
-    ...     editor_class = CarEditor
+    >>> from stoqlib.domain.person import ClientView
+    >>> from stoqlib.gui.editors.personeditor import ClientEditor
+
+    >>> class ClientSearch(SearchEditor):
+    ...     title = _("Client Search")
+    ...     table = ClientView
+    ...     editor_class = ClientEditor
     ...     size = (465, 390)
-    ...     searchbar_result_strings = _("Car"), _("Cars")
+    ...     searchbar_result_strings = _("Client"), _("Clients")
     ...
     ...     def get_columns(self):
-    ...         return [Column('brand', _('Brand'), data_type=str, width=90),
-    ...                 Column('description', _('Description'), data_type=str,
+    ...         return [Column('name', _('Client name'), data_type=str, width=90),
+    ...                 Column('status', _('Status'), data_type=str,
     ...                         expand=True)]
 
-    This will create a new editor called CarSearch.
-      - It will be populated using the table Car.
-      - The title of the editor is "Car Search".
-      - To create new Car objects or to edit an existing Car object the
-        CarEditor table will be used, which needs to be a subclass of BaseEditor.
+    This will create a new editor called ClientSearch:
+
+      - It will be populated using the table ClientView.
+      - The title of the editor is "Client Search".
+      - To create new Client objects or to edit an existing Client object the
+        ClientEditor table will be used, which needs to be a subclass of BaseEditor.
       - The size of the new dialog will be 465 pixels wide and 390 pixels high.
-      - When displaying results, the verb car and cars will be used, eg:
-        1 car or 34 cars.
+      - When displaying results, the verb client and clients will be used, eg:
+        ``1 client`` or ``34 clients``.
       - The get_columns() methods is required to be implemented, otherwise
         there's no way to know which data is going to be displayed.
         get_columns must return a list of kiwi objectlist columns.
         In this case we will display two columns, brand and description.
-        They will be fetched from the car object using the attribute brand or
+        They will be fetched from the client object using the attribute brand or
         description. Both of them are strings (data_type=str), the width of
         the first column is 90 pixels and the second column is expanded so
         it uses the rest of the available width.
@@ -616,13 +642,13 @@ class SearchEditor(SearchDialog):
     has_new_button = has_edit_button = True
     model_list_lookup_attr = 'id'
 
-    def __init__(self, conn, table=None, editor_class=None, interface=None,
+    def __init__(self, store, table=None, editor_class=None, interface=None,
                  search_table=None, hide_footer=True,
                  title='', selection_mode=gtk.SELECTION_BROWSE,
                  hide_toolbar=False, double_click_confirm=False):
         """
         Create a new SearchEditor object.
-        :param conn:
+        :param store:
         :param table:
         :param editor_class:
         :param interface: The interface which we need to apply to the objects in
@@ -642,7 +668,7 @@ class SearchEditor(SearchDialog):
         self._read_only = False
         self._message_bar = None
 
-        SearchDialog.__init__(self, conn, table, search_table,
+        SearchDialog.__init__(self, store, table, search_table,
                               hide_footer=hide_footer, title=title,
                               selection_mode=selection_mode,
                               double_click_confirm=double_click_confirm)
@@ -733,7 +759,7 @@ class SearchEditor(SearchDialog):
         """
         if self._selected:
             selected = self._selected
-            selected.syncUpdate()
+            Store.of(selected).flush()
             self.results.update(selected)
         else:
             # user just added a new instance
@@ -757,15 +783,15 @@ class SearchEditor(SearchDialog):
         return run_dialog(editor_class, parent, *args, **kwargs)
 
     def run_editor(self, obj):
-        trans = api.new_transaction()
-        retval = self.run_dialog(self.editor_class, self, trans,
-                                 trans.get(obj), visual_mode=self._read_only)
-        if api.finish_transaction(trans, retval):
+        store = api.new_store()
+        retval = self.run_dialog(self.editor_class, self, store,
+                                 store.fetch(obj), visual_mode=self._read_only)
+        if store.confirm(retval):
             # If the return value is an ORMObject, fetch it from
             # the right connection
             if isinstance(retval, ORMObject):
-                retval = type(retval).get(retval.id, connection=self.conn)
-        trans.close()
+                retval = type(retval).get(retval.id, store=self.store)
+        store.close()
         return retval
 
     def row_activate(self, obj):
@@ -810,16 +836,8 @@ class SearchEditor(SearchDialog):
     #
 
     def get_searchlist_model(self, model):
-        # Ideally we want to use selectOneBy here, but it is not
-        # yet implemented on viewable.
-        items = self.search_table.select(
-            getattr(self.search_table.q,
-                    self.model_list_lookup_attr) == model.id,
-            connection=self.conn)
-        if items.count() != 1:
-            raise DatabaseInconsistency(
-                "There should be exactly one item for %r " % model)
-        return items[0]
+        query = (getattr(self.search_table, self.model_list_lookup_attr) == model.id)
+        return self.store.find(self.search_table, query).one()
 
     def get_editor_model(self, model):
         """This hook must be redefined on child when changing the type of
