@@ -31,7 +31,7 @@ from kiwi.ui.objectlist import ObjectList
 from kiwi.ui.widgets.list import Column
 
 from stoqlib.api import api
-from stoqlib.database.runtime import get_connection
+from stoqlib.database.runtime import get_default_store
 from stoqlib.gui.base.dialogs import BasicDialog, run_dialog
 from stoqlib.gui.stockicons import STOQ_PLUGIN
 from stoqlib.lib.parameters import is_developer_mode
@@ -70,14 +70,14 @@ class PluginManagerDialog(BasicDialog):
     title = _(u'Plugin Manager')
     help_section = 'plugin'
 
-    def __init__(self, conn):
+    def __init__(self, store):
         header = _(u'Select the plugin you want to activate and click in '
                     'the apply button.')
         BasicDialog.__init__(self, hide_footer=False,
                              size=PluginManagerDialog.size,
                              title=PluginManagerDialog.title,
                              header_text=header)
-        self.conn = conn
+        self.store = store
         self._manager = get_plugin_manager()
         self._setup_widgets()
 
@@ -125,8 +125,8 @@ class PluginManagerDialog(BasicDialog):
         plugin_name = plugin_model.name
         # This should not really be necessary, but there may be deadlocks when
         # activating the plugin. See bug 5272
-        conn = get_connection()
-        conn.commit()
+        default_store = get_default_store()
+        default_store.commit()
         self._manager.install_plugin(plugin_name)
         self._manager.activate_plugin(plugin_name)
 
@@ -155,4 +155,4 @@ class PluginManagerDialog(BasicDialog):
 
 if __name__ == '__main__':  # pragma nocover
     ec = api.prepare_test()
-    run_dialog(PluginManagerDialog, None, ec.trans)
+    run_dialog(PluginManagerDialog, None, ec.store)
