@@ -32,9 +32,9 @@ from kiwi.enums import ListType
 from kiwi.python import AttributeForwarder
 from kiwi.ui.objectlist import Column
 from kiwi.ui.listdialog import ListSlave
+from storm.expr import And, LeftJoin, Or
 
 from stoqlib.api import api
-from stoqlib.database.orm import AND, OR, LeftJoin
 from stoqlib.domain.production import ProductionOrder, ProductionMaterial
 from stoqlib.domain.purchase import PurchaseOrder, PurchaseItem
 from stoqlib.domain.sale import Sale
@@ -61,13 +61,13 @@ class _TemporaryQuoteItem(AttributeForwarder):
         self.average_cost = self._get_average_cost(item)
 
     def _get_purchase_items_by_sellable(self):
-        query = AND(PurchaseItem.q.sellable_id == self.target.sellable.id,
-                    OR(PurchaseOrder.q.status == PurchaseOrder.ORDER_CONFIRMED,
-                       PurchaseOrder.q.status == PurchaseOrder.ORDER_CLOSED))
+        query = And(PurchaseItem.sellable_id == self.target.sellable.id,
+                    Or(PurchaseOrder.status == PurchaseOrder.ORDER_CONFIRMED,
+                       PurchaseOrder.status == PurchaseOrder.ORDER_CLOSED))
         join = LeftJoin(PurchaseOrder,
-                          PurchaseItem.q.order_id == PurchaseOrder.q.id)
-        conn = self.target.get_connection()
-        return PurchaseItem.select(query, join=join, connection=conn)
+                        PurchaseItem.order_id == PurchaseOrder.id)
+        store = self.target.store
+        return store.using(PurchaseItem, join).find(PurchaseItem, query)
 
     def _get_last_cost(self, item):
         purchase_items = list(self._get_purchase_items_by_sellable())
@@ -76,7 +76,7 @@ class _TemporaryQuoteItem(AttributeForwarder):
         return currency(item.cost)
 
     def _get_average_cost(self, item):
-        cost = self._get_purchase_items_by_sellable().avg(PurchaseItem.q.cost)
+        cost = self._get_purchase_items_by_sellable().avg(PurchaseItem.cost)
         if cost:
             return currency(cost)
         return currency(item.cost)
@@ -88,8 +88,8 @@ class QuoteFillingDialog(BaseEditor):
     title = _(u"Quote Filling")
     size = (750, 450)
 
-    def __init__(self, model, conn):
-        BaseEditor.__init__(self, conn, model)
+    def __init__(self, model, store):
+        BaseEditor.__init__(self, store, model)
         self._setup_widgets()
 
     def _setup_widgets(self):
@@ -157,22 +157,22 @@ class ConfirmSaleMissingDialog(SimpleListDialog):
                 Column('stock', title=_(u'Stock'),
                        data_type=int)]
 
-    def _create_production_order(self, trans):
+    def _create_production_order(self, store):
         desc = (_('Production for Sale order %s')
                    % self.sale.get_order_number_str())
         if self.sale.client:
             desc += ' (%s)' % self.sale.client.get_name()
-        user = api.get_current_user(trans)
+        user = api.get_current_user(store)
         employee = user.person.employee
-        order = ProductionOrder(branch=trans.get(self.sale.branch),
+        order = ProductionOrder(branch=store.fetch(self.sale.branch),
                                 status=ProductionOrder.ORDER_WAITING,
                                 responsible=employee,
                                 description=desc,
-                                connection=trans)
+                                store=store)
 
         materials = {}
         for item in self.missing:
-            product = item.storable.product
+            product = store.fetch(item.storable.product)
             components = list(product.get_components())
             if not components:
                 continue
@@ -188,22 +188,22 @@ class ConfirmSaleMissingDialog(SimpleListDialog):
             ProductionMaterial(needed=needed,
                                order=order,
                                product=material,
-                               connection=trans)
+                               store=store)
 
         if materials:
             info(_('A new production was created for the missing composed '
                    'products'))
         else:
-            ProductionOrder.delete(order.id, trans)
+            store.remove(order)
 
     def confirm(self, *args):
         if self.sale.status == Sale.STATUS_QUOTE:
-            trans = api.new_transaction()
-            sale = trans.get(self.sale)
-            self._create_production_order(trans)
+            store = api.new_store()
+            sale = store.fetch(self.sale)
+            self._create_production_order(store)
             sale.order()
-            api.finish_transaction(trans, True)
-            trans.close()
+            store.confirm(True)
+            store.close()
         return SimpleListDialog.confirm(self, *args)
 
 
