@@ -93,13 +93,13 @@ class SaleDetailsDialog(BaseEditor):
                        'total_paid',
                        'total_value', )
 
-    def __init__(self, conn, model=None, visual_mode=False):
+    def __init__(self, store, model=None, visual_mode=False):
         """ Creates a new SaleDetailsDialog object
 
-        :param conn: a database connection
+        :param store: a store
         :param model: a :class:`stoqlib.domain.sale.Sale` object
         """
-        BaseEditor.__init__(self, conn, model,
+        BaseEditor.__init__(self, store, model,
                             visual_mode=visual_mode)
 
     def _setup_columns(self):
@@ -120,7 +120,7 @@ class SaleDetailsDialog(BaseEditor):
             self.details_button.set_sensitive(False)
         self._setup_columns()
 
-        self.sale_order = Sale.get(self.model.id, connection=self.conn)
+        self.sale_order = self.store.get(Sale, self.model.id)
 
         if self.sale_order.status == Sale.STATUS_RENEGOTIATED:
             self.status_details_button.show()
@@ -135,8 +135,8 @@ class SaleDetailsDialog(BaseEditor):
         if details:
             notes.append(details)
 
-        returned_sale = ReturnedSale.selectOneBy(connection=self.conn,
-                                                 new_sale=self.model.id)
+        returned_sale = self.store.find(ReturnedSale,
+                                        new_sale=self.model.id).one()
         if returned_sale:
             if returned_sale.sale:
                 traded_sale = returned_sale.sale.get_order_number_str()
@@ -151,8 +151,8 @@ class SaleDetailsDialog(BaseEditor):
                 ]
             notes.append('\n'.join(trade_notes))
 
-        returned_items = list(ReturnedSaleItemsView.select_by_sale(self.sale_order,
-                                                                   self.conn))
+        returned_items = list(ReturnedSaleItemsView.find_by_sale(self.store,
+                                                                 self.sale_order))
         if returned_items:
             self.returned_items_list.add_list(returned_items)
             seen_set = set()
@@ -182,13 +182,12 @@ class SaleDetailsDialog(BaseEditor):
         self.notes.set_buffer(buffer)
 
         self.payments_list.add_list(self._get_payments(self.sale_order))
-        changes = PaymentChangeHistoryView.select_by_group(
-            self.sale_order.group,
-            connection=self.conn)
+        changes = PaymentChangeHistoryView.find_by_group(self.store,
+                                                         self.sale_order.group)
         self.payments_info_list.add_list(changes)
 
-        for widget, method_name in [(self.print_bills, 'bill'),
-                                    (self.print_booklets, 'store_credit')]:
+        for widget, method_name in [(self.print_bills, u'bill'),
+                                    (self.print_booklets, u'store_credit')]:
             widget.set_visible(any([p.method.method_name == method_name
                                     for p in self.payments_list]))
 
@@ -271,13 +270,12 @@ class SaleDetailsDialog(BaseEditor):
     #
 
     def on_print_button__clicked(self, button):
-        print_report(SaleOrderReport,
-                     Sale.get(self.model.id, connection=self.conn))
+        print_report(SaleOrderReport, self.store.get(Sale, self.model.id))
 
     def on_print_bills__clicked(self, button):
         # Remove cancelled and not bill payments
         payments = [p for p in self.payments_list if
-                    p.method.method_name == 'bill' and
+                    p.method.method_name == u'bill' and
                     not p.is_cancelled()]
 
         if not BillReport.check_printable(payments):
@@ -288,7 +286,7 @@ class SaleDetailsDialog(BaseEditor):
     def on_print_booklets__clicked(self, button):
         # Remove cancelled and not store_credit payments
         payments = [p for p in self.payments_list if
-                    p.method.method_name == 'store_credit' and
+                    p.method.method_name == u'store_credit' and
                     not p.is_cancelled()]
 
         print_report(BookletReport, payments)
@@ -297,12 +295,11 @@ class SaleDetailsDialog(BaseEditor):
         if not self.model.client_id:
             raise StoqlibError("You should never call ClientDetailsDialog "
                                "for sales which clients were not specified")
-        client = Client.get(self.model.client_id,
-                            connection=self.conn)
-        run_dialog(ClientDetailsDialog, self, self.conn, client)
+        client = self.store.get(Client, self.model.client_id)
+        run_dialog(ClientDetailsDialog, self, self.store, client)
 
     def on_status_details_button__clicked(self, button):
         if self.sale_order.status == Sale.STATUS_RENEGOTIATED:
             # XXX: Rename to renegotiated
-            run_dialog(RenegotiationDetailsDialog, self, self.conn,
+            run_dialog(RenegotiationDetailsDialog, self, self.store,
                        self.sale_order.group.renegotiation)
