@@ -23,13 +23,11 @@
 ##
 ##
 
-import gettext
 
 import gtk
 from kiwi.ui.objectlist import ObjectList
 from kiwi.ui.widgets.list import Column
 
-from stoqlib.api import api
 from stoqlib.gui.base.dialogs import BasicDialog
 from stoqlib.domain.uiform import UIForm, UIField
 from stoqlib.lib.translation import stoqlib_gettext
@@ -41,8 +39,8 @@ class FormFieldEditor(BasicDialog):
     size = (700, 400)
     title = _("Form fields")
 
-    def __init__(self, conn):
-        self.conn = conn
+    def __init__(self, store):
+        self.store = store
         BasicDialog.__init__(self, size=FormFieldEditor.size,
                              title=FormFieldEditor.title)
         self._create_ui()
@@ -55,8 +53,8 @@ class FormFieldEditor(BasicDialog):
 
         self.forms = ObjectList(
             [Column('description', title=_('Description'), sorted=True,
-                    expand=True, format_func=gettext.gettext)],
-            UIForm.select(connection=self.conn),
+                    expand=True, format_func=stoqlib_gettext)],
+            self.store.find(UIForm),
             gtk.SELECTION_BROWSE)
         self.forms.connect('selection-changed',
                            self._on_forms__selection_changed)
@@ -79,22 +77,22 @@ class FormFieldEditor(BasicDialog):
     def _on_forms__selection_changed(self, forms, form):
         if not form:
             return
-        self.fields.add_list(UIField.selectBy(connection=self.conn,
-                                              ui_form=form), clear=True)
+        self.fields.add_list(self.store.find(UIField,
+                                             ui_form=form), clear=True)
 
     def _get_columns(self):
         return [Column('description', title=_('Description'), data_type=str,
                        expand=True, sorted=True,
-                       format_func=gettext.gettext),
+                       format_func=stoqlib_gettext),
                 Column('visible', title=_('Visible'), data_type=bool,
                        width=120, editable=True),
                 Column('mandatory', title=_('Mandatory'), data_type=bool,
                        width=120, editable=True)]
 
     def confirm(self, *args):
-        api.finish_transaction(self.conn, True)
+        self.store.confirm(True)
         BasicDialog.confirm(self, *args)
 
     def cancel(self, *args):
-        self.conn.rollback(close=False)
+        self.store.rollback(close=False)
         BasicDialog.confirm(self, *args)
