@@ -41,33 +41,33 @@ from stoqlib.lib.translation import stoqlib_gettext
 _ = stoqlib_gettext
 
 _TANGO_PALETTE = [
-    '#eeeeec',
-    '#d3d7cf',
-    '#babdb6',
-    '#fce94f',
-    '#edd400',
-    '#c4a000',
-    '#8ae234',
-    '#73d216',
-    '#4e9a06',
-    '#fcaf3e',
-    '#f57900',
-    '#ce5c00',
-    '#e9b96e',
-    '#c17d11',
-    '#8f5902',
-    '#729fcf',
-    '#3465a4',
-    '#204a87',
-    '#ad7fa8',
-    '#75507b',
-    '#5c3566',
-    '#888a85',
-    '#555753',
-    '#2e3436',
-    '#ef2929',
-    '#cc0000',
-    '#a40000',
+    u'#eeeeec',
+    u'#d3d7cf',
+    u'#babdb6',
+    u'#fce94f',
+    u'#edd400',
+    u'#c4a000',
+    u'#8ae234',
+    u'#73d216',
+    u'#4e9a06',
+    u'#fcaf3e',
+    u'#f57900',
+    u'#ce5c00',
+    u'#e9b96e',
+    u'#c17d11',
+    u'#8f5902',
+    u'#729fcf',
+    u'#3465a4',
+    u'#204a87',
+    u'#ad7fa8',
+    u'#75507b',
+    u'#5c3566',
+    u'#888a85',
+    u'#555753',
+    u'#2e3436',
+    u'#ef2929',
+    u'#cc0000',
+    u'#a40000',
     ]
 
 
@@ -75,17 +75,18 @@ class PaymentCategoryEditor(BaseEditor):
     model_name = _('Payment Category')
     model_type = PaymentCategory
     confirm_widgets = ['name']
+    proxy_widgets = ['category_type']
 
     fields = dict(
-        name=TextField(_('Name')),
-        color=ColorField(_('Color')),
+        name=TextField(_('Name'), proxy=True),
+        color=ColorField(_('Color'), proxy=True),
         category_type=ChoiceField(_('Type'), data_type=int),
     )
 
-    def __init__(self, conn, model=None,
+    def __init__(self, store, model=None,
                  category_type=None, visual_mode=False):
         self._category_type = category_type or PaymentCategory.TYPE_PAYABLE
-        BaseEditor.__init__(self, conn, model, visual_mode=visual_mode)
+        BaseEditor.__init__(self, store, model, visual_mode=visual_mode)
         if category_type is not None:
             self.category_type.set_sensitive(False)
 
@@ -99,8 +100,8 @@ class PaymentCategoryEditor(BaseEditor):
             self._original_category_type == category_type):
             return True
 
-        payments = Payment.selectBy(connection=self.conn,
-                                    category=self.model)
+        payments = self.store.find(Payment,
+                                   category=self.model)
         payments_count = payments.count()
 
         if (payments_count > 0 and not
@@ -114,24 +115,24 @@ class PaymentCategoryEditor(BaseEditor):
 
         return True
 
-    def create_model(self, trans):
+    def create_model(self, store):
         used_colors = set([
-            pc.color for pc in PaymentCategory.select(connection=trans)])
+            pc.color for pc in store.find(PaymentCategory)])
         random.shuffle(_TANGO_PALETTE)
         for color in _TANGO_PALETTE:
             if not color in used_colors:
                 break
-        return PaymentCategory(name='',
+        return PaymentCategory(name=u'',
                                color=color,
                                category_type=int(self._category_type),
-                               connection=trans)
+                               store=store)
 
     def setup_proxies(self):
         self.name.grab_focus()
         self.category_type.prefill([
             (_('Payable'), PaymentCategory.TYPE_PAYABLE),
             (_('Receivable'), PaymentCategory.TYPE_RECEIVABLE)])
-        self.add_proxy(self.model, ['name', 'color', 'category_type'])
+        self.add_proxy(self.model, self.proxy_widgets)
         self._original_category_type = self.model.category_type
 
     #
@@ -142,15 +143,16 @@ class PaymentCategoryEditor(BaseEditor):
         if not new_name:
             return ValidationError(
                 _(u"The payment category should have name."))
-        if self.model.check_unique_value_exists('name', new_name):
+        if self.model.check_unique_value_exists(PaymentCategory.name,
+                                                new_name):
             return ValidationError(
                 _(u"The payment category '%s' already exists.") % new_name)
 
 
 def test():  # pragma nocover
     creator = api.prepare_test()
-    retval = run_dialog(PaymentCategoryEditor, None, creator.trans, None)
-    api.finish_transaction(creator.trans, retval)
+    retval = run_dialog(PaymentCategoryEditor, None, creator.store, None)
+    creator.store.confirm(retval)
 
 
 if __name__ == '__main__':  # pragma nocover
