@@ -26,12 +26,11 @@
 
 
 import datetime
-import operator
 
 from kiwi import ValueUnset
 from kiwi.currency import currency
 from kiwi.datatypes import ValidationError
-from kiwi.ui.forms import ChoiceField, DateField, PriceField, TextField
+from kiwi.ui.forms import BoolField, ChoiceField, DateField, PriceField, TextField
 
 from stoqlib.api import api
 from stoqlib.domain.payment.category import PaymentCategory
@@ -42,14 +41,17 @@ from stoqlib.domain.person import Client, Supplier, Branch
 from stoqlib.domain.sale import SaleView
 from stoqlib.exceptions import SellError
 from stoqlib.gui.base.dialogs import run_dialog
+from stoqlib.gui.dialogs.stockdecreasedialog import StockDecreaseDetailsDialog
 from stoqlib.gui.dialogs.paymentdetails import LonelyPaymentDetailsDialog
 from stoqlib.gui.dialogs.purchasedetails import PurchaseDetailsDialog
 from stoqlib.gui.dialogs.renegotiationdetails import RenegotiationDetailsDialog
 from stoqlib.gui.dialogs.saledetails import SaleDetailsDialog
 from stoqlib.gui.editors.baseeditor import BaseEditor
-from stoqlib.gui.fields import PaymentCategoryField, PersonField
-from stoqlib.lib.dateutils import get_interval_type_items
-from stoqlib.lib.translation import locale_sorted, stoqlib_gettext
+from stoqlib.gui.fields import (AttachmentField, PaymentCategoryField,
+                                PersonField, PaymentMethodField)
+from stoqlib.lib.dateutils import (get_interval_type_items,
+                                   interval_type_as_relativedelta)
+from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
 _ONCE = -1
@@ -63,33 +65,35 @@ class _PaymentEditor(BaseEditor):
     # Override in subclass
     person_type = None
     category_type = None
+    payment_type = None
 
-    # FIXME: Person should really be a proxy_widget attribute,
-    # but it breaks when displaying an existing payment
     fields = dict(
         branch=PersonField(_('Branch'), proxy=True, person_type=Branch,
-                           can_add=False, can_edit=False),
-        method=ChoiceField(_('Method')),
+                           can_add=False, can_edit=False, mandatory=True),
+        method=PaymentMethodField(_('Method'), proxy=True, mandatory=True,
+                                  separate=True),
         description=TextField(_('Description'), proxy=True, mandatory=True),
         person=PersonField(proxy=True),
         value=PriceField(_('Value'), proxy=True, mandatory=True),
         due_date=DateField(_('Due date'), proxy=True, mandatory=True),
-        category=PaymentCategoryField(_('Category')),
+        category=PaymentCategoryField(_('Category'), proxy=True),
         repeat=ChoiceField(_('Repeat')),
         end_date=DateField(_('End date')),
+        attachment=AttachmentField(_('Attachment'))
         )
 
-    def __init__(self, conn, model=None, category=None):
+    def __init__(self, store, model=None, category=None):
         """ A base class for additional payments
 
-        :param conn: a database connection
+        :param store: a store
         :param model: a :class:`stoqlib.domain.payment.payment.Payment` object or None
 
         """
         self.fields['person'].person_type = self.person_type
         self.fields['category'].category_type = self.category_type
+        self.fields['method'].payment_type = self.payment_type
 
-        BaseEditor.__init__(self, conn, model)
+        BaseEditor.__init__(self, store, model)
         self._setup_widgets()
         if category:
             self.category.select_item_by_label(category)
@@ -99,16 +103,16 @@ class _PaymentEditor(BaseEditor):
     # BaseEditor hooks
     #
 
-    def create_model(self, trans):
-        group = PaymentGroup(connection=trans)
-        money = PaymentMethod.get_by_name(trans, 'money')
-        branch = api.get_current_branch(trans)
+    def create_model(self, store):
+        group = PaymentGroup()
+        money = PaymentMethod.get_by_name(store, u'money')
+        branch = api.get_current_branch(store)
         # Set status to PENDING now, to avoid calling set_pending on
         # on_confirm for payments that shoud not have its status changed.
         return Payment(open_date=datetime.date.today(),
                        branch=branch,
                        status=Payment.STATUS_PENDING,
-                       description='',
+                       description=u'',
                        value=currency(0),
                        base_value=currency(0),
                        due_date=None,
@@ -117,10 +121,9 @@ class _PaymentEditor(BaseEditor):
                        till=None,
                        category=None,
                        payment_type=self.payment_type,
-                       connection=trans)
+                       bill_received=False)
 
     def setup_proxies(self):
-        self._fill_method_combo()
         repeat_types = get_interval_type_items(with_multiples=True,
                                                adverb=True)
         repeat_types.insert(0, (_('Once'), _ONCE))
@@ -146,34 +149,21 @@ class _PaymentEditor(BaseEditor):
             person != ""):
             setattr(self.model.group,
                     self.person_attribute,
-                    self.conn.get(person.person))
-        self.model.category = self.conn.get(self.category.get_selected())
-        method = self.method.get_selected()
-        if method is not None:
-            self.model.method = method
+                    self.store.fetch(person.person))
+
+        self.model.attachment = self.fields['attachment'].attachment
+
+        self.store.add(self.model.group)
+        self.store.add(self.model)
 
         if self.repeat.get_selected() != _ONCE:
-            Payment.create_repeated(self.conn, self.model,
+            Payment.create_repeated(self.store, self.model,
                                     self.repeat.get_selected(),
                                     self.model.due_date.date(),
                                     self.end_date.get_date())
 
     # Private
 
-    def _fill_method_combo(self):
-        methods = set()
-        if not self.edit_mode:
-            methods.update(set(PaymentMethod.get_creatable_methods(
-                self.trans,
-                self.payment_type,
-                separate=True)))
-        methods.add(self.model.method)
-        self.method.set_sensitive(not self.edit_mode)
-        self.method.prefill(locale_sorted(
-            [(m.description, m) for m in methods],
-            key=operator.itemgetter(0)))
-        self.method.select(self.model.method)
-
     def _setup_widgets(self):
         self.person_lbl.set_label(self._person_label)
         if self.model.group.sale:
@@ -191,7 +181,7 @@ class _PaymentEditor(BaseEditor):
         self.end_date.set_sensitive(False)
         if self.edit_mode:
             for field_name in ['value', 'due_date', 'person',
-                               'repeat', 'end_date', 'branch']:
+                               'repeat', 'end_date', 'branch', 'method']:
                 field = self.fields[field_name]
                 field.can_add = False
                 field.can_edit = False
@@ -199,32 +189,45 @@ class _PaymentEditor(BaseEditor):
 
         person = getattr(self.model.group, self.person_attribute)
         if person:
-            facet = self.person_type.selectOneBy(person=person,
-                                    connection=person.get_connection())
+            store = person.store
+            facet = store.find(self.person_type, person=person).one()
             self.person.select(facet)
 
     def _show_order_dialog(self):
         group = self.model.group
         if group.sale:
-            sale_view = SaleView.get(group.sale.id,
-                                     connection=self.conn)
-            run_dialog(SaleDetailsDialog, self, self.conn, sale_view)
+            sale_view = self.store.find(SaleView, id=group.sale.id).one()
+            run_dialog(SaleDetailsDialog, self, self.store, sale_view)
         elif group.purchase:
-            run_dialog(PurchaseDetailsDialog, self, self.conn, group.purchase)
+            run_dialog(PurchaseDetailsDialog, self, self.store, group.purchase)
         elif group._renegotiation:
-            run_dialog(RenegotiationDetailsDialog, self, self.conn,
+            run_dialog(RenegotiationDetailsDialog, self, self.store,
                        group._renegotiation)
+        elif group.stock_decrease:
+            run_dialog(StockDecreaseDetailsDialog, self, self.store,
+                       group.stock_decrease)
         else:
-            run_dialog(LonelyPaymentDetailsDialog, self, self.conn, self.model)
+            run_dialog(LonelyPaymentDetailsDialog, self, self.store, self.model)
+
+    def _get_min_date_for_interval(self, due_date, interval_type):
+        if not due_date or interval_type is None:
+            return None
+        return due_date + interval_type_as_relativedelta(interval_type)
 
     def _validate_date(self):
         if not self.end_date.props.sensitive:
             return True
         end_date = self.end_date.get_date()
         due_date = self.due_date.get_date()
+        min_date = self._get_min_date_for_interval(due_date, self.repeat.read())
+
         if end_date and due_date:
             if end_date < due_date:
                 self.end_date.set_invalid(_("End date cannot be before start date"))
+            elif min_date and end_date < min_date:
+                self.end_date.set_invalid(_("End date must be after %s for this "
+                                            "repeat interval") %
+                                                min_date.strftime('%x'))
             else:
                 self.end_date.set_valid()
                 self.refresh_ok(self.is_valid)
@@ -275,6 +278,7 @@ class _PaymentEditor(BaseEditor):
         self._show_order_dialog()
 
     def on_method__content_changed(self, method):
+        self.person.validate(force=True)
         self._validate_person()
 
 
@@ -290,19 +294,12 @@ class InPaymentEditor(_PaymentEditor):
         if not value:
             return
 
-        # FIXME: If the object was created in the current dialog, its
-        # transaction will be already closed, so se need to fetch it again from
-        # the current connection
-        value = self.conn.get(value)
         try:
             #FIXME: model is not being updated correctly
             value.can_purchase(self.method.read(), self.value.read())
         except SellError as e:
             return ValidationError(e)
 
-    def on_method__changed(self, method):
-        self.person.validate(force=True)
-
     def on_value__changed(self, value):
         self.person.validate(force=True)
 
@@ -315,6 +312,9 @@ class OutPaymentEditor(_PaymentEditor):
     help_section = 'account-payable'
     category_type = PaymentCategory.TYPE_PAYABLE
 
+    fields = _PaymentEditor.fields.copy()
+    fields['bill_received'] = BoolField(_('The bill has arrived.'), proxy=True)
+
 
 def get_dialog_for_payment(payment):
     if payment is None:
@@ -331,8 +331,8 @@ def get_dialog_for_payment(payment):
 
 def test():  # pragma nocover
     creator = api.prepare_test()
-    retval = run_dialog(InPaymentEditor, None, creator.trans, None)
-    api.finish_transaction(creator.trans, retval)
+    retval = run_dialog(InPaymentEditor, None, creator.store, None)
+    creator.store.confirm(retval)
 
 
 if __name__ == '__main__':  # pragma nocover
