@@ -34,7 +34,7 @@ from kiwi.ui.objectlist import Column, ColoredColumn, SummaryLabel
 from stoqdrivers.exceptions import DriverError
 
 from stoqlib.api import api
-from stoqlib.database.orm import const
+from stoqlib.database.expr import TransactionTimestamp
 from stoqlib.domain.account import AccountTransaction
 from stoqlib.domain.events import (TillOpenEvent, TillCloseEvent,
                                    TillAddTillEntryEvent,
@@ -44,21 +44,21 @@ from stoqlib.domain.till import Till
 from stoqlib.exceptions import DeviceError, TillError
 from stoqlib.gui.editors.baseeditor import BaseEditor
 from stoqlib.gui.slaves.tillslave import RemoveCashSlave, BaseCashSlave
+from stoqlib.lib.message import warning
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
-from stoqlib.lib.message import warning
 
 _ = stoqlib_gettext
 
 
-def _create_transaction(conn, till_entry):
+def _create_transaction(store, till_entry):
     AccountTransaction(description=till_entry.description,
-                       source_account=sysparam(conn).IMBALANCE_ACCOUNT,
-                       account=sysparam(conn).TILLS_ACCOUNT,
+                       source_account=sysparam(store).IMBALANCE_ACCOUNT,
+                       account=sysparam(store).TILLS_ACCOUNT,
                        value=till_entry.value,
-                       code=str(till_entry.id),
-                       date=const.NOW(),
-                       connection=conn,
+                       code=unicode(till_entry.id),
+                       date=TransactionTimestamp(),
+                       store=store,
                        payment=till_entry.payment)
 
 
@@ -117,8 +117,8 @@ class TillOpeningEditor(BaseEditor):
     # BaseEditorSlave
     #
 
-    def create_model(self, conn):
-        till = Till(connection=conn, station=api.get_current_station(conn))
+    def create_model(self, store):
+        till = Till(store=store, station=api.get_current_station(store))
         till.open_till()
 
         return _TillOpeningModel(till=till, value=currency(0))
@@ -128,9 +128,9 @@ class TillOpeningEditor(BaseEditor):
 
     def on_confirm(self):
         till = self.model.till
-        # Using api.get_connection instead of self.conn
+        # Using api.get_default_store instead of self.store
         # or it will return self.model.till
-        last_opened = Till.get_last_opened(api.get_connection())
+        last_opened = Till.get_last_opened(api.get_default_store())
         if (last_opened and
             last_opened.opening_date.date() == till.opening_date.date()):
             warning(_("A till was opened earlier this day."))
@@ -147,10 +147,8 @@ class TillOpeningEditor(BaseEditor):
         value = self.proxy.model.value
         if value:
             TillAddCashEvent.emit(till=till, value=value)
-            till_entry = till.add_credit_entry(value,
-                            (_(u'Initial Cash amount of %s')
-                             % till.opening_date.strftime('%x')))
-            _create_transaction(self.conn, till_entry)
+            till_entry = till.add_credit_entry(value, _(u'Initial Cash amount'))
+            _create_transaction(self.store, till_entry)
             # The callsite is responsible for interacting with
             # the fiscal printer
 
@@ -180,19 +178,19 @@ class TillClosingEditor(BaseEditor):
 
     help_section = 'till-close'
 
-    def __init__(self, conn, model=None, previous_day=False, close_db=True,
+    def __init__(self, store, model=None, previous_day=False, close_db=True,
                  close_ecf=True):
         """
         Create a new TillClosingEditor object.
         :param previous_day: If the till wasn't closed previously
         """
         self._previous_day = previous_day
-        self.till = Till.get_last(conn)
+        self.till = Till.get_last(store)
         if close_db:
             assert self.till
         self._close_db = close_db
         self._close_ecf = close_ecf
-        BaseEditor.__init__(self, conn, model)
+        BaseEditor.__init__(self, store, model)
         self._setup_widgets()
 
     def _setup_widgets(self):
@@ -272,21 +270,22 @@ class TillClosingEditor(BaseEditor):
         till = self.model.till
         removed = abs(self.model.value)
         if removed:
-            assert self._close_ecf
             # We need to do this inside a new transaction, because if the
             # till closing fails further on, this still needs to be recorded
             # in the database
-            trans = api.new_transaction()
-            t_till = trans.get(till)
+            store = api.new_store()
+            t_till = store.fetch(till)
             TillRemoveCashEvent.emit(till=t_till, value=removed)
-            till_entry = t_till.add_debit_entry(removed,
-                                 _(u'Amount removed from Till on %s') %
-                                   till.opening_date.strftime('%x'))
+
+            reason = _('Amount removed from Till by %s') % (
+                api.get_current_user(self.store).get_description(), )
+            till_entry = t_till.add_debit_entry(removed, reason)
+
             # Financial transaction
-            _create_transaction(trans, till_entry)
+            _create_transaction(store, till_entry)
             # DB transaction
-            api.finish_transaction(trans, True)
-            trans.close()
+            store.confirm(True)
+            store.close()
 
         if self._close_ecf:
             try:
@@ -332,6 +331,22 @@ class TillClosingEditor(BaseEditor):
         self.proxy.update('balance')
 
 
+class TillVerifyEditor(TillClosingEditor):
+    title = _('Till verification')
+    help_section = 'till-verify'
+
+    def __init__(self, store, model=None, previous_day=False,
+                 close_db=False, close_ecf=False):
+        assert not close_db and not close_ecf
+        super(TillVerifyEditor, self).__init__(store, model=model,
+                                               previous_day=previous_day,
+                                               close_db=close_db,
+                                               close_ecf=close_ecf)
+        self.set_message(
+            _("Use this to adjust the till for the next user.\n"
+              "Note that this will not really close the till or ecf."))
+
+
 class CashAdvanceEditor(BaseEditor):
     """An editor which extends BaseCashSlave to include.
     It extends BaseCashSlave to include an employee combobox
@@ -348,7 +363,7 @@ class CashAdvanceEditor(BaseEditor):
         return self.employee_combo.get_selected_label()
 
     def _setup_widgets(self):
-        employees = Employee.select(connection=self.conn)
+        employees = self.store.find(Employee)
         self.employee_combo.prefill(api.for_person_combo(employees))
         self.employee_combo.set_active(0)
 
@@ -356,8 +371,8 @@ class CashAdvanceEditor(BaseEditor):
     # BaseEditorSlave
     #
 
-    def create_model(self, conn):
-        till = Till.get_current(self.conn)
+    def create_model(self, store):
+        till = Till.get_current(self.store)
         return Settable(employee=None,
                         payment=None,
                         # FIXME: should send in consts.now()
@@ -367,7 +382,7 @@ class CashAdvanceEditor(BaseEditor):
                         value=currency(0))
 
     def setup_slaves(self):
-        self.cash_slave = RemoveCashSlave(self.conn,
+        self.cash_slave = RemoveCashSlave(self.store,
                                           self.model)
         self.cash_slave.value.connect('content-changed',
                                       self._on_cash_slave__value_changed)
@@ -388,8 +403,8 @@ class CashAdvanceEditor(BaseEditor):
             value, (_(u'Cash advance paid to employee: %s') % (
             self._get_employee_name(), )))
 
-        TillAddTillEntryEvent.emit(till_entry, self.conn)
-        _create_transaction(self.conn, till_entry)
+        TillAddTillEntryEvent.emit(till_entry, self.store)
+        _create_transaction(self.store, till_entry)
 
     #
     # Callbacks
@@ -411,8 +426,8 @@ class CashOutEditor(BaseEditor):
 
     help_section = 'till-remove-money'
 
-    def __init__(self, conn):
-        BaseEditor.__init__(self, conn)
+    def __init__(self, store):
+        BaseEditor.__init__(self, store)
         self.set_confirm_widget(self.reason)
         self.set_confirm_widget(self.cash_slave.value)
 
@@ -420,15 +435,15 @@ class CashOutEditor(BaseEditor):
     # BaseEditorSlave
     #
 
-    def create_model(self, conn):
-        till = Till.get_current(conn)
+    def create_model(self, store):
+        till = Till.get_current(store)
         return Settable(value=currency(0),
-                        reason='',
+                        reason=u'',
                         till=till,
                         balance=till.get_balance())
 
     def setup_slaves(self):
-        self.cash_slave = RemoveCashSlave(self.conn, self.model)
+        self.cash_slave = RemoveCashSlave(self.store, self.model)
         self.cash_slave.value.connect('content-changed',
                                       self._on_cash_slave__value_changed)
         self.attach_slave("base_cash_holder", self.cash_slave)
@@ -447,8 +462,8 @@ class CashOutEditor(BaseEditor):
         till_entry = till.add_debit_entry(
             value, (_(u'Cash out: %s') % (self.reason.get_text(), )))
 
-        TillAddTillEntryEvent.emit(till_entry, self.conn)
-        _create_transaction(self.conn, till_entry)
+        TillAddTillEntryEvent.emit(till_entry, self.store)
+        _create_transaction(self.store, till_entry)
 
     def _on_cash_slave__value_changed(self, entry):
         self.cash_slave.model.value = -abs(self.cash_slave.model.value)
@@ -465,8 +480,8 @@ class CashInEditor(BaseEditor):
 
     help_section = 'till-add-money'
 
-    def __init__(self, conn):
-        BaseEditor.__init__(self, conn)
+    def __init__(self, store):
+        BaseEditor.__init__(self, store)
         self.set_confirm_widget(self.reason)
         self.set_confirm_widget(self.cash_slave.value)
 
@@ -474,23 +489,22 @@ class CashInEditor(BaseEditor):
     # BaseEditorSlave
     #
 
-    def create_model(self, conn):
-        till = Till.get_current(conn)
+    def create_model(self, store):
+        till = Till.get_current(store)
         return Settable(value=currency(0),
-                        reason='',
+                        reason=u'',
                         till=till,
                         balance=till.get_balance())
 
     def setup_slaves(self):
-        self.cash_slave = BaseCashSlave(self.conn, self.model)
+        self.cash_slave = BaseCashSlave(self.store, self.model)
         self.attach_slave("base_cash_holder", self.cash_slave)
 
     def on_confirm(self):
         till = self.model.till
         assert till
         try:
-            TillAddCashEvent.emit(till=till,
-                                  value=self.model.value)
+            TillAddCashEvent.emit(till=till, value=self.model.value)
         except (TillError, DeviceError, DriverError), e:
             warning(str(e))
             self.retval = False
@@ -500,5 +514,5 @@ class CashInEditor(BaseEditor):
             self.model.value,
             (_(u'Cash in: %s') % (self.reason.get_text(), )))
 
-        TillAddTillEntryEvent.emit(till_entry, self.conn)
-        _create_transaction(self.conn, till_entry)
+        TillAddTillEntryEvent.emit(till_entry, self.store)
+        _create_transaction(self.store, till_entry)
