@@ -32,6 +32,7 @@
 import pickle
 
 import gobject
+import glib
 import pango
 import gtk
 from gtk import gdk
@@ -127,14 +128,11 @@ class FieldInfo(object):
 class FieldGrid(gtk.Layout):
     """FieldGrid is a Grid like widget which you can add fields to
 
-    Signals
-    =======
-      - B{field-added} (object):
-        - Emitted when a field is added to the grid
-      - B{field-removed} (object):
-        - Emitted when a field is removed from the grid
-      - B{selection-changed} (object):
-        - Emitted when a field is selected or deselected by the user.
+    * **field-added** (object): Emitted when a field is added to the grid
+    * **field-removed** (object): Emitted when a field is removed
+      from the grid
+    * ** selection-changed** (object): Emitted when a field is selected or
+      deselected by the user.
     """
 
     gsignal('selection-changed', object,
@@ -201,7 +199,8 @@ class FieldGrid(gtk.Layout):
         if not description:
             description = text
         label.set_markup(
-            '<span letter_spacing="3072">%s</span>' % (description, ))
+            '<span letter_spacing="3072">%s</span>' % (
+            glib.markup_escape_text(description), ))
         label.modify_font(self.font)
         field = FieldInfo(self, text, label, x, y, width, height)
         self._fields.append(field)
