@@ -23,12 +23,19 @@
 ##
 ##
 
+import os
+import tempfile
 
+import gio
 import gobject
-
-from kiwi.ui.forms import ChoiceField
+import gtk
+from kiwi.ui.dialogs import selectfile
+from kiwi.ui.forms import ChoiceField, Field
+import pango
 
 from stoqlib.api import api
+from stoqlib.domain.attachment import Attachment
+from stoqlib.gui.filters import get_filters_for_attachment
 from stoqlib.lib.translation import stoqlib_gettext
 
 _ = stoqlib_gettext
@@ -69,13 +76,14 @@ class DomainChoiceField(ChoiceField):
     # Private
 
     def _run_editor(self, model=None):
-        trans = api.new_transaction()
-        model = trans.get(model)
-        model = self.run_dialog(trans, model)
-        rv = api.finish_transaction(trans, model)
+        store = api.new_store()
+        model = store.fetch(model)
+        model = self.run_dialog(store, model)
+        rv = store.confirm(model)
         if rv:
-            self.populate(model, trans)
-        trans.close()
+            main_store = self.form.main_view.store
+            self.populate(main_store.fetch(model), main_store)
+        store.close()
 
     def _update_add_button_sensitivity(self):
         self.add_button.set_sensitive(self.can_add)
@@ -96,7 +104,7 @@ class DomainChoiceField(ChoiceField):
 
     # Overrides
 
-    def run_dialog(self, trans, model):
+    def run_dialog(self, store, model):
         raise NotImplementedError
 
 
@@ -113,12 +121,11 @@ class AddressField(DomainChoiceField):
         self.connect('notify::person', self._on_person__notify)
         super(AddressField, self).attach()
 
-    def populate(self, address, trans):
+    def populate(self, address, store):
         from stoqlib.domain.address import Address
         self.person = address.person if address else None
-        addresses = Address.selectBy(
-            connection=trans,
-            person=self.person).orderBy('street')
+        addresses = store.find(Address,
+            person=self.person).order_by(Address.street)
 
         self.widget.prefill(api.for_combo(addresses))
         if address:
@@ -127,10 +134,10 @@ class AddressField(DomainChoiceField):
         self.add_button.set_tooltip_text(_("Add a new address"))
         self.edit_button.set_tooltip_text(_("Edit the selected address"))
 
-    def run_dialog(self, trans, address):
+    def run_dialog(self, store, address):
         from stoqlib.gui.editors.addresseditor import AddressEditor
         from stoqlib.gui.base.dialogs import run_dialog
-        return run_dialog(AddressEditor, self.toplevel, trans, self.person,
+        return run_dialog(AddressEditor, self.toplevel, store, self.person,
                           address, visual_mode=not self.can_edit)
 
     # Public
@@ -138,7 +145,7 @@ class AddressField(DomainChoiceField):
     def set_from_client(self, client):
         self.person = client.person
         self.populate(self.person.get_main_address(),
-                      self.person.get_connection())
+                      self.person.store)
 
     # Private
 
@@ -147,6 +154,32 @@ class AddressField(DomainChoiceField):
         self.add_button.set_sensitive(bool(self.person))
 
 
+class PaymentMethodField(ChoiceField):
+    #: The type of the payment used to get creatable methods.
+    #: See :meth:`stoqlib.lib.interfaces.IPaymentOperation.creatable`
+    #: for more information
+    payment_type = gobject.property(type=object, default=None)
+
+    #: If this is being created separated from a |sale|/|purchase|
+    #: See :meth:`stoqlib.lib.interfaces.IPaymentOperation.creatable`
+    #: for more information
+    separate = gobject.property(type=bool, default=True)
+
+    # Field
+
+    def populate(self, value, store):
+        from stoqlib.domain.payment.method import PaymentMethod
+        assert self.payment_type is not None
+        methods = set(PaymentMethod.get_creatable_methods(
+            store, self.payment_type, separate=self.separate))
+        # Add the current value, just in case the payment method is not
+        # currently creatable
+        methods.add(value)
+        self.widget.prefill(api.for_combo(methods))
+        if value is not None:
+            self.widget.select(value)
+
+
 class PaymentCategoryField(DomainChoiceField):
     #: This is the type of payment category we will display in this field, it
     #: it should either be PaymentCategory.TYPE_PAYABLE or
@@ -155,11 +188,9 @@ class PaymentCategoryField(DomainChoiceField):
 
     # Field
 
-    def populate(self, value, trans):
+    def populate(self, value, store):
         from stoqlib.domain.payment.category import PaymentCategory
-        categories = PaymentCategory.selectBy(
-            connection=trans,
-            category_type=self.category_type).orderBy('name')
+        categories = PaymentCategory.get_by_type(store, self.category_type)
         values = api.for_combo(
             categories, empty=_('No category'), attr='name')
         self.widget.prefill(values)
@@ -168,10 +199,10 @@ class PaymentCategoryField(DomainChoiceField):
         self.add_button.set_tooltip_text(_("Add a new payment category"))
         self.edit_button.set_tooltip_text(_("Edit the selected payment category"))
 
-    def run_dialog(self, trans, category):
+    def run_dialog(self, store, category):
         from stoqlib.gui.editors.paymentcategoryeditor import PaymentCategoryEditor
         from stoqlib.gui.base.dialogs import run_dialog
-        return run_dialog(PaymentCategoryEditor, self.toplevel, trans, category,
+        return run_dialog(PaymentCategoryEditor, self.toplevel, store, category,
                           self.category_type, visual_mode=not self.can_edit)
 
 
@@ -185,40 +216,40 @@ class PersonField(DomainChoiceField):
 
     # Field
 
-    def populate(self, person, trans):
+    def populate(self, person, store):
         from stoqlib.domain.person import (Client, Supplier, Transporter,
                                            SalesPerson, Branch)
         person_type = self.person_type
         if person_type == Supplier:
-            facets = person_type.get_active_suppliers(trans)
+            objects = Supplier.get_active_suppliers(store)
             self.add_button.set_tooltip_text(_("Add a new supplier"))
             self.edit_button.set_tooltip_text(_("Edit the selected supplier"))
         elif person_type == Client:
-            facets = person_type.get_active_clients(trans)
+            objects = Client.get_active_clients(store)
             self.add_button.set_tooltip_text(_("Add a new client"))
             self.edit_button.set_tooltip_text(_("Edit the selected client"))
         elif person_type == Transporter:
-            facets = person_type.get_active_transporters(trans)
+            objects = Transporter.get_active_transporters(store)
             self.add_button.set_tooltip_text(_("Add a new transporter"))
             self.edit_button.set_tooltip_text(_("Edit the selected transporter"))
         elif person_type == SalesPerson:
-            facets = person_type.get_active_salespersons(trans)
+            objects = SalesPerson.get_active_salespersons(store)
             self.add_button.set_tooltip_text(_("Add a new sales person"))
             self.edit_button.set_tooltip_text(_("Edit the selected sales person"))
         elif person_type == Branch:
-            facets = person_type.get_active_branches(trans)
+            objects = Branch.get_active_branches(store)
             self.add_button.set_tooltip_text(_("Add a new branch"))
             self.edit_button.set_tooltip_text(_("Edit the selected branch"))
         else:
             raise AssertionError(self.person_type)
 
-        self.widget.prefill(api.for_person_combo(facets))
+        self.widget.prefill(api.for_person_combo(objects))
 
         if person:
             assert isinstance(person, person_type)
             self.widget.select(person)
 
-    def run_dialog(self, trans, person):
+    def run_dialog(self, store, person):
         from stoqlib.domain.person import Branch, Client, Supplier, Transporter
         from stoqlib.gui.editors.personeditor import (BranchEditor,
                                                       ClientEditor,
@@ -235,5 +266,124 @@ class PersonField(DomainChoiceField):
             raise NotImplementedError(self.person_type)
 
         from stoqlib.gui.wizards.personwizard import run_person_role_dialog
-        return run_person_role_dialog(editor, self.toplevel, trans, person,
+        return run_person_role_dialog(editor, self.toplevel, store, person,
                                       visual_mode=not self.can_edit)
+
+
+class AttachmentField(Field):
+    """This field allows attaching files to models.
+
+      It has:
+      * a button, which you can click if there's an attachment. The attachment
+        will open in the default system application based on its mimetype
+      * the add_button, which you can click to add an attachment in case
+        there's none
+      * the edit_button, which you can click to change an attachment
+      * the delete_button, which you can click to delete an attachment
+
+      It is the editor's responsibility to get the attachment and associate it
+      to the model. For example:
+
+         self.model.attachment = self.fields['attachment'].attachment
+    """
+    widget_data_type = object
+
+    has_add_button = True
+    has_edit_button = True
+    has_delete_button = True
+
+    no_attachment_lbl = _('No attachment.')
+
+    def build_widget(self):
+        button = gtk.Button()
+        button.connect('clicked', self._on_open_button__clicked)
+
+        box = gtk.HBox(False, 4)
+        button.add(box)
+
+        self._label = gtk.Label(self.no_attachment_lbl)
+        self._label.set_ellipsize(pango.ELLIPSIZE_END)
+        self._label.set_alignment(0.5, 0.5)
+        box.pack_start(self._label, True, True, 0)
+
+        self.image = gtk.Image()
+        box.pack_end(self.image, False, False, 0)
+
+        self.sep = gtk.VSeparator()
+        box.pack_start(self.sep, False, False, 0)
+
+        button.show_all()
+
+        return button
+
+    def populate(self, attachment, store):
+        self.store = store
+        self.attachment = attachment
+        self._update_widget()
+
+    def _update_widget(self):
+        has_attachment = bool(self.attachment and self.attachment.blob)
+
+        if has_attachment:
+            self._label.set_label(self.attachment.get_description())
+            app_info = gio.app_info_get_default_for_type(
+                                                      self.attachment.mimetype,
+                                                      must_support_uris=False)
+            if app_info:
+                gicon = app_info.get_icon()
+                self.image.set_from_gicon(gicon, gtk.ICON_SIZE_SMALL_TOOLBAR)
+        else:
+            self._label.set_label(self.no_attachment_lbl)
+
+        can_open = bool(has_attachment and app_info)
+
+        self._open_button__set_sensitive(can_open)
+        self.add_button.set_sensitive(not has_attachment)
+        self.edit_button.set_sensitive(has_attachment)
+        self.delete_button.set_sensitive(has_attachment)
+
+    def _open_button__set_sensitive(self, can_open):
+        self.widget.set_sensitive(can_open)
+        self.image.set_visible(can_open)
+        self.sep.set_visible(can_open)
+
+    def delete_button_clicked(self, button):
+        self.attachment.blob = None
+        self._update_widget()
+
+    def add_button_clicked(self, button):
+        self._update_attachment()
+
+    def edit_button_clicked(self, button):
+        self._update_attachment()
+
+    def _update_attachment(self):
+        filters = get_filters_for_attachment()
+        with selectfile(_("Select attachment"), filters=filters) as sf:
+            rv = sf.run()
+            filename = sf.get_filename()
+            if rv != gtk.RESPONSE_OK or not filename:
+                return
+
+        data = open(filename, 'rb').read()
+        mimetype = gio.content_type_guess(filename, data, False)
+        if self.attachment is None:
+            self.attachment = Attachment(store=self.store)
+        self.attachment.name = unicode(os.path.basename(filename))
+        self.attachment.mimetype = unicode(mimetype)
+        self.attachment.blob = data
+        self._update_widget()
+
+    def _on_open_button__clicked(self, widget):
+        assert self.attachment
+        assert self.attachment.blob
+
+        name = '%s-%s' % ('stoq-attachment', self.attachment.get_description())
+        with tempfile.NamedTemporaryFile(suffix=name, delete=False) as f:
+            filename = f.name
+            f.write(self.attachment.blob)
+
+        gfile = gio.File(path=filename)
+        app_info = gio.app_info_get_default_for_type(
+            self.attachment.mimetype, False)
+        app_info.launch([gfile])
