@@ -25,6 +25,7 @@
 import datetime
 import sys
 
+import glib
 import gobject
 import gtk
 from kiwi.log import Logger
@@ -45,7 +46,9 @@ from stoqlib.domain.till import Till
 from stoqlib.drivers.cheque import print_cheques_for_payment_group
 from stoqlib.exceptions import DeviceError, TillError
 from stoqlib.gui.base.dialogs import run_dialog
-from stoqlib.gui.editors.tilleditor import TillOpeningEditor, TillClosingEditor
+from stoqlib.gui.editors.tilleditor import (TillOpeningEditor,
+                                            TillClosingEditor,
+                                            TillVerifyEditor)
 from stoqlib.gui.events import CouponCreatedEvent
 from stoqlib.lib.message import warning, yesno
 from stoqlib.lib.parameters import sysparam
@@ -93,32 +96,32 @@ class FiscalPrinterHelper(gobject.GObject):
                         # has_ecf
     gsignal('ecf-changed', bool)
 
-    def __init__(self, conn, parent):
+    def __init__(self, store, parent):
         """ Creates a new FiscalPrinterHelper object
-        :param conn:
+        :param store: a store
         :param parent: a gtk.Window subclass or None
         """
         gobject.GObject.__init__(self)
-        self.conn = conn
+        self.store = store
         self._parent = parent
 
     def open_till(self):
         """Opens the till
         """
-        if Till.get_current(self.conn) is not None:
+        if Till.get_current(self.store) is not None:
             warning("You already have a till operation opened. "
                     "Close the current Till and open another one.")
             return False
 
-        trans = api.new_transaction()
+        store = api.new_store()
         try:
-            model = run_dialog(TillOpeningEditor, self._parent, trans)
+            model = run_dialog(TillOpeningEditor, self._parent, store)
         except TillError, e:
             warning(str(e))
             model = None
 
-        retval = api.finish_transaction(trans, model)
-        trans.close()
+        retval = store.confirm(model)
+        store.close()
         if retval:
             self._till_status_changed(closed=False, blocked=False)
         return retval
@@ -126,47 +129,68 @@ class FiscalPrinterHelper(gobject.GObject):
     def close_till(self, close_db=True, close_ecf=True):
         """Closes the till
 
-        close_db and close_ecf should be different than True only when
-        fixing an conflicting status: If the DB is open but the ECF is
-        closed, or the other way around.
+        There are 3 possibilities for parameters combination:
+          * *total close*: Both *close_db* and *close_ecf* are ``True``.
+            The till on both will be closed.
+          * *partial close*: Both *close_db* and *close_ecf* are ``False``.
+            It's more like a till verification. The actual user will do it
+            to check and maybe remove money from till, leaving it ready
+            for the next one. Note that this will not emit
+            'till-status-changed' event, since the till will not
+            really close.
+          * *fix conflicting status*: *close_db* and *close_ecf* are
+            different. Use this only if you need to fix a conflicting
+            status, like if the DB is open but the ECF is closed, or
+            the other way around.
 
         :param close_db: If the till in the DB should be closed
         :param close_ecf: If the till in the ECF should be closed
         :returns: True if the till was closed, otherwise False
         """
+        is_partial = not close_db and not close_ecf
 
-        if not self._previous_day:
+        if not is_partial and not self._previous_day:
             if not yesno(_("You can only close the till once per day. "
                            "You won't be able to make any more sales today.\n\n"
                            "Close the till?"),
                          gtk.RESPONSE_NO, _("Close Till"), _("Not now")):
                 return
-        else:
+        elif not is_partial:
             # When closing from a previous day, close only what is needed.
             close_db = self._close_db
             close_ecf = self._close_ecf
 
         if close_db:
-            till = Till.get_last_opened(self.conn)
+            till = Till.get_last_opened(self.store)
             assert till
 
-        trans = api.new_transaction()
-        model = run_dialog(TillClosingEditor, self._parent, trans,
+        store = api.new_store()
+        editor_class = TillVerifyEditor if is_partial else TillClosingEditor
+        model = run_dialog(editor_class, self._parent, store,
                            previous_day=self._previous_day, close_db=close_db,
                            close_ecf=close_ecf)
 
         if not model:
-            api.finish_transaction(trans, model)
-            trans.close()
+            store.confirm(model)
+            store.close()
             return
 
         # TillClosingEditor closes the till
-        retval = api.finish_transaction(trans, model)
-        trans.close()
-        if retval:
+        retval = store.confirm(model)
+        store.close()
+        if retval and not is_partial:
             self._till_status_changed(closed=True, blocked=False)
+
         return retval
 
+    def verify_till(self):
+        """Verifies the till
+
+        This is just a shortcut for calling  :obj:`.close_till` passing
+        close_db/close_ecf = ``False``. See it's doc for more info.
+        """
+        return self.close_till(close_db=False, close_ecf=False)
+
     def needs_closing(self):
         """Checks if the last opened till was closed and asks the
         user if he wants to close it
@@ -180,7 +204,7 @@ class FiscalPrinterHelper(gobject.GObject):
         """
         ecf_needs_closing = HasPendingReduceZ.emit()
 
-        last_till = Till.get_last(self.conn)
+        last_till = Till.get_last(self.store)
         if last_till:
             db_needs_closing = last_till.needs_closing()
         else:
@@ -200,8 +224,8 @@ class FiscalPrinterHelper(gobject.GObject):
         :returns: a new coupon
         """
 
-        if sysparam(self.conn).DEMO_MODE:
-            branch = api.get_current_branch(self.conn)
+        if sysparam(self.store).DEMO_MODE:
+            branch = api.get_current_branch(self.store)
             company = branch.person.company
             if company and company.cnpj not in ['24.198.774/7322-35',
                                                 '66.873.574/0001-82']:
@@ -236,7 +260,7 @@ class FiscalPrinterHelper(gobject.GObject):
         delta = midnight - now
 
         # Call check_till at the first seconds of the next day.
-        gobject.timeout_add(delta.seconds * 1000, self.check_till)
+        glib.timeout_add(delta.seconds * 1000, self.check_till)
 
     def _till_status_changed(self, closed, blocked):
         self.emit('till-status-changed', closed, blocked)
@@ -248,7 +272,7 @@ class FiscalPrinterHelper(gobject.GObject):
         if needs_closing is CLOSE_TILL_NONE:
             self._previous_day = False
             # We still need to check if the till is open or closed.
-            till = Till.get_current(self.conn)
+            till = Till.get_current(self.store)
             self._till_status_changed(closed=not till, blocked=False)
             return True
 
@@ -439,27 +463,49 @@ class FiscalCoupon(gobject.GObject):
         self.payments_setup = False
         return True
 
-    def confirm(self, sale, trans):
+    def confirm(self, sale, store, savepoint=None,
+                subtotal=None,
+                total_paid=0):
+        """Confirms a |sale| on fiscalprinter and database
+
+        If the sale is confirmed, the store will be committed for you.
+        There's no need for the callsite to call store.confirm().
+        If the sale is not confirmed, for instance the user cancelled the
+        sale or there was a problem with the fiscal printer, then the
+        store will be rolled back.
+
+        :param sale: the |sale| to be confirmed
+        :param trans: a store
+        :param savepoint: if specified, a database savepoint name that
+            will be used to rollback to if the sale was not confirmed.
+        :param subtotal: the total value of all the items in the sale
+        :param total_paid: what has already been paid on this sale,
+            used when returning an item
+        """
         # Actually, we are confirming the sale here, so the sale
         # confirmation process will be available to others applications
         # like Till and not only to the POS.
-        model = run_dialog(ConfirmSaleWizard, self._parent, trans, sale)
+        model = run_dialog(ConfirmSaleWizard, self._parent, store, sale,
+                           subtotal=subtotal,
+                           total_paid=total_paid)
         if not model:
             CancelPendingPaymentsEvent.emit()
-            api.finish_transaction(trans, False)
+            store.rollback(name=savepoint, close=False)
             return False
+
         if sale.client and not self.is_customer_identified():
             self.identify_customer(sale.client.person)
 
         if not self.totalize(sale):
-            api.finish_transaction(trans, False)
+            store.rollback(name=savepoint, close=False)
             return False
 
         if not self.setup_payments(sale):
-            api.finish_transaction(trans, False)
+            store.rollback(name=savepoint, close=False)
             return False
-        if not self.close(sale, trans):
-            api.finish_transaction(trans, False)
+
+        if not self.close(sale, store):
+            store.rollback(name=savepoint, close=False)
             return False
 
         sale.confirm()
@@ -473,10 +519,10 @@ class FiscalCoupon(gobject.GObject):
         else:
             sale.group.pay_money_payments()
 
-        print_cheques_for_payment_group(trans, sale.group)
+        print_cheques_for_payment_group(store, sale.group)
 
         # Only finish the transaction after everything passed above.
-        api.finish_transaction(trans, model)
+        store.confirm(model)
 
         return True
 
@@ -603,7 +649,7 @@ class FiscalCoupon(gobject.GObject):
                     return False
                 _flush_interface()
 
-    def close(self, sale, trans):
+    def close(self, sale, store):
         # XXX: Remove this when bug #2827 is fixed.
         if not self._item_ids:
             return True
