@@ -66,6 +66,8 @@ _bindings = [
      _('Show help contents')),
 
     # Admin application
+    ('app.admin.search_cost_centers', '',
+     _("Search for cost centers")),
     ('app.admin.search_roles', '<Primary><Alt>o',
      _("Search for employee roles")),
     ('app.admin.search_employees', '<Primary><Alt>e',
@@ -128,7 +130,7 @@ _bindings = [
      _("Delete account transaction")),
     ('app.financial.new_account', '<Primary>a',
      _("Create a new account")),
-    ('app.financial.new_transaction', '<Primary>t',
+    ('app.financial.new_store', '<Primary>t',
      _("Create a new account transaction")),
     ('app.financial.edit', '',
      _("Edit an account or account transaction")),
@@ -178,6 +180,8 @@ _bindings = [
      _("Open the till")),
     ('app.pos.till_close', '<Primary>F7',
      _("Close the till")),
+    ('app.pos.till_verify', '<Primary>F8',
+     _("Verify the till")),
     ('app.pos.order_confirm', '<Primary>F10',
      _("Confirm the current order")),
     ('app.pos.order_cancel', '<Primary><Alt>o',
@@ -196,6 +200,8 @@ _bindings = [
      _("Search for services")),
     ('app.pos.search_deliveries', '<Primary><Alt>e',
      _("Search for deliveries")),
+    ('app.pos.payment_receive', '',
+     _("Receive payment")),
     # ecf till read memory: <Primary>F9
     # ecf till summarize: <Primary>F11
     # books search books: <Primary><Alt>B
@@ -372,6 +378,8 @@ _bindings = [
      _("Open the till")),
     ('app.till.close_till', '<Primary>F7',
      _("Close the till")),
+    ('app.till.verify_till', '<Primary>F8',
+     _("Verify the till")),
     ('app.till.search_clients', '<Primary><Alt>c',
      _("Search for clients")),
     ('app.till.search_sale', '<Primary><Alt>a',
@@ -388,6 +396,8 @@ _bindings = [
      _("Return the sale")),
     ('app.till.sale_details', '',
      _("Show details of the sale")),
+    ('app.till.payment_receive', '',
+     _("Receive payment")),
     # ecf till read memory: <Primary>F9
     # ecf till summarize: <Primary>F11
 ]
