@@ -29,8 +29,8 @@ from kiwi.ui.objectlist import Column
 
 from stoqlib.gui.base.search import SearchDialog
 from stoqlib.domain.event import Event
+from stoqlib.lib.dateutils import pretty_date
 from stoqlib.lib.translation import stoqlib_gettext
-from stoqlib.lib.prettydate import pretty_date
 
 _ = stoqlib_gettext
 
