@@ -25,14 +25,14 @@
 
 from kiwi.argcheck import argcheck
 from kiwi.ui.objectlist import Column
+from storm.expr import And
 from zope.interface import providedBy
 
 from stoqlib.api import api
-from stoqlib.database.orm import AND
 from stoqlib.domain.base import Domain
 from stoqlib.domain.interfaces import IDescribable
 from stoqlib.domain.parameter import ParameterData
-from stoqlib.lib.parameters import sysparam, DirectoryParameter
+from stoqlib.lib.parameters import sysparam, PathParameter
 from stoqlib.lib.translation import stoqlib_gettext, dgettext
 from stoqlib.gui.base.columns import AccessorColumn
 from stoqlib.gui.base.dialogs import run_dialog
@@ -48,21 +48,21 @@ class ParameterSearch(BaseEditor):
     size = (750, 450)
     title = _(u"Stoq System Parameters")
 
-    def __init__(self, conn):
-        BaseEditor.__init__(self, conn, model=object())
+    def __init__(self, store):
+        BaseEditor.__init__(self, store, model=object())
         self._parameters = []
         self._setup_widgets()
 
     def _setup_widgets(self):
         self.results.set_columns(self._get_columns())
-        clause = AND(
+        clause = And(
             # Do not allow this parameter to be used by general users for now
-            ParameterData.q.field_name != "ALLOW_TRADE_NOT_REGISTERED_SALES",
+            ParameterData.field_name != u"ALLOW_TRADE_NOT_REGISTERED_SALES",
             # FIXME: This isn't doing anything for now. Not showing
             # on the search as it could confuse the users.
-            ParameterData.q.field_name != "RETURN_MONEY_ON_SALES",
+            ParameterData.field_name != u"RETURN_MONEY_ON_SALES",
             )
-        self._parameters = ParameterData.select(clause, connection=self.conn)
+        self._parameters = self.store.find(ParameterData, clause)
         self._reset_results()
         self.edit_button.set_sensitive(False)
 
@@ -84,8 +84,8 @@ class ParameterSearch(BaseEditor):
         """Given a ParameterData object, returns a string representation of
         its current value.
         """
-        constant = sysparam(self.conn).get_parameter_constant(obj.field_name)
-        data = getattr(sysparam(self.conn), obj.field_name)
+        constant = sysparam(self.store).get_parameter_constant(obj.field_name)
+        data = getattr(sysparam(self.store), obj.field_name)
         if isinstance(data, Domain):
             if not (IDescribable in providedBy(data)):
                 raise TypeError("Parameter `%s' must implement IDescribable "
@@ -93,11 +93,11 @@ class ParameterSearch(BaseEditor):
             return data.get_description()
         elif constant.options:
             return constant.options[int(obj.field_value)]
-        elif isinstance(data, DirectoryParameter):
+        elif isinstance(data, PathParameter):
             return data.path
         elif isinstance(data, bool):
             return [_("No"), _("Yes")][data]
-        elif obj.field_name == 'COUNTRY_SUGGESTED':
+        elif obj.field_name == u'COUNTRY_SUGGESTED':
             return dgettext("iso_3166", data)
         elif isinstance(data, unicode):
             #FIXME: workaround to handle locale specific data
@@ -105,13 +105,13 @@ class ParameterSearch(BaseEditor):
         return data
 
     def _edit_item(self, item):
-        trans = api.new_transaction()
-        parameter = trans.get(item)
-        retval = run_dialog(SystemParameterEditor, self, trans, parameter)
-        if api.finish_transaction(trans, retval):
-            sysparam(trans).rebuild_cache_for(item.field_name)
+        store = api.new_store()
+        parameter = store.fetch(item)
+        retval = run_dialog(SystemParameterEditor, self, store, parameter)
+        if store.confirm(retval):
+            sysparam(store).rebuild_cache_for(item.field_name)
             self.results.update(item)
-        trans.close()
+        store.close()
 
     def _filter_results(self, text):
         query = text.lower()
