@@ -33,7 +33,6 @@ from kiwi.ui.search import ComboSearchFilter, DateSearchFilter, Today
 from kiwi.ui.objectlist import Column, ColoredColumn, SearchColumn
 
 from stoqlib.api import api
-from stoqlib.database.orm import AND
 from stoqlib.domain.person import Branch
 from stoqlib.domain.product import Product, ProductHistory
 from stoqlib.domain.sellable import Sellable
@@ -68,13 +67,13 @@ class ProductSearch(SearchEditor):
     footer_ok_label = _('Add products')
     searchbar_result_strings = (_('product'), _('products'))
 
-    def __init__(self, conn, hide_footer=True, hide_toolbar=False,
+    def __init__(self, store, hide_footer=True, hide_toolbar=False,
                  selection_mode=gtk.SELECTION_BROWSE,
                  hide_cost_column=False, use_product_statuses=None,
                  hide_price_column=False):
         """
         Create a new ProductSearch object.
-        :param conn: a orm Transaction instance
+        :param store: a store
         :param hide_footer: do I have to hide the dialog footer?
         :param hide_toolbar: do I have to hide the dialog toolbar?
         :param selection_mode: the kiwi list selection mode
@@ -89,7 +88,7 @@ class ProductSearch(SearchEditor):
         self.use_product_statuses = use_product_statuses
         self.hide_cost_column = hide_cost_column
         self.hide_price_column = hide_price_column
-        SearchEditor.__init__(self, conn, hide_footer=hide_footer,
+        SearchEditor.__init__(self, store, hide_footer=hide_footer,
                               hide_toolbar=hide_toolbar,
                               selection_mode=selection_mode)
         self.set_searchbar_labels(_('matching'))
@@ -188,19 +187,14 @@ class ProductSearch(SearchEditor):
                                  data_type=Decimal, width=80))
         return cols
 
-    def executer_query(self, query, having, conn):
-        branch = self.branch_filter.get_state().value
-        if branch is not None:
-            branch = Branch.get(branch, connection=conn)
-
-        composed_query = Product.q.is_composed == False
-        if query:
-            query = AND(query, composed_query)
+    def executer_query(self, store):
+        branch_id = self.branch_filter.get_state().value
+        if branch_id is None:
+            branch = None
         else:
-            query = composed_query
-
-        return self.search_table.select_by_branch(query, branch,
-                                                  connection=conn)
+            branch = store.get(Branch, branch_id)
+        results = self.search_table.find_by_branch(store, branch)
+        return results.find(Product.is_composed == False)
 
     #
     # Callbacks
@@ -230,24 +224,24 @@ class ProductSearchQuantity(SearchDialog):
     advanced_search = False
     show_production_columns = False
 
-    def on_print_button_clicked(self, button):
-        print_report(ProductQuantityReport, self.results, list(self.results),
-                     filters=self.search.get_search_filters())
-
     #
     # SearchDialog Hooks
     #
 
+    def on_print_button_clicked(self, button):
+        print_report(ProductQuantityReport, self.results, list(self.results),
+                     filters=self.search.get_search_filters())
+
     def create_filters(self):
         self.set_text_field_columns(['description'])
 
         # Date
         date_filter = DateSearchFilter(_('Date:'))
         date_filter.select(Today)
-        columns = [ProductHistory.q.sold_date,
-                   ProductHistory.q.received_date,
-                   ProductHistory.q.production_date,
-                   ProductHistory.q.decreased_date]
+        columns = [ProductHistory.sold_date,
+                   ProductHistory.received_date,
+                   ProductHistory.production_date,
+                   ProductHistory.decreased_date]
         self.add_filter(date_filter, columns=columns)
         self.date_filter = date_filter
 
@@ -322,13 +316,15 @@ class ProductsSoldSearch(SearchDialog):
                         position=SearchFilterPosition.TOP)
         self.branch_filter = branch_filter
 
-    def executer_query(self, query, having, conn):
+    def executer_query(self, store):
         # We have to do this manual filter since adding this columns to the
         # view would also group the results by those fields, leading to
         # duplicate values in the results.
-        branch = self.branch_filter.get_state().value
-        if branch is not None:
-            branch = Branch.get(branch, connection=conn)
+        branch_id = self.branch_filter.get_state().value
+        if branch_id is None:
+            branch = None
+        else:
+            branch = store.get(Branch, branch_id)
 
         date = self.date_filter.get_state()
         if isinstance(date, DateQueryState):
@@ -336,8 +332,7 @@ class ProductsSoldSearch(SearchDialog):
         elif isinstance(date, DateIntervalQueryState):
             date = (date.start, date.end)
 
-        return self.table.select_by_branch_date(query, branch, date,
-                                           connection=conn)
+        return self.table.find_by_branch_date(store, branch, date)
     #
     # SearchEditor Hooks
     #
@@ -385,7 +380,7 @@ class ProductStockSearch(SearchEditor):
         self.executer.set_query(self.executer_query)
 
         branch_filter = self.create_branch_filter(_('In branch:'))
-        branch_filter.select(api.get_current_branch(self.conn).id)
+        branch_filter.select(api.get_current_branch(self.store).id)
         self.add_filter(branch_filter, columns=[])
         self.branch_filter = branch_filter
 
@@ -426,11 +421,13 @@ class ProductStockSearch(SearchEditor):
                               format_func=format_data, data_type=Decimal,
                               data_func=lambda x: x <= Decimal(0))]
 
-    def executer_query(self, query, having, conn):
-        branch = self.branch_filter.get_state().value
-        if branch is not None:
-            branch = Branch.get(branch, connection=conn)
-        return self.table.select_by_branch(query, branch, connection=conn)
+    def executer_query(self, store):
+        branch_id = self.branch_filter.get_state().value
+        if branch_id is None:
+            branch = None
+        else:
+            branch = store.get(Branch, branch_id)
+        return self.table.find_by_branch(store, branch)
 
 
 class ProductClosedStockSearch(ProductSearch):
@@ -440,11 +437,11 @@ class ProductClosedStockSearch(ProductSearch):
     table = search_table = ProductClosedStockView
     has_new_button = False
 
-    def __init__(self, conn, hide_footer=True, hide_toolbar=True,
+    def __init__(self, store, hide_footer=True, hide_toolbar=True,
                  selection_mode=gtk.SELECTION_BROWSE,
                  hide_cost_column=True, use_product_statuses=None,
                  hide_price_column=True):
-        ProductSearch.__init__(self, conn, hide_footer, hide_toolbar,
+        ProductSearch.__init__(self, store, hide_footer, hide_toolbar,
                                selection_mode, hide_cost_column,
                                use_product_statuses, hide_price_column)
 
