@@ -38,7 +38,7 @@ from stoqlib.gui.base.search import SearchDialog
 from stoqlib.gui.dialogs.transferorderdialog import TransferOrderDetailsDialog
 from stoqlib.gui.printing import print_report
 from stoqlib.lib.translation import stoqlib_gettext
-from stoqlib.reporting.transfer_receipt import TransferOrderReceipt
+from stoqlib.reporting.transferreceipt import TransferOrderReceipt
 
 _ = stoqlib_gettext
 
@@ -52,14 +52,14 @@ class TransferOrderSearch(SearchDialog):
     search_by_date = True
     advanced_search = False
 
-    def __init__(self, conn):
-        SearchDialog.__init__(self, conn, self.search_table,
+    def __init__(self, store):
+        SearchDialog.__init__(self, store, self.search_table,
                               title=self.title)
         self._setup_widgets()
 
     def _show_transfer_order_details(self, order_view):
         transfer_order = order_view.transfer_order
-        run_dialog(TransferOrderDetailsDialog, self, self.conn,
+        run_dialog(TransferOrderDetailsDialog, self, self.store,
                    transfer_order)
 
     def _setup_widgets(self):
