@@ -57,8 +57,7 @@ class CommissionSlave(BaseEditorSlave):
 
     def _get_source(self):
         sellable = self.model
-        return CommissionSource.selectOneBy(sellable=sellable,
-                                            connection=self.conn)
+        return self.store.find(CommissionSource, sellable=sellable).one()
 
     def _create_source(self):
         direct = self._get_direct_commission()
@@ -66,10 +65,10 @@ class CommissionSlave(BaseEditorSlave):
         CommissionSource(direct_value=direct,
                          installments_value=inst,
                          sellable=self.model,
-                         connection=self.conn)
+                         store=self.store)
 
     def _delete_source(self, source):
-        CommissionSource.delete(source.id, connection=self.conn)
+        CommissionSource.delete(source.id, store=self.store)
 
     def _update_source(self, source):
         source.direct_value = self._get_direct_commission()
@@ -111,8 +110,7 @@ class CategoryCommissionSlave(CommissionSlave):
     model_type = SellableCategory
 
     def _get_source(self):
-        return CommissionSource.selectOneBy(category=self.model,
-                                            connection=self.conn)
+        return self.store.find(CommissionSource, category=self.model).one()
 
     def _create_source(self):
         direct = self._get_direct_commission()
@@ -120,7 +118,7 @@ class CategoryCommissionSlave(CommissionSlave):
         CommissionSource(direct_value=direct,
                          installments_value=inst,
                          category=self.model,
-                         connection=self.conn)
+                         store=self.store)
 
     def on_commission_check_btn__content_changed(self, widget):
         CommissionSlave.on_commission_check_btn__content_changed(self, widget)
@@ -128,8 +126,7 @@ class CategoryCommissionSlave(CommissionSlave):
         if widget.get_active():
             category = self.model.category
             while category:
-                cs = CommissionSource.selectOneBy(connection=self.conn,
-                                                  category=category)
+                cs = self.store.find(CommissionSource, category=category).one()
                 if cs:
                     self.commission_spin.update(cs.direct_value)
                     self.commission_inst_spin.update(cs.installments_value)
