@@ -22,7 +22,10 @@
 ## Author(s): Stoq Team <stoq-devel@async.com.br>
 ##
 ##
-""" Slaves for payment management """
+"""Slaves for payment creation
+
+This slaves will be used when payments are being created.
+"""
 
 from copy import deepcopy
 import datetime
@@ -41,14 +44,16 @@ from kiwi.ui.objectlist import Column
 
 from stoqlib.api import api
 from stoqlib.domain.events import CreatePaymentEvent
+from stoqlib.domain.payment.card import CreditProvider, CreditCardData
+from stoqlib.domain.payment.card import CardPaymentDevice
 from stoqlib.domain.payment.group import PaymentGroup
-from stoqlib.domain.payment.method import PaymentMethod, CreditCardData
+from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.payment.payment import Payment, PaymentChangeHistory
 from stoqlib.domain.payment.renegotiation import PaymentRenegotiation
-from stoqlib.domain.person import CreditProvider
 from stoqlib.domain.purchase import PurchaseOrder
 from stoqlib.domain.returnedsale import ReturnedSale
 from stoqlib.domain.sale import Sale
+from stoqlib.domain.stockdecrease import StockDecrease
 from stoqlib.drivers.cheque import get_current_cheque_printer_settings
 from stoqlib.enums import CreatePaymentStatus
 from stoqlib.exceptions import SellError
@@ -86,8 +91,9 @@ class _BaseTemporaryMethodData(object):
 
 
 class _TemporaryCreditProviderGroupData(_BaseTemporaryMethodData):
-    def __init__(self, provider=None):
+    def __init__(self, provider=None, device=None):
         self.provider = provider
+        self.device = device
         _BaseTemporaryMethodData.__init__(self)
 
 
@@ -150,7 +156,7 @@ class _BasePaymentDataEditor(BaseEditor):
     #
 
     def on_due_date__validate(self, widget, value):
-        if sysparam(self.conn).ALLOW_OUTDATED_OPERATIONS:
+        if sysparam(self.store).ALLOW_OUTDATED_OPERATIONS:
             return
 
         if value < datetime.date.today():
@@ -228,7 +234,7 @@ class PaymentListSlave(GladeSlaveDelegate):
         return self.method.method_name != 'money'
 
     def _has_bank_account(self):
-        return self.method.method_name == 'check'
+        return self.method.method_name == u'check'
 
     def _get_columns(self):
         columns = [Column('description', title=_('Description'),
@@ -246,7 +252,7 @@ class PaymentListSlave(GladeSlaveDelegate):
                                    data_type=str, justify=gtk.JUSTIFY_RIGHT)])
 
         # Money methods doesn't have a payment_number related with it.
-        if self.method.method_name != 'money':
+        if self.method.method_name != u'money':
             columns.append(Column('payment_number', title=_('Number'),
                                   data_type=str, justify=gtk.JUSTIFY_RIGHT))
 
@@ -373,7 +379,7 @@ class PaymentListSlave(GladeSlaveDelegate):
         return (total_payments - self.total_value)
 
     def are_due_dates_valid(self):
-        if sysparam(self.method.get_connection()).ALLOW_OUTDATED_OPERATIONS:
+        if sysparam(self.method.store).ALLOW_OUTDATED_OPERATIONS:
             return True
 
         previous_date = datetime.date.today() + datetime.timedelta(days=-1)
@@ -420,7 +426,7 @@ class BasePaymentMethodSlave(BaseEditorSlave):
                      'first_duedate',
                      'installments_number')
 
-    def __init__(self, wizard, parent, conn, order_obj, payment_method,
+    def __init__(self, wizard, parent, store, order_obj, payment_method,
                  outstanding_value=currency(0), first_duedate=None,
                  installments_number=None):
         self.wizard = wizard
@@ -439,7 +445,7 @@ class BasePaymentMethodSlave(BaseEditorSlave):
         self._first_duedate = first_duedate
         self._installments_number = installments_number
 
-        BaseEditorSlave.__init__(self, conn)
+        BaseEditorSlave.__init__(self, store)
         self.register_validate_function(self._refresh_next)
 
         # Most of slaves don't have bank information
@@ -505,7 +511,8 @@ class BasePaymentMethodSlave(BaseEditorSlave):
             raise TypeError
 
     def _get_payment_type(self):
-        if isinstance(self.order, (Sale, PaymentRenegotiation, ReturnedSale)):
+        if isinstance(self.order, (Sale, PaymentRenegotiation, ReturnedSale,
+                                   StockDecrease)):
             return Payment.TYPE_IN
         elif isinstance(self.order, PurchaseOrder):
             return Payment.TYPE_OUT
@@ -564,7 +571,7 @@ class BasePaymentMethodSlave(BaseEditorSlave):
         self.proxy = self.add_proxy(self.model,
                                     BasePaymentMethodSlave.proxy_widgets)
 
-    def create_model(self, conn):
+    def create_model(self, store):
         return _BaseTemporaryMethodData(self._first_duedate,
                                         self._installments_number)
 
@@ -604,7 +611,7 @@ class BasePaymentMethodSlave(BaseEditorSlave):
                                      max_installments)
 
     def on_first_duedate__validate(self, widget, value):
-        if sysparam(self.conn).ALLOW_OUTDATED_OPERATIONS:
+        if sysparam(self.store).ALLOW_OUTDATED_OPERATIONS:
             return
 
         if value < datetime.date.today():
@@ -622,10 +629,10 @@ class CheckMethodSlave(BasePaymentMethodSlave):
 
     data_editor_class = CheckDataEditor
 
-    def __init__(self, wizard, parent, conn, total_amount,
+    def __init__(self, wizard, parent, store, total_amount,
                  payment_method, outstanding_value=currency(0),
                  first_duedate=None, installments_number=None):
-        BasePaymentMethodSlave.__init__(self, wizard, parent, conn,
+        BasePaymentMethodSlave.__init__(self, wizard, parent, store,
                                         total_amount, payment_method,
                                         outstanding_value=outstanding_value,
                                         installments_number=installments_number,
@@ -634,7 +641,7 @@ class CheckMethodSlave(BasePaymentMethodSlave):
         self.bank_label.show()
 
     def _setup_widgets(self):
-        printer = get_current_cheque_printer_settings(self.conn)
+        printer = get_current_cheque_printer_settings(self.store)
         if not printer:
             self.bank_combo.hide()
             self.bank_label.hide()
@@ -667,7 +674,7 @@ class CardMethodSlave(BaseEditorSlave):
     model_type = _TemporaryCreditProviderGroupData
     proxy_widgets = ('credit_provider', 'installments_number')
 
-    def __init__(self, wizard, parent, conn, order, payment_method,
+    def __init__(self, wizard, parent, store, order, payment_method,
                  outstanding_value=currency(0), first_duedate=None,
                  installments_number=None):
         self.order = order
@@ -677,7 +684,7 @@ class CardMethodSlave(BaseEditorSlave):
         self.total_value = (outstanding_value or
                             self._get_total_amount())
         self._selected_type = CreditCardData.TYPE_CREDIT
-        BaseEditorSlave.__init__(self, conn)
+        BaseEditorSlave.__init__(self, store)
         self.register_validate_function(self._refresh_next)
         self.parent = parent
         self._order = order
@@ -709,9 +716,13 @@ class CardMethodSlave(BaseEditorSlave):
         self.credit_provider.select_item_by_position(1)
         self.credit_provider.select_item_by_position(0)
 
-    def create_model(self, conn):
+    def create_model(self, store):
+        if store.find(CardPaymentDevice).is_empty():
+            raise ValueError('You must have card devices registered '
+                             'before start doing sales')
+
         providers = CreditProvider.get_card_providers(
-            self.method.get_connection())
+            self.method.store)
         if providers.count() == 0:
             raise ValueError('You must have credit providers information '
                              'stored in the database before start doing '
@@ -731,8 +742,11 @@ class CardMethodSlave(BaseEditorSlave):
             raise TypeError
 
     def _setup_widgets(self):
+        devices = CardPaymentDevice.get_devices(self.method.store)
+        self.card_device.prefill(api.for_combo(devices))
+
         providers = CreditProvider.get_card_providers(
-            self.method.get_connection())
+            self.method.store)
         self.credit_provider.prefill(api.for_combo(providers))
 
         self._radio_group = None
@@ -768,43 +782,91 @@ class CardMethodSlave(BaseEditorSlave):
         if type == CreditCardData.TYPE_CREDIT_INSTALLMENTS_STORE:
             maximum = self.method.max_installments
         elif type == CreditCardData.TYPE_CREDIT_INSTALLMENTS_PROVIDER:
-            maximum = self.model.provider.max_installments
+            # In this case the installments will be validated using
+            # CreditCardCost. Let the use type any value he wants.
+            maximum = 100
 
         if maximum > 1:
             minimum = 2
         else:
             minimum = 1
 
-        self.installments_number.set_sensitive(maximum != 1)
+        # Use set_editable instead of set_sensitive so that the invalid state
+        # disables the finish
+        self.installments_number.set_editable(maximum != 1)
+
+        # TODO: Prevent validation signal here to avoid duplicate effort
         self.installments_number.set_range(minimum, maximum)
+        self.installments_number.validate(force=True)
+
+    def _get_payment_details(self):
+        """Given the current state of this slave, this method will return a
+        tuple containing:
+
+        - The due date of the first payment. All other payments will have a one
+          month delta
+        - The fee (percentage) of the payments
+        - The fare (fixed cost) of the payments
+
+        The state considered is:
+
+        - Selected card device
+        - Selected card provider
+        - Selected card type
+        - Number of installments
+        """
+        # If its a purchase order, the due date is today, and there is no fee
+        # and fare
+        if isinstance(self._order, PurchaseOrder):
+            return datetime.datetime.today(), 0, 0
+
+        device = self.card_device.read()
+        cost = device.get_provider_cost(provider=self.model.provider,
+                                        card_type=self._selected_type,
+                                        installments=self.model.installments_number)
+
+        # If there is no configuration for this payment settings, still let the
+        # user sell, but there will be no automatic calculation of the first due
+        # date and any other cost related to the payment.
+        if cost:
+            payment_days = cost.payment_days
+            fare = cost.fare
+            fee = cost.fee
+        else:
+            payment_days = 0
+            fare = 0
+            fee = 0
+
+        today = datetime.datetime.today()
+        first_duedate = today + relativedelta(days=payment_days)
+        return first_duedate, fare, fee
 
     def _setup_payments(self):
-        provider = self.model.provider
-        payment_type = self._selected_type
+        first_duedate, fare, fee = self._get_payment_details()
         due_dates = []
-        first_duedate = datetime.datetime.today()
         for i in range(self.model.installments_number):
-            if first_duedate.day > provider.closing_day:
-                first_duedate += relativedelta(months=+1)
-            due_dates.append(first_duedate.replace(day=provider.payment_day))
-            first_duedate += relativedelta(months=+1)
+            due_dates.append(first_duedate + relativedelta(months=i))
 
         if isinstance(self._order, PurchaseOrder):
             payments = self.method.create_outpayments(self._payment_group,
                                                       self.order.branch,
                                                       self.total_value, due_dates)
-        else:
-            payments = self.method.create_inpayments(self._payment_group,
-                                                     self.order.branch,
-                                                     self.total_value, due_dates)
+            return
 
+        payments = self.method.create_inpayments(self._payment_group,
+                                                 self.order.branch,
+                                                 self.total_value, due_dates)
+
+        device = self.card_device.read()
         operation = self.method.operation
         for payment in payments:
             data = operation.get_card_data_by_payment(payment)
-            data.card_type = payment_type
-            data.provider = provider
-            data.fee = provider.get_fee_for_payment(data)
-            data.fee_value = data.fee * payment.value / 100
+            data.card_type = self._selected_type
+            data.provider = self.model.provider
+            data.device = device
+            data.fare = fare
+            data.fee = fee
+            data.fee_value = fee * payment.value / 100
 
     #
     #   Callbacks
@@ -813,7 +875,16 @@ class CardMethodSlave(BaseEditorSlave):
     def on_credit_provider__changed(self, combo):
         self._setup_max_installments()
 
+    def on_card_device__changed(self, combo):
+        self.installments_number.validate(force=True)
+
     def on_installments_number__validate(self, entry, installments):
+        provider = self.credit_provider.read()
+        device = self.card_device.read()
+        # Prevent validating in case the dialog is still beeing setup
+        if ValueUnset in (device, provider, installments):
+            return
+
         max_installments = self.installments_number.get_range()[1]
         min_installments = self.installments_number.get_range()[0]
         if not min_installments <= installments <= max_installments:
@@ -832,16 +903,16 @@ class _MultipleMethodEditor(BaseEditor):
     model_name = _(u'Payment')
     size = (-1, 375)
 
-    def __init__(self, wizard, parent, conn, order, payment_method,
+    def __init__(self, wizard, parent, store, order, payment_method,
                  outstanding_value=currency(0)):
-        BaseEditor.__init__(self, conn, order.group)
+        BaseEditor.__init__(self, store, order.group)
 
         self._method = payment_method
         dsm = get_utility(IDomainSlaveMapper)
         slave_class = dsm.get_slave_class(self._method)
         assert slave_class
 
-        self.conn.savepoint('before_payment_creation')
+        self.store.savepoint('before_payment_creation')
 
         #FIXME: This is a workaround to make the slave_class to ignore the
         #       payments created previously.
@@ -849,12 +920,12 @@ class _MultipleMethodEditor(BaseEditor):
             def get_created_adapted_payments(self):
                 return []
 
-        self.slave = _InnerSlaveClass(wizard, parent, self.conn, order,
+        self.slave = _InnerSlaveClass(wizard, parent, self.store, order,
                                       self._method, outstanding_value)
         #FIXME: We need to control how many payments could be created, since
         #       we are ignoring the payments created previously.
-        payments = order.group.get_valid_payments().filter(
-                                        Payment.q.method_id == self._method.id)
+        payments = order.group.get_valid_payments().find(
+                                        Payment.method_id == self._method.id)
         max_installments = self._method.max_installments - payments.count()
         self.slave.installments_number.set_range(1, max_installments)
 
@@ -864,7 +935,7 @@ class _MultipleMethodEditor(BaseEditor):
         return self.slave.finish()
 
     def on_cancel(self):
-        self.conn.rollback_to_savepoint('before_payment_creation')
+        self.store.rollback_to_savepoint('before_payment_creation')
 
 
 class MultipleMethodSlave(BaseEditorSlave):
@@ -872,7 +943,7 @@ class MultipleMethodSlave(BaseEditorSlave):
     gladefile = 'MultipleMethodSlave'
     model_type = object
 
-    def __init__(self, wizard, parent, conn, order, payment_method,
+    def __init__(self, wizard, parent, store, order, payment_method,
                  outstanding_value=currency(0), finish_on_total=True,
                  allow_remove_paid=True):
         """
@@ -888,9 +959,9 @@ class MultipleMethodSlave(BaseEditorSlave):
         self._holder = Settable(value=Decimal(0))
         self._wizard = wizard
         # 'money' is the default payment method and it is always avaliable.
-        self._method = PaymentMethod.get_by_name(conn, 'money')
+        self._method = PaymentMethod.get_by_name(store, u'money')
 
-        BaseEditorSlave.__init__(self, conn, order)
+        BaseEditorSlave.__init__(self, store, order)
         self._outstanding_value = (outstanding_value or
                                    self._get_total_amount())
         self._total_value = self._outstanding_value
@@ -934,23 +1005,26 @@ class MultipleMethodSlave(BaseEditorSlave):
             # include the freight (the freight can also be in a different
             # payment group - witch should not be considered here.)
             return self.model.group.get_total_value()
+        elif isinstance(self.model, StockDecrease):
+            return self.model.get_total_cost()
         else:
             raise AssertionError
 
     def _setup_widgets(self):
         self.remove_button.hide()
-        if isinstance(self.model, (PaymentRenegotiation, Sale, ReturnedSale)):
+        if isinstance(self.model, (PaymentRenegotiation, Sale, ReturnedSale,
+                                   StockDecrease)):
             payment_type = Payment.TYPE_IN
         elif isinstance(self.model, PurchaseOrder):
             payment_type = Payment.TYPE_OUT
         else:
             raise AssertionError
 
-        money_method = PaymentMethod.get_by_name(self.conn, 'money')
+        money_method = PaymentMethod.get_by_name(self.store, u'money')
         self._add_method(money_method)
         for method in PaymentMethod.get_creatable_methods(
-            self.conn, payment_type, separate=False):
-            if method.method_name in ['multiple', 'money']:
+            self.store, payment_type, separate=False):
+            if method.method_name in [u'multiple', u'money']:
                 continue
             self._add_method(method)
 
@@ -1033,7 +1107,9 @@ class MultipleMethodSlave(BaseEditorSlave):
         # bill and store_credit payment method is not allowed without a client.
         if (payment_method.method_name == 'bill' or
             payment_method.method_name == 'store_credit'):
-            if (not isinstance(self.model, PurchaseOrder) and
+            if isinstance(self.model, StockDecrease):
+                return
+            elif (not isinstance(self.model, PurchaseOrder) and
                 self.model.client is None):
                 return
             elif (isinstance(self.model, PurchaseOrder) and
@@ -1067,8 +1143,8 @@ class MultipleMethodSlave(BaseEditorSlave):
             return False
 
         payments = self.model.group.get_valid_payments()
-        payment_count = payments.filter(
-            Payment.q.method_id == self._method.id).count()
+        payment_count = payments.find(
+            Payment.method_id == self._method.id).count()
         if payment_count >= self._method.max_installments:
             info(_(u'You can not add more payments using the %s '
                    'payment method.') % self._method.description)
@@ -1076,11 +1152,12 @@ class MultipleMethodSlave(BaseEditorSlave):
 
         # If we are creaing out payments (PurchaseOrder) or the Sale does not
         # have a client, assume all options available are creatable.
-        if isinstance(self.model, PurchaseOrder) or not self.model.client:
+        if (isinstance(self.model, (PurchaseOrder, StockDecrease))
+            or not self.model.client):
             return True
 
         method_values = {self._method: self._holder.value}
-        for i, payment in enumerate(self.model.group.payments.orderBy('id')):
+        for i, payment in enumerate(self.model.group.payments):
             method_values.setdefault(payment.method, 0)
             method_values[payment.method] += payment.value
         for method, value in method_values.items():
@@ -1098,7 +1175,7 @@ class MultipleMethodSlave(BaseEditorSlave):
         if not self._can_add_payment():
             return
 
-        if self._method.method_name == 'money':
+        if self._method.method_name == u'money':
             self._setup_cash_payment()
 
         # We are about to create payments, so we need to consider the fiscal
@@ -1107,12 +1184,12 @@ class MultipleMethodSlave(BaseEditorSlave):
         # (We only emit this event for sales.)
         if not isinstance(self.model, PurchaseOrder):
             retval = CreatePaymentEvent.emit(self._method, self.model,
-                                             self.conn, self._holder.value)
+                                             self.store, self._holder.value)
         else:
             retval = None
 
         if retval is None or retval == CreatePaymentStatus.UNHANDLED:
-            if not self._method.method_name == 'money':
+            if not self._method.method_name == u'money':
                 self._run_payment_editor()
 
         self._has_modified_payments = True
@@ -1126,13 +1203,13 @@ class MultipleMethodSlave(BaseEditorSlave):
     def _remove_payment(self, payment):
         if payment.is_preview():
             payment.group.remove_item(payment)
-            Payment.delete(payment.id, connection=self.conn)
+            payment.delete()
         elif payment.is_paid():
             if not self._allow_remove_paid:
                 return
             entry = PaymentChangeHistory(payment=payment,
                              change_reason=_('Payment renegotiated'),
-                             connection=self.conn)
+                             store=self.store)
             payment.set_not_paid(entry)
             entry.new_status = Payment.STATUS_CANCELLED
             payment.cancel()
@@ -1169,7 +1246,7 @@ class MultipleMethodSlave(BaseEditorSlave):
         # rename the payments at runtime.
         self.payments.clear()
         payment_group = self.model.group
-        payments = list(payment_group.payments.orderBy(Payment.q.id))
+        payments = list(payment_group.payments.order_by(Payment.id))
         preview_payments = [p for p in payments if p.is_preview()]
         len_preview_payments = len(preview_payments)
 
@@ -1191,7 +1268,7 @@ class MultipleMethodSlave(BaseEditorSlave):
         else:
             toplevel = None
         retval = run_dialog(_MultipleMethodEditor, toplevel, self._wizard,
-                            self, self.conn, self.model, self._method,
+                            self, self.store, self.model, self._method,
                             self._holder.value)
         return retval
 
@@ -1282,7 +1359,7 @@ class MultipleMethodSlave(BaseEditorSlave):
         if self._outstanding_value < 0:
             self._outstanding_value = 0
 
-        is_money_method = self._method and self._method.method_name == 'money'
+        is_money_method = self._method and self._method.method_name == u'money'
         if self._outstanding_value - value < 0 and not is_money_method:
             retval = ValidationError(_(u'The value must be lesser than the '
                                        'missing value.'))
@@ -1290,9 +1367,10 @@ class MultipleMethodSlave(BaseEditorSlave):
         if not value and self._outstanding_value > 0:
             retval = ValidationError(_(u'You must provide a payment value.'))
 
-        if (self._method.method_name == 'store_credit' and
-                value > self.model.client.remaining_store_credit):
-            retval = ValidationError(_(u'Client does not have enough credit.'))
+        if not isinstance(self.model, StockDecrease):
+            if (self._method.method_name == 'store_credit'
+                and value > self.model.client.remaining_store_credit):
+                retval = ValidationError(_(u'Client does not have enough credit.'))
 
         self._holder.value = value
         self.toggle_new_payments()
@@ -1304,15 +1382,15 @@ class MultipleMethodSlave(BaseEditorSlave):
 
 def register_payment_slaves():
     dsm = get_utility(IDomainSlaveMapper)
-    conn = api.get_connection()
+    default_store = api.get_default_store()
     for method_name, slave_class in [
-        ('money', MoneyMethodSlave),
-        ('bill', BillMethodSlave),
-        ('check', CheckMethodSlave),
-        ('card', CardMethodSlave),
-        ('store_credit', StoreCreditMethodSlave),
-        ('multiple', MultipleMethodSlave),
-        ('deposit', DepositMethodSlave)]:
+        (u'money', MoneyMethodSlave),
+        (u'bill', BillMethodSlave),
+        (u'check', CheckMethodSlave),
+        (u'card', CardMethodSlave),
+        (u'store_credit', StoreCreditMethodSlave),
+        (u'multiple', MultipleMethodSlave),
+        (u'deposit', DepositMethodSlave)]:
 
-        method = PaymentMethod.get_by_name(conn, method_name)
+        method = PaymentMethod.get_by_name(default_store, method_name)
         dsm.register(method, slave_class)
