@@ -30,6 +30,6 @@ from stoqlib.gui.editors.productioneditor import ProductionItemProducedEditor
 class TestProductionItemProducedEditor(GUITest):
     def testShow(self):
         production_item = self.create_production_item()
-        editor = ProductionItemProducedEditor(self.trans, production_item)
+        editor = ProductionItemProducedEditor(self.store, production_item)
         editor.order_number.set_text("12345")
         self.check_editor(editor, 'editor-productionitemproduced-show')
