@@ -30,6 +30,6 @@ from stoqlib.gui.editors.productioneditor import ProductionMaterialAllocateEdito
 class TestProductionMaterialAllocateEditor(GUITest):
     def testShow(self):
         material = self.create_production_material()
-        editor = ProductionMaterialAllocateEditor(self.trans, material)
+        editor = ProductionMaterialAllocateEditor(self.store, material)
         editor.order_number.set_label("12345")
         self.check_editor(editor, 'editor-productionmaterialallocate-show')
