@@ -30,6 +30,6 @@ from stoqlib.gui.editors.productioneditor import ProductionMaterialLostEditor
 class TestProductionMaterialLostEditor(GUITest):
     def testShow(self):
         material = self.create_production_material()
-        editor = ProductionMaterialLostEditor(self.trans, material)
+        editor = ProductionMaterialLostEditor(self.store, material)
         editor.order_number.set_label("12345")
         self.check_editor(editor, 'editor-productionmateriallosteditor-show')
