@@ -29,5 +29,17 @@ from stoqlib.gui.editors.categoryeditor import SellableCategoryEditor
 
 class TestSellableCategoryEditor(GUITest):
     def testCreate(self):
-        editor = SellableCategoryEditor(self.trans)
+        editor = SellableCategoryEditor(self.store)
         self.check_editor(editor, 'editor-sellablecategory-create')
+
+    def testDescriptionValidation(self):
+        # Just create an existing category to check unique value above
+        self.create_sellable_category(u'Existing category')
+
+        editor = SellableCategoryEditor(self.store)
+
+        self.assertInvalid(editor, ['description'])
+        editor.description.update('Non-existing category')
+        self.assertValid(editor, ['description'])
+        editor.description.update('Existing category')
+        self.assertInvalid(editor, ['description'])
