@@ -39,9 +39,10 @@ from kiwi.datatypes import ValidationError
 from kiwi.ui.widgets.list import SummaryLabel
 from kiwi.ui.objectlist import SearchColumn, Column
 from kiwi.python import Settable
+from storm.expr import And
 
 from stoqlib.api import api
-from stoqlib.database.orm import AND, ORMObject
+from stoqlib.database.orm import ORMObject
 from stoqlib.domain.sellable import Sellable
 from stoqlib.domain.product import Product, ProductSupplierInfo
 from stoqlib.domain.service import ServiceView
@@ -62,26 +63,29 @@ from stoqlib.lib.translation import stoqlib_gettext
 _ = stoqlib_gettext
 
 
-class _SellableSearch(SearchEditor):
+class AdvancedSellableSearch(SearchEditor):
 
     title = _('Item search')
     size = (800, 450)
     has_new_button = True
     editor_class = ProductEditor
 
-    def __init__(self, conn, selection_mode=gtk.SELECTION_BROWSE,
-                 search_str=None, query=None, supplier=None,
-                 hide_footer=False, double_click_confirm=True,
-                 table=None, editable=False,
-                 ):
-        self._query = query
-        self._supplier = supplier
-        self._table = table
+    def __init__(self, store, item_step, search_str=None, supplier=None):
+        """
+        :param item_step: The item step this search is for.
+        :param search_str: If this search should already filter for some string
+        :param supplier: If provided and a new product is created from this
+          search, then the created product will be associated with this
+          supplier.
+        """
 
-        SearchEditor.__init__(self, conn, selection_mode=selection_mode,
-                              hide_footer=hide_footer, table=table,
-                              double_click_confirm=double_click_confirm,
-                              hide_toolbar=not editable)
+        self._table, self._query = item_step.get_sellable_view_query()
+        self._supplier = supplier
+
+        SearchEditor.__init__(self, store, selection_mode=gtk.SELECTION_BROWSE,
+                              hide_footer=False, table=self._table,
+                              double_click_confirm=True,
+                              hide_toolbar=not item_step.sellable_editable)
         if search_str:
             self.set_searchbar_search_string(search_str)
             self.search.refresh()
@@ -97,12 +101,11 @@ class _SellableSearch(SearchEditor):
                                      'category_description', 'code'])
         self.executer.set_query(self.executer_query)
 
-    def executer_query(self, query, having, conn):
-        new_query = self._query
-        if query:
-            new_query = AND(query, new_query)
-
-        return self.search_table.select(new_query, connection=conn)
+    def executer_query(self, store):
+        results = store.find(self._table)
+        if self._query:
+            return results.find(self._query)
+        return results
 
     def update_widgets(self):
         sellable_view = self.results.get_selected()
@@ -121,12 +124,12 @@ class _SellableSearch(SearchEditor):
                    SearchColumn('model', title=_('Model'),
                                 data_type=str, visible=False)]
 
-        if 'minimum_quantity' in self._table.columns:
+        if hasattr(self._table, 'minimum_quantity'):
             columns.append(SearchColumn('minimum_quantity',
                                         title=_(u'Minimum Qty'),
                                         data_type=Decimal, visible=False))
 
-        if 'stock' in self._table.columns:
+        if hasattr(self._table, 'stock'):
             columns.append(Column('stock', title=_(u'In Stock'),
                                   data_type=Decimal))
 
@@ -140,32 +143,32 @@ class _SellableSearch(SearchEditor):
         return model.product
 
     def run_editor(self, obj=None):
-        trans = api.new_transaction()
-        product = self.run_dialog(self.editor_class, self, trans,
-                                 trans.get(obj), visual_mode=self._read_only)
+        store = api.new_store()
+        product = self.run_dialog(self.editor_class, self, store,
+                                 store.fetch(obj), visual_mode=self._read_only)
 
         # This means we are creating a new product. After that, add the
         # current supplier as the supplier for this product
         if (obj is None and product
             and not product.is_supplied_by(self._supplier)):
-            ProductSupplierInfo(connection=trans,
-                                supplier=trans.get(self._supplier),
+            ProductSupplierInfo(store=store,
+                                supplier=store.fetch(self._supplier),
                                 product=product,
                                 base_cost=product.sellable.cost,
                                 is_main_supplier=True)
 
-        if api.finish_transaction(trans, product):
+        if store.confirm(product):
             # If the return value is an ORMObject, fetch it from
             # the right connection
             if isinstance(product, ORMObject):
-                product = type(product).get(product.id, connection=self.conn)
+                product = type(product).get(product.id, store=self.store)
 
             # If we created a new object, confirm the dialog automatically
             if obj is None:
                 self.confirm(product)
-                trans.close()
+                store.close()
                 return
-        trans.close()
+        store.close()
 
         return product
 
@@ -222,14 +225,14 @@ class SellableItemStep(WizardEditorStep):
     sellable_editable = False
     cost_editable = True
 
-    def __init__(self, wizard, previous, conn, model):
-        WizardEditorStep.__init__(self, conn, wizard, model, previous)
+    def __init__(self, wizard, previous, store, model):
+        WizardEditorStep.__init__(self, store, wizard, model, previous)
         self.unit_label.set_bold(True)
         for widget in [self.quantity, self.cost]:
             widget.set_adjustment(gtk.Adjustment(lower=0, upper=sys.maxint,
                                                  step_incr=1))
         self._reset_sellable()
-        self.cost.set_digits(sysparam(conn).COST_PRECISION_DIGITS)
+        self.cost.set_digits(sysparam(store).COST_PRECISION_DIGITS)
         self.quantity.set_digits(3)
         WizardSellableItemStepEvent.emit(self)
 
@@ -274,10 +277,12 @@ class SellableItemStep(WizardEditorStep):
     #
 
     def get_sellable_view_query(self):
-        """This method should return a query that should be used when
-        filtering the sellables that can and cannot be added to this step.
+        """This method should return a tuple containing the viewable that should
+        be used and a query that should filter the sellables that can and cannot
+        be added to this step.
         """
-        return Sellable.get_unblocked_sellables_query(self.conn)
+        return (self.sellable_view,
+                Sellable.get_unblocked_sellables_query(self.store))
 
     def get_order_item(self, sellable, value, quantity):
         """Adds the sellable to the current model
@@ -386,7 +391,7 @@ class SellableItemStep(WizardEditorStep):
 
     def setup_slaves(self):
         self.slave = AdditionListSlave(
-            self.conn, self.get_columns(),
+            self.store, self.get_columns(),
             klist_objects=self.get_saved_items(),
             restore_name=self.__class__.__name__)
         self.slave.connect('before-delete-items',
@@ -421,14 +426,11 @@ class SellableItemStep(WizardEditorStep):
         has_supplier = hasattr(self.model, 'supplier')
         if has_supplier:
             supplier = self.model.supplier
-        ret = run_dialog(_SellableSearch, self.wizard,
-                         self.conn,
+
+        ret = run_dialog(AdvancedSellableSearch, self.wizard,
+                         self.store, self,
                          search_str=search_str,
-                         table=self.sellable_view,
-                         supplier=supplier,
-                         editable=self.sellable_editable,
-                         query=self.get_sellable_view_query()
-            )
+                         supplier=supplier)
         if not ret:
             return
 
@@ -456,16 +458,18 @@ class SellableItemStep(WizardEditorStep):
         barcode = self.barcode.get_text()
         if not barcode:
             return None
+        barcode = unicode(barcode, 'utf-8')
 
-        query = self.sellable_view.q.barcode == barcode
-        new_query = self.get_sellable_view_query()
-        if new_query:
-            query = AND(query, new_query)
+        viewable, default_query = self.get_sellable_view_query()
+        query = viewable.barcode == barcode
+
+        if default_query:
+            query = And(query, default_query)
 
         # FIXME: doing list() here is wrong. But there is a bug in one of
         # the queries, that len() == 1 but results.count() == 2.
-        results = list(self.sellable_view.select(query,
-                                                 connection=self.conn))
+        results = list(self.store.find(viewable, query))
+
         if len(results) != 1:
             return None
 
@@ -481,7 +485,7 @@ class SellableItemStep(WizardEditorStep):
         sellable = self.proxy.model.sellable
         assert sellable
 
-        sellable = self.conn.get(sellable)
+        sellable = self.store.fetch(sellable)
 
         self.add_sellable(sellable)
         self.proxy.set_model(None)
@@ -543,7 +547,7 @@ class SellableItemStep(WizardEditorStep):
         sellable = self._get_sellable()
 
         if not sellable:
-            search_str = self.barcode.get_text()
+            search_str = unicode(self.barcode.get_text())
             self._run_advanced_search(search_str)
             return
 
