@@ -26,6 +26,7 @@
 
 from decimal import Decimal
 import datetime
+import sys
 
 import gtk
 from kiwi.currency import currency
@@ -35,17 +36,16 @@ from kiwi.ui.widgets.entry import ProxyEntry
 from kiwi.ui.objectlist import Column, SearchColumn
 
 from stoqlib.api import api
-from stoqlib.database.orm import ORMObjectQueryExecuter
+from stoqlib.database.queryexecuter import StoqlibQueryExecuter
 from stoqlib.domain.person import (Client, LoginUser,
                                    ClientCategory)
 from stoqlib.domain.loan import Loan, LoanItem
 from stoqlib.domain.payment.group import PaymentGroup
 from stoqlib.domain.sale import Sale
 from stoqlib.domain.views import LoanView, ProductFullStockItemView
+from stoqlib.lib.formatters import format_quantity
 from stoqlib.lib.message import info, yesno
 from stoqlib.lib.translation import stoqlib_gettext
-from stoqlib.lib.parameters import sysparam
-from stoqlib.lib.formatters import format_quantity, get_formatted_cost
 from stoqlib.gui.base.dialogs import run_dialog
 from stoqlib.gui.base.search import StoqlibSearchSlaveDelegate
 from stoqlib.gui.base.wizards import (WizardEditorStep, BaseWizard,
@@ -58,6 +58,7 @@ from stoqlib.gui.editors.noteeditor import NoteEditor
 from stoqlib.gui.editors.personeditor import ClientEditor
 from stoqlib.gui.editors.loaneditor import LoanItemEditor
 from stoqlib.gui.printing import print_report
+from stoqlib.gui.wizards.abstractwizard import SellableItemStep
 from stoqlib.gui.wizards.personwizard import run_person_role_dialog
 from stoqlib.gui.wizards.salequotewizard import SaleQuoteItemStep
 from stoqlib.reporting.loanreceipt import LoanReceipt
@@ -85,10 +86,14 @@ class StartNewLoanStep(WizardEditorStep):
         self.invoice_number_label.hide()
         self.invoice_number.hide()
 
+        # Hide cost center combobox
+        self.cost_center_lbl.hide()
+        self.cost_center.hide()
+
         # Responsible combo
         self.salesperson_lbl.set_text(_(u'Responsible:'))
         self.salesperson.model_attribute = 'responsible'
-        users = LoginUser.selectBy(is_active=True, connection=self.conn)
+        users = self.store.find(LoginUser, is_active=True)
         self.salesperson.prefill(api.for_person_combo(users))
         self.salesperson.set_sensitive(False)
 
@@ -122,12 +127,12 @@ class StartNewLoanStep(WizardEditorStep):
         # FIXME: This should not be using a normal ProxyComboEntry,
         #        we need a specialized widget that does the searching
         #        on demand.
-        clients = Client.get_active_clients(self.conn)
+        clients = Client.get_active_clients(self.store)
         self.client.prefill(api.for_person_combo(clients))
         self.client.mandatory = True
 
     def _fill_clients_category_combo(self):
-        categories = ClientCategory.select(connection=self.conn)
+        categories = self.store.find(ClientCategory)
         self.client_category.prefill(api.for_combo(categories, empty=''))
 
     def _replace_widget(self, old_widget, new_widget):
@@ -152,7 +157,7 @@ class StartNewLoanStep(WizardEditorStep):
         self.force_validation()
 
     def next_step(self):
-        return LoanItemStep(self.wizard, self, self.conn, self.model)
+        return LoanItemStep(self.wizard, self, self.store, self.model)
 
     def has_previous_step(self):
         return False
@@ -171,11 +176,11 @@ class StartNewLoanStep(WizardEditorStep):
     #
 
     def on_create_client__clicked(self, button):
-        trans = api.new_transaction()
-        client = run_person_role_dialog(ClientEditor, self.wizard, trans, None)
-        retval = api.finish_transaction(trans, client)
-        client = self.conn.get(client)
-        trans.close()
+        store = api.new_store()
+        client = run_person_role_dialog(ClientEditor, self.wizard, store, None)
+        retval = store.confirm(client)
+        client = self.store.fetch(client)
+        store.close()
         if not retval:
             return
         self._fill_clients_combo()
@@ -194,12 +199,12 @@ class StartNewLoanStep(WizardEditorStep):
             return ValidationError(msg)
 
     def on_notes_button__clicked(self, *args):
-        run_dialog(NoteEditor, self.wizard, self.conn, self.model, 'notes',
+        run_dialog(NoteEditor, self.wizard, self.store, self.model, 'notes',
                    title=_("Additional Information"))
 
     def on_client_details__clicked(self, button):
         client = self.model.client
-        run_dialog(ClientDetailsDialog, self.wizard, self.conn, client)
+        run_dialog(ClientDetailsDialog, self.wizard, self.store, client)
 
 
 class LoanItemStep(SaleQuoteItemStep):
@@ -233,8 +238,8 @@ class LoanItemStep(SaleQuoteItemStep):
 class LoanSelectionStep(BaseWizardStep):
     gladefile = 'HolderTemplate'
 
-    def __init__(self, wizard, conn):
-        BaseWizardStep.__init__(self, conn, wizard)
+    def __init__(self, wizard, store):
+        BaseWizardStep.__init__(self, store, wizard)
         self.setup_slaves()
 
     def _create_filters(self):
@@ -260,14 +265,14 @@ class LoanSelectionStep(BaseWizardStep):
         self.wizard.refresh_next(has_selected)
 
     def get_extra_query(self, states):
-        return LoanView.q.status == Loan.STATUS_OPEN
+        return LoanView.status == Loan.STATUS_OPEN
 
     def setup_slaves(self):
         self.search = StoqlibSearchSlaveDelegate(self._get_columns(),
                                         restore_name=self.__class__.__name__)
         self.search.enable_advanced_search()
         self.attach_slave('place_holder', self.search)
-        self.executer = ORMObjectQueryExecuter(self.conn)
+        self.executer = StoqlibQueryExecuter(self.store)
         self.search.set_query_executer(self.executer)
         self.executer.set_table(LoanView)
         self.executer.add_query_callback(self.get_extra_query)
@@ -289,9 +294,10 @@ class LoanSelectionStep(BaseWizardStep):
 
     def next_step(self):
         loan = self.search.results.get_selected().loan
-        # FIXME: For some reason, the loan isn't in self.conn transaction
-        self.wizard.model = self.conn.get(loan)
-        return LoanItemSelectionStep(self.wizard, self, self.conn)
+        # FIXME: For some reason, the loan isn't in self.store
+        self.wizard.model = self.store.fetch(loan)
+        return LoanItemSelectionStep(self.wizard, self, self.store,
+                                     self.wizard.model)
 
     #
     # Callbacks
@@ -301,109 +307,131 @@ class LoanSelectionStep(BaseWizardStep):
         self._refresh_next()
 
 
-class LoanItemSelectionStep(BaseWizardStep):
-    gladefile = 'LoanItemSelectionStep'
+class LoanItemSelectionStep(SellableItemStep):
+    model_type = Loan
+    item_table = LoanItem
+    cost_editable = False
+    summary_label_column = None
+
+    def __init__(self, wizard, previous, store, model):
+        super(LoanItemSelectionStep, self).__init__(wizard, previous,
+                                                    store, model)
+        for item in self.model.loaned_items:
+            self.wizard.original_items[item] = Settable(
+                quantity=item.quantity,
+                sale_quantity=item.sale_quantity,
+                return_quantity=item.return_quantity,
+                remaining_quantity=item.get_remaining_quantity(),
+                )
 
-    def __init__(self, wizard, previous, conn):
-        self.loan = wizard.model
-        BaseWizardStep.__init__(self, conn, wizard, previous)
-        self._original_items = {}
-        self._setup_widgets()
         LoanItemSelectionStepEvent.emit(self)
 
-    def _setup_widgets(self):
-        self.loan_items.set_columns(self.get_columns())
-        self.loan_items.add_list(self.get_saved_items())
-        self.edit_button.set_sensitive(False)
-
-    def _validate_step(self, value):
-        self.wizard.refresh_next(value)
-
-    def _edit_item(self, item):
-        retval = run_dialog(LoanItemEditor, self.wizard, self.conn, item,
-                            expanded_edition=True)
-        self.loan_items.update(item)
-        if retval:
-            self._validate_step(True)
-
-    def get_saved_items(self):
-        for item in self.loan.get_items():
-            self._original_items[item.id] = Settable(item_id=item.id,
-                                 sale_qty=item.sale_quantity or Decimal(0),
-                                 return_qty=item.return_quantity or Decimal(0))
-            yield item
-
-    def get_columns(self):
-        return [
-            Column('sellable.code', title=_('Code'), width=70, data_type=str),
-            Column('sellable.description', title=_('Description'),
-                   data_type=str, expand=True, searchable=True),
-            Column('quantity', title=_('Loaned'), data_type=Decimal,
-                   format_func=format_quantity),
-            Column('sale_quantity', title=_('Sold'), data_type=Decimal,
-                   format_func=format_quantity),
-            Column('return_quantity', title=_('Returned'), data_type=Decimal,
-                   format_func=format_quantity),
-            Column('price', title=_('Price'), data_type=currency,
-                   format_func=get_formatted_cost)]
-
     #
-    # WizardStep
+    #  SellableItemStep
     #
 
-    def post_init(self):
-        self.register_validate_function(self._validate_step)
-        self.force_validation()
-        self._validate_step(False)
-        self.wizard.enable_finish()
-
-    def has_previous_step(self):
-        return True
-
     def has_next_step(self):
-        return True
+        return False
 
-    def next_step(self):
-        sale_items = []
-        for final in self.loan_items:
-            initial = self._original_items[final.id]
-            sale_quantity = final.sale_quantity - initial.sale_qty
+    def post_init(self):
+        super(LoanItemSelectionStep, self).post_init()
+
+        self.hide_add_button()
+        self.hide_edit_button()
+        self.hide_del_button()
+        self.hide_item_addition_toolbar()
+        for widget in [self.minimum_quantity_lbl, self.minimum_quantity,
+                       self.stock_quantity, self.stock_quantity_lbl]:
+            widget.hide()
+
+        self.slave.klist.connect('cell-edited', self._on_klist__cell_edited)
+        self.slave.klist.connect('cell-editing-started',
+                                 self._on_klist__cell_editing_started)
+        self.force_validation()
+
+    def get_columns(self):
+        adjustment = gtk.Adjustment(lower=0, upper=sys.maxint, step_incr=1)
+        return [
+            Column('sellable.code', title=_('Code'),
+                   data_type=str, visible=False),
+            Column('sellable.barcode', title=_('Barcode'),
+                   data_type=str, visible=False),
+            Column('sellable.description', title=_('Description'),
+                   data_type=str, expand=True),
+            Column('quantity', title=_('Loaned'),
+                   data_type=Decimal, format_func=format_quantity),
+            Column('sale_quantity', title=_('Sold'),
+                   data_type=Decimal, format_func=format_quantity,
+                   editable=True, spin_adjustment=adjustment),
+            Column('return_quantity', title=_('Returned'),
+                   data_type=Decimal, format_func=format_quantity,
+                   editable=True, spin_adjustment=adjustment),
+            Column('remaining_quantity', title=_('Remaining'),
+                   data_type=Decimal, format_func=format_quantity),
+            Column('price', title=_('Price'), data_type=currency),
+            ]
+
+    def get_saved_items(self):
+        return self.model.loaned_items
+
+    def validate_step(self):
+        any_changed = False
+        has_sale_items = False
+
+        for item in self.model.loaned_items:
+            original = self.wizard.original_items[item]
+            sale_quantity = item.sale_quantity - original.sale_quantity
             if sale_quantity > 0:
-                sale_items.append((final, sale_quantity))
+                has_sale_items = True
 
-        if sale_items:
-            user = api.get_current_user(self.conn)
-            sale = Sale(connection=self.conn,
-                        branch=self.loan.branch,
-                        client=self.loan.client,
-                        salesperson=user.person.salesperson,
-                        cfop=sysparam(self.conn).DEFAULT_SALES_CFOP,
-                        group=PaymentGroup(connection=self.conn),
-                        coupon_id=None)
+            if item.get_remaining_quantity() < original.remaining_quantity:
+                any_changed = True
 
-            for item, quantity in sale_items:
-                sale.add_sellable(item.sellable, quantity, item.price)
+            # Should not happen!
+            assert (item.sale_quantity >= original.sale_quantity or
+                    item.return_quantity >= original.return_quantity)
+            assert item.quantity >= item.sale_quantity + item.return_quantity
 
-            sale.order()
-            self.wizard.created_sale = sale
-            info(_("Close loan details..."),
-                 _("A sale was created from loan items. You can confirm "
-                   "that sale in the Till application later."))
+        if self.wizard.require_sale_items and not has_sale_items:
+            return False
+
+        # Don't let user finish if he didn't mark anything to return/sale
+        return any_changed
+
+    def validate(self, value):
+        self.wizard.refresh_next(value and self.validate_step())
 
     #
-    # Kiwi Callbacks
+    #  Callbacks
     #
 
-    def on_loan_items__selection_changed(self, widget, item):
-        self.edit_button.set_sensitive(bool(item))
+    def _on_klist__cell_edited(self, klist, obj, attr):
+        # FIXME: Even with the adjustment, the user still can type
+        # values out of range with the keyboard. Maybe it's kiwi's fault
+        if attr in ['sale_quantity', 'return_quantity']:
+            value = getattr(obj, attr)
+            lower_value = getattr(self.wizard.original_items[obj], attr)
+            if value < lower_value:
+                setattr(obj, attr, lower_value)
 
-    def on_loan_items__row_activated(self, widget, item):
-        if self.edit_button.get_sensitive() and self.edit_button.get_visible():
-            self._edit_item(item)
+            diff = obj.quantity - obj.return_quantity - obj.sale_quantity
+            if diff < 0:
+                setattr(obj, attr, value + diff)
 
-    def on_edit_button__clicked(self, widget):
-        item = self.loan_items.get_selected()
-        self._edit_item(item)
+        self.force_validation()
+
+    def _on_klist__cell_editing_started(self, klist, obj, attr,
+                                        renderer, editable):
+        original_item = self.wizard.original_items[obj]
+
+        if attr == 'sale_quantity':
+            adjustment = editable.get_adjustment()
+            adjustment.set_lower(original_item.sale_quantity)
+            adjustment.set_upper(obj.quantity - obj.return_quantity)
+        if attr == 'return_quantity':
+            adjustment = editable.get_adjustment()
+            adjustment.set_lower(original_item.return_quantity)
+            adjustment.set_upper(obj.quantity - obj.sale_quantity)
 
 
 #
@@ -415,25 +443,25 @@ class NewLoanWizard(BaseWizard):
     size = (775, 400)
     help_section = 'loan'
 
-    def __init__(self, conn, model=None):
+    def __init__(self, store, model=None):
         title = self._get_title(model)
-        model = model or self._create_model(conn)
+        model = model or self._create_model(store)
         if model.status != Loan.STATUS_OPEN:
             raise ValueError('Invalid loan status. It should '
                              'be STATUS_OPEN')
 
-        first_step = StartNewLoanStep(conn, self, model)
-        BaseWizard.__init__(self, conn, first_step, model, title=title,
+        first_step = StartNewLoanStep(store, self, model)
+        BaseWizard.__init__(self, store, first_step, model, title=title,
                             edit_mode=False)
 
     def _get_title(self, model=None):
         if not model:
             return _('New Loan Wizard')
 
-    def _create_model(self, conn):
-        loan = Loan(responsible=api.get_current_user(conn),
-                    branch=api.get_current_branch(conn),
-                    connection=conn)
+    def _create_model(self, store):
+        loan = Loan(responsible=api.get_current_user(store),
+                    branch=api.get_current_branch(store),
+                    store=store)
         # Temporarily save the client_category, so it works fine with
         # SaleQuoteItemStep
         loan.client_category = None
@@ -462,20 +490,74 @@ class CloseLoanWizard(BaseWizard):
     title = _(u'Close Loan Wizard')
     help_section = 'loan'
 
-    def __init__(self, conn):
-        self.created_sale = None
-        first_step = LoanSelectionStep(self, conn)
-        BaseWizard.__init__(self, conn, first_step, model=None,
+    def __init__(self, store, create_sale=True, require_sale_items=False):
+        """
+        :param store: A database store
+        :param create_sale: If a sale should be created for all the items that
+          will be sold from this loan.
+        :param require_sale_items: If there should be at least one item sold in
+          the Loan. If ``False``, a loan with only returned items will be allowed
+          to be confirmed. When ``True``, there should be at least one item in
+          the loan that will be sold before confirming this wizard.
+        """
+        self._create_sale = create_sale
+        self._sold_items = []
+        self.original_items = {}
+        self.require_sale_items = require_sale_items
+        first_step = LoanSelectionStep(self, store)
+        BaseWizard.__init__(self, store, first_step, model=None,
                             title=self.title, edit_mode=False)
 
+    #
+    #  Public API
+    #
+
+    def get_sold_items(self):
+        """Get items set to be sold on this wizard
+
+        Returns a list of sold |sellables|, the quantity sold of those
+        |sellables| and the price it was sold at.
+
+        :returns: a list of tuples (|sellable|, quantity, price)
+        """
+        return self._sold_items
+
     #
     # WizardStep hooks
     #
 
     def finish(self):
+        for item in self.model.loaned_items:
+            original = self.original_items[item]
+            sale_quantity = item.sale_quantity - original.sale_quantity
+            if sale_quantity > 0:
+                self._sold_items.append(
+                    (item.sellable, sale_quantity, item.price))
+
+        if self._create_sale and self._sold_items:
+            user = api.get_current_user(self.store)
+            sale = Sale(
+                store=self.store,
+                branch=self.model.branch,
+                client=self.model.client,
+                salesperson=user.person.salesperson,
+                group=PaymentGroup(store=self.store),
+                coupon_id=None)
+
+            for sellable, quantity, price in self._sold_items:
+                sale.add_sellable(sellable, quantity, price)
+
+            sale.order()
+            info(_("Close loan details..."),
+                 _("A sale was created from loan items. You can confirm "
+                   "that sale in the Till application later."))
+        else:
+            sale = None
+
         self.model.sync_stock()
         if self.model.can_close():
             self.model.close()
+
         self.retval = self.model
         self.close()
-        CloseLoanWizardFinishEvent.emit(self.model, self.created_sale)
+        CloseLoanWizardFinishEvent.emit(self.model, sale, self)
