@@ -31,9 +31,9 @@ import gtk
 from kiwi.currency import currency
 from kiwi.datatypes import ValidationError, converter
 from kiwi.ui.objectlist import Column
+from storm.expr import Or
 
 from stoqlib.api import api
-from stoqlib.database.orm import AND, OR
 from stoqlib.database.runtime import get_current_user, get_current_branch
 from stoqlib.domain.returnedsale import ReturnedSale, ReturnedSaleItem
 from stoqlib.domain.sale import Sale
@@ -75,7 +75,7 @@ class SaleReturnSelectionStep(WizardEditorStep):
     #  WizardEditorStep
     #
 
-    def create_model(self, conn):
+    def create_model(self, store):
         # FIXME: We don't really need a model, but we need to use a
         # WizardEditorStep subclass so we can attach slaves
         return object()
@@ -89,7 +89,7 @@ class SaleReturnSelectionStep(WizardEditorStep):
         self.force_validation()
 
     def setup_slaves(self):
-        self.slave = SaleSearch(self.conn)
+        self.slave = SaleSearch(self.store)
         self.slave.executer.set_query(self._sale_executer_query)
         self.attach_slave('place_holder', self.slave)
         self.slave.search.refresh()
@@ -97,7 +97,7 @@ class SaleReturnSelectionStep(WizardEditorStep):
     def next_step(self):
         self._update_wizard_model()
         return SaleReturnItemsStep(self.wizard, self,
-                                   self.conn, self.wizard.model)
+                                   self.store, self.wizard.model)
 
     def has_next_step(self):
         return True
@@ -107,7 +107,7 @@ class SaleReturnSelectionStep(WizardEditorStep):
     #
 
     def _allow_unknown_sales(self):
-        return sysparam(self.conn).ALLOW_TRADE_NOT_REGISTERED_SALES
+        return sysparam(self.store).ALLOW_TRADE_NOT_REGISTERED_SALES
 
     def _validation_func(self, value):
         has_selected = self.slave.results.get_selected()
@@ -123,38 +123,34 @@ class SaleReturnSelectionStep(WizardEditorStep):
         if wizard_model:
             # We are replacing the model. Remove old one
             for item in wizard_model.returned_items:
-                item.delete(item.id, connection=item.get_connection())
+                item.delete(item.id, store=item.store)
             wizard_model.delete(wizard_model.id,
-                                connection=wizard_model.get_connection())
+                                store=wizard_model.store)
 
         sale_view = self.slave.results.get_selected()
         # FIXME: Selecting a sale and then clicking on unknown_sale_check
         # will not really deselect it, not until the results are sensitive
         # again. This should be as simple as 'if sale_view'.
         if sale_view and not self.unknown_sale_check.get_active():
-            sale = self.conn.get(sale_view.sale)
+            sale = self.store.fetch(sale_view.sale)
             model = sale.create_sale_return_adapter()
             for item in model.returned_items:
                 _adjust_returned_sale_item(item)
         else:
             assert self._allow_unknown_sales()
             model = ReturnedSale(
-                connection=self.conn,
-                responsible=get_current_user(self.conn),
-                branch=get_current_branch(self.conn),
+                store=self.store,
+                responsible=get_current_user(self.store),
+                branch=get_current_branch(self.store),
                 )
 
         self.wizard.model = model
 
-    def _sale_executer_query(self, query, having, conn):
+    def _sale_executer_query(self, store):
         # Only show sales that can be returned
-        new_query = OR(Sale.q.status == Sale.STATUS_CONFIRMED,
-                       Sale.q.status == Sale.STATUS_PAID)
-        if query:
-            new_query = AND(query, new_query)
-
-        return self.slave.search_table.select(new_query,
-                                              having=having, connection=conn)
+        query = Or(Sale.status == Sale.STATUS_CONFIRMED,
+                   Sale.status == Sale.STATUS_PAID)
+        return store.find(self.slave.search_table, query)
 
     #
     #  Callbacks
@@ -202,7 +198,7 @@ class SaleReturnItemsStep(SellableItemStep):
         self.force_validation()
 
     def next_step(self):
-        return SaleReturnInvoiceStep(self.conn, self.wizard,
+        return SaleReturnInvoiceStep(self.store, self.wizard,
                                      model=self.model, previous=self)
 
     def get_columns(self, editable=True):
@@ -211,6 +207,10 @@ class SaleReturnItemsStep(SellableItemStep):
         columns = [
             Column('will_return', title=_('Return'),
                    data_type=bool, editable=editable),
+            Column('sellable.code', title=_('Code'),
+                   data_type=str, visible=False),
+            Column('sellable.barcode', title=_('Barcode'),
+                   data_type=str, visible=False),
             Column('sellable.description', title=_('Description'),
                    data_type=str, expand=True),
             Column('price', title=_('Sale price'),
@@ -240,7 +240,7 @@ class SaleReturnItemsStep(SellableItemStep):
 
     def get_order_item(self, sellable, price, quantity):
         item = ReturnedSaleItem(
-            connection=self.conn,
+            store=self.store,
             quantity=quantity,
             price=price,
             sellable=sellable,
@@ -292,6 +292,8 @@ class SaleReturnItemsStep(SellableItemStep):
             # Unchecking will_return will make quantity goes to 0
             if not obj.will_return:
                 obj.quantity = 0
+            else:
+                obj.quantity = obj.max_quantity
 
         self.summary.update_total()
         self.force_validation()
@@ -333,7 +335,7 @@ class SaleReturnInvoiceStep(WizardEditorStep):
         self._update_widgets()
 
     def next_step(self):
-        return SaleReturnPaymentStep(self.conn, self.wizard,
+        return SaleReturnPaymentStep(self.store, self.wizard,
                                      model=self.model, previous=self)
 
     def has_next_step(self):
@@ -369,7 +371,8 @@ class SaleReturnInvoiceStep(WizardEditorStep):
         if not 0 < value <= 999999999:
             return ValidationError(_("Invoice number must be between "
                                      "1 and 999999999"))
-        if self.model.check_unique_value_exists('invoice_number', value):
+        if self.model.check_unique_value_exists(ReturnedSale.invoice_number,
+                                                value):
             return ValidationError(_("Invoice number already exists."))
 
 
@@ -398,7 +401,7 @@ class SaleReturnPaymentStep(WizardEditorStep):
         register_payment_slaves()
         outstanding_value = (self.model.total_amount_abs +
                              self.model.paid_total)
-        self.slave = MultipleMethodSlave(self.wizard, self, self.conn,
+        self.slave = MultipleMethodSlave(self.wizard, self, self.store,
                                          self.model, None,
                                          outstanding_value=outstanding_value,
                                          finish_on_total=False,
@@ -429,18 +432,18 @@ class SaleReturnPaymentStep(WizardEditorStep):
 class _BaseSaleReturnWizard(BaseWizard):
     size = (600, 350)
 
-    def __init__(self, conn, model=None):
+    def __init__(self, store, model=None):
         self.unkown_sale = False
         if model:
             # Adjust items befre creating the step, so that plugins may have a
             # chance to change the value
             for item in model.returned_items:
                 _adjust_returned_sale_item(item)
-            first_step = SaleReturnItemsStep(self, None, conn, model)
+            first_step = SaleReturnItemsStep(self, None, store, model)
         else:
-            first_step = SaleReturnSelectionStep(conn, self, None)
+            first_step = SaleReturnSelectionStep(store, self, None)
 
-        BaseWizard.__init__(self, conn, first_step, model)
+        BaseWizard.__init__(self, store, first_step, model)
 
 
 class SaleReturnWizard(_BaseSaleReturnWizard):
