@@ -29,17 +29,17 @@ from kiwi.component import get_utility
 from kiwi.currency import currency
 from kiwi.datatypes import ValidationError
 from kiwi.python import Settable
+from storm.expr import And
 
 from stoqlib.api import api
 from stoqlib.database.exceptions import IntegrityError
-from stoqlib.database.orm import AND
+from stoqlib.domain.costcenter import CostCenter
 from stoqlib.domain.events import CreatePaymentEvent
 from stoqlib.domain.fiscal import CfopData
-from stoqlib.domain.person import (Client,
-                                   CreditProvider, SalesPerson, Transporter)
+from stoqlib.domain.payment.card import CreditProvider
 from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.payment.payment import Payment
-from stoqlib.domain.payment.renegotiation import PaymentRenegotiation
+from stoqlib.domain.person import Client, SalesPerson, Transporter
 from stoqlib.domain.sale import Sale
 from stoqlib.enums import CreatePaymentStatus
 from stoqlib.exceptions import SellError, StoqlibError
@@ -57,7 +57,8 @@ from stoqlib.gui.interfaces import IDomainSlaveMapper
 from stoqlib.gui.printing import print_report
 from stoqlib.gui.slaves.cashchangeslave import CashChangeSlave
 from stoqlib.gui.slaves.paymentmethodslave import SelectPaymentMethodSlave
-from stoqlib.gui.slaves.paymentslave import register_payment_slaves
+from stoqlib.gui.slaves.paymentslave import (register_payment_slaves,
+                                             MultipleMethodSlave)
 from stoqlib.gui.slaves.saleslave import SaleDiscountSlave
 from stoqlib.gui.wizards.personwizard import run_person_role_dialog
 from stoqlib.reporting.boleto import BillReport
@@ -74,7 +75,21 @@ class PaymentMethodStep(BaseWizardStep):
     gladefile = 'HolderTemplate'
     slave_holder = 'place_holder'
 
-    def __init__(self, wizard, previous, conn, model, method, outstanding_value=None):
+    def __init__(self, wizard, previous, store, model, method,
+                 outstanding_value=None, finish_on_total=True):
+        """
+        :param wizard: the wizard this step is in
+        :param previous: the previous step if there is any
+        :param store: the store this step is executed
+        :param model: the model of this step
+        :param method: the payment method
+        :param finish_on_total: if it is ``True`` automatically closes
+           the wizard when payments total is equals to the total cost
+           of the operation. When it is ``False``, waits for the user to
+           click the finish button
+        :param outstanding_value: if this value is not ``None``, it will
+            be used as the total value of the payment
+        """
         self._method_name = method
         self._method_slave = None
         self.model = model
@@ -82,8 +97,9 @@ class PaymentMethodStep(BaseWizardStep):
         if outstanding_value is None:
             outstanding_value = currency(0)
         self._outstanding_value = outstanding_value
+        self._finish_on_total = finish_on_total
 
-        BaseWizardStep.__init__(self, conn, wizard, previous)
+        BaseWizardStep.__init__(self, store, wizard, previous)
 
         register_payment_slaves()
         self._create_ui()
@@ -96,9 +112,14 @@ class PaymentMethodStep(BaseWizardStep):
         dsm = get_utility(IDomainSlaveMapper)
         slave_class = dsm.get_slave_class(method)
         assert slave_class
-        method = self.conn.get(method)
-        slave = slave_class(self.wizard, self, self.conn, self.model,
-                            method, outstanding_value=self._outstanding_value)
+        method = self.store.fetch(method)
+        if slave_class is MultipleMethodSlave:
+            slave = slave_class(self.wizard, self, self.store, self.model,
+                                method, outstanding_value=self._outstanding_value,
+                                finish_on_total=self._finish_on_total)
+        else:
+            slave = slave_class(self.wizard, self, self.store, self.model,
+                                method, outstanding_value=self._outstanding_value)
         self._method_slave = slave
         return slave
 
@@ -133,9 +154,9 @@ class BaseMethodSelectionStep(object):
     #
 
     def _update_next_step(self, method):
-        if method and method.method_name == 'money':
+        if method and method.method_name == u'money':
             self.wizard.enable_finish()
-            if self.need_create_payment():
+            if self.wizard.need_create_payment():
                 self.cash_change_slave.enable_cash_change()
             else:
                 self.cash_change_slave.disable_cash_change()
@@ -143,29 +164,16 @@ class BaseMethodSelectionStep(object):
             self.wizard.disable_finish()
             self.cash_change_slave.disable_cash_change()
 
-    def _get_total_amount(self):
-        if isinstance(self.model, Sale):
-            return self.model.get_total_to_pay()
-        elif isinstance(self.model, PaymentRenegotiation):
-            return self.model.total
-        else:
-            raise TypeError
-
     #
     #   Public API
     #
 
-    def need_create_payment(self):
-        # If the sale is already paid, we cannot let the user create more,
-        # or even edit the existing ones.
-        return self._get_total_amount() > 0
-
     def get_selected_method(self):
         return self.pm_slave.get_selected_method()
 
     def setup_cash_payment(self, total=None):
-        money_method = PaymentMethod.get_by_name(self.conn, 'money')
-        total = total or self._get_total_amount()
+        money_method = PaymentMethod.get_by_name(self.store, u'money')
+        total = total or self.wizard.get_total_to_pay()
         return money_method.create_inpayment(self.model.group,
                                              self.model.branch, total)
 
@@ -174,7 +182,7 @@ class BaseMethodSelectionStep(object):
     #
 
     def post_init(self):
-        if not self.need_create_payment():
+        if not self.wizard.need_create_payment():
             for widget in [self.select_method_holder,
                            self.subtotal_expander]:
                 widget.hide()
@@ -183,23 +191,23 @@ class BaseMethodSelectionStep(object):
 
     def setup_slaves(self):
         marker('SelectPaymentMethodSlave')
-        self.pm_slave = SelectPaymentMethodSlave(connection=self.conn,
+        self.pm_slave = SelectPaymentMethodSlave(store=self.store,
                                                  payment_type=Payment.TYPE_IN)
         self.pm_slave.connect('method-changed', self.on_payment_method_changed)
         self.attach_slave('select_method_holder', self.pm_slave)
 
         marker('CashChangeSlave')
-        self.cash_change_slave = CashChangeSlave(self.conn, self.model)
+        self.cash_change_slave = CashChangeSlave(self.store, self.model, self.wizard)
         self.attach_slave('cash_change_holder', self.cash_change_slave)
         self.cash_change_slave.received_value.connect(
             'activate', lambda entry: self.wizard.go_to_next())
 
     def next_step(self):
-        if not self.need_create_payment():
+        if not self.wizard.need_create_payment():
             return
 
         selected_method = self.get_selected_method()
-        if selected_method.method_name == 'money':
+        if selected_method.method_name == u'money':
             if not self.cash_change_slave.can_finish():
                 warning(_(u"Invalid value, please verify if it was "
                           "properly typed."))
@@ -217,16 +225,16 @@ class BaseMethodSelectionStep(object):
             # Return None here means call wizard.finish, which is exactly
             # what we need
             return None
-        elif selected_method.method_name == 'store_credit':
+        elif selected_method.method_name == u'store_credit':
             client = self.model.client
-            total = self._get_total_amount()
+            total = self.wizard.get_total_amount()
 
             assert client.can_purchase(selected_method, total)
 
             step_class = PaymentMethodStep
         elif selected_method.method_name == 'card':
-            providers = CreditProvider.get_card_providers(self.conn)
-            if not providers:
+            providers = CreditProvider.get_card_providers(self.store)
+            if providers.is_empty():
                 warning(_("You need active credit providers to use the "
                           "card payment method."))
                 return self
@@ -235,7 +243,7 @@ class BaseMethodSelectionStep(object):
             step_class = PaymentMethodStep
 
         retval = CreatePaymentEvent.emit(selected_method, self.model,
-                                         self.conn)
+                                         self.store)
 
         # None means no one catched this event
         if retval is None or retval == CreatePaymentStatus.UNHANDLED:
@@ -244,9 +252,9 @@ class BaseMethodSelectionStep(object):
             if selected_method.method_name == 'multiple':
                 outstanding_value = None
             else:
-                outstanding_value = self._get_total_amount()
+                outstanding_value = self.wizard.get_total_to_pay()
 
-            return step_class(self.wizard, self, self.conn, self.model,
+            return step_class(self.wizard, self, self.store, self.model,
                               selected_method,
                               outstanding_value=outstanding_value)
 
@@ -271,17 +279,15 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
     """
     gladefile = 'SalesPersonStep'
     model_type = Sale
-    proxy_widgets = ('total_lbl',
-                     'subtotal_lbl',
-                     'salesperson',
+    proxy_widgets = ('salesperson',
                      'client',
-                     'total_paid_lbl',
-                     'transporter', )
+                     'transporter',
+                     'cost_center')
 
     invoice_widgets = ('invoice_number', )
     cfop_widgets = ('cfop', )
 
-    def __init__(self, wizard, conn, model, payment_group,
+    def __init__(self, wizard, store, model, payment_group,
                  invoice_model):
         self.invoice_model = invoice_model
 
@@ -289,8 +295,9 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
 
         BaseMethodSelectionStep.__init__(self)
         marker("WizardEditorStep.__init__")
-        WizardEditorStep.__init__(self, conn, wizard, model)
+        WizardEditorStep.__init__(self, store, wizard, model)
 
+        self._update_totals()
         self.update_discount_and_surcharge()
 
     #
@@ -298,14 +305,20 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
     #
 
     def _update_totals(self):
-        for field_name in ['total_to_pay', 'total_paid', 'sale_subtotal']:
-            self.proxy.update(field_name)
-        self.cash_change_slave.update_total_sale_amount()
+        subtotal = self.wizard.get_subtotal()
+        self.subtotal_lbl.update(subtotal)
+
+        total_paid = self.wizard.get_total_paid()
+        self.total_paid_lbl.update(total_paid)
+
+        to_pay = self.model.get_total_sale_amount(subtotal=subtotal) - total_paid
+        self.cash_change_slave.update_total_sale_amount(to_pay)
+        self.total_lbl.update(to_pay)
 
     def _update_widgets(self):
         has_client = bool(self.client.get_selected())
-        self.pm_slave.method_set_sensitive('store_credit', has_client)
-        self.pm_slave.method_set_sensitive('bill', has_client)
+        self.pm_slave.method_set_sensitive(u'store_credit', has_client)
+        self.pm_slave.method_set_sensitive(u'bill', has_client)
 
     def _fill_clients_combo(self):
         marker('Filling clients')
@@ -313,31 +326,46 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         #        we need a specialized widget that does the searching
         #        on demand.
 
-        clients = Client.get_active_clients(self.conn)
+        clients = Client.get_active_clients(self.store)
         self.client.prefill(api.for_person_combo(clients))
         self.client.set_sensitive(len(self.client.get_model()))
         marker('Filled clients')
 
     def _fill_transporter_combo(self):
         marker('Filling transporters')
-        transporters = Transporter.get_active_transporters(self.conn)
+        transporters = Transporter.get_active_transporters(self.store)
         items = api.for_person_combo(transporters)
         self.transporter.prefill(items)
         self.transporter.set_sensitive(len(items))
         marker('Filled transporters')
 
+    def _fill_cost_center_combo(self):
+        marker('Filling cost centers')
+        cost_centers = CostCenter.get_active(self.store)
+
+        # we keep this value because each call to is_empty() is a new sql query
+        # to the database
+        cost_centers_exists = not cost_centers.is_empty()
+
+        if cost_centers_exists:
+            self.cost_center.prefill(api.for_combo(cost_centers, attr='name',
+                                                   empty=_('No cost center.')))
+        self.cost_center.set_visible(cost_centers_exists)
+        self.cost_center_lbl.set_visible(cost_centers_exists)
+        marker('Filled cost centers')
+
     def _fill_cfop_combo(self):
         marker('Filling CFOPs')
-        cfops = CfopData.select(connection=self.conn)
+        cfops = self.store.find(CfopData)
         self.cfop.prefill(api.for_combo(cfops))
         marker('Filled CFOPs')
 
     def _create_client(self):
-        trans = api.new_transaction()
-        client = run_person_role_dialog(ClientEditor, self.wizard, trans, None)
-        api.finish_transaction(trans, client)
-        client = self.conn.get(client)
-        trans.close()
+        store = api.new_store()
+        client = run_person_role_dialog(ClientEditor, self.wizard, store, None)
+        store.confirm(client)
+        client = self.store.fetch(client)
+        store.close()
         if not client:
             return
         if len(self.client) == 0:
@@ -370,7 +398,7 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         # Sale in the POS application, i.e, we should not reset the
         # discount and surcharge if they are already set (this is the
         # case when CONFIRM_SALES_ON_TILL parameter is enabled).
-        if not sysparam(self.conn).CONFIRM_SALES_ON_TILL:
+        if not sysparam(self.store).CONFIRM_SALES_ON_TILL:
             self.model.discount_value = currency(0)
             self.model.surcharge_value = currency(0)
 
@@ -396,20 +424,21 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
             self.client.set_property('mandatory', mandatory_client)
 
         marker('Filling sales persons')
-        salespersons = SalesPerson.select(connection=self.conn)
+        salespersons = self.store.find(SalesPerson)
         self.salesperson.prefill(api.for_person_combo(salespersons))
         marker('Finished filling sales persons')
 
         marker('Read parameter')
-        if not sysparam(self.conn).ACCEPT_CHANGE_SALESPERSON:
+        if not sysparam(self.store).ACCEPT_CHANGE_SALESPERSON:
             self.salesperson.set_sensitive(False)
         else:
             self.salesperson.grab_focus()
         marker('Finished reading parameter')
         self._fill_clients_combo()
         self._fill_transporter_combo()
+        self._fill_cost_center_combo()
 
-        if sysparam(self.conn).ASK_SALES_CFOP:
+        if sysparam(self.store).ASK_SALES_CFOP:
             self._fill_cfop_combo()
         else:
             self.cfop_lbl.hide()
@@ -421,7 +450,7 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
             gtk.Adjustment(lower=1, upper=999999999, step_incr=1))
 
         if not self.model.invoice_number:
-            new_invoice_number = Sale.get_last_invoice_number(self.conn) + 1
+            new_invoice_number = Sale.get_last_invoice_number(self.store) + 1
             self.invoice_model.invoice_number = new_invoice_number
         else:
             new_invoice_number = self.model.invoice_number
@@ -445,11 +474,10 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
 
         marker('Entering post_init')
         self.toogle_client_details()
-        if self.need_create_payment():
+        if self.wizard.need_create_payment():
             self.wizard.payment_group.clear_unused()
         self.register_validate_function(self._refresh_next)
         self._update_next_step(self.get_selected_method())
-
         if hasattr(self, 'cash_change_slave'):
             self.cash_change_slave.received_value.grab_focus()
 
@@ -461,13 +489,13 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         BaseMethodSelectionStep.setup_slaves(self)
         marker('Finished parent')
 
-        self.pm_slave.method_set_sensitive('store_credit',
+        self.pm_slave.method_set_sensitive(u'store_credit',
                                            bool(self.model.client))
-        self.pm_slave.method_set_sensitive('bill',
+        self.pm_slave.method_set_sensitive(u'bill',
                                            bool(self.model.client))
 
         marker('Setting discount')
-        self.discount_slave = SaleDiscountSlave(self.conn, self.model,
+        self.discount_slave = SaleDiscountSlave(self.store, self.model,
                                                 self.model_type)
         marker('Finshed setting up discount')
 
@@ -489,7 +517,7 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         if self.model.client:
             self.client.set_sensitive(False)
             self.create_client.set_sensitive(False)
-        if sysparam(self.conn).ASK_SALES_CFOP:
+        if sysparam(self.store).ASK_SALES_CFOP:
             self.add_proxy(self.model, SalesPersonStep.cfop_widgets)
         marker('Finished setting up proxies')
 
@@ -530,14 +558,15 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         self._create_client()
 
     def on_create_transporter__clicked(self, button):
-        trans = api.new_transaction()
-        transporter = trans.get(self.model.transporter)
-        model = run_person_role_dialog(TransporterEditor, self.wizard, trans,
+        store = api.new_store()
+        transporter = store.fetch(self.model.transporter)
+        model = run_person_role_dialog(TransporterEditor, self.wizard, store,
                                        transporter)
-        rv = api.finish_transaction(trans, model)
-        trans.close()
+        rv = store.confirm(model)
+        store.close()
         if rv:
             self._fill_transporter_combo()
+            model = self.store.fetch(model)
             self.transporter.select(model)
 
     def on_discount_slave_changed(self, slave):
@@ -545,32 +574,32 @@ class SalesPersonStep(BaseMethodSelectionStep, WizardEditorStep):
         self.client.validate()
 
     def on_notes_button__clicked(self, *args):
-        run_dialog(NoteEditor, self.wizard, self.conn, self.model, 'notes',
+        run_dialog(NoteEditor, self.wizard, self.store, self.model, 'notes',
                    title=_("Additional Information"))
 
     def on_create_cfop__clicked(self, widget):
-        self.conn.savepoint('before_run_editor_cfop')
-        cfop = run_dialog(CfopEditor, self.wizard, self.conn, None)
+        self.store.savepoint('before_run_editor_cfop')
+        cfop = run_dialog(CfopEditor, self.wizard, self.store, None)
         if cfop:
             self.cfop.append_item(cfop.get_description(), cfop)
             self.cfop.select_item_by_data(cfop)
         else:
-            self.conn.rollback_to_savepoint('before_run_editor_cfop')
+            self.store.rollback_to_savepoint('before_run_editor_cfop')
 
     def on_invoice_number__validate(self, widget, value):
         if not 0 < value <= 999999999:
             return ValidationError(
                 _("Invoice number must be between 1 and 999999999"))
 
-        exists = Sale.select(AND(Sale.q.invoice_number == value,
-                                 Sale.q.id != self.model.id),
-                             connection=self.conn)
-        if exists.count() > 0:
+        exists = self.store.find(
+            Sale, And(Sale.invoice_number == value,
+                      Sale.id != self.model.id))
+        if not exists.is_empty():
             return ValidationError(_(u'Invoice number already used.'))
 
     def on_client_details__clicked(self, button):
         client = self.model.client
-        run_dialog(ClientDetailsDialog, self.wizard, self.conn, client)
+        run_dialog(ClientDetailsDialog, self.wizard, self.store, client)
 
 
 #
@@ -586,21 +615,39 @@ class ConfirmSaleWizard(BaseWizard):
     title = _("Sale Checkout")
     help_section = 'sale-confirm'
 
-    def __init__(self, conn, model):
+    # FIXME: In the long term, we should only create the sale at the end
+    #        of this process, but that requires major surgery of the
+    #        interaction between salewizard.py, pos.py and fiscalprinter.py
+    def __init__(self, store, model,
+                 subtotal,
+                 total_paid=0):
+        """Creates a new SaleWizard that confirms a sale.
+        To avoid excessive querying of the database we pass
+        some data already queried/calculated before hand.
+
+        :param store: a store
+        :param model: a |sale|
+        :param subtotal: subtotal of the sale
+        :param total_paid: totaly value already paid
+        """
         marker('ConfirmSaleWizard')
-        self._check_payment_group(model, conn)
+        self._check_payment_group(model, store)
+
+        self._subtotal = subtotal
+        self._total_paid = total_paid
+        self.model = model
 
         # invoice_model is a Settable so avoid bug 4218, where more
         # than one checkout may try to use the same invoice number.
         self.invoice_model = Settable(invoice_number=None,
                                      original_invoice=None)
         marker('running SalesPersonStep')
-        first_step = self.first_step(self, conn, model, self.payment_group,
+        first_step = self.first_step(self, store, model, self.payment_group,
                                      self.invoice_model)
         marker('finished creating SalesPersonStep')
-        BaseWizard.__init__(self, conn, first_step, model)
+        BaseWizard.__init__(self, store, first_step, model)
 
-        if not sysparam(self.conn).CONFIRM_SALES_ON_TILL:
+        if not sysparam(self.store).CONFIRM_SALES_ON_TILL:
             # This was added to allow us to work even if an error
             # happened while adding a payment, where we already order
             # but cannot confirm and are thrown back to the main
@@ -610,7 +657,7 @@ class ConfirmSaleWizard(BaseWizard):
 
         marker('leaving ConfirmSaleWizard.__init__')
 
-    def _check_payment_group(self, model, conn):
+    def _check_payment_group(self, model, store):
         if not isinstance(model, Sale):
             raise StoqlibError("Invalid datatype for model, it should be "
                                "of type Sale, got %s instead" % model)
@@ -618,25 +665,64 @@ class ConfirmSaleWizard(BaseWizard):
 
     def _invoice_changed(self):
         return (self.invoice_model.invoice_number !=
-                    self.invoice_model.original_invoice)
+                self.invoice_model.original_invoice)
+
+    def get_subtotal(self):
+        """Fetch the sale subtotal without querying the database.
+        The subtotal is the value of all items that are being sold
+
+        :returns: the subtotal of the current sale
+        """
+        return self._subtotal
+
+    def get_total_amount(self):
+        """Fetch the total sale amount without querying the database.
+        The total sale amount is the subtotal with discount and markups
+        taken into account.
+
+        :returns: the total amount of the current sale
+        """
+        return self.model.get_total_sale_amount(subtotal=self._subtotal)
+
+    def get_total_paid(self):
+        """Fetch the value already paid for this sale.
+        This is only used when we return a project we already paid for.
+
+        :returns: the total paid value for the current sale
+        """
+        return self._total_paid
+
+    def get_total_to_pay(self):
+        """Fetch the value the client still needs to pay.
+
+        This is a short hand for self.get_total_amount() - self.get_total_paid()
+        """
+        return self.get_total_amount() - self.get_total_paid()
+
+    def need_create_payment(self):
+        return self.get_total_amount() > 0
 
     def finish(self):
         self.retval = True
         invoice_number = self.invoice_model.invoice_number
 
         # Workaround for bug 4218: If the invoice is was already used by
-        # another transaction (another cashier), try using the next one
+        # another store (another cashier), try using the next one
         # available, or show a warning if the number was manually set.
         while True:
             try:
-                self.conn.savepoint('before_set_invoice_number')
+                self.store.savepoint('before_set_invoice_number')
                 self.model.invoice_number = invoice_number
+                # We need to flush the database here, or a possible collision
+                # of invoice_number will only be detected later on, when the
+                # execution flow is not in the try-except anymore.
+                self.store.flush()
             except IntegrityError:
-                self.conn.rollback_to_savepoint('before_set_invoice_number')
+                self.store.rollback_to_savepoint('before_set_invoice_number')
                 if self._invoice_changed():
                     warning(_(u"The invoice number %s is already used. "
-                       "Confirm the sale again to chose another one.") %
-                       invoice_number)
+                              "Confirm the sale again to chose another one.") %
+                            invoice_number)
                     self.retval = False
                     break
                 else:
@@ -651,8 +737,8 @@ class ConfirmSaleWizard(BaseWizard):
         #        have a payer, we won't be able to print bills/booklets.
         group.payer = self.model.client and self.model.client.person
 
-        booklets = list(group.get_payments_by_method_name('store_credit'))
-        bills = list(group.get_payments_by_method_name('bill'))
+        booklets = list(group.get_payments_by_method_name(u'store_credit'))
+        bills = list(group.get_payments_by_method_name(u'bill'))
 
         if (booklets and
             yesno(_("Do you want to print the booklets for this sale?"),
@@ -668,9 +754,9 @@ class ConfirmSaleWizard(BaseWizard):
 def test():  # pragma nocover
     creator = api.prepare_test()
     sale_item = creator.create_sale_item()
-    retval = run_dialog(ConfirmSaleWizard, None, creator.trans,
+    retval = run_dialog(ConfirmSaleWizard, None, creator.store,
                         sale_item.sale)
-    api.finish_transaction(creator.trans, retval)
+    creator.store.confirm(retval)
 
 
 if __name__ == '__main__':  # pragma nocover
