@@ -27,17 +27,23 @@
 from decimal import Decimal
 
 import gtk
+from kiwi.currency import currency
 from kiwi.datatypes import ValidationError
 from kiwi.ui.widgets.list import Column
+from storm.expr import And
 
 from stoqlib.api import api
-from stoqlib.database.orm import AND
+from stoqlib.domain.costcenter import CostCenter
 from stoqlib.domain.fiscal import CfopData
+from stoqlib.domain.payment.group import PaymentGroup
+from stoqlib.domain.payment.method import PaymentMethod
 from stoqlib.domain.person import Branch, Employee
 from stoqlib.domain.product import Product, ProductStockItem
 from stoqlib.domain.sellable import Sellable
 from stoqlib.domain.stockdecrease import StockDecrease, StockDecreaseItem
-from stoqlib.lib.message import yesno
+from stoqlib.domain.till import Till
+from stoqlib.exceptions import TillError
+from stoqlib.lib.message import warning, yesno
 from stoqlib.lib.parameters import sysparam
 from stoqlib.lib.translation import stoqlib_gettext
 from stoqlib.lib.formatters import format_quantity
@@ -46,6 +52,7 @@ from stoqlib.gui.editors.decreaseeditor import DecreaseItemEditor
 from stoqlib.gui.events import StockDecreaseWizardFinishEvent
 from stoqlib.gui.printing import print_report
 from stoqlib.gui.wizards.abstractwizard import SellableItemStep
+from stoqlib.gui.wizards.salewizard import PaymentMethodStep
 from stoqlib.reporting.stockdecreasereceipt import StockDecreaseReceipt
 
 _ = stoqlib_gettext
@@ -64,25 +71,43 @@ class StartStockDecreaseStep(WizardEditorStep):
                      'reason',
                      'removed_by',
                      'cfop',
+                     'cost_center'
                      )
 
     def _fill_employee_combo(self):
-        self.removed_by.prefill(api.for_person_combo(
-            Employee.select(connection=self.conn)))
+        employess = self.store.find(Employee)
+        self.removed_by.prefill(api.for_person_combo(employess))
 
     def _fill_branch_combo(self):
-        branches = Branch.get_active_branches(self.conn)
+        branches = Branch.get_active_branches(self.store)
         self.branch.prefill(api.for_person_combo(branches))
 
     def _fill_cfop_combo(self):
-        cfops = CfopData.select(connection=self.conn)
+        cfops = self.store.find(CfopData)
         self.cfop.prefill(api.for_combo(cfops))
 
+    def _fill_cost_center_combo(self):
+        cost_centers = CostCenter.get_active(self.store)
+
+        # we keep this value because each call to is_empty() is a new sql query
+        # to the database
+        cost_centers_exists = not cost_centers.is_empty()
+
+        if cost_centers_exists:
+            self.cost_center.prefill(api.for_combo(cost_centers, attr='name',
+                                                   empty=_('No cost center.')))
+        self.cost_center.set_visible(cost_centers_exists)
+        self.cost_center_lbl.set_visible(cost_centers_exists)
+
     def _setup_widgets(self):
         self.confirm_date.set_sensitive(False)
         self._fill_employee_combo()
         self._fill_branch_combo()
         self._fill_cfop_combo()
+        self._fill_cost_center_combo()
+
+        if not sysparam(self.store).CREATE_PAYMENTS_ON_STOCK_DECREASE:
+            self.create_payments.hide()
 
     #
     # WizardStep hooks
@@ -96,7 +121,20 @@ class StartStockDecreaseStep(WizardEditorStep):
         self.force_validation()
 
     def next_step(self):
-        return DecreaseItemStep(self.wizard, self, self.conn, self.model)
+        self.wizard.create_payments = self.create_payments.read()
+
+        if self.wizard.create_payments:
+            try:
+                till = Till.get_current(self.store)
+            except TillError as e:
+                warning(str(e))
+                return self
+
+            if not till:
+                warning(_("You need to open the till before doing this operation."))
+                return self
+
+        return DecreaseItemStep(self.wizard, self, self.store, self.model)
 
     def has_previous_step(self):
         return False
@@ -120,20 +158,22 @@ class DecreaseItemStep(SellableItemStep):
     #
 
     def get_sellable_view_query(self):
-        branch = api.get_current_branch(self.conn)
-        branch_query = ProductStockItem.q.branch_id == branch.id
+        branch = self.model.branch
+        branch_query = ProductStockItem.branch_id == branch.id
         # The stock quantity of consigned products can not be
         # decreased manually. See bug 5212.
-        return AND(branch_query,
-                   Product.q.consignment == False,
-                   Sellable.get_available_sellables_query(self.conn))
+        query = And(branch_query,
+                    Product.consignment == False,
+                    Sellable.get_available_sellables_query(self.store))
+        return self.sellable_view, query
 
     def setup_slaves(self):
         SellableItemStep.setup_slaves(self)
         self.hide_add_button()
 
-        self.cost_label.hide()
-        self.cost.hide()
+        if not self.wizard.create_payments:
+            self.cost_label.hide()
+            self.cost.hide()
         self.quantity.connect('validate', self._on_quantity__validate)
 
     #
@@ -146,14 +186,14 @@ class DecreaseItemStep(SellableItemStep):
         self.wizard.refresh_next(can_decrease)
 
     def get_order_item(self, sellable, cost, quantity):
-        item = self.model.add_sellable(sellable, quantity)
+        item = self.model.add_sellable(sellable, cost, quantity)
         return item
 
     def get_saved_items(self):
         return list(self.model.get_items())
 
     def get_columns(self):
-        return [
+        columns = [
             Column('sellable.code', title=_('Code'), width=100, data_type=str),
             Column('sellable.description', title=_('Description'),
                    data_type=str, expand=True, searchable=True),
@@ -165,6 +205,14 @@ class DecreaseItemStep(SellableItemStep):
                    width=70),
             ]
 
+        if self.wizard.create_payments:
+            columns.extend([
+                Column('cost', title=_('Cost'), data_type=currency),
+                Column('total', title=_('Total'), data_type=currency),
+            ])
+
+        return columns
+
     #
     # WizardStep hooks
     #
@@ -176,10 +224,17 @@ class DecreaseItemStep(SellableItemStep):
         self._refresh_next()
 
     def has_next_step(self):
-        return False
+        return self.wizard.create_payments
 
     def next_step(self):
-        return None
+        if not self.wizard.create_payments:
+            return
+
+        group = PaymentGroup(store=self.store)
+        self.model.group = group
+        return PaymentMethodStep(self.wizard, self, self.store, self.model,
+                                 PaymentMethod.get_by_name(self.store, u'multiple'),
+                                 finish_on_total=False)
 
     #
     # Callbacks
@@ -209,23 +264,24 @@ class StockDecreaseWizard(BaseWizard):
     size = (775, 400)
     title = _('Manual Stock Decrease')
 
-    def __init__(self, conn):
-        model = self._create_model(conn)
+    def __init__(self, store):
+        model = self._create_model(store)
 
-        first_step = StartStockDecreaseStep(conn, self, model)
-        BaseWizard.__init__(self, conn, first_step, model)
+        first_step = StartStockDecreaseStep(store, self, model)
+        BaseWizard.__init__(self, store, first_step, model)
+        self.create_payments = False
 
-    def _create_model(self, conn):
-        branch = api.get_current_branch(conn)
-        user = api.get_current_user(conn)
+    def _create_model(self, store):
+        branch = api.get_current_branch(store)
+        user = api.get_current_user(store)
         employee = user.person.employee
-        cfop = sysparam(conn).DEFAULT_STOCK_DECREASE_CFOP
+        cfop = sysparam(store).DEFAULT_STOCK_DECREASE_CFOP
         return StockDecrease(responsible=user,
                              removed_by=employee,
                              branch=branch,
                              status=StockDecrease.STATUS_INITIAL,
                              cfop=cfop,
-                             connection=conn)
+                             store=store)
 
     def _receipt_dialog(self):
         msg = _('Would you like to print a receipt?')
