@@ -23,7 +23,9 @@
 ##
 ##
 
-from stoqlib.database.runtime import get_connection
+from decimal import Decimal
+
+from stoqlib.database.runtime import get_default_store
 from stoqlib.domain.commission import CommissionSource
 from stoqlib.domain.person import Supplier
 from stoqlib.domain.product import (Product, ProductSupplierInfo,
@@ -54,28 +56,28 @@ class ProductImporter(CSVImporter):
 
     def __init__(self):
         super(ProductImporter, self).__init__()
-        conn = get_connection()
-        suppliers = Supplier.select(connection=conn)
+        default_store = get_default_store()
+        suppliers = default_store.find(Supplier)
         if not suppliers.count():
-            raise ValueError('You must have at least one suppliers on your '
-                             'database at this point.')
+            raise ValueError(u'You must have at least one suppliers on your '
+                             u'database at this point.')
         self.supplier = suppliers[0]
 
         self.units = {}
-        for unit in SellableUnit.select(connection=conn):
+        for unit in default_store.find(SellableUnit):
             self.units[unit.description] = unit
 
-        self.tax_constant = sysparam(conn).DEFAULT_PRODUCT_TAX_CONSTANT
+        self.tax_constant = sysparam(default_store).DEFAULT_PRODUCT_TAX_CONSTANT
 
-    def _get_or_create(self, table, trans, **attributes):
-        obj = table.selectOneBy(connection=trans, **attributes)
+    def _get_or_create(self, table, store, **attributes):
+        obj = store.find(table, **attributes).one()
         if obj is None:
-            obj = table(connection=trans, **attributes)
+            obj = table(store=store, **attributes)
         return obj
 
-    def process_one(self, data, fields, trans):
+    def process_one(self, data, fields, store):
         base_category = self._get_or_create(
-            SellableCategory, trans,
+            SellableCategory, store,
             suggested_markup=int(data.markup),
             salesperson_commission=int(data.commission),
             category=None,
@@ -83,40 +85,35 @@ class ProductImporter(CSVImporter):
 
         # create a commission source
         self._get_or_create(
-            CommissionSource, trans,
+            CommissionSource, store,
             direct_value=int(data.commission),
             installments_value=int(data.commission2),
             category=base_category)
 
         category = self._get_or_create(
-            SellableCategory, trans,
+            SellableCategory, store,
             description=data.category,
             suggested_markup=int(data.markup2),
             category=base_category)
 
-        if 'unit' in fields:
-            if not data.unit in self.units:
-                raise ValueError("invalid unit: %s" % data.unit)
-            unit = trans.get(self.units[data.unit])
-        else:
-            unit = None
-
-        tax = trans.get(self.tax_constant)
-        sellable = Sellable(connection=trans,
-                            cost=float(data.cost),
-                            code=data.barcode,
-                            barcode=data.barcode,
+        sellable = Sellable(store=store,
+                            cost=Decimal(data.cost),
                             category=category,
                             description=data.description,
-                            price=int(data.price),
-                            unit=unit,
-                            tax_constant=tax)
-        product = Product(sellable=sellable, connection=trans)
+                            price=int(data.price))
+        sellable.barcode = sellable.code = data.barcode
+        if u'unit' in fields:
+            if not data.unit in self.units:
+                raise ValueError(u"invalid unit: %s" % data.unit)
+            sellable.unit = store.fetch(self.units[data.unit])
+        sellable.tax_constant = store.fetch(self.tax_constant)
 
-        supplier = trans.get(self.supplier)
-        ProductSupplierInfo(connection=trans,
+        product = Product(sellable=sellable, store=store)
+
+        supplier = store.fetch(self.supplier)
+        ProductSupplierInfo(store=store,
                             supplier=supplier,
                             is_main_supplier=True,
-                            base_cost=float(data.cost),
+                            base_cost=Decimal(data.cost),
                             product=product)
-        Storable(product=product, connection=trans)
+        Storable(product=product, store=store)
