@@ -394,8 +394,8 @@ class BankBanrisul(BankInfo):
     description = 'Banrisul'
     bank_number = 41
     logo = 'logo_banrisul.jpg'
-    options = {'agencia': BILL_OPTION_BANK_BRANCH,
-               'conta': BILL_OPTION_BANK_BRANCH}
+    options = {u'agencia': BILL_OPTION_BANK_BRANCH,
+               u'conta': BILL_OPTION_BANK_BRANCH}
 
     nosso_numero = custom_property('nosso_numero', 8)
     conta = custom_property('conta', 6)
@@ -418,9 +418,9 @@ class BankBradesco(BankInfo):
     bank_number = 237
     logo = "logo_bancobradesco.jpg"
 
-    options = {'carteira': BILL_OPTION_CUSTOM,
-               'agencia': BILL_OPTION_BANK_BRANCH,
-               'conta': BILL_OPTION_BANK_BRANCH}
+    options = {u'carteira': BILL_OPTION_CUSTOM,
+               u'agencia': BILL_OPTION_BANK_BRANCH,
+               u'conta': BILL_OPTION_BANK_BRANCH}
 
     validate_field_func = 'modulo11'
     validate_field_dv_10 = '0'
@@ -483,9 +483,9 @@ class BankBB(BankInfo):
     description = 'Banco do Brasil'
     bank_number = 1
     logo = 'logo_bb.gif'
-    options = {'convenio': BILL_OPTION_CUSTOM,
-               'agencia': BILL_OPTION_BANK_BRANCH,
-               'conta': BILL_OPTION_BANK_BRANCH}
+    options = {u'convenio': BILL_OPTION_CUSTOM,
+               u'agencia': BILL_OPTION_BANK_BRANCH,
+               u'conta': BILL_OPTION_BANK_BRANCH}
 
     validate_field_func = 'modulo11'
     validate_field_dv_10 = 'x'
@@ -598,9 +598,9 @@ class BankCaixa(BankInfo):
     description = 'Caixa Econômica Federal'
     bank_number = 104
     logo = 'logo_bancocaixa.jpg'
-    options = {'carteira': BILL_OPTION_CUSTOM,
-              'agencia': BILL_OPTION_BANK_BRANCH,
-              'conta': BILL_OPTION_BANK_BRANCH}
+    options = {u'carteira': BILL_OPTION_CUSTOM,
+               u'agencia': BILL_OPTION_BANK_BRANCH,
+               u'conta': BILL_OPTION_BANK_BRANCH}
 
     inicio_nosso_numero = '80'
 
@@ -640,9 +640,9 @@ class BankItau(BankInfo):
     description = 'Banco Itaú'
     bank_number = 341
     logo = 'logo_itau.gif'
-    options = {'carteira': BILL_OPTION_CUSTOM,
-              'agencia': BILL_OPTION_BANK_BRANCH,
-              'conta': BILL_OPTION_BANK_BRANCH}
+    options = {u'carteira': BILL_OPTION_CUSTOM,
+               u'agencia': BILL_OPTION_BANK_BRANCH,
+               u'conta': BILL_OPTION_BANK_BRANCH}
 
     nosso_numero = custom_property('nosso_numero', 8)
     agencia = custom_property('agencia', 4)
@@ -690,9 +690,9 @@ class BankReal(BankInfo):
     description = 'Banco Real'
     bank_number = 356
     logo = 'logo_bancoreal.jpg'
-    options = {'carteira': BILL_OPTION_CUSTOM,
-               'agencia': BILL_OPTION_BANK_BRANCH,
-               'conta': BILL_OPTION_BANK_BRANCH}
+    options = {u'carteira': BILL_OPTION_CUSTOM,
+               u'agencia': BILL_OPTION_BANK_BRANCH,
+               u'conta': BILL_OPTION_BANK_BRANCH}
 
     @property
     def agencia_conta(self):
@@ -720,9 +720,9 @@ class BankSantander(BankInfo):
     description = 'Banco Santander'
     bank_number = 33
     logo = 'logo_santander.jpg'
-    options = {'carteira': BILL_OPTION_CUSTOM,
-               'agencia': BILL_OPTION_BANK_BRANCH,
-               'conta': BILL_OPTION_BANK_BRANCH}
+    options = {u'carteira': BILL_OPTION_CUSTOM,
+               u'agencia': BILL_OPTION_BANK_BRANCH,
+               u'conta': BILL_OPTION_BANK_BRANCH}
 
     # Numero fixo na posição 5
     fixo = '9'
