@@ -30,7 +30,7 @@ from kiwi.component import get_utility, provide_utility
 from kiwi.log import Logger
 from zope.interface import implements
 
-from stoqlib.database.runtime import get_connection, new_transaction
+from stoqlib.database.runtime import get_default_store, new_store
 from stoqlib.database.exceptions import SQLError
 from stoqlib.domain.plugin import InstalledPlugin
 from stoqlib.lib.message import error
@@ -48,7 +48,7 @@ class PluginError(Exception):
 
 class PluginDescription(object):
     def __init__(self, config, filename):
-        self.name = os.path.basename(os.path.dirname(filename))
+        self.name = unicode(os.path.basename(os.path.dirname(filename)))
         self.entry = config.get('Plugin', 'Module')
         self.filename = filename
 
@@ -94,8 +94,8 @@ class PluginManager(object):
     @property
     def installed_plugins_names(self):
         """A list of names of all installed plugins"""
-        return [installed_plugin.plugin_name for installed_plugin in
-                InstalledPlugin.select(connection=get_connection())]
+        default_store = get_default_store()
+        return [p.plugin_name for p in default_store.find(InstalledPlugin)]
 
     def get_description_by_name(self, plugin_name):
         return self._plugin_descriptions.get(plugin_name)
@@ -208,11 +208,11 @@ class PluginManager(object):
             raise PluginError("Plugin %s is already enabled."
                               % (plugin_name, ))
 
-        trans = new_transaction()
-        InstalledPlugin(connection=trans,
+        store = new_store()
+        InstalledPlugin(store=store,
                         plugin_name=plugin_name,
                         plugin_version=0)
-        trans.commit(close=True)
+        store.commit(close=True)
 
         migration = plugin.get_migration()
         if migration:
