@@ -269,7 +269,7 @@ class SintegraFile(object):
         if filename is not None and fp is not None:
             raise TypeError
         if fp is None:
-            fp = open(filename, 'w')
+            fp = open(filename, 'wb')
 
         for register in self.get_registers():
             fp.write(register.get_string())
@@ -558,7 +558,7 @@ class SintegraRegister90(SintegraRegister):
     sintegra_requires = 10, 11
 
 
-def test():
+def test():  # pragma nocover
     s = SintegraFile()
     cgc = int('03852995000107')
     estadual = '110042490114'
@@ -576,5 +576,5 @@ def test():
     s.close()
     s.write('/mondo/tmp/sintegra-dos.txt')
 
-if __name__ == '__main__':
+if __name__ == '__main__':  # pragma nocover
     test()
