@@ -28,12 +28,11 @@ from stoqdrivers.enum import TaxType
 from stoqlib.database.runtime import get_current_branch
 from stoqlib.domain.invoice import InvoiceLayout, InvoiceField
 from stoqlib.domain.payment.method import PaymentMethod
-from stoqlib.domain.product import Storable
 from stoqlib.domain.sellable import SellableTaxConstant
 from stoqlib.domain.test.domaintest import DomainTest
 from stoqlib.lib.diffutils import diff_files
 from stoqlib.lib.invoice import SaleInvoice
-from stoqlib.lib import test
+from stoqlib.lib.unittestutils import get_tests_datadir
 
 
 def compare_invoice_file(invoice, basename):
@@ -47,7 +46,7 @@ def compare_invoice_file(invoice, basename):
             fp.write(line.tostring())
         fp.write('-- PAGE %d - END ----\n' % (n + 1, ))
     fp.close()
-    expected = os.path.join(test.__path__[0], expected)
+    expected = get_tests_datadir(expected)
     diff = diff_files(expected, output)
     os.unlink(output)
     if diff:
@@ -56,7 +55,7 @@ def compare_invoice_file(invoice, basename):
 
 class InvoiceTest(DomainTest):
     def _add_payments(self, sale):
-        method = PaymentMethod.get_by_name(self.trans, 'money')
+        method = PaymentMethod.get_by_name(self.store, u'money')
         payment = method.create_inpayment(sale.group, sale.branch,
                                           sale.get_sale_subtotal())
         payment.due_date = datetime.datetime(2000, 1, 1)
@@ -67,21 +66,19 @@ class InvoiceTest(DomainTest):
         if code:
             sellable.code = code
         sellable.tax_constant = SellableTaxConstant(
-            description=str(tax),
+            description=unicode(tax),
             tax_type=int(TaxType.CUSTOM),
             tax_value=tax,
-            connection=self.trans)
+            store=self.store)
         sale.add_sellable(sellable, quantity=1)
-        storable = Storable(product=product,
-                            connection=self.trans)
-        storable.increase_stock(100, get_current_branch(self.trans))
+        self.create_storable(product, get_current_branch(self.store), stock=100)
         return sellable
 
     def testSaleInvoice(self):
         sale = self.create_sale()
         for i in range(10):
             price = 50 + i
-            code = str(1000 + i)
+            code = unicode(1000 + i)
             self._add_product(sale, tax=18, price=price, code=code)
 
         sale.order()
@@ -91,7 +88,7 @@ class InvoiceTest(DomainTest):
         address = self.create_address()
         address.person = sale.client.person
 
-        layout = InvoiceLayout.selectOne(connection=self.trans)
+        layout = self.store.find(InvoiceLayout).one()
         invoice = SaleInvoice(sale, layout)
         invoice.today = datetime.datetime(2007, 1, 1, 10, 20, 30)
 
@@ -112,16 +109,15 @@ class InvoiceTest(DomainTest):
         address = self.create_address()
         address.person = sale.client.person
 
-        layout = InvoiceLayout.selectOne(connection=self.trans)
+        layout = self.store.find(InvoiceLayout).one()
         invoice = SaleInvoice(sale, layout)
         self.assertFalse(invoice.has_invoice_number())
 
-        field = InvoiceField.selectOneBy(field_name='INVOICE_NUMBER',
-                                         connection=self.trans)
+        field = self.store.find(InvoiceField, field_name=u'INVOICE_NUMBER').one()
         if field is None:
             field = InvoiceField(x=0, y=0, width=6, height=1, layout=layout,
-                                 field_name='INVOICE_NUMBER',
-                                 connection=self.trans)
+                                 field_name=u'INVOICE_NUMBER',
+                                 store=self.store)
         else:
             field.layout = layout
 
